--[[
************************************************************************
Alchemy.lua
Alchemy data for all of Ackis Recipe List
************************************************************************
File date: 2010-02-06T06:32:10Z 
File revision: 2849 
Project revision: 2853
Project version: r2853
************************************************************************
Please see http://www.wowace.com/addons/arl/ for more information.
************************************************************************
This source code is released under All Rights Reserved.
************************************************************************
]]--

-------------------------------------------------------------------------------
-- AddOn namespace.
-------------------------------------------------------------------------------
local MODNAME	= "Ackis Recipe List"
local addon	= LibStub("AceAddon-3.0"):GetAddon(MODNAME)
local L		= LibStub("AceLocale-3.0"):GetLocale(MODNAME)

local private	= select(2, ...)

-------------------------------------------------------------------------------
-- Item "rarity"
-------------------------------------------------------------------------------
local R_COMMON, R_UNCOMMON, R_RARE, R_EPIC, R_LEGENDARY, R_ARTIFACT = 1, 2, 3, 4, 5, 6

-------------------------------------------------------------------------------
-- Origin
-------------------------------------------------------------------------------
local GAME_ORIG, GAME_TBC, GAME_WOTLK = 0, 1, 2

-------------------------------------------------------------------------------
-- Filter flags. Acquire types, and Reputation levels.
-------------------------------------------------------------------------------
local F		= private.filter_flags
local A		= private.acquire_types
local REP	= private.rep_levels
local FAC	= private.faction_ids

local FRIENDLY	= 1
local HONORED	= 2
local REVERED	= 3
local EXALTED	= 4

local initialized = false
local num_recipes = 0

function addon:InitAlchemy(RecipeDB)
	if initialized then
		return num_recipes
	end

	initialized = true

	--------------------------------------------------------------------------------------------------------------------
	-- Counter and wrapper function
	--------------------------------------------------------------------------------------------------------------------
	local function AddRecipe(SpellID, Skill, ItemID, Rarity, Game, Orange, Yellow, Green, Gray)
		num_recipes = num_recipes + 1
		self:addTradeSkill(RecipeDB, SpellID, Skill, ItemID, Rarity, 51304, nil, Game, Orange, Yellow, Green, Gray)
	end

	-- Elixir of Lion's Strength -- 2329
	AddRecipe(2329, 1, 2454, R_COMMON, GAME_ORIG, 1, 55, 75, 95)
	self:addTradeFlags(RecipeDB, 2329, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.DPS)
	self:addTradeAcquire(RecipeDB, 2329, A.CUSTOM, 8)

	-- Minor Healing Potion -- 2330
	AddRecipe(2330, 1, 118, R_COMMON, GAME_ORIG, 1, 55, 75, 95)
	self:addTradeFlags(RecipeDB, 2330, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP)
	self:addTradeAcquire(RecipeDB, 2330, A.CUSTOM, 8)

	-- Minor Mana Potion -- 2331
	AddRecipe(2331, 25, 2455, R_COMMON, GAME_ORIG, 25, 65, 85, 105)
	self:addTradeFlags(RecipeDB, 2331, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP)
	self:addTradeAcquire(RecipeDB, 2331, A.TRAINER, 1215, A.TRAINER, 1246, A.TRAINER, 1386, A.TRAINER, 1470, A.TRAINER, 2132, A.TRAINER, 2391, A.TRAINER, 2837, A.TRAINER, 3009, A.TRAINER, 3184, A.TRAINER, 3347, A.TRAINER, 3603, A.TRAINER, 4160, A.TRAINER, 4611, A.TRAINER, 5177, A.TRAINER, 5499, A.TRAINER, 7948, A.TRAINER, 16161, A.TRAINER, 16588, A.TRAINER, 16642, A.TRAINER, 16723, A.TRAINER, 17215, A.TRAINER, 18802, A.TRAINER, 19052, A.TRAINER, 27029, A.TRAINER, 3964, A.TRAINER, 33608, A.TRAINER, 33674, A.TRAINER, 27023, A.TRAINER, 4900)

	-- Minor Rejuvenation Potion -- 2332
	AddRecipe(2332, 40, 2456, R_COMMON, GAME_ORIG, 40, 70, 90, 110)
	self:addTradeFlags(RecipeDB, 2332, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP)
	self:addTradeAcquire(RecipeDB, 2332, A.TRAINER, 1215, A.TRAINER, 1246, A.TRAINER, 1386, A.TRAINER, 1470, A.TRAINER, 2132, A.TRAINER, 2391, A.TRAINER, 2837, A.TRAINER, 3009, A.TRAINER, 3184, A.TRAINER, 3347, A.TRAINER, 3603, A.TRAINER, 4160, A.TRAINER, 4611, A.TRAINER, 5177, A.TRAINER, 5499, A.TRAINER, 7948, A.TRAINER, 16161, A.TRAINER, 16588, A.TRAINER, 16642, A.TRAINER, 16723, A.TRAINER, 17215, A.TRAINER, 18802, A.TRAINER, 19052, A.TRAINER, 27029, A.TRAINER, 3964, A.TRAINER, 33608, A.TRAINER, 33674, A.TRAINER, 27023, A.TRAINER, 4900)

	-- Elixir of Lesser Agility -- 2333
	AddRecipe(2333, 140, 3390, R_UNCOMMON, GAME_ORIG, 140, 165, 185, 205)
	self:addTradeFlags(RecipeDB, 2333, F.ALLIANCE, F.HORDE, F.WORLD_DROP, F.IBOE, F.RBOE, F.DPS)
	self:addTradeAcquire(RecipeDB, 2333, A.WORLD_DROP, 2)

	-- Elixir of Minor Fortitude -- 2334
	AddRecipe(2334, 50, 2458, R_COMMON, GAME_ORIG, 50, 80, 100, 120)
	self:addTradeFlags(RecipeDB, 2334, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP)
	self:addTradeAcquire(RecipeDB, 2334, A.TRAINER, 1215, A.TRAINER, 1246, A.TRAINER, 1386, A.TRAINER, 1470, A.TRAINER, 2132, A.TRAINER, 2391, A.TRAINER, 2837, A.TRAINER, 3009, A.TRAINER, 3184, A.TRAINER, 3347, A.TRAINER, 3603, A.TRAINER, 4160, A.TRAINER, 4611, A.TRAINER, 5177, A.TRAINER, 5499, A.TRAINER, 7948, A.TRAINER, 16161, A.TRAINER, 16588, A.TRAINER, 16642, A.TRAINER, 16723, A.TRAINER, 17215, A.TRAINER, 18802, A.TRAINER, 19052, A.TRAINER, 27029, A.TRAINER, 3964, A.TRAINER, 33608, A.TRAINER, 33674, A.TRAINER, 27023, A.TRAINER, 4900)

	-- Swiftness Potion -- 2335
	AddRecipe(2335, 60, 2459, R_UNCOMMON, GAME_ORIG, 60, 90, 110, 130)
	self:addTradeFlags(RecipeDB, 2335, F.ALLIANCE, F.HORDE, F.WORLD_DROP, F.IBOE, F.RBOE)
	self:addTradeAcquire(RecipeDB, 2335, A.WORLD_DROP, 2)

	-- Lesser Healing Potion -- 2337
	AddRecipe(2337, 55, 858, R_COMMON, GAME_ORIG, 55, 85, 105, 125)
	self:addTradeFlags(RecipeDB, 2337, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP)
	self:addTradeAcquire(RecipeDB, 2337, A.TRAINER, 1215, A.TRAINER, 1246, A.TRAINER, 1386, A.TRAINER, 1470, A.TRAINER, 2132, A.TRAINER, 2391, A.TRAINER, 2837, A.TRAINER, 3009, A.TRAINER, 3184, A.TRAINER, 3347, A.TRAINER, 3603, A.TRAINER, 4160, A.TRAINER, 4611, A.TRAINER, 5177, A.TRAINER, 5499, A.TRAINER, 7948, A.TRAINER, 16161, A.TRAINER, 16588, A.TRAINER, 16642, A.TRAINER, 16723, A.TRAINER, 17215, A.TRAINER, 18802, A.TRAINER, 19052, A.TRAINER, 27029, A.TRAINER, 3964, A.TRAINER, 33608, A.TRAINER, 33674, A.TRAINER, 27023, A.TRAINER, 4900)

	-- Weak Troll's Blood Elixir -- 3170
	AddRecipe(3170, 15, 3382, R_COMMON, GAME_ORIG, 15, 60, 80, 100)
	self:addTradeFlags(RecipeDB, 3170, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP)
	self:addTradeAcquire(RecipeDB, 3170, A.TRAINER, 1215, A.TRAINER, 1246, A.TRAINER, 1386, A.TRAINER, 1470, A.TRAINER, 2132, A.TRAINER, 2391, A.TRAINER, 2837, A.TRAINER, 3009, A.TRAINER, 3184, A.TRAINER, 3347, A.TRAINER, 3603, A.TRAINER, 4160, A.TRAINER, 4611, A.TRAINER, 5177, A.TRAINER, 5499, A.TRAINER, 7948, A.TRAINER, 16161, A.TRAINER, 16588, A.TRAINER, 16642, A.TRAINER, 16723, A.TRAINER, 17215, A.TRAINER, 18802, A.TRAINER, 19052, A.TRAINER, 27029, A.TRAINER, 3964, A.TRAINER, 33608, A.TRAINER, 33674, A.TRAINER, 27023, A.TRAINER, 4900)

	-- Elixir of Wisdom -- 3171
	AddRecipe(3171, 90, 3383, R_COMMON, GAME_ORIG, 90, 120, 140, 160)
	self:addTradeFlags(RecipeDB, 3171, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP)
	self:addTradeAcquire(RecipeDB, 3171, A.TRAINER, 1386, A.TRAINER, 2391, A.TRAINER, 2837, A.TRAINER, 3009, A.TRAINER, 3347, A.TRAINER, 4160, A.TRAINER, 4611, A.TRAINER, 5177, A.TRAINER, 5499, A.TRAINER, 7948, A.TRAINER, 16588, A.TRAINER, 16642, A.TRAINER, 16723, A.TRAINER, 18802, A.TRAINER, 19052, A.TRAINER, 27029, A.TRAINER, 3603, A.TRAINER, 1470, A.TRAINER, 3964, A.TRAINER, 2132, A.TRAINER, 3184, A.TRAINER, 33608, A.TRAINER, 33674, A.TRAINER, 27023, A.TRAINER, 4900, A.TRAINER, 1215, A.TRAINER, 16161)

	-- Minor Magic Resistance Potion -- 3172
	AddRecipe(3172, 110, 3384, R_COMMON, GAME_ORIG, 110, 135, 155, 175)
	self:addTradeFlags(RecipeDB, 3172, F.ALLIANCE, F.HORDE, F.WORLD_DROP, F.IBOE, F.RBOE)
	self:addTradeAcquire(RecipeDB, 3172, A.WORLD_DROP, 1)

	-- Lesser Mana Potion -- 3173
	AddRecipe(3173, 120, 3385, R_COMMON, GAME_ORIG, 120, 145, 165, 185)
	self:addTradeFlags(RecipeDB, 3173, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP)
	self:addTradeAcquire(RecipeDB, 3173, A.TRAINER, 1386, A.TRAINER, 2391, A.TRAINER, 2837, A.TRAINER, 3009, A.TRAINER, 3347, A.TRAINER, 3964, A.TRAINER, 4160, A.TRAINER, 4611, A.TRAINER, 5177, A.TRAINER, 5499, A.TRAINER, 7948, A.TRAINER, 16588, A.TRAINER, 16642, A.TRAINER, 16723, A.TRAINER, 18802, A.TRAINER, 19052, A.TRAINER, 27029, A.TRAINER, 3603, A.TRAINER, 1470, A.TRAINER, 2132, A.TRAINER, 3184, A.TRAINER, 33608, A.TRAINER, 33674, A.TRAINER, 27023, A.TRAINER, 4900, A.TRAINER, 1215, A.TRAINER, 16161)

	-- Potion of Curing -- 3174
	AddRecipe(3174, 120, 3386, R_COMMON, GAME_ORIG, 120, 145, 165, 185)
	self:addTradeFlags(RecipeDB, 3174, F.ALLIANCE, F.HORDE, F.WORLD_DROP, F.IBOE, F.RBOE)
	self:addTradeAcquire(RecipeDB, 3174, A.WORLD_DROP, 1)

	-- Limited Invulnerability Potion -- 3175
	AddRecipe(3175, 250, 3387, R_UNCOMMON, GAME_ORIG, 250, 275, 295, 315)
	self:addTradeFlags(RecipeDB, 3175, F.ALLIANCE, F.HORDE, F.WORLD_DROP, F.IBOE, F.RBOE)
	self:addTradeAcquire(RecipeDB, 3175, A.WORLD_DROP, 2)

	-- Strong Troll's Blood Elixir -- 3176
	AddRecipe(3176, 125, 3388, R_COMMON, GAME_ORIG, 125, 150, 170, 190)
	self:addTradeFlags(RecipeDB, 3176, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP)
	self:addTradeAcquire(RecipeDB, 3176, A.TRAINER, 1386, A.TRAINER, 2391, A.TRAINER, 2837, A.TRAINER, 3009, A.TRAINER, 3347, A.TRAINER, 3964, A.TRAINER, 4160, A.TRAINER, 4611, A.TRAINER, 5177, A.TRAINER, 5499, A.TRAINER, 7948, A.TRAINER, 16588, A.TRAINER, 16642, A.TRAINER, 16723, A.TRAINER, 18802, A.TRAINER, 19052, A.TRAINER, 27029, A.TRAINER, 3603, A.TRAINER, 1470, A.TRAINER, 2132, A.TRAINER, 3184, A.TRAINER, 33608, A.TRAINER, 33674, A.TRAINER, 27023, A.TRAINER, 4900, A.TRAINER, 1215, A.TRAINER, 16161)

	-- Elixir of Defense -- 3177
	AddRecipe(3177, 130, 3389, R_COMMON, GAME_ORIG, 130, 155, 175, 195)
	self:addTradeFlags(RecipeDB, 3177, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.TANK)
	self:addTradeAcquire(RecipeDB, 3177, A.TRAINER, 1386, A.TRAINER, 2391, A.TRAINER, 2837, A.TRAINER, 3009, A.TRAINER, 3347, A.TRAINER, 3964, A.TRAINER, 4160, A.TRAINER, 4611, A.TRAINER, 5177, A.TRAINER, 5499, A.TRAINER, 7948, A.TRAINER, 16588, A.TRAINER, 16642, A.TRAINER, 16723, A.TRAINER, 18802, A.TRAINER, 19052, A.TRAINER, 27029, A.TRAINER, 3603, A.TRAINER, 1470, A.TRAINER, 2132, A.TRAINER, 3184, A.TRAINER, 33608, A.TRAINER, 33674, A.TRAINER, 27023, A.TRAINER, 4900, A.TRAINER, 1215, A.TRAINER, 16161)

	-- Elixir of Ogre's Strength -- 3188
	AddRecipe(3188, 150, 3391, R_COMMON, GAME_ORIG, 150, 175, 195, 215)
	self:addTradeFlags(RecipeDB, 3188, F.ALLIANCE, F.HORDE, F.TRAINER, F.WORLD_DROP, F.IBOE, F.RBOE, F.DPS)
	self:addTradeAcquire(RecipeDB, 3188, A.WORLD_DROP, 1)

	-- Elixir of Minor Agility -- 3230
	AddRecipe(3230, 50, 2457, R_UNCOMMON, GAME_ORIG, 50, 80, 100, 120)
	self:addTradeFlags(RecipeDB, 3230, F.ALLIANCE, F.HORDE, F.WORLD_DROP, F.IBOE, F.RBOE, F.DPS)
	self:addTradeAcquire(RecipeDB, 3230, A.WORLD_DROP, 1)

	-- Healing Potion -- 3447
	AddRecipe(3447, 110, 929, R_COMMON, GAME_ORIG, 110, 135, 155, 175)
	self:addTradeFlags(RecipeDB, 3447, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP)
	self:addTradeAcquire(RecipeDB, 3447, A.TRAINER, 1386, A.TRAINER, 2391, A.TRAINER, 2837, A.TRAINER, 3009, A.TRAINER, 3347, A.TRAINER, 3964, A.TRAINER, 4160, A.TRAINER, 4611, A.TRAINER, 5177, A.TRAINER, 5499, A.TRAINER, 7948, A.TRAINER, 16588, A.TRAINER, 16642, A.TRAINER, 16723, A.TRAINER, 18802, A.TRAINER, 19052, A.TRAINER, 27029, A.TRAINER, 3603, A.TRAINER, 1470, A.TRAINER, 2132, A.TRAINER, 3184, A.TRAINER, 33608, A.TRAINER, 33674, A.TRAINER, 27023, A.TRAINER, 4900, A.TRAINER, 1215, A.TRAINER, 16161)

	-- Lesser Invisibility Potion -- 3448
	AddRecipe(3448, 165, 3823, R_COMMON, GAME_ORIG, 165, 185, 205, 225)
	self:addTradeFlags(RecipeDB, 3448, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP)
	self:addTradeAcquire(RecipeDB, 3448, A.TRAINER, 1386, A.TRAINER, 4160, A.TRAINER, 4611, A.TRAINER, 7948, A.TRAINER, 16588, A.TRAINER, 18802, A.TRAINER, 19052, A.TRAINER, 16642, A.TRAINER, 27029, A.TRAINER, 3603, A.TRAINER, 16723, A.TRAINER, 3347, A.TRAINER, 3009, A.TRAINER, 2837, A.TRAINER, 5177, A.TRAINER, 1470, A.TRAINER, 3964, A.TRAINER, 2132, A.TRAINER, 3184, A.TRAINER, 33608, A.TRAINER, 33674, A.TRAINER, 2391, A.TRAINER, 27023, A.TRAINER, 4900, A.TRAINER, 1215, A.TRAINER, 5499, A.TRAINER, 16161)

	-- Shadow Oil -- 3449
	AddRecipe(3449, 165, 3824, R_COMMON, GAME_WOTLK, 165, 190, 210, 230)
	self:addTradeFlags(RecipeDB, 3449, F.ALLIANCE, F.HORDE, F.QUEST, F.IBOE, F.RBOP)
	self:addTradeAcquire(RecipeDB, 3449, A.VENDOR, 2481, A.VENDOR, 4878)

	-- Elixir of Fortitude -- 3450
	AddRecipe(3450, 175, 3825, R_COMMON, GAME_ORIG, 175, 195, 215, 235)
	self:addTradeFlags(RecipeDB, 3450, F.ALLIANCE, F.HORDE, F.TRAINER, F.WORLD_DROP, F.IBOE, F.RBOE)
	self:addTradeAcquire(RecipeDB, 3450, A.WORLD_DROP, 1, A.TRAINER, 1386, A.TRAINER, 4160, A.TRAINER, 4611, A.TRAINER, 7948, A.TRAINER, 16588, A.TRAINER, 18802, A.TRAINER, 19052, A.TRAINER, 16642, A.TRAINER, 27029, A.TRAINER, 3603, A.TRAINER, 16723, A.TRAINER, 3347, A.TRAINER, 3009, A.TRAINER, 2837, A.TRAINER, 5177, A.TRAINER, 1470, A.TRAINER, 3964, A.TRAINER, 2132, A.TRAINER, 3184, A.TRAINER, 33608, A.TRAINER, 33674, A.TRAINER, 2391, A.TRAINER, 27023, A.TRAINER, 4900, A.TRAINER, 1215, A.TRAINER, 5499, A.TRAINER, 16161)

	-- Major Troll's Blood Elixir -- 3451
	AddRecipe(3451, 180, 3826, R_COMMON, GAME_ORIG, 180, 200, 220, 240)
	self:addTradeFlags(RecipeDB, 3451, F.ALLIANCE, F.HORDE, F.WORLD_DROP, F.IBOE, F.RBOE)
	self:addTradeAcquire(RecipeDB, 3451, A.WORLD_DROP, 1)

	-- Mana Potion -- 3452
	AddRecipe(3452, 160, 3827, R_COMMON, GAME_ORIG, 160, 180, 200, 220)
	self:addTradeFlags(RecipeDB, 3452, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP)
	self:addTradeAcquire(RecipeDB, 3452, A.TRAINER, 1386, A.TRAINER, 4160, A.TRAINER, 4611, A.TRAINER, 7948, A.TRAINER, 16588, A.TRAINER, 18802, A.TRAINER, 19052, A.TRAINER, 16642, A.TRAINER, 27029, A.TRAINER, 3603, A.TRAINER, 16723, A.TRAINER, 3347, A.TRAINER, 3009, A.TRAINER, 2837, A.TRAINER, 5177, A.TRAINER, 1470, A.TRAINER, 3964, A.TRAINER, 2132, A.TRAINER, 3184, A.TRAINER, 33608, A.TRAINER, 33674, A.TRAINER, 2391, A.TRAINER, 27023, A.TRAINER, 4900, A.TRAINER, 1215, A.TRAINER, 5499, A.TRAINER, 16161)

	-- Elixir of Detect Lesser Invisibility -- 3453
	AddRecipe(3453, 195, 3828, R_UNCOMMON, GAME_ORIG, 195, 215, 235, 255)
	self:addTradeFlags(RecipeDB, 3453, F.ALLIANCE, F.HORDE, F.WORLD_DROP, F.IBOE, F.RBOE)
	self:addTradeAcquire(RecipeDB, 3453, A.WORLD_DROP, 2)

	-- Frost Oil -- 3454
	AddRecipe(3454, 200, 3829, R_UNCOMMON, GAME_ORIG, 200, 220, 240, 260)
	self:addTradeFlags(RecipeDB, 3454, F.ALLIANCE, F.HORDE, F.QUEST, F.IBOE, F.RBOE)
	self:addTradeAcquire(RecipeDB, 3454, A.VENDOR, 2480)

	-- Discolored Healing Potion -- 4508
	AddRecipe(4508, 50, 4596, R_UNCOMMON, GAME_ORIG, 50, 80, 100, 120)
	self:addTradeFlags(RecipeDB, 4508, F.HORDE, F.QUEST, F.IBOE, F.RBOE)
	self:addTradeAcquire(RecipeDB, 4508, A.QUEST, 429)

	-- Lesser Stoneshield Potion -- 4942
	AddRecipe(4942, 215, 4623, R_COMMON, GAME_ORIG, 215, 230, 250, 270)
	self:addTradeFlags(RecipeDB, 4942, F.ALLIANCE, F.HORDE, F.QUEST, F.IBOE, F.RBOE)
	self:addTradeAcquire(RecipeDB, 4942, A.QUEST, 715)

	-- Rage Potion -- 6617
	AddRecipe(6617, 60, 5631, R_COMMON, GAME_ORIG, 60, 90, 110, 130)
	self:addTradeFlags(RecipeDB, 6617, F.ALLIANCE, F.HORDE, F.QUEST, F.DRUID, F.WARRIOR, F.IBOE, F.RBOE, F.DPS, F.TANK)
	self:addTradeAcquire(RecipeDB, 6617, A.VENDOR, 1669, A.VENDOR, 1685, A.VENDOR, 3335, A.VENDOR, 3499)

	-- Great Rage Potion -- 6618
	AddRecipe(6618, 175, 5633, R_COMMON, GAME_ORIG, 175, 195, 215, 235)
	self:addTradeFlags(RecipeDB, 6618, F.ALLIANCE, F.HORDE, F.QUEST, F.DRUID, F.WARRIOR, F.IBOE, F.RBOE, F.DPS, F.TANK)
	self:addTradeAcquire(RecipeDB, 6618, A.VENDOR, 3335, A.VENDOR, 4226)

	-- Free Action Potion -- 6624
	AddRecipe(6624, 150, 5634, R_COMMON, GAME_WOTLK, 150, 175, 195, 215)
	self:addTradeFlags(RecipeDB, 6624, F.ALLIANCE, F.HORDE, F.QUEST, F.IBOE, F.RBOE)
	self:addTradeAcquire(RecipeDB, 6624, A.VENDOR, 3348, A.VENDOR, 5178, A.VENDOR, 4226)

	-- Elixir of Water Breathing -- 7179
	AddRecipe(7179, 90, 5996, R_COMMON, GAME_ORIG, 90, 120, 140, 160)
	self:addTradeFlags(RecipeDB, 7179, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP)
	self:addTradeAcquire(RecipeDB, 7179, A.TRAINER, 1386, A.TRAINER, 2391, A.TRAINER, 2837, A.TRAINER, 3009, A.TRAINER, 3347, A.TRAINER, 4160, A.TRAINER, 4611, A.TRAINER, 5177, A.TRAINER, 5499, A.TRAINER, 7948, A.TRAINER, 16588, A.TRAINER, 16642, A.TRAINER, 16723, A.TRAINER, 18802, A.TRAINER, 19052, A.TRAINER, 27029, A.TRAINER, 3603, A.TRAINER, 1470, A.TRAINER, 3964, A.TRAINER, 2132, A.TRAINER, 3184, A.TRAINER, 33608, A.TRAINER, 33674, A.TRAINER, 27023, A.TRAINER, 4900, A.TRAINER, 1215, A.TRAINER, 16161)

	-- Greater Healing Potion -- 7181
	AddRecipe(7181, 155, 1710, R_COMMON, GAME_ORIG, 155, 175, 195, 215)
	self:addTradeFlags(RecipeDB, 7181, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP)
	self:addTradeAcquire(RecipeDB, 7181, A.TRAINER, 1386, A.TRAINER, 4160, A.TRAINER, 4611, A.TRAINER, 7948, A.TRAINER, 16588, A.TRAINER, 18802, A.TRAINER, 19052, A.TRAINER, 16642, A.TRAINER, 27029, A.TRAINER, 3603, A.TRAINER, 16723, A.TRAINER, 3347, A.TRAINER, 3009, A.TRAINER, 2837, A.TRAINER, 5177, A.TRAINER, 1470, A.TRAINER, 3964, A.TRAINER, 2132, A.TRAINER, 3184, A.TRAINER, 33608, A.TRAINER, 33674, A.TRAINER, 2391, A.TRAINER, 27023, A.TRAINER, 4900, A.TRAINER, 1215, A.TRAINER, 5499, A.TRAINER, 16161)

	-- Elixir of Minor Defense -- 7183
	AddRecipe(7183, 1, 5997, R_COMMON, GAME_ORIG, 1, 55, 75, 95)
	self:addTradeFlags(RecipeDB, 7183, F.ALLIANCE, F.TRAINER, F.IBOE, F.RBOP, F.TANK)
	self:addTradeAcquire(RecipeDB, 7183, A.CUSTOM, 8)

	-- Holy Protection Potion -- 7255
	AddRecipe(7255, 100, 6051, R_COMMON, GAME_ORIG, 100, 130, 150, 170)
	self:addTradeFlags(RecipeDB, 7255, F.ALLIANCE, F.HORDE, F.QUEST, F.IBOE, F.RBOE)
	self:addTradeAcquire(RecipeDB, 7255, A.VENDOR, 1685, A.VENDOR, 3134, A.VENDOR, 3490)

	-- Shadow Protection Potion -- 7256
	AddRecipe(7256, 135, 6048, R_COMMON, GAME_ORIG, 135, 160, 180, 200)
	self:addTradeFlags(RecipeDB, 7256, F.ALLIANCE, F.HORDE, F.QUEST, F.IBOE, F.RBOE)
	self:addTradeAcquire(RecipeDB, 7256, A.VENDOR, 2393, A.VENDOR, 3956)

	-- Fire Protection Potion -- 7257
	AddRecipe(7257, 165, 6049, R_COMMON, GAME_ORIG, 165, 210, 230, 250)
	self:addTradeFlags(RecipeDB, 7257, F.ALLIANCE, F.HORDE, F.QUEST, F.IBOE, F.RBOP)
	self:addTradeAcquire(RecipeDB, 7257, A.VENDOR, 4083, A.VENDOR, 2380)

	-- Frost Protection Potion -- 7258
	AddRecipe(7258, 190, 6050, R_COMMON, GAME_ORIG, 190, 205, 225, 245)
	self:addTradeFlags(RecipeDB, 7258, F.ALLIANCE, F.HORDE, F.QUEST, F.IBOE, F.RBOE)
	self:addTradeAcquire(RecipeDB, 7258, A.VENDOR, 2812, A.VENDOR, 2848)

	-- Nature Protection Potion -- 7259
	AddRecipe(7259, 190, 6052, R_COMMON, GAME_ORIG, 190, 210, 230, 250)
	self:addTradeFlags(RecipeDB, 7259, F.ALLIANCE, F.HORDE, F.QUEST, F.IBOE, F.RBOE)
	self:addTradeAcquire(RecipeDB, 7259, A.VENDOR, 2848, A.VENDOR, 8157, A.VENDOR, 8158, A.VENDOR, 5594)

	-- Blackmouth Oil -- 7836
	AddRecipe(7836, 80, 6370, R_COMMON, GAME_ORIG, 80, 80, 90, 100)
	self:addTradeFlags(RecipeDB, 7836, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP)
	self:addTradeAcquire(RecipeDB, 7836, A.TRAINER, 1386, A.TRAINER, 2391, A.TRAINER, 2837, A.TRAINER, 3009, A.TRAINER, 3347, A.TRAINER, 4160, A.TRAINER, 4611, A.TRAINER, 5177, A.TRAINER, 5499, A.TRAINER, 7948, A.TRAINER, 16588, A.TRAINER, 16642, A.TRAINER, 16723, A.TRAINER, 18802, A.TRAINER, 19052, A.TRAINER, 27029, A.TRAINER, 3603, A.TRAINER, 1470, A.TRAINER, 3964, A.TRAINER, 2132, A.TRAINER, 3184, A.TRAINER, 33608, A.TRAINER, 33674, A.TRAINER, 27023, A.TRAINER, 4900, A.TRAINER, 1215, A.TRAINER, 16161)

	-- Fire Oil -- 7837
	AddRecipe(7837, 130, 6371, R_COMMON, GAME_ORIG, 130, 150, 160, 170)
	self:addTradeFlags(RecipeDB, 7837, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP)
	self:addTradeAcquire(RecipeDB, 7837, A.TRAINER, 1386, A.TRAINER, 2391, A.TRAINER, 2837, A.TRAINER, 3009, A.TRAINER, 3347, A.TRAINER, 3964, A.TRAINER, 4160, A.TRAINER, 4611, A.TRAINER, 5177, A.TRAINER, 5499, A.TRAINER, 7948, A.TRAINER, 16588, A.TRAINER, 16642, A.TRAINER, 16723, A.TRAINER, 18802, A.TRAINER, 19052, A.TRAINER, 27029, A.TRAINER, 3603, A.TRAINER, 1470, A.TRAINER, 2132, A.TRAINER, 3184, A.TRAINER, 33608, A.TRAINER, 33674, A.TRAINER, 27023, A.TRAINER, 4900, A.TRAINER, 1215, A.TRAINER, 16161)

	-- Swim Speed Potion -- 7841
	AddRecipe(7841, 100, 6372, R_COMMON, GAME_ORIG, 100, 130, 150, 170)
	self:addTradeFlags(RecipeDB, 7841, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP)
	self:addTradeAcquire(RecipeDB, 7841, A.TRAINER, 1386, A.TRAINER, 2391, A.TRAINER, 2837, A.TRAINER, 3009, A.TRAINER, 3347, A.TRAINER, 4160, A.TRAINER, 4611, A.TRAINER, 5177, A.TRAINER, 5499, A.TRAINER, 7948, A.TRAINER, 16588, A.TRAINER, 16642, A.TRAINER, 16723, A.TRAINER, 18802, A.TRAINER, 19052, A.TRAINER, 27029, A.TRAINER, 3603, A.TRAINER, 1470, A.TRAINER, 3964, A.TRAINER, 2132, A.TRAINER, 3184, A.TRAINER, 33608, A.TRAINER, 33674, A.TRAINER, 27023, A.TRAINER, 4900, A.TRAINER, 1215, A.TRAINER, 16161)

	-- Elixir of Firepower -- 7845
	AddRecipe(7845, 140, 6373, R_COMMON, GAME_ORIG, 140, 165, 185, 205)
	self:addTradeFlags(RecipeDB, 7845, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.HEALER, F.CASTER)
	self:addTradeAcquire(RecipeDB, 7845, A.TRAINER, 1386, A.TRAINER, 2391, A.TRAINER, 2837, A.TRAINER, 3009, A.TRAINER, 3347, A.TRAINER, 3964, A.TRAINER, 4160, A.TRAINER, 4611, A.TRAINER, 5177, A.TRAINER, 5499, A.TRAINER, 7948, A.TRAINER, 16588, A.TRAINER, 16642, A.TRAINER, 16723, A.TRAINER, 18802, A.TRAINER, 19052, A.TRAINER, 27029, A.TRAINER, 3603, A.TRAINER, 1470, A.TRAINER, 2132, A.TRAINER, 3184, A.TRAINER, 33608, A.TRAINER, 33674, A.TRAINER, 27023, A.TRAINER, 4900, A.TRAINER, 1215, A.TRAINER, 16161)

	-- Elixir of Giant Growth -- 8240
	AddRecipe(8240, 90, 6662, R_UNCOMMON, GAME_ORIG, 90, 120, 140, 160)
	self:addTradeFlags(RecipeDB, 8240, F.ALLIANCE, F.HORDE, F.WORLD_DROP, F.IBOE, F.RBOE, F.DPS)
	self:addTradeAcquire(RecipeDB, 8240, A.WORLD_DROP, 2)

	-- Greater Mana Potion -- 11448
	AddRecipe(11448, 205, 6149, R_COMMON, GAME_ORIG, 205, 220, 240, 260)
	self:addTradeFlags(RecipeDB, 11448, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP)
	self:addTradeAcquire(RecipeDB, 11448, A.TRAINER, 1386, A.TRAINER, 4160, A.TRAINER, 4611, A.TRAINER, 7948, A.TRAINER, 16588, A.TRAINER, 18802, A.TRAINER, 19052, A.TRAINER, 16642, A.TRAINER, 27029, A.TRAINER, 3603, A.TRAINER, 16723, A.TRAINER, 3347, A.TRAINER, 3009, A.TRAINER, 2837, A.TRAINER, 5177, A.TRAINER, 1470, A.TRAINER, 3964, A.TRAINER, 2132, A.TRAINER, 3184, A.TRAINER, 33608, A.TRAINER, 33674, A.TRAINER, 2391, A.TRAINER, 27023, A.TRAINER, 4900, A.TRAINER, 1215, A.TRAINER, 5499, A.TRAINER, 16161)

	-- Elixir of Agility -- 11449
	AddRecipe(11449, 185, 8949, R_COMMON, GAME_ORIG, 185, 205, 225, 245)
	self:addTradeFlags(RecipeDB, 11449, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.DPS)
	self:addTradeAcquire(RecipeDB, 11449, A.TRAINER, 1386, A.TRAINER, 4160, A.TRAINER, 4611, A.TRAINER, 7948, A.TRAINER, 16588, A.TRAINER, 18802, A.TRAINER, 19052, A.TRAINER, 16642, A.TRAINER, 27029, A.TRAINER, 3603, A.TRAINER, 16723, A.TRAINER, 3347, A.TRAINER, 3009, A.TRAINER, 2837, A.TRAINER, 5177, A.TRAINER, 1470, A.TRAINER, 3964, A.TRAINER, 2132, A.TRAINER, 3184, A.TRAINER, 33608, A.TRAINER, 33674, A.TRAINER, 2391, A.TRAINER, 27023, A.TRAINER, 4900, A.TRAINER, 1215, A.TRAINER, 5499, A.TRAINER, 16161)

	-- Elixir of Greater Defense -- 11450
	AddRecipe(11450, 195, 8951, R_COMMON, GAME_ORIG, 195, 215, 235, 255)
	self:addTradeFlags(RecipeDB, 11450, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.TANK)
	self:addTradeAcquire(RecipeDB, 11450, A.TRAINER, 1386, A.TRAINER, 4160, A.TRAINER, 4611, A.TRAINER, 7948, A.TRAINER, 16588, A.TRAINER, 18802, A.TRAINER, 19052, A.TRAINER, 16642, A.TRAINER, 27029, A.TRAINER, 3603, A.TRAINER, 16723, A.TRAINER, 3347, A.TRAINER, 3009, A.TRAINER, 2837, A.TRAINER, 5177, A.TRAINER, 1470, A.TRAINER, 3964, A.TRAINER, 2132, A.TRAINER, 3184, A.TRAINER, 33608, A.TRAINER, 33674, A.TRAINER, 2391, A.TRAINER, 27023, A.TRAINER, 4900, A.TRAINER, 1215, A.TRAINER, 5499, A.TRAINER, 16161)

	-- Oil of Immolation -- 11451
	AddRecipe(11451, 205, 8956, R_COMMON, GAME_ORIG, 205, 220, 240, 260)
	self:addTradeFlags(RecipeDB, 11451, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP)
	self:addTradeAcquire(RecipeDB, 11451, A.TRAINER, 1386, A.TRAINER, 4160, A.TRAINER, 4611, A.TRAINER, 7948, A.TRAINER, 16588, A.TRAINER, 18802, A.TRAINER, 19052, A.TRAINER, 16642, A.TRAINER, 27029, A.TRAINER, 3603, A.TRAINER, 16723, A.TRAINER, 3347, A.TRAINER, 3009, A.TRAINER, 2837, A.TRAINER, 5177, A.TRAINER, 1470, A.TRAINER, 3964, A.TRAINER, 2132, A.TRAINER, 3184, A.TRAINER, 33608, A.TRAINER, 33674, A.TRAINER, 2391, A.TRAINER, 27023, A.TRAINER, 4900, A.TRAINER, 1215, A.TRAINER, 5499, A.TRAINER, 16161)

	-- Restorative Potion -- 11452
	AddRecipe(11452, 210, 9030, R_COMMON, GAME_ORIG, 210, 225, 245, 265)
	self:addTradeFlags(RecipeDB, 11452, F.ALLIANCE, F.HORDE, F.QUEST, F.IBOE, F.RBOP)
	self:addTradeAcquire(RecipeDB, 11452, A.QUEST, 2203, A.QUEST, 2501)

	-- Magic Resistance Potion -- 11453
	AddRecipe(11453, 210, 9036, R_UNCOMMON, GAME_ORIG, 210, 225, 245, 265)
	self:addTradeFlags(RecipeDB, 11453, F.ALLIANCE, F.HORDE, F.WORLD_DROP, F.IBOE, F.RBOE)
	self:addTradeAcquire(RecipeDB, 11453, A.WORLD_DROP, 2)

	-- Goblin Rocket Fuel -- 11456
	AddRecipe(11456, 210, 9061, R_COMMON, GAME_ORIG, 210, 225, 245, 265)
	self:addTradeFlags(RecipeDB, 11456, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP)
	self:addTradeAcquire(RecipeDB, 11456, A.CUSTOM, 9)

	-- Superior Healing Potion -- 11457
	AddRecipe(11457, 215, 3928, R_COMMON, GAME_ORIG, 215, 230, 250, 270)
	self:addTradeFlags(RecipeDB, 11457, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP)
	self:addTradeAcquire(RecipeDB, 11457, A.TRAINER, 1386, A.TRAINER, 4160, A.TRAINER, 4611, A.TRAINER, 7948, A.TRAINER, 16588, A.TRAINER, 18802, A.TRAINER, 19052, A.TRAINER, 16642, A.TRAINER, 27029, A.TRAINER, 3603, A.TRAINER, 16723, A.TRAINER, 3347, A.TRAINER, 3009, A.TRAINER, 2837, A.TRAINER, 5177, A.TRAINER, 1470, A.TRAINER, 3964, A.TRAINER, 2132, A.TRAINER, 3184, A.TRAINER, 33608, A.TRAINER, 33674, A.TRAINER, 2391, A.TRAINER, 27023, A.TRAINER, 4900, A.TRAINER, 1215, A.TRAINER, 5499, A.TRAINER, 16161)

	-- Wildvine Potion -- 11458
	AddRecipe(11458, 225, 9144, R_UNCOMMON, GAME_ORIG, 225, 240, 260, 280)
	self:addTradeFlags(RecipeDB, 11458, F.ALLIANCE, F.HORDE, F.WORLD_DROP, F.IBOE, F.RBOE)
	self:addTradeAcquire(RecipeDB, 11458, A.WORLD_DROP, 2)

	-- Philosopher's Stone -- 11459
	AddRecipe(11459, 225, 9149, R_COMMON, GAME_ORIG, 225, 240, 260, 280)
	self:addTradeFlags(RecipeDB, 11459, F.ALLIANCE, F.HORDE, F.QUEST, F.IBOP, F.RBOP, F.HEALER, F.CASTER, F.TRINKET)
	self:addTradeAcquire(RecipeDB, 11459, A.VENDOR, 5594)

	-- Elixir of Detect Undead -- 11460
	AddRecipe(11460, 230, 9154, R_COMMON, GAME_ORIG, 230, 245, 265, 285)
	self:addTradeFlags(RecipeDB, 11460, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP)
	self:addTradeAcquire(RecipeDB, 11460, A.TRAINER, 1386, A.TRAINER, 7948, A.TRAINER, 16588, A.TRAINER, 18802, A.TRAINER, 19052, A.TRAINER, 4611, A.TRAINER, 4160, A.TRAINER, 3603, A.TRAINER, 16723, A.TRAINER, 3347, A.TRAINER, 3009, A.TRAINER, 2837, A.TRAINER, 5177, A.TRAINER, 1470, A.TRAINER, 3964, A.TRAINER, 2132, A.TRAINER, 3184, A.TRAINER, 33608, A.TRAINER, 16642, A.TRAINER, 33674, A.TRAINER, 2391, A.TRAINER, 27023, A.TRAINER, 27029, A.TRAINER, 4900, A.TRAINER, 1215, A.TRAINER, 5499, A.TRAINER, 16161)

	-- Arcane Elixir -- 11461
	AddRecipe(11461, 235, 9155, R_COMMON, GAME_ORIG, 235, 250, 270, 290)
	self:addTradeFlags(RecipeDB, 11461, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.HEALER, F.CASTER)
	self:addTradeAcquire(RecipeDB, 11461, A.TRAINER, 1386, A.TRAINER, 7948, A.TRAINER, 16588, A.TRAINER, 18802, A.TRAINER, 19052, A.TRAINER, 4611, A.TRAINER, 4160, A.TRAINER, 3603, A.TRAINER, 16723, A.TRAINER, 3347, A.TRAINER, 3009, A.TRAINER, 2837, A.TRAINER, 5177, A.TRAINER, 1470, A.TRAINER, 3964, A.TRAINER, 2132, A.TRAINER, 3184, A.TRAINER, 33608, A.TRAINER, 16642, A.TRAINER, 33674, A.TRAINER, 2391, A.TRAINER, 27023, A.TRAINER, 27029, A.TRAINER, 4900, A.TRAINER, 1215, A.TRAINER, 5499, A.TRAINER, 16161)

	-- Invisibility Potion -- 11464
	AddRecipe(11464, 235, 9172, R_UNCOMMON, GAME_ORIG, 235, 250, 270, 290)
	self:addTradeFlags(RecipeDB, 11464, F.ALLIANCE, F.HORDE, F.WORLD_DROP, F.IBOE, F.RBOE)
	self:addTradeAcquire(RecipeDB, 11464, A.WORLD_DROP, 2)

	-- Elixir of Greater Intellect -- 11465
	AddRecipe(11465, 235, 9179, R_COMMON, GAME_ORIG, 235, 250, 270, 290)
	self:addTradeFlags(RecipeDB, 11465, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP)
	self:addTradeAcquire(RecipeDB, 11465, A.TRAINER, 1386, A.TRAINER, 7948, A.TRAINER, 16588, A.TRAINER, 18802, A.TRAINER, 19052, A.TRAINER, 4611, A.TRAINER, 4160, A.TRAINER, 3603, A.TRAINER, 16723, A.TRAINER, 3347, A.TRAINER, 3009, A.TRAINER, 2837, A.TRAINER, 5177, A.TRAINER, 1470, A.TRAINER, 3964, A.TRAINER, 2132, A.TRAINER, 3184, A.TRAINER, 33608, A.TRAINER, 16642, A.TRAINER, 33674, A.TRAINER, 2391, A.TRAINER, 27023, A.TRAINER, 27029, A.TRAINER, 4900, A.TRAINER, 1215, A.TRAINER, 5499, A.TRAINER, 16161)

	-- Gift of Arthas -- 11466
	AddRecipe(11466, 240, 9088, R_UNCOMMON, GAME_ORIG, 240, 255, 275, 295)
	self:addTradeFlags(RecipeDB, 11466, F.ALLIANCE, F.HORDE, F.MOB_DROP, F.IBOE, F.RBOE)
	self:addTradeAcquire(RecipeDB, 11466, A.MOB, 1783, A.MOB, 1791)

	-- Elixir of Greater Agility -- 11467
	AddRecipe(11467, 240, 9187, R_COMMON, GAME_ORIG, 240, 255, 275, 295)
	self:addTradeFlags(RecipeDB, 11467, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.DPS)
	self:addTradeAcquire(RecipeDB, 11467, A.TRAINER, 1386, A.TRAINER, 7948, A.TRAINER, 16588, A.TRAINER, 18802, A.TRAINER, 19052, A.TRAINER, 4611, A.TRAINER, 4160, A.TRAINER, 3603, A.TRAINER, 16723, A.TRAINER, 3347, A.TRAINER, 3009, A.TRAINER, 2837, A.TRAINER, 5177, A.TRAINER, 1470, A.TRAINER, 3964, A.TRAINER, 2132, A.TRAINER, 3184, A.TRAINER, 33608, A.TRAINER, 16642, A.TRAINER, 33674, A.TRAINER, 2391, A.TRAINER, 27023, A.TRAINER, 27029, A.TRAINER, 4900, A.TRAINER, 1215, A.TRAINER, 5499, A.TRAINER, 16161)

	-- Elixir of Dream Vision -- 11468
	AddRecipe(11468, 240, 9197, R_UNCOMMON, GAME_ORIG, 240, 255, 275, 295)
	self:addTradeFlags(RecipeDB, 11468, F.ALLIANCE, F.HORDE, F.WORLD_DROP, F.IBOE, F.RBOE)
	self:addTradeAcquire(RecipeDB, 11468, A.WORLD_DROP, 2)

	-- Elixir of Giants -- 11472
	AddRecipe(11472, 245, 9206, R_UNCOMMON, GAME_ORIG, 245, 260, 280, 300)
	self:addTradeFlags(RecipeDB, 11472, F.ALLIANCE, F.HORDE, F.WORLD_DROP, F.IBOE, F.RBOE, F.DPS)
	self:addTradeAcquire(RecipeDB, 11472, A.WORLD_DROP, 2)

	-- Ghost Dye -- 11473
	AddRecipe(11473, 245, 9210, R_COMMON, GAME_ORIG, 245, 260, 280, 300)
	self:addTradeFlags(RecipeDB, 11473, F.ALLIANCE, F.HORDE, F.QUEST, F.IBOE, F.RBOE)
	self:addTradeAcquire(RecipeDB, 11473, A.VENDOR, 8157, A.VENDOR, 8158)

	-- Elixir of Shadow Power -- 11476
	AddRecipe(11476, 250, 9264, R_UNCOMMON, GAME_ORIG, 250, 265, 285, 305)
	self:addTradeFlags(RecipeDB, 11476, F.ALLIANCE, F.HORDE, F.QUEST, F.IBOE, F.RBOE, F.HEALER, F.CASTER)
	self:addTradeAcquire(RecipeDB, 11476, A.VENDOR, 1313, A.VENDOR, 4610)

	-- Elixir of Demonslaying -- 11477
	AddRecipe(11477, 250, 9224, R_COMMON, GAME_ORIG, 250, 265, 285, 305)
	self:addTradeFlags(RecipeDB, 11477, F.ALLIANCE, F.HORDE, F.QUEST, F.IBOE, F.RBOE, F.DPS)
	self:addTradeAcquire(RecipeDB, 11477, A.VENDOR, 8177, A.VENDOR, 8178)

	-- Elixir of Detect Demon -- 11478
	AddRecipe(11478, 250, 9233, R_COMMON, GAME_ORIG, 250, 265, 285, 305)
	self:addTradeFlags(RecipeDB, 11478, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP)
	self:addTradeAcquire(RecipeDB, 11478, A.TRAINER, 1386, A.TRAINER, 7948, A.TRAINER, 16588, A.TRAINER, 18802, A.TRAINER, 19052, A.TRAINER, 4611, A.TRAINER, 4160, A.TRAINER, 3603, A.TRAINER, 16723, A.TRAINER, 3347, A.TRAINER, 3009, A.TRAINER, 2837, A.TRAINER, 5177, A.TRAINER, 1470, A.TRAINER, 3964, A.TRAINER, 2132, A.TRAINER, 3184, A.TRAINER, 33608, A.TRAINER, 16642, A.TRAINER, 33674, A.TRAINER, 2391, A.TRAINER, 27023, A.TRAINER, 27029, A.TRAINER, 4900, A.TRAINER, 1215, A.TRAINER, 5499, A.TRAINER, 16161)

	-- Transmute: Iron to Gold -- 11479
	AddRecipe(11479, 225, 3577, R_COMMON, GAME_ORIG, 225, 240, 260, 280)
	self:addTradeFlags(RecipeDB, 11479, F.ALLIANCE, F.HORDE, F.QUEST, F.IBOE, F.RBOE)
	self:addTradeAcquire(RecipeDB, 11479, A.VENDOR, 5594)

	-- Transmute: Mithril to Truesilver -- 11480
	AddRecipe(11480, 225, 6037, R_COMMON, GAME_ORIG, 225, 240, 260, 280)
	self:addTradeFlags(RecipeDB, 11480, F.ALLIANCE, F.HORDE, F.QUEST, F.IBOE, F.RBOE)
	self:addTradeAcquire(RecipeDB, 11480, A.VENDOR, 5594)

	-- Catseye Elixir -- 12609
	AddRecipe(12609, 200, 10592, R_COMMON, GAME_ORIG, 200, 220, 240, 260)
	self:addTradeFlags(RecipeDB, 12609, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP)
	self:addTradeAcquire(RecipeDB, 12609, A.TRAINER, 1386, A.TRAINER, 4160, A.TRAINER, 4611, A.TRAINER, 7948, A.TRAINER, 16588, A.TRAINER, 18802, A.TRAINER, 19052, A.TRAINER, 16642, A.TRAINER, 27029, A.TRAINER, 3603, A.TRAINER, 16723, A.TRAINER, 3347, A.TRAINER, 3009, A.TRAINER, 2837, A.TRAINER, 5177, A.TRAINER, 1470, A.TRAINER, 3964, A.TRAINER, 2132, A.TRAINER, 3184, A.TRAINER, 33608, A.TRAINER, 33674, A.TRAINER, 2391, A.TRAINER, 27023, A.TRAINER, 4900, A.TRAINER, 1215, A.TRAINER, 5499, A.TRAINER, 16161)

	-- Dreamless Sleep Potion -- 15833
	AddRecipe(15833, 230, 12190, R_COMMON, GAME_ORIG, 230, 245, 265, 285)
	self:addTradeFlags(RecipeDB, 15833, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP)
	self:addTradeAcquire(RecipeDB, 15833, A.TRAINER, 1386, A.TRAINER, 7948, A.TRAINER, 16588, A.TRAINER, 18802, A.TRAINER, 19052, A.TRAINER, 4611, A.TRAINER, 4160, A.TRAINER, 3603, A.TRAINER, 16723, A.TRAINER, 3347, A.TRAINER, 3009, A.TRAINER, 2837, A.TRAINER, 5177, A.TRAINER, 1470, A.TRAINER, 3964, A.TRAINER, 2132, A.TRAINER, 3184, A.TRAINER, 33608, A.TRAINER, 16642, A.TRAINER, 33674, A.TRAINER, 2391, A.TRAINER, 27023, A.TRAINER, 27029, A.TRAINER, 4900, A.TRAINER, 1215, A.TRAINER, 5499, A.TRAINER, 16161)

	-- Transmute: Arcanite -- 17187
	AddRecipe(17187, 275, 12360, R_COMMON, GAME_ORIG, 275, 275, 282, 290)
	self:addTradeFlags(RecipeDB, 17187, F.ALLIANCE, F.HORDE, F.QUEST, F.IBOE, F.RBOE)
	self:addTradeAcquire(RecipeDB, 17187, A.VENDOR, 5594)

	-- Stonescale Oil -- 17551
	AddRecipe(17551, 250, 13423, R_COMMON, GAME_ORIG, 250, 250, 255, 260)
	self:addTradeFlags(RecipeDB, 17551, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP)
	self:addTradeAcquire(RecipeDB, 17551, A.TRAINER, 1386, A.TRAINER, 7948, A.TRAINER, 16588, A.TRAINER, 18802, A.TRAINER, 19052, A.TRAINER, 4611, A.TRAINER, 4160, A.TRAINER, 3603, A.TRAINER, 16723, A.TRAINER, 3347, A.TRAINER, 3009, A.TRAINER, 2837, A.TRAINER, 5177, A.TRAINER, 1470, A.TRAINER, 3964, A.TRAINER, 2132, A.TRAINER, 3184, A.TRAINER, 33608, A.TRAINER, 16642, A.TRAINER, 33674, A.TRAINER, 2391, A.TRAINER, 27023, A.TRAINER, 27029, A.TRAINER, 4900, A.TRAINER, 1215, A.TRAINER, 5499, A.TRAINER, 16161)

	-- Mighty Rage Potion -- 17552
	AddRecipe(17552, 255, 13442, R_UNCOMMON, GAME_ORIG, 255, 270, 290, 310)
	self:addTradeFlags(RecipeDB, 17552, F.ALLIANCE, F.HORDE, F.TRAINER, F.DRUID, F.WARRIOR, F.IBOE, F.RBOE, F.DPS, F.TANK)
	self:addTradeAcquire(RecipeDB, 17552, A.TRAINER, 1386, A.TRAINER, 7948, A.TRAINER, 16588, A.TRAINER, 18802, A.TRAINER, 19052, A.TRAINER, 4611, A.TRAINER, 4160, A.TRAINER, 3603, A.TRAINER, 16723, A.TRAINER, 3347, A.TRAINER, 3009, A.TRAINER, 2837, A.TRAINER, 5177, A.TRAINER, 1470, A.TRAINER, 3964, A.TRAINER, 2132, A.TRAINER, 3184, A.TRAINER, 33608, A.TRAINER, 16642, A.TRAINER, 33674, A.TRAINER, 2391, A.TRAINER, 27023, A.TRAINER, 27029, A.TRAINER, 4900, A.TRAINER, 1215, A.TRAINER, 5499, A.TRAINER, 16161)

	-- Superior Mana Potion -- 17553
	AddRecipe(17553, 260, 13443, R_COMMON, GAME_ORIG, 260, 275, 295, 315)
	self:addTradeFlags(RecipeDB, 17553, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOE)
	self:addTradeAcquire(RecipeDB, 17553, A.TRAINER, 1386, A.TRAINER, 7948, A.TRAINER, 16588, A.TRAINER, 18802, A.TRAINER, 19052, A.TRAINER, 4611, A.TRAINER, 4160, A.TRAINER, 3603, A.TRAINER, 16723, A.TRAINER, 3347, A.TRAINER, 3009, A.TRAINER, 2837, A.TRAINER, 5177, A.TRAINER, 1470, A.TRAINER, 3964, A.TRAINER, 2132, A.TRAINER, 3184, A.TRAINER, 33608, A.TRAINER, 16642, A.TRAINER, 33674, A.TRAINER, 2391, A.TRAINER, 27023, A.TRAINER, 27029, A.TRAINER, 4900, A.TRAINER, 1215, A.TRAINER, 5499, A.TRAINER, 16161)

	-- Elixir of Superior Defense -- 17554
	AddRecipe(17554, 265, 13445, R_COMMON, GAME_ORIG, 265, 280, 300, 320)
	self:addTradeFlags(RecipeDB, 17554, F.ALLIANCE, F.HORDE, F.TRAINER, F.QUEST, F.IBOE, F.RBOE, F.TANK)
	self:addTradeAcquire(RecipeDB, 17554, A.VENDOR, 5178, A.VENDOR, 3348)

	-- Elixir of the Sages -- 17555
	AddRecipe(17555, 270, 13447, R_UNCOMMON, GAME_ORIG, 270, 285, 305, 325)
	self:addTradeFlags(RecipeDB, 17555, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOE, F.HEALER, F.CASTER)
	self:addTradeAcquire(RecipeDB, 17555, A.TRAINER, 1386, A.TRAINER, 7948, A.TRAINER, 16588, A.TRAINER, 18802, A.TRAINER, 19052, A.TRAINER, 4611, A.TRAINER, 4160, A.TRAINER, 3603, A.TRAINER, 16723, A.TRAINER, 3347, A.TRAINER, 3009, A.TRAINER, 2837, A.TRAINER, 5177, A.TRAINER, 1470, A.TRAINER, 3964, A.TRAINER, 2132, A.TRAINER, 3184, A.TRAINER, 33608, A.TRAINER, 16642, A.TRAINER, 33674, A.TRAINER, 2391, A.TRAINER, 27023, A.TRAINER, 27029, A.TRAINER, 4900, A.TRAINER, 1215, A.TRAINER, 5499, A.TRAINER, 16161)

	-- Major Healing Potion -- 17556
	AddRecipe(17556, 275, 13446, R_COMMON, GAME_ORIG, 275, 290, 310, 330)
	self:addTradeFlags(RecipeDB, 17556, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOE)
	self:addTradeAcquire(RecipeDB, 17556, A.TRAINER, 1386, A.TRAINER, 7948, A.TRAINER, 16588, A.TRAINER, 18802, A.TRAINER, 19052, A.TRAINER, 4611, A.TRAINER, 4160, A.TRAINER, 3603, A.TRAINER, 16723, A.TRAINER, 3347, A.TRAINER, 3009, A.TRAINER, 2837, A.TRAINER, 5177, A.TRAINER, 1470, A.TRAINER, 3964, A.TRAINER, 2132, A.TRAINER, 3184, A.TRAINER, 33608, A.TRAINER, 16642, A.TRAINER, 33674, A.TRAINER, 2391, A.TRAINER, 27023, A.TRAINER, 27029, A.TRAINER, 4900, A.TRAINER, 1215, A.TRAINER, 5499, A.TRAINER, 16161)

	-- Elixir of Brute Force -- 17557
	AddRecipe(17557, 275, 13453, R_UNCOMMON, GAME_ORIG, 275, 290, 310, 330)
	self:addTradeFlags(RecipeDB, 17557, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOE, F.DPS)
	self:addTradeAcquire(RecipeDB, 17557, A.TRAINER, 1386, A.TRAINER, 7948, A.TRAINER, 16588, A.TRAINER, 18802, A.TRAINER, 19052, A.TRAINER, 4611, A.TRAINER, 4160, A.TRAINER, 3603, A.TRAINER, 16723, A.TRAINER, 3347, A.TRAINER, 3009, A.TRAINER, 2837, A.TRAINER, 5177, A.TRAINER, 1470, A.TRAINER, 3964, A.TRAINER, 2132, A.TRAINER, 3184, A.TRAINER, 33608, A.TRAINER, 16642, A.TRAINER, 33674, A.TRAINER, 2391, A.TRAINER, 27023, A.TRAINER, 27029, A.TRAINER, 4900, A.TRAINER, 1215, A.TRAINER, 5499, A.TRAINER, 16161)

	-- Transmute: Air to Fire -- 17559
	AddRecipe(17559, 275, 7078, R_UNCOMMON, GAME_ORIG, 275, 275, 282, 290)
	self:addTradeFlags(RecipeDB, 17559, F.ALLIANCE, F.HORDE, F.QUEST, F.IBOE, F.RBOP, F.ARGENTDAWN)
	self:addTradeAcquire(RecipeDB, 17559, A.REPUTATION, FAC.ARGENTDAWN, REP.HONORED, 10856, A.REPUTATION, FAC.ARGENTDAWN, REP.HONORED, 10857, A.REPUTATION, FAC.ARGENTDAWN, REP.HONORED, 11536)

	-- Transmute: Fire to Earth -- 17560
	AddRecipe(17560, 275, 7076, R_UNCOMMON, GAME_ORIG, 275, 275, 282, 290)
	self:addTradeFlags(RecipeDB, 17560, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOP)
	self:addTradeAcquire(RecipeDB, 17560, A.VENDOR, 9499)

	-- Transmute: Earth to Water -- 17561
	AddRecipe(17561, 275, 7080, R_UNCOMMON, GAME_ORIG, 275, 275, 282, 290)
	self:addTradeFlags(RecipeDB, 17561, F.ALLIANCE, F.HORDE, F.QUEST, F.IBOE, F.RBOP, F.TIMBERMAW_HOLD)
	self:addTradeAcquire(RecipeDB, 17561, A.REPUTATION, FAC.TIMBERMAW_HOLD, REP.FRIENDLY, 11557)

	-- Transmute: Water to Air -- 17562
	AddRecipe(17562, 275, 7082, R_UNCOMMON, GAME_ORIG, 275, 275, 282, 290)
	self:addTradeFlags(RecipeDB, 17562, F.ALLIANCE, F.HORDE, F.QUEST, F.IBOE, F.RBOP)
	self:addTradeAcquire(RecipeDB, 17562, A.VENDOR, 11278)

	-- Transmute: Undeath to Water -- 17563
	AddRecipe(17563, 275, 7080, R_UNCOMMON, GAME_ORIG, 275, 275, 282, 290)
	self:addTradeFlags(RecipeDB, 17563, F.ALLIANCE, F.HORDE, F.WORLD_DROP, F.IBOE, F.RBOE)
	self:addTradeAcquire(RecipeDB, 17563, A.WORLD_DROP, 2)

	-- Transmute: Water to Undeath -- 17564
	AddRecipe(17564, 275, 12808, R_UNCOMMON, GAME_ORIG, 275, 275, 282, 290)
	self:addTradeFlags(RecipeDB, 17564, F.ALLIANCE, F.HORDE, F.WORLD_DROP, F.IBOE, F.RBOE)
	self:addTradeAcquire(RecipeDB, 17564, A.WORLD_DROP, 2)

	-- Transmute: Life to Earth -- 17565
	AddRecipe(17565, 275, 7076, R_UNCOMMON, GAME_ORIG, 275, 275, 282, 290)
	self:addTradeFlags(RecipeDB, 17565, F.ALLIANCE, F.HORDE, F.WORLD_DROP, F.IBOE, F.RBOE)
	self:addTradeAcquire(RecipeDB, 17565, A.WORLD_DROP, 2)

	-- Transmute: Earth to Life -- 17566
	AddRecipe(17566, 275, 12803, R_UNCOMMON, GAME_ORIG, 275, 275, 282, 290)
	self:addTradeFlags(RecipeDB, 17566, F.ALLIANCE, F.HORDE, F.WORLD_DROP, F.IBOE, F.RBOE)
	self:addTradeAcquire(RecipeDB, 17566, A.WORLD_DROP, 2)

	-- Greater Stoneshield Potion -- 17570
	AddRecipe(17570, 280, 13455, R_UNCOMMON, GAME_ORIG, 280, 295, 315, 335)
	self:addTradeFlags(RecipeDB, 17570, F.ALLIANCE, F.HORDE, F.WORLD_DROP, F.IBOE, F.RBOE)
	self:addTradeAcquire(RecipeDB, 17570, A.WORLD_DROP, 2)

	-- Elixir of the Mongoose -- 17571
	AddRecipe(17571, 280, 13452, R_UNCOMMON, GAME_ORIG, 280, 295, 315, 335)
	self:addTradeFlags(RecipeDB, 17571, F.ALLIANCE, F.HORDE, F.MOB_DROP, F.IBOE, F.RBOE, F.DPS)
	self:addTradeAcquire(RecipeDB, 17571, A.MOB, 6201, A.MOB, 7106)

	-- Purification Potion -- 17572
	AddRecipe(17572, 285, 13462, R_UNCOMMON, GAME_ORIG, 285, 300, 320, 340)
	self:addTradeFlags(RecipeDB, 17572, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOE)
	self:addTradeAcquire(RecipeDB, 17572, A.TRAINER, 1386, A.TRAINER, 7948, A.TRAINER, 16588, A.TRAINER, 18802, A.TRAINER, 19052, A.TRAINER, 4611, A.TRAINER, 4160, A.TRAINER, 3603, A.TRAINER, 16723, A.TRAINER, 3347, A.TRAINER, 3009, A.TRAINER, 2837, A.TRAINER, 5177, A.TRAINER, 1470, A.TRAINER, 3964, A.TRAINER, 2132, A.TRAINER, 3184, A.TRAINER, 33608, A.TRAINER, 16642, A.TRAINER, 33674, A.TRAINER, 2391, A.TRAINER, 27023, A.TRAINER, 27029, A.TRAINER, 4900, A.TRAINER, 1215, A.TRAINER, 5499, A.TRAINER, 16161)

	-- Greater Arcane Elixir -- 17573
	AddRecipe(17573, 285, 13454, R_UNCOMMON, GAME_ORIG, 285, 300, 320, 340)
	self:addTradeFlags(RecipeDB, 17573, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOE, F.HEALER, F.CASTER)
	self:addTradeAcquire(RecipeDB, 17573, A.TRAINER, 1386, A.TRAINER, 7948, A.TRAINER, 16588, A.TRAINER, 18802, A.TRAINER, 19052, A.TRAINER, 4611, A.TRAINER, 4160, A.TRAINER, 3603, A.TRAINER, 16723, A.TRAINER, 3347, A.TRAINER, 3009, A.TRAINER, 2837, A.TRAINER, 5177, A.TRAINER, 1470, A.TRAINER, 3964, A.TRAINER, 2132, A.TRAINER, 3184, A.TRAINER, 33608, A.TRAINER, 16642, A.TRAINER, 33674, A.TRAINER, 2391, A.TRAINER, 27023, A.TRAINER, 27029, A.TRAINER, 4900, A.TRAINER, 1215, A.TRAINER, 5499, A.TRAINER, 16161)

	-- Greater Fire Protection Potion -- 17574
	AddRecipe(17574, 290, 13457, R_UNCOMMON, GAME_ORIG, 290, 305, 325, 345)
	self:addTradeFlags(RecipeDB, 17574, F.ALLIANCE, F.HORDE, F.INSTANCE, F.IBOE, F.RBOE)
	self:addTradeAcquire(RecipeDB, 17574, A.MOB, 9262, A.MOB, 9264)

	-- Greater Frost Protection Potion -- 17575
	AddRecipe(17575, 290, 13456, R_UNCOMMON, GAME_ORIG, 290, 305, 325, 345)
	self:addTradeFlags(RecipeDB, 17575, F.ALLIANCE, F.HORDE, F.MOB_DROP, F.IBOE, F.RBOE)
	self:addTradeAcquire(RecipeDB, 17575, A.MOB, 7428)

	-- Greater Nature Protection Potion -- 17576
	AddRecipe(17576, 290, 13458, R_UNCOMMON, GAME_ORIG, 290, 305, 325, 345)
	self:addTradeFlags(RecipeDB, 17576, F.ALLIANCE, F.HORDE, F.MOB_DROP, F.IBOE, F.RBOE)
	self:addTradeAcquire(RecipeDB, 17576, A.MOB, 1812, A.MOB, 1813)

	-- Greater Arcane Protection Potion -- 17577
	AddRecipe(17577, 290, 13461, R_UNCOMMON, GAME_ORIG, 290, 305, 325, 345)
	self:addTradeFlags(RecipeDB, 17577, F.ALLIANCE, F.HORDE, F.MOB_DROP, F.IBOE, F.RBOE)
	self:addTradeAcquire(RecipeDB, 17577, A.MOB, 7437)

	-- Greater Shadow Protection Potion -- 17578
	AddRecipe(17578, 290, 13459, R_UNCOMMON, GAME_ORIG, 290, 305, 325, 345)
	self:addTradeFlags(RecipeDB, 17578, F.ALLIANCE, F.HORDE, F.MOB_DROP, F.IBOE, F.RBOE)
	self:addTradeAcquire(RecipeDB, 17578, A.MOB, 8546, A.MOB, 8550)

	-- Major Mana Potion -- 17580
	AddRecipe(17580, 295, 13444, R_UNCOMMON, GAME_ORIG, 295, 310, 330, 350)
	self:addTradeFlags(RecipeDB, 17580, F.ALLIANCE, F.HORDE, F.INSTANCE, F.QUEST, F.IBOE, F.RBOP)
	self:addTradeAcquire(RecipeDB, 17580, A.MOB, 1853, A.VENDOR, 11278)

	-- Alchemist's Stone -- 17632
	AddRecipe(17632, 350, 13503, R_COMMON, GAME_ORIG, 350, 365, 372, 380)
	self:addTradeFlags(RecipeDB, 17632, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOP, F.RBOP, F.HEALER, F.CASTER, F.TRINKET, F.SHATAR)
	self:addTradeAcquire(RecipeDB, 17632, A.REPUTATION, FAC.SHATAR, REP.REVERED, 21432)

	-- Potion of Petrification -- 17634
	AddRecipe(17634, 300, 13506, R_UNCOMMON, GAME_ORIG, 300, 315, 322, 330)
	self:addTradeFlags(RecipeDB, 17634, F.ALLIANCE, F.HORDE, F.WORLD_DROP, F.IBOE, F.RBOE)
	self:addTradeAcquire(RecipeDB, 17634, A.WORLD_DROP, 2)

	-- Flask of the Titans -- 17635
	AddRecipe(17635, 300, 13510, R_UNCOMMON, GAME_TBC, 300, 315, 322, 330)
	self:addTradeFlags(RecipeDB, 17635, F.ALLIANCE, F.HORDE, F.VENDOR, F.INSTANCE, F.IBOE, F.RBOP, F.TANK, F.SHATAR)
	self:addTradeAcquire(RecipeDB, 17635, A.MOB, 10363, A.REPUTATION, FAC.SHATAR, REP.EXALTED, 21432)

	-- Flask of Distilled Wisdom -- 17636
	AddRecipe(17636, 300, 13511, R_UNCOMMON, GAME_TBC, 300, 315, 322, 330)
	self:addTradeFlags(RecipeDB, 17636, F.ALLIANCE, F.HORDE, F.QUEST, F.IBOE, F.RBOP, F.HEALER, F.CASTER, F.CENARION_EXPEDITION)
	self:addTradeAcquire(RecipeDB, 17636, A.REPUTATION, FAC.CENARION_EXPEDITION, REP.EXALTED, 17904, A.MOB, 10813)

	-- Flask of Supreme Power -- 17637
	AddRecipe(17637, 300, 13512, R_UNCOMMON, GAME_TBC, 300, 315, 322, 330)
	self:addTradeFlags(RecipeDB, 17637, F.ALLIANCE, F.HORDE, F.INSTANCE, F.QUEST, F.IBOE, F.RBOP, F.HEALER, F.CASTER, F.KOT)
	self:addTradeAcquire(RecipeDB, 17637, A.MOB, 10508, A.REPUTATION, FAC.KEEPERS_OF_TIME, REP.EXALTED, 21643)

	-- Flask of Chromatic Resistance -- 17638
	AddRecipe(17638, 300, 13513, R_UNCOMMON, GAME_TBC, 300, 315, 322, 330)
	self:addTradeFlags(RecipeDB, 17638, F.ALLIANCE, F.HORDE, F.INSTANCE, F.QUEST, F.IBOE, F.RBOP, F.LOWERCITY)
	self:addTradeAcquire(RecipeDB, 17638, A.MOB, 10339, A.REPUTATION, FAC.LOWERCITY, REP.EXALTED, 21655)

	-- Elixir of Frost Power -- 21923
	AddRecipe(21923, 190, 17708, R_COMMON, GAME_ORIG, 190, 210, 230, 250)
	self:addTradeFlags(RecipeDB, 21923, F.ALLIANCE, F.HORDE, F.SEASONAL, F.IBOE, F.RBOE, F.HEALER, F.CASTER)
	self:addTradeAcquire(RecipeDB, 21923, A.SEASONAL, 1)

	-- Major Rejuvenation Potion -- 22732
	AddRecipe(22732, 300, 18253, R_RARE, GAME_ORIG, 300, 310, 320, 330)
	self:addTradeFlags(RecipeDB, 22732, F.ALLIANCE, F.HORDE, F.RAID, F.IBOE, F.RBOE)
	self:addTradeAcquire(RecipeDB, 22732, A.CUSTOM, 26)

	-- Elixir of Greater Water Breathing -- 22808
	AddRecipe(22808, 215, 18294, R_COMMON, GAME_ORIG, 215, 230, 250, 270)
	self:addTradeFlags(RecipeDB, 22808, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP)
	self:addTradeAcquire(RecipeDB, 22808, A.TRAINER, 1386, A.TRAINER, 4160, A.TRAINER, 4611, A.TRAINER, 7948, A.TRAINER, 16588, A.TRAINER, 18802, A.TRAINER, 19052, A.TRAINER, 16642, A.TRAINER, 27029, A.TRAINER, 3603, A.TRAINER, 16723, A.TRAINER, 3347, A.TRAINER, 3009, A.TRAINER, 2837, A.TRAINER, 5177, A.TRAINER, 1470, A.TRAINER, 3964, A.TRAINER, 2132, A.TRAINER, 3184, A.TRAINER, 33608, A.TRAINER, 33674, A.TRAINER, 2391, A.TRAINER, 27023, A.TRAINER, 4900, A.TRAINER, 1215, A.TRAINER, 16161)

	-- Gurubashi Mojo Madness -- 24266
	AddRecipe(24266, 300, 19931, R_RARE, GAME_ORIG, 300, 315, 322, 330)
	self:addTradeFlags(RecipeDB, 24266, F.ALLIANCE, F.HORDE, F.RAID, F.IBOE, F.RBOP)
	self:addTradeAcquire(RecipeDB, 24266, A.CUSTOM, 11)

	-- Mageblood Elixir -- 24365
	AddRecipe(24365, 275, 20007, R_COMMON, GAME_ORIG, 275, 290, 310, 330)
	self:addTradeFlags(RecipeDB, 24365, F.ALLIANCE, F.HORDE, F.QUEST, F.IBOE, F.RBOP, F.ZANDALAR)
	self:addTradeAcquire(RecipeDB, 24365, A.REPUTATION, FAC.ZANDALAR, REP.REVERED, 14921)

	-- Greater Dreamless Sleep Potion -- 24366
	AddRecipe(24366, 275, 20002, R_COMMON, GAME_ORIG, 275, 290, 310, 330)
	self:addTradeFlags(RecipeDB, 24366, F.ALLIANCE, F.HORDE, F.QUEST, F.IBOE, F.RBOP, F.ZANDALAR)
	self:addTradeAcquire(RecipeDB, 24366, A.REPUTATION, FAC.ZANDALAR, REP.FRIENDLY, 14921)

	-- Living Action Potion -- 24367
	AddRecipe(24367, 285, 20008, R_COMMON, GAME_ORIG, 285, 300, 320, 340)
	self:addTradeFlags(RecipeDB, 24367, F.ALLIANCE, F.HORDE, F.QUEST, F.IBOE, F.RBOP, F.ZANDALAR)
	self:addTradeAcquire(RecipeDB, 24367, A.REPUTATION, FAC.ZANDALAR, REP.EXALTED, 14921)

	-- Mighty Troll's Blood Elixir -- 24368
	AddRecipe(24368, 290, 20004, R_COMMON, GAME_ORIG, 290, 305, 325, 345)
	self:addTradeFlags(RecipeDB, 24368, F.ALLIANCE, F.HORDE, F.QUEST, F.IBOE, F.RBOP, F.ZANDALAR)
	self:addTradeAcquire(RecipeDB, 24368, A.REPUTATION, FAC.ZANDALAR, REP.HONORED, 14921)

	-- Transmute: Elemental Fire -- 25146
	AddRecipe(25146, 300, 7068, R_COMMON, GAME_ORIG, 300, 301, 305, 310)
	self:addTradeFlags(RecipeDB, 25146, F.ALLIANCE, F.HORDE, F.QUEST, F.IBOE, F.RBOP, F.THORIUM_BROTHERHOOD)
	self:addTradeAcquire(RecipeDB, 25146, A.REPUTATION, FAC.THORIUM_BROTHERHOOD, REP.FRIENDLY, 12944)

	-- Elixir of Greater Firepower -- 26277
	AddRecipe(26277, 250, 21546, R_UNCOMMON, GAME_ORIG, 250, 265, 285, 305)
	self:addTradeFlags(RecipeDB, 26277, F.ALLIANCE, F.HORDE, F.MOB_DROP, F.IBOE, F.RBOE, F.HEALER, F.CASTER)
	self:addTradeAcquire(RecipeDB, 26277, A.MOB, 5844, A.MOB, 5846, A.MOB, 8637)

	-- Elixir of Camouflage -- 28543
	AddRecipe(28543, 305, 22823, R_COMMON, GAME_TBC, 305, 320, 327, 335)
	self:addTradeFlags(RecipeDB, 28543, F.ALLIANCE, F.HORDE, F.TRAINER, F.VENDOR, F.IBOE, F.RBOE)
	self:addTradeAcquire(RecipeDB, 28543, A.VENDOR, 16588, A.VENDOR, 16641, A.VENDOR, 16705, A.VENDOR, 18802)

	-- Elixir of Major Strength -- 28544
	AddRecipe(28544, 305, 22824, R_COMMON, GAME_TBC, 305, 320, 327, 335)
	self:addTradeFlags(RecipeDB, 28544, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.DPS)
	self:addTradeAcquire(RecipeDB, 28544, A.TRAINER, 16588, A.TRAINER, 18802, A.TRAINER, 19052, A.TRAINER, 27029, A.TRAINER, 33608, A.TRAINER, 33674, A.TRAINER, 27023)

	-- Elixir of Healing Power -- 28545
	AddRecipe(28545, 310, 22825, R_COMMON, GAME_TBC, 310, 325, 332, 340)
	self:addTradeFlags(RecipeDB, 28545, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.HEALER, F.CASTER)
	self:addTradeAcquire(RecipeDB, 28545, A.TRAINER, 16588, A.TRAINER, 18802, A.TRAINER, 19052, A.TRAINER, 27029, A.TRAINER, 33608, A.TRAINER, 33674, A.TRAINER, 27023)

	-- Sneaking Potion -- 28546
	AddRecipe(28546, 315, 22826, R_COMMON, GAME_TBC, 315, 330, 337, 345)
	self:addTradeFlags(RecipeDB, 28546, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOE)
	self:addTradeAcquire(RecipeDB, 28546, A.VENDOR, 18017, A.VENDOR, 19042)

	-- Elixir of Major Frost Power -- 28549
	AddRecipe(28549, 320, 22827, R_COMMON, GAME_TBC, 320, 335, 342, 350)
	self:addTradeFlags(RecipeDB, 28549, F.ALLIANCE, F.HORDE, F.TRAINER, F.VENDOR, F.IBOE, F.RBOE, F.HEALER, F.CASTER)
	self:addTradeAcquire(RecipeDB, 28549, A.VENDOR, 18005, A.VENDOR, 18017)

	-- Insane Strength Potion -- 28550
	AddRecipe(28550, 320, 22828, R_UNCOMMON, GAME_TBC, 320, 335, 342, 350)
	self:addTradeFlags(RecipeDB, 28550, F.ALLIANCE, F.HORDE, F.WORLD_DROP, F.IBOE, F.RBOE, F.DPS)
	self:addTradeAcquire(RecipeDB, 28550, A.WORLD_DROP, 2)

	-- Super Healing Potion -- 28551
	AddRecipe(28551, 325, 22829, R_COMMON, GAME_TBC, 325, 340, 347, 355)
	self:addTradeFlags(RecipeDB, 28551, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP)
	self:addTradeAcquire(RecipeDB, 28551, A.TRAINER, 16588, A.TRAINER, 18802, A.TRAINER, 19052, A.TRAINER, 27029, A.TRAINER, 33608, A.TRAINER, 33674, A.TRAINER, 27023)

	-- Elixir of the Searching Eye -- 28552
	AddRecipe(28552, 325, 22830, R_UNCOMMON, GAME_TBC, 325, 340, 347, 355)
	self:addTradeFlags(RecipeDB, 28552, F.ALLIANCE, F.HORDE, F.WORLD_DROP, F.IBOE, F.RBOE)
	self:addTradeAcquire(RecipeDB, 28552, A.WORLD_DROP, 2)

	-- Elixir of Major Agility -- 28553
	AddRecipe(28553, 330, 22831, R_COMMON, GAME_TBC, 330, 345, 352, 360)
	self:addTradeFlags(RecipeDB, 28553, F.ALLIANCE, F.HORDE, F.QUEST, F.IBOE, F.RBOP, F.DPS, F.HELLFIRE)
	self:addTradeAcquire(RecipeDB, 28553, A.REPUTATION, FAC.HONOR_HOLD, REP.HONORED, 17657, A.REPUTATION, FAC.THRALLMAR, REP.HONORED, 17585)

	-- Shrouding Potion -- 28554
	AddRecipe(28554, 335, 22871, R_UNCOMMON, GAME_TBC, 335, 350, 357, 365)
	self:addTradeFlags(RecipeDB, 28554, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOP, F.SPOREGGAR)
	self:addTradeAcquire(RecipeDB, 28554, A.REPUTATION, FAC.SPOREGGAR, REP.EXALTED, 18382)

	-- Super Mana Potion -- 28555
	AddRecipe(28555, 340, 22832, R_COMMON, GAME_TBC, 340, 355, 362, 370)
	self:addTradeFlags(RecipeDB, 28555, F.ALLIANCE, F.HORDE, F.QUEST, F.IBOE, F.RBOE)
	self:addTradeAcquire(RecipeDB, 28555, A.VENDOR, 18005, A.VENDOR, 19837)

	-- Elixir of Major Firepower -- 28556
	AddRecipe(28556, 345, 22833, R_UNCOMMON, GAME_TBC, 345, 360, 367, 375)
	self:addTradeFlags(RecipeDB, 28556, F.ALLIANCE, F.HORDE, F.TRAINER, F.VENDOR, F.IBOE, F.RBOP, F.HEALER, F.CASTER, F.SCRYER)
	self:addTradeAcquire(RecipeDB, 28556, A.REPUTATION, FAC.SCRYER, REP.REVERED, 19331)

	-- Elixir of Major Defense -- 28557
	AddRecipe(28557, 345, 22834, R_COMMON, GAME_TBC, 345, 360, 367, 375)
	self:addTradeFlags(RecipeDB, 28557, F.ALLIANCE, F.HORDE, F.TRAINER, F.VENDOR, F.IBOE, F.RBOE, F.TANK)
	self:addTradeAcquire(RecipeDB, 28557, A.VENDOR, 18005, A.VENDOR, 19837)

	-- Elixir of Major Shadow Power -- 28558
	AddRecipe(28558, 350, 22835, R_UNCOMMON, GAME_TBC, 350, 365, 372, 380)
	self:addTradeFlags(RecipeDB, 28558, F.ALLIANCE, F.HORDE, F.QUEST, F.IBOE, F.RBOP, F.HEALER, F.CASTER, F.LOWERCITY)
	self:addTradeAcquire(RecipeDB, 28558, A.REPUTATION, FAC.LOWERCITY, REP.REVERED, 21655)

	-- Major Dreamless Sleep Potion -- 28562
	AddRecipe(28562, 350, 22836, R_COMMON, GAME_TBC, 350, 365, 372, 380)
	self:addTradeFlags(RecipeDB, 28562, F.ALLIANCE, F.HORDE, F.QUEST, F.IBOE, F.RBOE)
	self:addTradeAcquire(RecipeDB, 28562, A.VENDOR, 19042, A.VENDOR, 19837)

	-- Heroic Potion -- 28563
	AddRecipe(28563, 350, 22837, R_UNCOMMON, GAME_TBC, 350, 365, 372, 380)
	self:addTradeFlags(RecipeDB, 28563, F.ALLIANCE, F.HORDE, F.WORLD_DROP, F.IBOE, F.RBOE, F.DPS)
	self:addTradeAcquire(RecipeDB, 28563, A.WORLD_DROP, 2)

	-- Haste Potion -- 28564
	AddRecipe(28564, 350, 22838, R_UNCOMMON, GAME_TBC, 350, 365, 372, 380)
	self:addTradeFlags(RecipeDB, 28564, F.ALLIANCE, F.HORDE, F.MOB_DROP, F.IBOE, F.RBOP)
	self:addTradeAcquire(RecipeDB, 28564, A.MOB, 24664)

	-- Destruction Potion -- 28565
	AddRecipe(28565, 350, 22839, R_UNCOMMON, GAME_TBC, 350, 365, 372, 380)
	self:addTradeFlags(RecipeDB, 28565, F.ALLIANCE, F.HORDE, F.WORLD_DROP, F.IBOE, F.RBOE, F.HEALER, F.CASTER)
	self:addTradeAcquire(RecipeDB, 28565, A.WORLD_DROP, 2)

	-- Transmute: Primal Air to Fire -- 28566
	AddRecipe(28566, 350, 21884, R_UNCOMMON, GAME_TBC, 350, 365, 372, 380)
	self:addTradeFlags(RecipeDB, 28566, F.ALLIANCE, F.HORDE, F.QUEST, F.IBOE, F.RBOP, F.SHATAR)
	self:addTradeAcquire(RecipeDB, 28566, A.REPUTATION, FAC.SHATAR, REP.REVERED, 21432)

	-- Transmute: Primal Earth to Water -- 28567
	AddRecipe(28567, 350, 21885, R_UNCOMMON, GAME_TBC, 350, 365, 372, 380)
	self:addTradeFlags(RecipeDB, 28567, F.ALLIANCE, F.HORDE, F.QUEST, F.IBOE, F.RBOP, F.SPOREGGAR)
	self:addTradeAcquire(RecipeDB, 28567, A.REPUTATION, FAC.SPOREGGAR, REP.REVERED, 18382)

	-- Transmute: Primal Fire to Earth -- 28568
	AddRecipe(28568, 350, 22452, R_UNCOMMON, GAME_TBC, 350, 365, 372, 380)
	self:addTradeFlags(RecipeDB, 28568, F.ALLIANCE, F.HORDE, F.QUEST, F.IBOE, F.RBOP, F.NAGRAND)
	self:addTradeAcquire(RecipeDB, 28568, A.REPUTATION, FAC.KURENI, REP.REVERED, 20240)

	-- Transmute: Primal Water to Air -- 28569
	AddRecipe(28569, 350, 22451, R_UNCOMMON, GAME_TBC, 350, 365, 372, 380)
	self:addTradeFlags(RecipeDB, 28569, F.ALLIANCE, F.HORDE, F.QUEST, F.IBOE, F.RBOP, F.CENARION_EXPEDITION)
	self:addTradeAcquire(RecipeDB, 28569, A.REPUTATION, FAC.CENARION_EXPEDITION, REP.REVERED, 17904)

	-- Elixir of Major Mageblood -- 28570
	AddRecipe(28570, 355, 22840, R_UNCOMMON, GAME_TBC, 355, 370, 375, 380)
	self:addTradeFlags(RecipeDB, 28570, F.ALLIANCE, F.HORDE, F.WORLD_DROP, F.IBOE, F.RBOE)
	self:addTradeAcquire(RecipeDB, 28570, A.WORLD_DROP, 2)

	-- Major Fire Protection Potion -- 28571
	AddRecipe(28571, 360, 22841, R_UNCOMMON, GAME_TBC, 360, 375, 377, 380)
	self:addTradeFlags(RecipeDB, 28571, F.ALLIANCE, F.HORDE, F.INSTANCE, F.IBOE, F.RBOP)
	self:addTradeAcquire(RecipeDB, 28571, A.MOB, 19168, A.MOB, 19221)

	-- Major Frost Protection Potion -- 28572
	AddRecipe(28572, 360, 22842, R_UNCOMMON, GAME_TBC, 360, 375, 377, 380)
	self:addTradeFlags(RecipeDB, 28572, F.ALLIANCE, F.HORDE, F.INSTANCE, F.MOB_DROP, F.IBOE, F.RBOP)
	self:addTradeAcquire(RecipeDB, 28572, A.MOB, 18344)

	-- Major Nature Protection Potion -- 28573
	AddRecipe(28573, 360, 22844, R_COMMON, GAME_TBC, 360, 375, 377, 380)
	self:addTradeFlags(RecipeDB, 28573, F.ALLIANCE, F.HORDE, F.QUEST, F.IBOE, F.RBOP, F.CENARION_EXPEDITION)
	self:addTradeAcquire(RecipeDB, 28573, A.REPUTATION, FAC.CENARION_EXPEDITION, REP.EXALTED, 17904)

	-- Major Arcane Protection Potion -- 28575
	AddRecipe(28575, 360, 22845, R_UNCOMMON, GAME_TBC, 360, 375, 377, 380)
	self:addTradeFlags(RecipeDB, 28575, F.ALLIANCE, F.HORDE, F.MOB_DROP, F.IBOE, F.RBOP)
	self:addTradeAcquire(RecipeDB, 28575, A.MOB, 17150)

	-- Major Shadow Protection Potion -- 28576
	AddRecipe(28576, 360, 22846, R_UNCOMMON, GAME_TBC, 360, 375, 377, 380)
	self:addTradeFlags(RecipeDB, 28576, F.ALLIANCE, F.HORDE, F.MOB_DROP, F.IBOE, F.RBOP)
	self:addTradeAcquire(RecipeDB, 28576, A.MOB, 21302)

	-- Major Holy Protection Potion -- 28577
	AddRecipe(28577, 360, 22847, R_UNCOMMON, GAME_TBC, 360, 375, 377, 380)
	self:addTradeFlags(RecipeDB, 28577, F.ALLIANCE, F.HORDE, F.MOB_DROP, F.IBOE, F.RBOP)
	self:addTradeAcquire(RecipeDB, 28577, A.MOB, 19973)

	-- Elixir of Empowerment -- 28578
	AddRecipe(28578, 365, 22848, R_UNCOMMON, GAME_TBC, 365, 375, 377, 380)
	self:addTradeFlags(RecipeDB, 28578, F.ALLIANCE, F.HORDE, F.TRAINER, F.MOB_DROP, F.IBOE, F.RBOP)
	self:addTradeAcquire(RecipeDB, 28578, A.MOB, 24664)

	-- Ironshield Potion -- 28579
	AddRecipe(28579, 365, 22849, R_UNCOMMON, GAME_TBC, 365, 375, 377, 380)
	self:addTradeFlags(RecipeDB, 28579, F.ALLIANCE, F.HORDE, F.INSTANCE, F.IBOE, F.RBOP)
	self:addTradeAcquire(RecipeDB, 28579, A.MOB, 17862)

	-- Transmute: Primal Shadow to Water -- 28580
	AddRecipe(28580, 375, 21885, R_UNCOMMON, GAME_TBC, 375, 375, 377, 380)
	self:addTradeFlags(RecipeDB, 28580, F.ALLIANCE, F.HORDE, F.DISC, F.IBOE, F.RBOP)
	self:addTradeAcquire(RecipeDB, 28580, A.CUSTOM, 3)

	-- Transmute: Primal Water to Shadow -- 28581
	AddRecipe(28581, 375, 22456, R_UNCOMMON, GAME_TBC, 375, 375, 377, 380)
	self:addTradeFlags(RecipeDB, 28581, F.ALLIANCE, F.HORDE, F.DISC, F.IBOE, F.RBOP)
	self:addTradeAcquire(RecipeDB, 28581, A.CUSTOM, 3)

	-- Transmute: Primal Mana to Fire -- 28582
	AddRecipe(28582, 375, 21884, R_UNCOMMON, GAME_TBC, 375, 375, 377, 380)
	self:addTradeFlags(RecipeDB, 28582, F.ALLIANCE, F.HORDE, F.DISC, F.IBOE, F.RBOP)
	self:addTradeAcquire(RecipeDB, 28582, A.CUSTOM, 3)

	-- Transmute: Primal Fire to Mana -- 28583
	AddRecipe(28583, 375, 22457, R_UNCOMMON, GAME_TBC, 375, 375, 377, 380)
	self:addTradeFlags(RecipeDB, 28583, F.ALLIANCE, F.HORDE, F.DISC, F.IBOE, F.RBOP)
	self:addTradeAcquire(RecipeDB, 28583, A.CUSTOM, 3)

	-- Transmute: Primal Life to Earth -- 28584
	AddRecipe(28584, 375, 22452, R_UNCOMMON, GAME_TBC, 375, 375, 377, 380)
	self:addTradeFlags(RecipeDB, 28584, F.ALLIANCE, F.HORDE, F.DISC, F.IBOE, F.RBOP)
	self:addTradeAcquire(RecipeDB, 28584, A.CUSTOM, 3)

	-- Transmute: Primal Earth to Life -- 28585
	AddRecipe(28585, 375, 21886, R_UNCOMMON, GAME_TBC, 375, 375, 377, 380)
	self:addTradeFlags(RecipeDB, 28585, F.ALLIANCE, F.HORDE, F.DISC, F.IBOE, F.RBOP)
	self:addTradeAcquire(RecipeDB, 28585, A.CUSTOM, 3)

	-- Super Rejuvenation Potion -- 28586
	AddRecipe(28586, 375, 22850, R_COMMON, GAME_TBC, 375, 375, 377, 380)
	self:addTradeFlags(RecipeDB, 28586, F.ALLIANCE, F.HORDE, F.DISC, F.IBOE, F.RBOP)
	self:addTradeAcquire(RecipeDB, 28586, A.CUSTOM, 2)

	-- Flask of Fortification -- 28587
	AddRecipe(28587, 375, 22851, R_COMMON, GAME_TBC, 375, 375, 377, 380)
	self:addTradeFlags(RecipeDB, 28587, F.ALLIANCE, F.HORDE, F.DISC, F.IBOE, F.RBOP, F.TANK)
	self:addTradeAcquire(RecipeDB, 28587, A.CUSTOM, 1)

	-- Flask of Mighty Restoration -- 28588
	AddRecipe(28588, 375, 22853, R_COMMON, GAME_TBC, 375, 375, 377, 380)
	self:addTradeFlags(RecipeDB, 28588, F.ALLIANCE, F.HORDE, F.DISC, F.IBOE, F.RBOP)
	self:addTradeAcquire(RecipeDB, 28588, A.CUSTOM, 1)

	-- Flask of Relentless Assault -- 28589
	AddRecipe(28589, 375, 22854, R_COMMON, GAME_TBC, 375, 375, 377, 380)
	self:addTradeFlags(RecipeDB, 28589, F.ALLIANCE, F.HORDE, F.DISC, F.IBOE, F.RBOP, F.DPS)
	self:addTradeAcquire(RecipeDB, 28589, A.CUSTOM, 1)

	-- Flask of Blinding Light -- 28590
	AddRecipe(28590, 375, 22861, R_COMMON, GAME_TBC, 375, 375, 377, 380)
	self:addTradeFlags(RecipeDB, 28590, F.ALLIANCE, F.HORDE, F.DISC, F.IBOE, F.RBOP, F.HEALER, F.CASTER)
	self:addTradeAcquire(RecipeDB, 28590, A.CUSTOM, 1)

	-- Flask of Pure Death -- 28591
	AddRecipe(28591, 375, 22866, R_COMMON, GAME_TBC, 375, 375, 377, 380)
	self:addTradeFlags(RecipeDB, 28591, F.ALLIANCE, F.HORDE, F.DISC, F.IBOE, F.RBOP, F.HEALER, F.CASTER)
	self:addTradeAcquire(RecipeDB, 28591, A.CUSTOM, 1)

	-- Transmute: Primal Might -- 29688
	AddRecipe(29688, 350, 23571, R_UNCOMMON, GAME_TBC, 350, 365, 372, 380)
	self:addTradeFlags(RecipeDB, 29688, F.ALLIANCE, F.HORDE, F.QUEST, F.IBOE, F.RBOE)
	self:addTradeAcquire(RecipeDB, 29688, A.VENDOR, 16641, A.VENDOR, 16705, A.VENDOR, 19074)

	-- Transmute: Earthstorm Diamond -- 32765
	AddRecipe(32765, 350, 25867, R_COMMON, GAME_TBC, 350, 365, 372, 380)
	self:addTradeFlags(RecipeDB, 32765, F.ALLIANCE, F.HORDE, F.QUEST, F.IBOE, F.RBOP, F.CENARION_EXPEDITION)
	self:addTradeAcquire(RecipeDB, 32765, A.REPUTATION, FAC.CENARION_EXPEDITION, REP.HONORED, 17904)

	-- Transmute: Skyfire Diamond -- 32766
	AddRecipe(32766, 350, 25868, R_COMMON, GAME_TBC, 350, 365, 372, 380)
	self:addTradeFlags(RecipeDB, 32766, F.ALLIANCE, F.HORDE, F.QUEST, F.IBOE, F.RBOP, F.HELLFIRE)
	self:addTradeAcquire(RecipeDB, 32766, A.REPUTATION, FAC.HONOR_HOLD, REP.HONORED, 17657, A.REPUTATION, FAC.THRALLMAR, REP.HONORED, 17585)

	-- Volatile Healing Potion -- 33732
	AddRecipe(33732, 300, 28100, R_COMMON, GAME_TBC, 300, 315, 322, 330)
	self:addTradeFlags(RecipeDB, 33732, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP)
	self:addTradeAcquire(RecipeDB, 33732, A.TRAINER, 16588, A.TRAINER, 18802, A.TRAINER, 19052, A.TRAINER, 27029, A.TRAINER, 33608, A.TRAINER, 33674, A.TRAINER, 27023)

	-- Unstable Mana Potion -- 33733
	AddRecipe(33733, 310, 28101, R_COMMON, GAME_TBC, 310, 325, 332, 340)
	self:addTradeFlags(RecipeDB, 33733, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP)
	self:addTradeAcquire(RecipeDB, 33733, A.TRAINER, 16588, A.TRAINER, 18802, A.TRAINER, 19052, A.TRAINER, 27029, A.TRAINER, 33608, A.TRAINER, 33674, A.TRAINER, 27023)

	-- Onslaught Elixir -- 33738
	AddRecipe(33738, 300, 28102, R_COMMON, GAME_TBC, 300, 315, 322, 330)
	self:addTradeFlags(RecipeDB, 33738, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.DPS)
	self:addTradeAcquire(RecipeDB, 33738, A.TRAINER, 16588, A.TRAINER, 18802, A.TRAINER, 19052, A.TRAINER, 27029, A.TRAINER, 33608, A.TRAINER, 33674, A.TRAINER, 27023)

	-- Adept's Elixir -- 33740
	AddRecipe(33740, 300, 28103, R_COMMON, GAME_ORIG, 300, 315, 322, 330)
	self:addTradeFlags(RecipeDB, 33740, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.HEALER, F.CASTER)
	self:addTradeAcquire(RecipeDB, 33740, A.TRAINER, 16588, A.TRAINER, 18802, A.TRAINER, 19052, A.TRAINER, 27029, A.TRAINER, 33608, A.TRAINER, 33674, A.TRAINER, 27023)

	-- Elixir of Mastery -- 33741
	AddRecipe(33741, 315, 28104, R_COMMON, GAME_TBC, 315, 330, 337, 345)
	self:addTradeFlags(RecipeDB, 33741, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP)
	self:addTradeAcquire(RecipeDB, 33741, A.TRAINER, 16588, A.TRAINER, 18802, A.TRAINER, 19052, A.TRAINER, 27029, A.TRAINER, 33608, A.TRAINER, 33674, A.TRAINER, 27023)

	-- Mercurial Stone -- 38070
	AddRecipe(38070, 325, 31080, R_COMMON, GAME_TBC, 325, 340, 347, 355)
	self:addTradeFlags(RecipeDB, 38070, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.TRINKET)
	self:addTradeAcquire(RecipeDB, 38070, A.TRAINER, 16588, A.TRAINER, 18802, A.TRAINER, 19052, A.TRAINER, 27029, A.TRAINER, 33608, A.TRAINER, 33674, A.TRAINER, 27023)

	-- Fel Strength Elixir -- 38960
	AddRecipe(38960, 335, 31679, R_RARE, GAME_TBC, 335, 350, 357, 365)
	self:addTradeFlags(RecipeDB, 38960, F.ALLIANCE, F.HORDE, F.MOB_DROP, F.IBOE, F.RBOP, F.DPS)
	self:addTradeAcquire(RecipeDB, 38960, A.MOB, 19740, A.MOB, 19755, A.MOB, 21302, A.MOB, 21314)

	-- Fel Mana Potion -- 38961
	AddRecipe(38961, 360, 31677, R_RARE, GAME_TBC, 360, 375, 377, 380)
	self:addTradeFlags(RecipeDB, 38961, F.ALLIANCE, F.HORDE, F.MOB_DROP, F.IBOE, F.RBOP, F.HEALER, F.CASTER)
	self:addTradeAcquire(RecipeDB, 38961, A.MOB, 19792, A.MOB, 19795, A.MOB, 19796, A.MOB, 19806, A.MOB, 22016, A.MOB, 22017, A.MOB, 22018, A.MOB, 22076, A.MOB, 22093)

	-- Fel Regeneration Potion -- 38962
	AddRecipe(38962, 345, 31676, R_RARE, GAME_TBC, 345, 360, 367, 375)
	self:addTradeFlags(RecipeDB, 38962, F.ALLIANCE, F.HORDE, F.MOB_DROP, F.IBOE, F.RBOP)
	self:addTradeAcquire(RecipeDB, 38962, A.MOB, 19754, A.MOB, 19756, A.MOB, 20878, A.MOB, 20887)

	-- Elixir of Major Fortitude -- 39636
	AddRecipe(39636, 310, 32062, R_COMMON, GAME_TBC, 310, 325, 332, 340)
	self:addTradeFlags(RecipeDB, 39636, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP)
	self:addTradeAcquire(RecipeDB, 39636, A.TRAINER, 16588, A.TRAINER, 18802, A.TRAINER, 19052, A.TRAINER, 27029, A.TRAINER, 33608, A.TRAINER, 33674, A.TRAINER, 27023)

	-- Earthen Elixir -- 39637
	AddRecipe(39637, 320, 32063, R_COMMON, GAME_TBC, 320, 335, 342, 350)
	self:addTradeFlags(RecipeDB, 39637, F.ALLIANCE, F.HORDE, F.QUEST, F.IBOE, F.RBOP, F.CENARION_EXPEDITION)
	self:addTradeAcquire(RecipeDB, 39637, A.REPUTATION, FAC.CENARION_EXPEDITION, REP.HONORED, 17904)

	-- Elixir of Draenic Wisdom -- 39638
	AddRecipe(39638, 320, 32067, R_COMMON, GAME_TBC, 320, 335, 342, 350)
	self:addTradeFlags(RecipeDB, 39638, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.HEALER, F.CASTER)
	self:addTradeAcquire(RecipeDB, 39638, A.TRAINER, 16588, A.TRAINER, 18802, A.TRAINER, 19052, A.TRAINER, 27029, A.TRAINER, 33608, A.TRAINER, 33674, A.TRAINER, 27023)

	-- Elixir of Ironskin -- 39639
	AddRecipe(39639, 330, 32068, R_COMMON, GAME_TBC, 330, 345, 352, 360)
	self:addTradeFlags(RecipeDB, 39639, F.ALLIANCE, F.HORDE, F.QUEST, F.PVP, F.IBOE, F.RBOP)
	self:addTradeAcquire(RecipeDB, 39639, A.VENDOR, 18821, A.VENDOR, 18822)

	-- Cauldron of Major Arcane Protection -- 41458
	AddRecipe(41458, 360, 32839, R_COMMON, GAME_TBC, 360, 360, 370, 380)
	self:addTradeFlags(RecipeDB, 41458, F.ALLIANCE, F.HORDE, F.DISC, F.IBOE, F.RBOP)
	self:addTradeAcquire(RecipeDB, 41458, A.CUSTOM, 4)

	-- Cauldron of Major Fire Protection -- 41500
	AddRecipe(41500, 360, 32849, R_COMMON, GAME_TBC, 360, 360, 370, 380)
	self:addTradeFlags(RecipeDB, 41500, F.ALLIANCE, F.HORDE, F.DISC, F.IBOE, F.RBOP)
	self:addTradeAcquire(RecipeDB, 41500, A.CUSTOM, 4)

	-- Cauldron of Major Frost Protection -- 41501
	AddRecipe(41501, 360, 32850, R_COMMON, GAME_TBC, 360, 360, 370, 380)
	self:addTradeFlags(RecipeDB, 41501, F.ALLIANCE, F.HORDE, F.DISC, F.IBOE, F.RBOP)
	self:addTradeAcquire(RecipeDB, 41501, A.CUSTOM, 4)

	-- Cauldron of Major Nature Protection -- 41502
	AddRecipe(41502, 360, 32851, R_COMMON, GAME_TBC, 360, 360, 370, 380)
	self:addTradeFlags(RecipeDB, 41502, F.ALLIANCE, F.HORDE, F.DISC, F.IBOE, F.RBOP)
	self:addTradeAcquire(RecipeDB, 41502, A.CUSTOM, 4)

	-- Cauldron of Major Shadow Protection -- 41503
	AddRecipe(41503, 360, 32852, R_COMMON, GAME_TBC, 360, 360, 370, 380)
	self:addTradeFlags(RecipeDB, 41503, F.ALLIANCE, F.HORDE, F.DISC, F.IBOE, F.RBOP)
	self:addTradeAcquire(RecipeDB, 41503, A.CUSTOM, 4)

	-- Flask of Chromatic Wonder -- 42736
	AddRecipe(42736, 375, 33208, R_UNCOMMON, GAME_TBC, 375, 390, 397, 405)
	self:addTradeFlags(RecipeDB, 42736, F.ALLIANCE, F.HORDE, F.QUEST, F.IBOE, F.RBOE, F.VIOLETEYE)
	self:addTradeAcquire(RecipeDB, 42736, A.REPUTATION, FAC.VIOLETEYE, REP.HONORED, 18255)

	-- Mad Alchemist's Potion -- 45061
	AddRecipe(45061, 325, 34440, R_COMMON, GAME_TBC, 325, 335, 342, 350)
	self:addTradeFlags(RecipeDB, 45061, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP)
	self:addTradeAcquire(RecipeDB, 45061, A.TRAINER, 16588, A.TRAINER, 18802, A.TRAINER, 19052, A.TRAINER, 27023, A.TRAINER, 27029, A.TRAINER, 33608, A.TRAINER, 33674)

	-- Guardian's Alchemist Stone -- 47046
	AddRecipe(47046, 375, 35748, R_COMMON, GAME_TBC, 375, 380, 385, 390)
	self:addTradeFlags(RecipeDB, 47046, F.ALLIANCE, F.HORDE, F.QUEST, F.IBOP, F.RBOP, F.TANK, F.TRINKET, F.SHATTEREDSUN)
	self:addTradeAcquire(RecipeDB, 47046, A.REPUTATION, FAC.SHATTEREDSUN, REP.EXALTED, 25032)

	-- Sorcerer's Alchemist Stone -- 47048
	AddRecipe(47048, 375, 35749, R_COMMON, GAME_TBC, 375, 380, 385, 390)
	self:addTradeFlags(RecipeDB, 47048, F.ALLIANCE, F.HORDE, F.QUEST, F.IBOP, F.RBOP, F.HEALER, F.CASTER, F.TRINKET, F.SHATTEREDSUN)
	self:addTradeAcquire(RecipeDB, 47048, A.REPUTATION, FAC.SHATTEREDSUN, REP.EXALTED, 25032)

	-- Redeemer's Alchemist Stone -- 47049
	AddRecipe(47049, 375, 35750, R_COMMON, GAME_TBC, 375, 380, 385, 390)
	self:addTradeFlags(RecipeDB, 47049, F.ALLIANCE, F.HORDE, F.QUEST, F.IBOP, F.RBOP, F.HEALER, F.CASTER, F.TRINKET, F.SHATTEREDSUN)
	self:addTradeAcquire(RecipeDB, 47049, A.REPUTATION, FAC.SHATTEREDSUN, REP.EXALTED, 25032)

	-- Assassin's Alchemist Stone -- 47050
	AddRecipe(47050, 375, 35751, R_COMMON, GAME_TBC, 375, 380, 385, 390)
	self:addTradeFlags(RecipeDB, 47050, F.ALLIANCE, F.HORDE, F.QUEST, F.IBOP, F.RBOP, F.DPS, F.TRINKET, F.SHATTEREDSUN)
	self:addTradeAcquire(RecipeDB, 47050, A.REPUTATION, FAC.SHATTEREDSUN, REP.EXALTED, 25032)

	-- Transmute: Eternal Life to Shadow -- 53771
	AddRecipe(53771, 405, 35627, R_UNCOMMON, GAME_WOTLK, 405, 405, 415, 425)
	self:addTradeFlags(RecipeDB, 53771, F.ALLIANCE, F.HORDE, F.DISC, F.IBOE, F.RBOP)
	self:addTradeAcquire(RecipeDB, 53771, A.CUSTOM, 19)

	-- Transmute: Eternal Life to Fire -- 53773
	AddRecipe(53773, 405, 36860, R_UNCOMMON, GAME_WOTLK, 405, 405, 415, 425)
	self:addTradeFlags(RecipeDB, 53773, F.ALLIANCE, F.HORDE, F.DISC, F.IBOE, F.RBOP)
	self:addTradeAcquire(RecipeDB, 53773, A.CUSTOM, 19)

	-- Transmute: Eternal Fire to Water -- 53774
	AddRecipe(53774, 405, 35622, R_UNCOMMON, GAME_WOTLK, 405, 405, 415, 425)
	self:addTradeFlags(RecipeDB, 53774, F.ALLIANCE, F.HORDE, F.DISC, F.IBOE, F.RBOP)
	self:addTradeAcquire(RecipeDB, 53774, A.CUSTOM, 19)

	-- Transmute: Eternal Fire to Life -- 53775
	AddRecipe(53775, 405, 35625, R_UNCOMMON, GAME_WOTLK, 405, 405, 415, 425)
	self:addTradeFlags(RecipeDB, 53775, F.ALLIANCE, F.HORDE, F.DISC, F.IBOE, F.RBOP)
	self:addTradeAcquire(RecipeDB, 53775, A.CUSTOM, 19)

	-- Transmute: Eternal Air to Water -- 53776
	AddRecipe(53776, 405, 35622, R_UNCOMMON, GAME_WOTLK, 405, 405, 415, 425)
	self:addTradeFlags(RecipeDB, 53776, F.ALLIANCE, F.HORDE, F.DISC, F.IBOE, F.RBOP)
	self:addTradeAcquire(RecipeDB, 53776, A.CUSTOM, 19)

	-- Transmute: Eternal Air to Earth -- 53777
	AddRecipe(53777, 405, 35624, R_UNCOMMON, GAME_WOTLK, 405, 405, 415, 425)
	self:addTradeFlags(RecipeDB, 53777, F.ALLIANCE, F.HORDE, F.DISC, F.IBOE, F.RBOP)
	self:addTradeAcquire(RecipeDB, 53777, A.CUSTOM, 19)

	-- Transmute: Eternal Shadow to Earth -- 53779
	AddRecipe(53779, 405, 35624, R_UNCOMMON, GAME_WOTLK, 405, 405, 415, 425)
	self:addTradeFlags(RecipeDB, 53779, F.ALLIANCE, F.HORDE, F.DISC, F.IBOE, F.RBOP)
	self:addTradeAcquire(RecipeDB, 53779, A.CUSTOM, 19)

	-- Transmute: Eternal Shadow to Life -- 53780
	AddRecipe(53780, 405, 35625, R_UNCOMMON, GAME_WOTLK, 405, 405, 415, 425)
	self:addTradeFlags(RecipeDB, 53780, F.ALLIANCE, F.HORDE, F.DISC, F.IBOE, F.RBOP)
	self:addTradeAcquire(RecipeDB, 53780, A.CUSTOM, 19)

	-- Transmute: Eternal Earth to Air -- 53781
	AddRecipe(53781, 405, 35623, R_UNCOMMON, GAME_WOTLK, 405, 405, 415, 425)
	self:addTradeFlags(RecipeDB, 53781, F.ALLIANCE, F.HORDE, F.DISC, F.IBOE, F.RBOP)
	self:addTradeAcquire(RecipeDB, 53781, A.CUSTOM, 19)

	-- Transmute: Eternal Earth to Shadow -- 53782
	AddRecipe(53782, 405, 35627, R_UNCOMMON, GAME_WOTLK, 405, 405, 415, 425)
	self:addTradeFlags(RecipeDB, 53782, F.ALLIANCE, F.HORDE, F.DISC, F.IBOE, F.RBOP)
	self:addTradeAcquire(RecipeDB, 53782, A.CUSTOM, 19)

	-- Transmute: Eternal Water to Air -- 53783
	AddRecipe(53783, 405, 35623, R_UNCOMMON, GAME_WOTLK, 405, 405, 415, 425)
	self:addTradeFlags(RecipeDB, 53783, F.ALLIANCE, F.HORDE, F.DISC, F.IBOE, F.RBOP)
	self:addTradeAcquire(RecipeDB, 53783, A.CUSTOM, 19)

	-- Transmute: Eternal Water to Fire -- 53784
	AddRecipe(53784, 405, 36860, R_UNCOMMON, GAME_WOTLK, 405, 405, 415, 425)
	self:addTradeFlags(RecipeDB, 53784, F.ALLIANCE, F.HORDE, F.DISC, F.IBOE, F.RBOP)
	self:addTradeAcquire(RecipeDB, 53784, A.CUSTOM, 19)

	-- Pygmy Oil -- 53812
	AddRecipe(53812, 375, 40195, R_COMMON, GAME_WOTLK, 375, 380, 385, 390)
	self:addTradeFlags(RecipeDB, 53812, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP)
	self:addTradeAcquire(RecipeDB, 53812, A.TRAINER, 26903, A.TRAINER, 26951, A.TRAINER, 26975, A.TRAINER, 26987, A.TRAINER, 28703, A.TRAINER, 33588)

	-- Runic Healing Potion -- 53836
	AddRecipe(53836, 405, 33447, R_COMMON, GAME_WOTLK, 405, 415, 420, 425)
	self:addTradeFlags(RecipeDB, 53836, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP)
	self:addTradeAcquire(RecipeDB, 53836, A.TRAINER, 26903, A.TRAINER, 26951, A.TRAINER, 26975, A.TRAINER, 26987, A.TRAINER, 28703, A.TRAINER, 33588)

	-- Runic Mana Potion -- 53837
	AddRecipe(53837, 410, 33448, R_COMMON, GAME_WOTLK, 410, 420, 425, 430)
	self:addTradeFlags(RecipeDB, 53837, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP)
	self:addTradeAcquire(RecipeDB, 53837, A.TRAINER, 26903, A.TRAINER, 26951, A.TRAINER, 26975, A.TRAINER, 26987, A.TRAINER, 28703, A.TRAINER, 33588)

	-- Resurgent Healing Potion -- 53838
	AddRecipe(53838, 350, 39671, R_COMMON, GAME_WOTLK, 350, 360, 365, 370)
	self:addTradeFlags(RecipeDB, 53838, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP)
	self:addTradeAcquire(RecipeDB, 53838, A.TRAINER, 26903, A.TRAINER, 26951, A.TRAINER, 26975, A.TRAINER, 26987, A.TRAINER, 28703, A.TRAINER, 33588)

	-- Icy Mana Potion -- 53839
	AddRecipe(53839, 360, 40067, R_COMMON, GAME_WOTLK, 360, 370, 375, 380)
	self:addTradeFlags(RecipeDB, 53839, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP)
	self:addTradeAcquire(RecipeDB, 53839, A.TRAINER, 26903, A.TRAINER, 26951, A.TRAINER, 26975, A.TRAINER, 26987, A.TRAINER, 28703, A.TRAINER, 33588)

	-- Elixir of Mighty Agility -- 53840
	AddRecipe(53840, 395, 39666, R_COMMON, GAME_WOTLK, 395, 405, 410, 415)
	self:addTradeFlags(RecipeDB, 53840, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.DPS)
	self:addTradeAcquire(RecipeDB, 53840, A.TRAINER, 26903, A.TRAINER, 26951, A.TRAINER, 26975, A.TRAINER, 26987, A.TRAINER, 28703, A.TRAINER, 33588)

	-- Wrath Elixir -- 53841
	AddRecipe(53841, 355, 40068, R_COMMON, GAME_WOTLK, 355, 365, 370, 375)
	self:addTradeFlags(RecipeDB, 53841, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.DPS)
	self:addTradeAcquire(RecipeDB, 53841, A.TRAINER, 26903, A.TRAINER, 26951, A.TRAINER, 26975, A.TRAINER, 26987, A.TRAINER, 28703, A.TRAINER, 33588)

	-- Spellpower Elixir -- 53842
	AddRecipe(53842, 365, 40070, R_COMMON, GAME_WOTLK, 365, 375, 380, 385)
	self:addTradeFlags(RecipeDB, 53842, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.HEALER, F.CASTER)
	self:addTradeAcquire(RecipeDB, 53842, A.TRAINER, 26903, A.TRAINER, 26951, A.TRAINER, 26975, A.TRAINER, 26987, A.TRAINER, 28703, A.TRAINER, 33588)

	-- Elixir of Spirit -- 53847
	AddRecipe(53847, 385, 40072, R_COMMON, GAME_WOTLK, 385, 395, 400, 405)
	self:addTradeFlags(RecipeDB, 53847, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.HEALER, F.CASTER)
	self:addTradeAcquire(RecipeDB, 53847, A.TRAINER, 26903, A.TRAINER, 26951, A.TRAINER, 26975, A.TRAINER, 26987, A.TRAINER, 28703, A.TRAINER, 33588)

	-- Guru's Elixir -- 53848
	AddRecipe(53848, 375, 40076, R_COMMON, GAME_WOTLK, 375, 385, 390, 395)
	self:addTradeFlags(RecipeDB, 53848, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP)
	self:addTradeAcquire(RecipeDB, 53848, A.TRAINER, 26903, A.TRAINER, 26951, A.TRAINER, 26975, A.TRAINER, 26987, A.TRAINER, 28703, A.TRAINER, 33588)

	-- Crazy Alchemist's Potion -- 53895
	AddRecipe(53895, 400, 40077, R_COMMON, GAME_WOTLK, 400, 410, 415, 420)
	self:addTradeFlags(RecipeDB, 53895, F.ALLIANCE, F.HORDE, F.DISC, F.IBOE, F.RBOP)
	self:addTradeAcquire(RecipeDB, 53895, A.CUSTOM, 18)

	-- Elixir of Mighty Fortitude -- 53898
	AddRecipe(53898, 390, 40078, R_COMMON, GAME_WOTLK, 390, 400, 405, 410)
	self:addTradeFlags(RecipeDB, 53898, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP)
	self:addTradeAcquire(RecipeDB, 53898, A.TRAINER, 26903, A.TRAINER, 26951, A.TRAINER, 26975, A.TRAINER, 26987, A.TRAINER, 28703, A.TRAINER, 33588)

	-- Lesser Flask of Toughness -- 53899
	AddRecipe(53899, 375, 40079, R_COMMON, GAME_WOTLK, 375, 385, 390, 395)
	self:addTradeFlags(RecipeDB, 53899, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP)
	self:addTradeAcquire(RecipeDB, 53899, A.TRAINER, 26903, A.TRAINER, 26951, A.TRAINER, 26975, A.TRAINER, 26987, A.TRAINER, 28703, A.TRAINER, 33588)

	-- Potion of Nightmares -- 53900
	AddRecipe(53900, 380, 40081, R_COMMON, GAME_WOTLK, 380, 390, 395, 400)
	self:addTradeFlags(RecipeDB, 53900, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP)
	self:addTradeAcquire(RecipeDB, 53900, A.TRAINER, 26903, A.TRAINER, 26951, A.TRAINER, 26975, A.TRAINER, 26987, A.TRAINER, 28703, A.TRAINER, 33588)

	-- Flask of the Frost Wyrm -- 53901
	AddRecipe(53901, 435, 40082, R_COMMON, GAME_WOTLK, 435, 445, 450, 455)
	self:addTradeFlags(RecipeDB, 53901, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.HEALER, F.CASTER)
	self:addTradeAcquire(RecipeDB, 53901, A.TRAINER, 26903, A.TRAINER, 26951, A.TRAINER, 26975, A.TRAINER, 26987, A.TRAINER, 28703, A.TRAINER, 33588)

	-- Flask of Stoneblood -- 53902
	AddRecipe(53902, 435, 40083, R_COMMON, GAME_WOTLK, 435, 445, 450, 455)
	self:addTradeFlags(RecipeDB, 53902, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP)
	self:addTradeAcquire(RecipeDB, 53902, A.TRAINER, 26903, A.TRAINER, 26951, A.TRAINER, 26975, A.TRAINER, 26987, A.TRAINER, 28703, A.TRAINER, 33588)

	-- Flask of Endless Rage -- 53903
	AddRecipe(53903, 435, 40084, R_COMMON, GAME_WOTLK, 435, 445, 450, 455)
	self:addTradeFlags(RecipeDB, 53903, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.DPS)
	self:addTradeAcquire(RecipeDB, 53903, A.TRAINER, 26903, A.TRAINER, 26951, A.TRAINER, 26975, A.TRAINER, 26987, A.TRAINER, 28703, A.TRAINER, 33588)

	-- Powerful Rejuvenation Potion -- 53904
	AddRecipe(53904, 400, 40087, R_COMMON, GAME_WOTLK, 400, 410, 415, 420)
	self:addTradeFlags(RecipeDB, 53904, F.ALLIANCE, F.HORDE, F.DISC, F.IBOE, F.RBOP)
	self:addTradeAcquire(RecipeDB, 53904, A.CUSTOM, 18)

	-- Indestructible Potion -- 53905
	AddRecipe(53905, 395, 40093, R_COMMON, GAME_WOTLK, 395, 405, 410, 415)
	self:addTradeFlags(RecipeDB, 53905, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP)
	self:addTradeAcquire(RecipeDB, 53905, A.TRAINER, 26903, A.TRAINER, 26951, A.TRAINER, 26975, A.TRAINER, 26987, A.TRAINER, 28703, A.TRAINER, 33588)

	-- Mighty Arcane Protection Potion -- 53936
	AddRecipe(53936, 400, 40213, R_UNCOMMON, GAME_WOTLK, 400, 410, 415, 420)
	self:addTradeFlags(RecipeDB, 53936, F.ALLIANCE, F.HORDE, F.MOB_DROP, F.IBOE, F.RBOP)
	self:addTradeAcquire(RecipeDB, 53936, A.MOB, 32297, A.MOB, 31702)

	-- Mighty Frost Protection Potion -- 53937
	AddRecipe(53937, 400, 40215, R_UNCOMMON, GAME_WOTLK, 400, 410, 415, 420)
	self:addTradeFlags(RecipeDB, 53937, F.ALLIANCE, F.HORDE, F.MOB_DROP, F.IBOE, F.RBOP)
	self:addTradeAcquire(RecipeDB, 53937, A.MOB, 32289)

	-- Mighty Shadow Protection Potion -- 53938
	AddRecipe(53938, 400, 40217, R_UNCOMMON, GAME_WOTLK, 400, 410, 415, 420)
	self:addTradeFlags(RecipeDB, 53938, F.ALLIANCE, F.HORDE, F.MOB_DROP, F.IBOE, F.RBOP)
	self:addTradeAcquire(RecipeDB, 53938, A.MOB, 32349)

	-- Mighty Fire Protection Potion -- 53939
	AddRecipe(53939, 400, 40214, R_UNCOMMON, GAME_WOTLK, 400, 410, 415, 420)
	self:addTradeFlags(RecipeDB, 53939, F.ALLIANCE, F.HORDE, F.MOB_DROP, F.IBOE, F.RBOP)
	self:addTradeAcquire(RecipeDB, 53939, A.MOB, 30921)

	-- Mighty Nature Protection Potion -- 53942
	AddRecipe(53942, 400, 40216, R_UNCOMMON, GAME_WOTLK, 400, 410, 415, 420)
	self:addTradeFlags(RecipeDB, 53942, F.ALLIANCE, F.HORDE, F.MOB_DROP, F.IBOE, F.RBOP)
	self:addTradeAcquire(RecipeDB, 53942, A.MOB, 32290)

	-- Flask of Pure Mojo -- 54213
	AddRecipe(54213, 435, 40404, R_COMMON, GAME_WOTLK, 435, 445, 450, 455)
	self:addTradeFlags(RecipeDB, 54213, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP)
	self:addTradeAcquire(RecipeDB, 54213, A.TRAINER, 26903, A.TRAINER, 26951, A.TRAINER, 26975, A.TRAINER, 26987, A.TRAINER, 28703, A.TRAINER, 33588)

	-- Elixir of Mighty Strength -- 54218
	AddRecipe(54218, 385, 40073, R_COMMON, GAME_WOTLK, 385, 395, 400, 405)
	self:addTradeFlags(RecipeDB, 54218, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.DPS)
	self:addTradeAcquire(RecipeDB, 54218, A.TRAINER, 26903, A.TRAINER, 26951, A.TRAINER, 26975, A.TRAINER, 26987, A.TRAINER, 28703, A.TRAINER, 33588)

	-- Elixir of Protection -- 54220
	AddRecipe(54220, 400, 40097, R_COMMON, GAME_WOTLK, 400, 410, 415, 420)
	self:addTradeFlags(RecipeDB, 54220, F.ALLIANCE, F.HORDE, F.DISC, F.IBOE, F.RBOP)
	self:addTradeAcquire(RecipeDB, 54220, A.CUSTOM, 18)

	-- Potion of Speed -- 54221
	AddRecipe(54221, 400, 40211, R_COMMON, GAME_WOTLK, 400, 410, 415, 420)
	self:addTradeFlags(RecipeDB, 54221, F.ALLIANCE, F.HORDE, F.DISC, F.IBOE, F.RBOP)
	self:addTradeAcquire(RecipeDB, 54221, A.CUSTOM, 18)

	-- Potion of Wild Magic -- 54222
	AddRecipe(54222, 400, 40212, R_COMMON, GAME_WOTLK, 400, 410, 415, 420)
	self:addTradeFlags(RecipeDB, 54222, F.ALLIANCE, F.HORDE, F.DISC, F.IBOE, F.RBOP, F.HEALER, F.CASTER)
	self:addTradeAcquire(RecipeDB, 54222, A.CUSTOM, 18)

	-- Elixir of Mighty Mageblood -- 56519
	AddRecipe(56519, 400, 40109, R_COMMON, GAME_WOTLK, 400, 410, 415, 420)
	self:addTradeFlags(RecipeDB, 56519, F.ALLIANCE, F.HORDE, F.DISC, F.IBOE, F.RBOP)
	self:addTradeAcquire(RecipeDB, 56519, A.CUSTOM, 18)

	-- Transmute: Skyflare Diamond -- 57425
	AddRecipe(57425, 430, 41266, R_RARE, GAME_WOTLK, 430, 440, 445, 450)
	self:addTradeFlags(RecipeDB, 57425, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP)
	self:addTradeAcquire(RecipeDB, 57425, A.TRAINER, 26903, A.TRAINER, 26951, A.TRAINER, 26975, A.TRAINER, 26987, A.TRAINER, 28703, A.TRAINER, 33588)

	-- Transmute: Earthsiege Diamond -- 57427
	AddRecipe(57427, 425, 41334, R_RARE, GAME_WOTLK, 425, 435, 440, 445)
	self:addTradeFlags(RecipeDB, 57427, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP)
	self:addTradeAcquire(RecipeDB, 57427, A.TRAINER, 26903, A.TRAINER, 26951, A.TRAINER, 26975, A.TRAINER, 26987, A.TRAINER, 28703, A.TRAINER, 33588)

	-- Endless Mana Potion -- 58868
	AddRecipe(58868, 410, 43570, R_COMMON, GAME_WOTLK, 410, 420, 425, 430)
	self:addTradeFlags(RecipeDB, 58868, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOP, F.RBOP)
	self:addTradeAcquire(RecipeDB, 58868, A.TRAINER, 26903, A.TRAINER, 26951, A.TRAINER, 26975, A.TRAINER, 26987, A.TRAINER, 28703, A.TRAINER, 33588)

	-- Endless Healing Potion -- 58871
	AddRecipe(58871, 410, 43569, R_COMMON, GAME_WOTLK, 410, 420, 425, 430)
	self:addTradeFlags(RecipeDB, 58871, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOP, F.RBOP)
	self:addTradeAcquire(RecipeDB, 58871, A.TRAINER, 26903, A.TRAINER, 26951, A.TRAINER, 26975, A.TRAINER, 26987, A.TRAINER, 28703, A.TRAINER, 33588)

	-- Transmute: Titanium -- 60350
	AddRecipe(60350, 395, 41163, R_UNCOMMON, GAME_WOTLK, 395, 405, 410, 415)
	self:addTradeFlags(RecipeDB, 60350, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP)
	self:addTradeAcquire(RecipeDB, 60350, A.TRAINER, 26903, A.TRAINER, 26951, A.TRAINER, 26975, A.TRAINER, 26987, A.TRAINER, 28703, A.TRAINER, 33588)

	-- Elixir of Accuracy -- 60354
	AddRecipe(60354, 400, 44325, R_COMMON, GAME_WOTLK, 400, 415, 422, 430)
	self:addTradeFlags(RecipeDB, 60354, F.ALLIANCE, F.HORDE, F.DISC, F.IBOE, F.RBOP)
	self:addTradeAcquire(RecipeDB, 60354, A.CUSTOM, 18)

	-- Elixir of Deadly Strikes -- 60355
	AddRecipe(60355, 400, 44327, R_COMMON, GAME_WOTLK, 400, 410, 415, 420)
	self:addTradeFlags(RecipeDB, 60355, F.ALLIANCE, F.HORDE, F.DISC, F.IBOE, F.RBOP)
	self:addTradeAcquire(RecipeDB, 60355, A.CUSTOM, 18)

	-- Elixir of Mighty Defense -- 60356
	AddRecipe(60356, 400, 44328, R_COMMON, GAME_WOTLK, 400, 410, 415, 420)
	self:addTradeFlags(RecipeDB, 60356, F.ALLIANCE, F.HORDE, F.DISC, F.IBOE, F.RBOP, F.TANK)
	self:addTradeAcquire(RecipeDB, 60356, A.CUSTOM, 18)

	-- Elixir of Expertise -- 60357
	AddRecipe(60357, 400, 44329, R_COMMON, GAME_WOTLK, 400, 410, 415, 420)
	self:addTradeFlags(RecipeDB, 60357, F.ALLIANCE, F.HORDE, F.DISC, F.IBOE, F.RBOP, F.DPS)
	self:addTradeAcquire(RecipeDB, 60357, A.CUSTOM, 18)

	-- Elixir of Armor Piercing -- 60365
	AddRecipe(60365, 400, 44330, R_COMMON, GAME_WOTLK, 400, 410, 415, 420)
	self:addTradeFlags(RecipeDB, 60365, F.ALLIANCE, F.HORDE, F.DISC, F.IBOE, F.RBOP, F.DPS)
	self:addTradeAcquire(RecipeDB, 60365, A.CUSTOM, 18)

	-- Elixir of Lightning Speed -- 60366
	AddRecipe(60366, 400, 44331, R_COMMON, GAME_WOTLK, 400, 410, 415, 420)
	self:addTradeFlags(RecipeDB, 60366, F.ALLIANCE, F.HORDE, F.DISC, F.IBOE, F.RBOP)
	self:addTradeAcquire(RecipeDB, 60366, A.CUSTOM, 18)

	-- Elixir of Mighty Thoughts -- 60367
	AddRecipe(60367, 395, 44332, R_COMMON, GAME_WOTLK, 395, 405, 410, 415)
	self:addTradeFlags(RecipeDB, 60367, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP)
	self:addTradeAcquire(RecipeDB, 60367, A.TRAINER, 26903, A.TRAINER, 26951, A.TRAINER, 26975, A.TRAINER, 26987, A.TRAINER, 28703, A.TRAINER, 33588)

	-- Mercurial Alchemist Stone -- 60396
	AddRecipe(60396, 400, 44322, R_RARE, GAME_WOTLK, 400, 410, 415, 420)
	self:addTradeFlags(RecipeDB, 60396, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOP, F.RBOP, F.HEALER, F.CASTER, F.TRINKET)
	self:addTradeAcquire(RecipeDB, 60396, A.TRAINER, 26903, A.TRAINER, 26951, A.TRAINER, 26975, A.TRAINER, 26987, A.TRAINER, 28703, A.TRAINER, 33588)

	-- Indestructible Alchemist Stone -- 60403
	AddRecipe(60403, 400, 44323, R_RARE, GAME_WOTLK, 400, 410, 415, 420)
	self:addTradeFlags(RecipeDB, 60403, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOP, F.RBOP, F.TANK, F.TRINKET)
	self:addTradeAcquire(RecipeDB, 60403, A.TRAINER, 26903, A.TRAINER, 26951, A.TRAINER, 26975, A.TRAINER, 26987, A.TRAINER, 28703, A.TRAINER, 33588)

	-- Mighty Alchemist Stone -- 60405
	AddRecipe(60405, 400, 44324, R_RARE, GAME_WOTLK, 400, 410, 415, 420)
	self:addTradeFlags(RecipeDB, 60405, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOP, F.RBOP, F.DPS, F.TRINKET)
	self:addTradeAcquire(RecipeDB, 60405, A.TRAINER, 26903, A.TRAINER, 26951, A.TRAINER, 26975, A.TRAINER, 26987, A.TRAINER, 28703, A.TRAINER, 33588)

	-- Northrend Alchemy Research -- 60893
	AddRecipe(60893, 400, nil, R_COMMON, GAME_WOTLK, 400, 410, 415, 420)
	self:addTradeFlags(RecipeDB, 60893, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP)
	self:addTradeAcquire(RecipeDB, 60893, A.TRAINER, 26903, A.TRAINER, 26951, A.TRAINER, 26975, A.TRAINER, 26987, A.TRAINER, 28703, A.TRAINER, 33588)

	-- Lesser Flask of Resistance -- 62213
	AddRecipe(62213, 385, 44939, R_COMMON, GAME_WOTLK, 385, 395, 400, 405)
	self:addTradeFlags(RecipeDB, 62213, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP)
	self:addTradeAcquire(RecipeDB, 62213, A.TRAINER, 26903, A.TRAINER, 26951, A.TRAINER, 26975, A.TRAINER, 26987, A.TRAINER, 28703, A.TRAINER, 33588)

	-- Ethereal Oil -- 62409
	AddRecipe(62409, 375, 44958, R_COMMON, GAME_WOTLK, 375, 385, 390, 395)
	self:addTradeFlags(RecipeDB, 62409, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP)
	self:addTradeAcquire(RecipeDB, 62409, A.TRAINER, 26903, A.TRAINER, 26951, A.TRAINER, 26975, A.TRAINER, 26987, A.TRAINER, 28703, A.TRAINER, 33588)

	-- Elixir of Water Walking -- 62410
	AddRecipe(62410, 400, 8827, R_COMMON, GAME_WOTLK, 400, 410, 415, 420)
	self:addTradeFlags(RecipeDB, 62410, F.ALLIANCE, F.HORDE, F.DISC, F.IBOE, F.RBOP)
	self:addTradeAcquire(RecipeDB, 62410, A.CUSTOM, 18)

	-- Elixir of Minor Accuracy -- 63732
	AddRecipe(63732, 135, 45621, R_COMMON, GAME_WOTLK, 135, 160, 180, 200)
	self:addTradeFlags(RecipeDB, 63732, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP)
	self:addTradeAcquire(RecipeDB, 63732, A.TRAINER, 1386, A.TRAINER, 2391, A.TRAINER, 2837, A.TRAINER, 3009, A.TRAINER, 3347, A.TRAINER, 4160, A.TRAINER, 4611, A.TRAINER, 5177, A.TRAINER, 5499, A.TRAINER, 7948, A.TRAINER, 16588, A.TRAINER, 16642, A.TRAINER, 16723, A.TRAINER, 18802, A.TRAINER, 19052, A.TRAINER, 27029, A.TRAINER, 3603, A.TRAINER, 1470, A.TRAINER, 3964, A.TRAINER, 2132, A.TRAINER, 3184, A.TRAINER, 33608, A.TRAINER, 33674, A.TRAINER, 27023, A.TRAINER, 4900, A.TRAINER, 1215, A.TRAINER, 16161)

	-- Transmute: Ametrine -- 66658
	AddRecipe(66658, 450, 36931, R_COMMON, GAME_WOTLK, 450, 450, 452, 465)
	self:addTradeFlags(RecipeDB, 66658, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP)
	self:addTradeAcquire(RecipeDB, 66658, A.TRAINER, 26903, A.TRAINER, 26951, A.TRAINER, 26975, A.TRAINER, 26987, A.TRAINER, 28703, A.TRAINER, 33588)

	-- Transmute: Cardinal Ruby -- 66659
	AddRecipe(66659, 450, 36919, R_COMMON, GAME_WOTLK, 450, 450, 452, 465)
	self:addTradeFlags(RecipeDB, 66659, F.ALLIANCE, F.HORDE, F.QUEST, F.IBOE, F.RBOP)
	self:addTradeAcquire(RecipeDB, 66659, A.QUEST, 14151)

	-- Transmute: King's Amber -- 66660
	AddRecipe(66660, 450, 36922, R_COMMON, GAME_WOTLK, 450, 450, 452, 465)
	self:addTradeFlags(RecipeDB, 66660, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP)
	self:addTradeAcquire(RecipeDB, 66660, A.TRAINER, 26903, A.TRAINER, 26951, A.TRAINER, 26975, A.TRAINER, 26987, A.TRAINER, 28703, A.TRAINER, 33588)

	-- Transmute: Dreadstone -- 66662
	AddRecipe(66662, 450, 36928, R_COMMON, GAME_WOTLK, 450, 450, 452, 465)
	self:addTradeFlags(RecipeDB, 66662, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP)
	self:addTradeAcquire(RecipeDB, 66662, A.TRAINER, 26903, A.TRAINER, 26951, A.TRAINER, 26975, A.TRAINER, 26987, A.TRAINER, 28703, A.TRAINER, 33588)

	-- Transmute: Majestic Zircon -- 66663
	AddRecipe(66663, 450, 36925, R_COMMON, GAME_WOTLK, 450, 450, 452, 465)
	self:addTradeFlags(RecipeDB, 66663, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP)
	self:addTradeAcquire(RecipeDB, 66663, A.TRAINER, 26903, A.TRAINER, 26951, A.TRAINER, 26975, A.TRAINER, 26987, A.TRAINER, 28703, A.TRAINER, 33588)

	-- Transmute: Eye of Zul -- 66664
	AddRecipe(66664, 450, 36934, R_COMMON, GAME_WOTLK, 450, 450, 452, 465)
	self:addTradeFlags(RecipeDB, 66664, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP)
	self:addTradeAcquire(RecipeDB, 66664, A.TRAINER, 26903, A.TRAINER, 26951, A.TRAINER, 26975, A.TRAINER, 26987, A.TRAINER, 28703, A.TRAINER, 33588)

	-- Flask of the North -- 67025
	AddRecipe(67025, 425, 47499, R_COMMON, GAME_WOTLK, 425, 440, 445, 450)
	self:addTradeFlags(RecipeDB, 67025, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOP, F.RBOP, F.DPS)
	self:addTradeAcquire(RecipeDB, 67025, A.TRAINER, 26903, A.TRAINER, 26951, A.TRAINER, 26975, A.TRAINER, 26987, A.TRAINER, 28703, A.TRAINER, 33588)

	return num_recipes

end
