--[[
************************************************************************
Enchanting.lua
Enchanting data for all of Ackis Recipe List
************************************************************************
File date: 2010-02-06T07:03:15Z 
File revision: 2851 
Project revision: 2853
Project version: r2853
************************************************************************
Please see http://www.wowace.com/addons/arl/ for more information.
************************************************************************
This source code is released under All Rights Reserved.
************************************************************************
]]--

-------------------------------------------------------------------------------
-- AddOn namespace.
-------------------------------------------------------------------------------
local MODNAME	= "Ackis Recipe List"
local addon	= LibStub("AceAddon-3.0"):GetAddon(MODNAME)
local L		= LibStub("AceLocale-3.0"):GetLocale(MODNAME)

local private	= select(2, ...)

-------------------------------------------------------------------------------
-- Item "rarity"
-------------------------------------------------------------------------------
local R_COMMON, R_UNCOMMON, R_RARE, R_EPIC, R_LEGENDARY, R_ARTIFACT = 1, 2, 3, 4, 5, 6

-------------------------------------------------------------------------------
-- Origin
-------------------------------------------------------------------------------
local GAME_ORIG, GAME_TBC, GAME_WOTLK = 0, 1, 2

-------------------------------------------------------------------------------
-- Filter flags. Acquire types, and Reputation levels.
-------------------------------------------------------------------------------
local F		= private.filter_flags
local A		= private.acquire_types
local REP	= private.rep_levels
local FAC	= private.faction_ids

local FRIENDLY	= 1
local HONORED	= 2
local REVERED	= 3
local EXALTED	= 4

local initialized = false
local num_recipes = 0

function addon:InitEnchanting(RecipeDB)
	if initialized then
		return num_recipes
	end
	initialized = true

	--------------------------------------------------------------------------------------------------------------------
	-- Counter and wrapper function
	--------------------------------------------------------------------------------------------------------------------
	local function AddRecipe(SpellID, Skill, ItemID, Rarity, Game, Orange, Yellow, Green, Gray)
		num_recipes = num_recipes + 1
		self:addTradeSkill(RecipeDB, SpellID, Skill, ItemID, Rarity, 7411, nil, Game, Orange, Yellow, Green, Gray)
	end

	-- Enchant Bracer - Minor Health -- 7418
	AddRecipe(7418, 1, nil, R_COMMON, GAME_ORIG, 1, 70, 90, 110)
	self:addTradeFlags(RecipeDB, 7418, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP)
	self:addTradeAcquire(RecipeDB, 7418, A.CUSTOM, 8)

	-- Enchant Chest - Minor Health -- 7420
	AddRecipe(7420, 15, nil, R_COMMON, GAME_ORIG, 15, 70, 90, 110)
	self:addTradeFlags(RecipeDB, 7420, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOE)
	self:addTradeAcquire(RecipeDB, 7420, A.TRAINER, 1317, A.TRAINER, 3011, A.TRAINER, 3345, A.TRAINER, 3606, A.TRAINER, 4213, A.TRAINER, 4616, A.TRAINER, 5157, A.TRAINER, 5695, A.TRAINER, 11072, A.TRAINER, 11073, A.TRAINER, 11074, A.TRAINER, 16160, A.TRAINER, 16633, A.TRAINER, 16725, A.TRAINER, 19251, A.TRAINER, 19252, A.TRAINER, 33610, A.TRAINER, 33676, A.TRAINER, 18773, A.TRAINER, 7949, A.TRAINER, 19540, A.TRAINER, 18753)

	-- Runed Copper Rod -- 7421
	AddRecipe(7421, 1, 6218, R_COMMON, GAME_ORIG, 1, 5, 7, 10)
	self:addTradeFlags(RecipeDB, 7421, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOP, F.RBOP)
	self:addTradeAcquire(RecipeDB, 7421, A.CUSTOM, 8)

	-- Enchant Chest - Minor Absorption -- 7426
	AddRecipe(7426, 40, nil, R_COMMON, GAME_ORIG, 40, 90, 110, 130)
	self:addTradeFlags(RecipeDB, 7426, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOE)
	self:addTradeAcquire(RecipeDB, 7426, A.TRAINER, 1317, A.TRAINER, 3011, A.TRAINER, 3345, A.TRAINER, 3606, A.TRAINER, 4213, A.TRAINER, 4616, A.TRAINER, 5157, A.TRAINER, 5695, A.TRAINER, 11072, A.TRAINER, 11073, A.TRAINER, 11074, A.TRAINER, 16160, A.TRAINER, 16633, A.TRAINER, 16725, A.TRAINER, 19251, A.TRAINER, 19252, A.TRAINER, 33610, A.TRAINER, 33676, A.TRAINER, 18773, A.TRAINER, 7949, A.TRAINER, 19540, A.TRAINER, 18753)

	-- Enchant Bracer - Minor Deflection -- 7428
	AddRecipe(7428, 1, nil, R_COMMON, GAME_ORIG, 1, 80, 100, 120)
	self:addTradeFlags(RecipeDB, 7428, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.TANK)
	self:addTradeAcquire(RecipeDB, 7428, A.CUSTOM, 8)

	-- Enchant Chest - Minor Mana -- 7443
	AddRecipe(7443, 20, nil, R_COMMON, GAME_ORIG, 20, 80, 100, 120)
	self:addTradeFlags(RecipeDB, 7443, F.ALLIANCE, F.HORDE, F.WORLD_DROP, F.IBOE, F.RBOE)
	self:addTradeAcquire(RecipeDB, 7443, A.WORLD_DROP, 1)

	-- Enchant Cloak - Minor Resistance -- 7454
	AddRecipe(7454, 45, nil, R_COMMON, GAME_ORIG, 45, 95, 115, 135)
	self:addTradeFlags(RecipeDB, 7454, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOE, F.CLOAK)
	self:addTradeAcquire(RecipeDB, 7454, A.TRAINER, 1317, A.TRAINER, 3011, A.TRAINER, 3345, A.TRAINER, 3606, A.TRAINER, 4213, A.TRAINER, 4616, A.TRAINER, 5157, A.TRAINER, 5695, A.TRAINER, 11072, A.TRAINER, 11073, A.TRAINER, 11074, A.TRAINER, 16160, A.TRAINER, 16633, A.TRAINER, 16725, A.TRAINER, 19251, A.TRAINER, 19252, A.TRAINER, 33610, A.TRAINER, 33676, A.TRAINER, 18773, A.TRAINER, 7949, A.TRAINER, 19540, A.TRAINER, 18753)

	-- Enchant Bracer - Minor Stamina -- 7457
	AddRecipe(7457, 50, nil, R_COMMON, GAME_ORIG, 50, 100, 120, 140)
	self:addTradeFlags(RecipeDB, 7457, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOE)
	self:addTradeAcquire(RecipeDB, 7457, A.TRAINER, 1317, A.TRAINER, 3011, A.TRAINER, 3345, A.TRAINER, 3606, A.TRAINER, 4213, A.TRAINER, 4616, A.TRAINER, 5157, A.TRAINER, 5695, A.TRAINER, 11072, A.TRAINER, 11073, A.TRAINER, 11074, A.TRAINER, 16160, A.TRAINER, 16633, A.TRAINER, 16725, A.TRAINER, 19251, A.TRAINER, 19252, A.TRAINER, 33610, A.TRAINER, 33676, A.TRAINER, 18773, A.TRAINER, 7949, A.TRAINER, 19540, A.TRAINER, 18753)

	-- Enchant 2H Weapon - Minor Impact -- 7745
	AddRecipe(7745, 100, nil, R_COMMON, GAME_ORIG, 100, 130, 150, 170)
	self:addTradeFlags(RecipeDB, 7745, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOE, F.TWO_HAND)
	self:addTradeAcquire(RecipeDB, 7745, A.TRAINER, 1317, A.TRAINER, 3011, A.TRAINER, 3345, A.TRAINER, 4213, A.TRAINER, 4616, A.TRAINER, 5157, A.TRAINER, 11072, A.TRAINER, 11073, A.TRAINER, 11074, A.TRAINER, 16633, A.TRAINER, 16725, A.TRAINER, 19251, A.TRAINER, 19252, A.TRAINER, 33610, A.TRAINER, 3606, A.TRAINER, 33676, A.TRAINER, 18773, A.TRAINER, 5695, A.TRAINER, 7949, A.TRAINER, 19540, A.TRAINER, 18753, A.TRAINER, 16160)

	-- Enchant Chest - Lesser Health -- 7748
	AddRecipe(7748, 60, nil, R_COMMON, GAME_ORIG, 60, 105, 125, 145)
	self:addTradeFlags(RecipeDB, 7748, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOE)
	self:addTradeAcquire(RecipeDB, 7748, A.TRAINER, 1317, A.TRAINER, 3011, A.TRAINER, 3345, A.TRAINER, 3606, A.TRAINER, 4213, A.TRAINER, 4616, A.TRAINER, 5157, A.TRAINER, 5695, A.TRAINER, 11072, A.TRAINER, 11073, A.TRAINER, 11074, A.TRAINER, 16160, A.TRAINER, 16633, A.TRAINER, 16725, A.TRAINER, 19251, A.TRAINER, 19252, A.TRAINER, 33610, A.TRAINER, 33676, A.TRAINER, 18773, A.TRAINER, 7949, A.TRAINER, 19540, A.TRAINER, 18753)

	-- Enchant Bracer - Minor Spirit -- 7766
	AddRecipe(7766, 60, nil, R_COMMON, GAME_ORIG, 60, 105, 125, 145)
	self:addTradeFlags(RecipeDB, 7766, F.ALLIANCE, F.HORDE, F.WORLD_DROP, F.IBOE, F.RBOE, F.HEALER, F.CASTER)
	self:addTradeAcquire(RecipeDB, 7766, A.WORLD_DROP, 1)

	-- Enchant Cloak - Minor Protection -- 7771
	AddRecipe(7771, 70, nil, R_COMMON, GAME_ORIG, 70, 110, 130, 150)
	self:addTradeFlags(RecipeDB, 7771, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOE, F.CLOAK)
	self:addTradeAcquire(RecipeDB, 7771, A.TRAINER, 1317, A.TRAINER, 3011, A.TRAINER, 3345, A.TRAINER, 3606, A.TRAINER, 4213, A.TRAINER, 4616, A.TRAINER, 5157, A.TRAINER, 5695, A.TRAINER, 11072, A.TRAINER, 11073, A.TRAINER, 11074, A.TRAINER, 16160, A.TRAINER, 16633, A.TRAINER, 16725, A.TRAINER, 19251, A.TRAINER, 19252, A.TRAINER, 33610, A.TRAINER, 33676, A.TRAINER, 18773, A.TRAINER, 7949, A.TRAINER, 19540, A.TRAINER, 18753)

	-- Enchant Chest - Lesser Mana -- 7776
	AddRecipe(7776, 80, nil, R_COMMON, GAME_ORIG, 80, 115, 135, 155)
	self:addTradeFlags(RecipeDB, 7776, F.HORDE, F.VENDOR, F.IBOE, F.RBOE)
	self:addTradeAcquire(RecipeDB, 7776, A.VENDOR, 3346, A.VENDOR, 5757)

	-- Enchant Bracer - Minor Agility -- 7779
	AddRecipe(7779, 80, nil, R_COMMON, GAME_ORIG, 80, 115, 135, 155)
	self:addTradeFlags(RecipeDB, 7779, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOE, F.DPS)
	self:addTradeAcquire(RecipeDB, 7779, A.TRAINER, 1317, A.TRAINER, 3011, A.TRAINER, 3345, A.TRAINER, 4213, A.TRAINER, 4616, A.TRAINER, 5157, A.TRAINER, 11072, A.TRAINER, 11073, A.TRAINER, 11074, A.TRAINER, 16633, A.TRAINER, 16725, A.TRAINER, 19251, A.TRAINER, 19252, A.TRAINER, 33610, A.TRAINER, 3606, A.TRAINER, 33676, A.TRAINER, 18773, A.TRAINER, 5695, A.TRAINER, 7949, A.TRAINER, 19540, A.TRAINER, 18753, A.TRAINER, 16160)

	-- Enchant Bracer - Minor Strength -- 7782
	AddRecipe(7782, 80, nil, R_COMMON, GAME_ORIG, 80, 115, 135, 155)
	self:addTradeFlags(RecipeDB, 7782, F.ALLIANCE, F.HORDE, F.WORLD_DROP, F.IBOE, F.RBOE, F.DPS)
	self:addTradeAcquire(RecipeDB, 7782, A.WORLD_DROP, 1)

	-- Enchant Weapon - Minor Beastslayer -- 7786
	AddRecipe(7786, 90, nil, R_COMMON, GAME_ORIG, 90, 120, 140, 160)
	self:addTradeFlags(RecipeDB, 7786, F.ALLIANCE, F.HORDE, F.WORLD_DROP, F.IBOE, F.RBOE, F.ONE_HAND, F.TWO_HAND)
	self:addTradeAcquire(RecipeDB, 7786, A.WORLD_DROP, 1)

	-- Enchant Weapon - Minor Striking -- 7788
	AddRecipe(7788, 90, nil, R_COMMON, GAME_ORIG, 90, 120, 140, 160)
	self:addTradeFlags(RecipeDB, 7788, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOE, F.ONE_HAND, F.TWO_HAND)
	self:addTradeAcquire(RecipeDB, 7788, A.TRAINER, 1317, A.TRAINER, 3011, A.TRAINER, 3345, A.TRAINER, 4213, A.TRAINER, 4616, A.TRAINER, 5157, A.TRAINER, 11072, A.TRAINER, 11073, A.TRAINER, 11074, A.TRAINER, 16633, A.TRAINER, 16725, A.TRAINER, 19251, A.TRAINER, 19252, A.TRAINER, 33610, A.TRAINER, 3606, A.TRAINER, 33676, A.TRAINER, 18773, A.TRAINER, 5695, A.TRAINER, 7949, A.TRAINER, 19540, A.TRAINER, 18753, A.TRAINER, 16160)

	-- Enchant 2H Weapon - Lesser Intellect -- 7793
	AddRecipe(7793, 100, nil, R_COMMON, GAME_ORIG, 100, 130, 150, 170)
	self:addTradeFlags(RecipeDB, 7793, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOE, F.TWO_HAND)
	self:addTradeAcquire(RecipeDB, 7793, A.VENDOR, 3012, A.VENDOR, 3346, A.VENDOR, 5158, A.VENDOR, 5758)

	-- Runed Silver Rod -- 7795
	AddRecipe(7795, 100, 6339, R_COMMON, GAME_ORIG, 100, 130, 150, 170)
	self:addTradeFlags(RecipeDB, 7795, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOP, F.RBOP)
	self:addTradeAcquire(RecipeDB, 7795, A.TRAINER, 1317, A.TRAINER, 3011, A.TRAINER, 3345, A.TRAINER, 4213, A.TRAINER, 4616, A.TRAINER, 5157, A.TRAINER, 11072, A.TRAINER, 11073, A.TRAINER, 11074, A.TRAINER, 16633, A.TRAINER, 16725, A.TRAINER, 19251, A.TRAINER, 19252, A.TRAINER, 33610, A.TRAINER, 3606, A.TRAINER, 33676, A.TRAINER, 18773, A.TRAINER, 5695, A.TRAINER, 7949, A.TRAINER, 19540, A.TRAINER, 18753, A.TRAINER, 16160)

	-- Enchant Chest - Health -- 7857
	AddRecipe(7857, 120, nil, R_COMMON, GAME_ORIG, 120, 145, 165, 185)
	self:addTradeFlags(RecipeDB, 7857, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOE)
	self:addTradeAcquire(RecipeDB, 7857, A.TRAINER, 1317, A.TRAINER, 3011, A.TRAINER, 3345, A.TRAINER, 4213, A.TRAINER, 4616, A.TRAINER, 5157, A.TRAINER, 7949, A.TRAINER, 11072, A.TRAINER, 11073, A.TRAINER, 11074, A.TRAINER, 16633, A.TRAINER, 16725, A.TRAINER, 19251, A.TRAINER, 19252, A.TRAINER, 33610, A.TRAINER, 3606, A.TRAINER, 33676, A.TRAINER, 18773, A.TRAINER, 5695, A.TRAINER, 19540, A.TRAINER, 18753, A.TRAINER, 16160)

	-- Enchant Bracer - Lesser Spirit -- 7859
	AddRecipe(7859, 120, nil, R_COMMON, GAME_ORIG, 120, 145, 165, 185)
	self:addTradeFlags(RecipeDB, 7859, F.ALLIANCE, F.HORDE, F.WORLD_DROP, F.IBOE, F.RBOE, F.HEALER, F.CASTER)
	self:addTradeAcquire(RecipeDB, 7859, A.WORLD_DROP, 1)

	-- Enchant Cloak - Lesser Fire Resistance -- 7861
	AddRecipe(7861, 125, nil, R_COMMON, GAME_ORIG, 125, 150, 170, 190)
	self:addTradeFlags(RecipeDB, 7861, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOE, F.CLOAK)
	self:addTradeAcquire(RecipeDB, 7861, A.TRAINER, 1317, A.TRAINER, 3011, A.TRAINER, 3345, A.TRAINER, 4213, A.TRAINER, 4616, A.TRAINER, 5157, A.TRAINER, 7949, A.TRAINER, 11072, A.TRAINER, 11073, A.TRAINER, 11074, A.TRAINER, 16633, A.TRAINER, 16725, A.TRAINER, 19251, A.TRAINER, 19252, A.TRAINER, 33610, A.TRAINER, 3606, A.TRAINER, 33676, A.TRAINER, 18773, A.TRAINER, 5695, A.TRAINER, 19540, A.TRAINER, 18753, A.TRAINER, 16160)

	-- Enchant Boots - Minor Stamina -- 7863
	AddRecipe(7863, 125, nil, R_COMMON, GAME_ORIG, 125, 150, 170, 190)
	self:addTradeFlags(RecipeDB, 7863, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOE)
	self:addTradeAcquire(RecipeDB, 7863, A.TRAINER, 1317, A.TRAINER, 3011, A.TRAINER, 3345, A.TRAINER, 4213, A.TRAINER, 4616, A.TRAINER, 5157, A.TRAINER, 7949, A.TRAINER, 11072, A.TRAINER, 11073, A.TRAINER, 11074, A.TRAINER, 16633, A.TRAINER, 16725, A.TRAINER, 19251, A.TRAINER, 19252, A.TRAINER, 33610, A.TRAINER, 3606, A.TRAINER, 33676, A.TRAINER, 18773, A.TRAINER, 5695, A.TRAINER, 19540, A.TRAINER, 18753, A.TRAINER, 16160)

	-- Enchant Boots - Minor Agility -- 7867
	AddRecipe(7867, 125, nil, R_COMMON, GAME_ORIG, 125, 150, 170, 190)
	self:addTradeFlags(RecipeDB, 7867, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOE, F.DPS)
	self:addTradeAcquire(RecipeDB, 7867, A.VENDOR, 3012, A.VENDOR, 3537)

	-- Enchant Shield - Minor Stamina -- 13378
	AddRecipe(13378, 105, nil, R_COMMON, GAME_ORIG, 105, 130, 150, 170)
	self:addTradeFlags(RecipeDB, 13378, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOE, F.SHIELD)
	self:addTradeAcquire(RecipeDB, 13378, A.TRAINER, 1317, A.TRAINER, 3011, A.TRAINER, 3345, A.TRAINER, 4213, A.TRAINER, 4616, A.TRAINER, 5157, A.TRAINER, 7949, A.TRAINER, 11072, A.TRAINER, 11073, A.TRAINER, 11074, A.TRAINER, 16633, A.TRAINER, 16725, A.TRAINER, 19251, A.TRAINER, 19252, A.TRAINER, 33610, A.TRAINER, 3606, A.TRAINER, 33676, A.TRAINER, 18773, A.TRAINER, 19540, A.TRAINER, 18753, A.TRAINER, 16160)

	-- Enchant 2H Weapon - Lesser Spirit -- 13380
	AddRecipe(13380, 110, nil, R_COMMON, GAME_ORIG, 110, 135, 155, 175)
	self:addTradeFlags(RecipeDB, 13380, F.ALLIANCE, F.HORDE, F.WORLD_DROP, F.IBOE, F.RBOE, F.HEALER, F.CASTER, F.TWO_HAND)
	self:addTradeAcquire(RecipeDB, 13380, A.WORLD_DROP, 1)

	-- Enchant Cloak - Minor Agility -- 13419
	AddRecipe(13419, 110, nil, R_COMMON, GAME_ORIG, 110, 135, 155, 175)
	self:addTradeFlags(RecipeDB, 13419, F.ALLIANCE, F.HORDE, F.VENDOR, F.WORLD_DROP, F.IBOE, F.RBOE, F.DPS, F.CLOAK)
	self:addTradeAcquire(RecipeDB, 13419, A.WORLD_DROP, 1, A.VENDOR, 3954, A.VENDOR, 12043)

	-- Enchant Cloak - Lesser Protection -- 13421
	AddRecipe(13421, 115, nil, R_COMMON, GAME_ORIG, 115, 140, 160, 180)
	self:addTradeFlags(RecipeDB, 13421, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOE, F.CLOAK)
	self:addTradeAcquire(RecipeDB, 13421, A.TRAINER, 1317, A.TRAINER, 3011, A.TRAINER, 3345, A.TRAINER, 4213, A.TRAINER, 4616, A.TRAINER, 5157, A.TRAINER, 7949, A.TRAINER, 11072, A.TRAINER, 11073, A.TRAINER, 11074, A.TRAINER, 16633, A.TRAINER, 16725, A.TRAINER, 19251, A.TRAINER, 19252, A.TRAINER, 33610, A.TRAINER, 3606, A.TRAINER, 33676, A.TRAINER, 18773, A.TRAINER, 5695, A.TRAINER, 19540, A.TRAINER, 18753, A.TRAINER, 16160)

	-- Enchant Shield - Lesser Protection -- 13464
	AddRecipe(13464, 115, nil, R_COMMON, GAME_ORIG, 115, 140, 160, 180)
	self:addTradeFlags(RecipeDB, 13464, F.ALLIANCE, F.HORDE, F.WORLD_DROP, F.IBOE, F.RBOE, F.SHIELD)
	self:addTradeAcquire(RecipeDB, 13464, A.WORLD_DROP, 1)

	-- Enchant Shield - Lesser Spirit -- 13485
	AddRecipe(13485, 130, nil, R_COMMON, GAME_ORIG, 130, 155, 175, 195)
	self:addTradeFlags(RecipeDB, 13485, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOE, F.HEALER, F.CASTER, F.SHIELD)
	self:addTradeAcquire(RecipeDB, 13485, A.TRAINER, 1317, A.TRAINER, 3011, A.TRAINER, 3345, A.TRAINER, 4213, A.TRAINER, 4616, A.TRAINER, 5157, A.TRAINER, 7949, A.TRAINER, 11072, A.TRAINER, 11073, A.TRAINER, 11074, A.TRAINER, 16633, A.TRAINER, 16725, A.TRAINER, 19251, A.TRAINER, 19252, A.TRAINER, 33610, A.TRAINER, 3606, A.TRAINER, 33676, A.TRAINER, 18773, A.TRAINER, 5695, A.TRAINER, 19540, A.TRAINER, 18753, A.TRAINER, 16160)

	-- Enchant Bracer - Lesser Stamina -- 13501
	AddRecipe(13501, 130, nil, R_COMMON, GAME_ORIG, 130, 155, 175, 195)
	self:addTradeFlags(RecipeDB, 13501, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOE)
	self:addTradeAcquire(RecipeDB, 13501, A.TRAINER, 1317, A.TRAINER, 3011, A.TRAINER, 3345, A.TRAINER, 4213, A.TRAINER, 4616, A.TRAINER, 5157, A.TRAINER, 7949, A.TRAINER, 11072, A.TRAINER, 11073, A.TRAINER, 11074, A.TRAINER, 16633, A.TRAINER, 16725, A.TRAINER, 19251, A.TRAINER, 19252, A.TRAINER, 33610, A.TRAINER, 3606, A.TRAINER, 33676, A.TRAINER, 18773, A.TRAINER, 5695, A.TRAINER, 19540, A.TRAINER, 18753, A.TRAINER, 16160)

	-- Enchant Weapon - Lesser Striking -- 13503
	AddRecipe(13503, 140, nil, R_COMMON, GAME_ORIG, 140, 165, 185, 205)
	self:addTradeFlags(RecipeDB, 13503, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOE, F.ONE_HAND, F.TWO_HAND)
	self:addTradeAcquire(RecipeDB, 13503, A.TRAINER, 1317, A.TRAINER, 3011, A.TRAINER, 3345, A.TRAINER, 4213, A.TRAINER, 4616, A.TRAINER, 5157, A.TRAINER, 7949, A.TRAINER, 11072, A.TRAINER, 11073, A.TRAINER, 11074, A.TRAINER, 16633, A.TRAINER, 16725, A.TRAINER, 19251, A.TRAINER, 19252, A.TRAINER, 33610, A.TRAINER, 3606, A.TRAINER, 33676, A.TRAINER, 18773, A.TRAINER, 5695, A.TRAINER, 19540, A.TRAINER, 18753, A.TRAINER, 16160)

	-- Enchant Cloak - Lesser Shadow Resistance -- 13522
	AddRecipe(13522, 135, nil, R_COMMON, GAME_ORIG, 135, 160, 180, 200)
	self:addTradeFlags(RecipeDB, 13522, F.ALLIANCE, F.HORDE, F.WORLD_DROP, F.IBOE, F.RBOE, F.CLOAK)
	self:addTradeAcquire(RecipeDB, 13522, A.WORLD_DROP, 1)

	-- Enchant 2H Weapon - Lesser Impact -- 13529
	AddRecipe(13529, 145, nil, R_COMMON, GAME_ORIG, 145, 170, 190, 210)
	self:addTradeFlags(RecipeDB, 13529, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOE, F.TWO_HAND)
	self:addTradeAcquire(RecipeDB, 13529, A.TRAINER, 1317, A.TRAINER, 3011, A.TRAINER, 3345, A.TRAINER, 4213, A.TRAINER, 4616, A.TRAINER, 5157, A.TRAINER, 7949, A.TRAINER, 11072, A.TRAINER, 11073, A.TRAINER, 11074, A.TRAINER, 16633, A.TRAINER, 16725, A.TRAINER, 19251, A.TRAINER, 19252, A.TRAINER, 33610, A.TRAINER, 3606, A.TRAINER, 33676, A.TRAINER, 18773, A.TRAINER, 5695, A.TRAINER, 19540, A.TRAINER, 18753, A.TRAINER, 16160)

	-- Enchant Bracer - Lesser Strength -- 13536
	AddRecipe(13536, 140, nil, R_COMMON, GAME_ORIG, 140, 165, 185, 205)
	self:addTradeFlags(RecipeDB, 13536, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOE, F.DPS)
	self:addTradeAcquire(RecipeDB, 13536, A.VENDOR, 3954, A.VENDOR, 12043)

	-- Enchant Chest - Lesser Absorption -- 13538
	AddRecipe(13538, 140, nil, R_COMMON, GAME_ORIG, 140, 165, 185, 205)
	self:addTradeFlags(RecipeDB, 13538, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOE)
	self:addTradeAcquire(RecipeDB, 13538, A.TRAINER, 1317, A.TRAINER, 3011, A.TRAINER, 3345, A.TRAINER, 4213, A.TRAINER, 4616, A.TRAINER, 5157, A.TRAINER, 7949, A.TRAINER, 11072, A.TRAINER, 11073, A.TRAINER, 11074, A.TRAINER, 16633, A.TRAINER, 16725, A.TRAINER, 19251, A.TRAINER, 19252, A.TRAINER, 33610, A.TRAINER, 3606, A.TRAINER, 33676, A.TRAINER, 18773, A.TRAINER, 5695, A.TRAINER, 19540, A.TRAINER, 18753, A.TRAINER, 16160)

	-- Enchant Chest - Mana -- 13607
	AddRecipe(13607, 145, nil, R_COMMON, GAME_ORIG, 145, 170, 190, 210)
	self:addTradeFlags(RecipeDB, 13607, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOE)
	self:addTradeAcquire(RecipeDB, 13607, A.TRAINER, 1317, A.TRAINER, 3011, A.TRAINER, 3345, A.TRAINER, 4213, A.TRAINER, 4616, A.TRAINER, 5157, A.TRAINER, 7949, A.TRAINER, 11072, A.TRAINER, 11073, A.TRAINER, 11074, A.TRAINER, 16633, A.TRAINER, 16725, A.TRAINER, 19251, A.TRAINER, 19252, A.TRAINER, 33610, A.TRAINER, 3606, A.TRAINER, 33676, A.TRAINER, 18773, A.TRAINER, 5695, A.TRAINER, 19540, A.TRAINER, 18753, A.TRAINER, 16160)

	-- Enchant Gloves - Mining -- 13612
	AddRecipe(13612, 145, nil, R_COMMON, GAME_ORIG, 145, 170, 190, 210)
	self:addTradeFlags(RecipeDB, 13612, F.ALLIANCE, F.HORDE, F.MOB_DROP, F.IBOE, F.RBOE)
	self:addTradeAcquire(RecipeDB, 13612, A.MOB, 1054, A.MOB, 1051, A.MOB, 1052, A.MOB, 1053, A.MOB, 1364)

	-- Enchant Gloves - Herbalism -- 13617
	AddRecipe(13617, 145, nil, R_COMMON, GAME_ORIG, 145, 170, 190, 210)
	self:addTradeFlags(RecipeDB, 13617, F.ALLIANCE, F.HORDE, F.MOB_DROP, F.IBOE, F.RBOE)
	self:addTradeAcquire(RecipeDB, 13617, A.MOB, 4030, A.MOB, 4029, A.MOB, 3834, A.MOB, 3919, A.MOB, 4028)

	-- Enchant Gloves - Fishing -- 13620
	AddRecipe(13620, 145, nil, R_COMMON, GAME_ORIG, 145, 170, 190, 210)
	self:addTradeFlags(RecipeDB, 13620, F.ALLIANCE, F.HORDE, F.MOB_DROP, F.IBOE, F.RBOE)
	self:addTradeAcquire(RecipeDB, 13620, A.MOB, 2375, A.MOB, 2377, A.MOB, 2376, A.MOB, 2374, A.MOB, 14276)

	-- Enchant Bracer - Lesser Intellect -- 13622
	AddRecipe(13622, 150, nil, R_COMMON, GAME_ORIG, 150, 175, 195, 215)
	self:addTradeFlags(RecipeDB, 13622, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOE)
	self:addTradeAcquire(RecipeDB, 13622, A.TRAINER, 1317, A.TRAINER, 3011, A.TRAINER, 3345, A.TRAINER, 4213, A.TRAINER, 4616, A.TRAINER, 5157, A.TRAINER, 7949, A.TRAINER, 11072, A.TRAINER, 11073, A.TRAINER, 11074, A.TRAINER, 16633, A.TRAINER, 16725, A.TRAINER, 19251, A.TRAINER, 19252, A.TRAINER, 33610, A.TRAINER, 3606, A.TRAINER, 33676, A.TRAINER, 18773, A.TRAINER, 5695, A.TRAINER, 19540, A.TRAINER, 18753, A.TRAINER, 16160)

	-- Enchant Chest - Minor Stats -- 13626
	AddRecipe(13626, 150, nil, R_COMMON, GAME_ORIG, 150, 175, 195, 215)
	self:addTradeFlags(RecipeDB, 13626, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOE)
	self:addTradeAcquire(RecipeDB, 13626, A.TRAINER, 1317, A.TRAINER, 3011, A.TRAINER, 3345, A.TRAINER, 4213, A.TRAINER, 4616, A.TRAINER, 5157, A.TRAINER, 7949, A.TRAINER, 11072, A.TRAINER, 11073, A.TRAINER, 11074, A.TRAINER, 16633, A.TRAINER, 16725, A.TRAINER, 19251, A.TRAINER, 19252, A.TRAINER, 33610, A.TRAINER, 3606, A.TRAINER, 33676, A.TRAINER, 18773, A.TRAINER, 5695, A.TRAINER, 19540, A.TRAINER, 18753, A.TRAINER, 16160)

	-- Runed Golden Rod -- 13628
	AddRecipe(13628, 150, 11130, R_COMMON, GAME_ORIG, 150, 175, 195, 215)
	self:addTradeFlags(RecipeDB, 13628, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOP, F.RBOP)
	self:addTradeAcquire(RecipeDB, 13628, A.TRAINER, 1317, A.TRAINER, 3011, A.TRAINER, 3345, A.TRAINER, 4213, A.TRAINER, 4616, A.TRAINER, 5157, A.TRAINER, 7949, A.TRAINER, 11072, A.TRAINER, 11073, A.TRAINER, 11074, A.TRAINER, 16633, A.TRAINER, 16725, A.TRAINER, 19251, A.TRAINER, 19252, A.TRAINER, 33610, A.TRAINER, 3606, A.TRAINER, 33676, A.TRAINER, 18773, A.TRAINER, 5695, A.TRAINER, 19540, A.TRAINER, 18753, A.TRAINER, 16160)

	-- Enchant Shield - Lesser Stamina -- 13631
	AddRecipe(13631, 155, nil, R_COMMON, GAME_ORIG, 155, 175, 195, 215)
	self:addTradeFlags(RecipeDB, 13631, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOE, F.SHIELD)
	self:addTradeAcquire(RecipeDB, 13631, A.TRAINER, 11072, A.TRAINER, 11073, A.TRAINER, 11074, A.TRAINER, 19251, A.TRAINER, 19252, A.TRAINER, 33610, A.TRAINER, 16633, A.TRAINER, 1317, A.TRAINER, 3606, A.TRAINER, 4213, A.TRAINER, 16725, A.TRAINER, 3345, A.TRAINER, 3011, A.TRAINER, 33676, A.TRAINER, 18773, A.TRAINER, 5695, A.TRAINER, 4616, A.TRAINER, 7949, A.TRAINER, 5157, A.TRAINER, 19540, A.TRAINER, 18753, A.TRAINER, 16160)

	-- Enchant Cloak - Defense -- 13635
	AddRecipe(13635, 155, nil, R_COMMON, GAME_ORIG, 155, 175, 195, 215)
	self:addTradeFlags(RecipeDB, 13635, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOE, F.TANK, F.CLOAK)
	self:addTradeAcquire(RecipeDB, 13635, A.TRAINER, 11072, A.TRAINER, 11073, A.TRAINER, 11074, A.TRAINER, 19251, A.TRAINER, 19252, A.TRAINER, 33610, A.TRAINER, 16633, A.TRAINER, 1317, A.TRAINER, 3606, A.TRAINER, 4213, A.TRAINER, 16725, A.TRAINER, 3345, A.TRAINER, 3011, A.TRAINER, 33676, A.TRAINER, 18773, A.TRAINER, 5695, A.TRAINER, 4616, A.TRAINER, 7949, A.TRAINER, 5157, A.TRAINER, 19540, A.TRAINER, 18753, A.TRAINER, 16160)

	-- Enchant Boots - Lesser Agility -- 13637
	AddRecipe(13637, 160, nil, R_COMMON, GAME_ORIG, 160, 180, 200, 220)
	self:addTradeFlags(RecipeDB, 13637, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOE, F.DPS)
	self:addTradeAcquire(RecipeDB, 13637, A.TRAINER, 11072, A.TRAINER, 11073, A.TRAINER, 11074, A.TRAINER, 19251, A.TRAINER, 19252, A.TRAINER, 33610, A.TRAINER, 16633, A.TRAINER, 1317, A.TRAINER, 3606, A.TRAINER, 4213, A.TRAINER, 16725, A.TRAINER, 3345, A.TRAINER, 3011, A.TRAINER, 33676, A.TRAINER, 18773, A.TRAINER, 5695, A.TRAINER, 4616, A.TRAINER, 7949, A.TRAINER, 5157, A.TRAINER, 19540, A.TRAINER, 18753, A.TRAINER, 16160)

	-- Enchant Chest - Greater Health -- 13640
	AddRecipe(13640, 160, nil, R_COMMON, GAME_ORIG, 160, 180, 200, 220)
	self:addTradeFlags(RecipeDB, 13640, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOE)
	self:addTradeAcquire(RecipeDB, 13640, A.TRAINER, 11072, A.TRAINER, 11073, A.TRAINER, 11074, A.TRAINER, 19251, A.TRAINER, 19252, A.TRAINER, 33610, A.TRAINER, 16633, A.TRAINER, 1317, A.TRAINER, 3606, A.TRAINER, 4213, A.TRAINER, 16725, A.TRAINER, 3345, A.TRAINER, 3011, A.TRAINER, 33676, A.TRAINER, 18773, A.TRAINER, 5695, A.TRAINER, 4616, A.TRAINER, 7949, A.TRAINER, 5157, A.TRAINER, 19540, A.TRAINER, 18753, A.TRAINER, 16160)

	-- Enchant Bracer - Spirit -- 13642
	AddRecipe(13642, 165, nil, R_COMMON, GAME_ORIG, 165, 185, 205, 225)
	self:addTradeFlags(RecipeDB, 13642, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOE, F.HEALER, F.CASTER)
	self:addTradeAcquire(RecipeDB, 13642, A.TRAINER, 11072, A.TRAINER, 11073, A.TRAINER, 11074, A.TRAINER, 19251, A.TRAINER, 19252, A.TRAINER, 33610, A.TRAINER, 16633, A.TRAINER, 1317, A.TRAINER, 3606, A.TRAINER, 4213, A.TRAINER, 16725, A.TRAINER, 3345, A.TRAINER, 3011, A.TRAINER, 33676, A.TRAINER, 18773, A.TRAINER, 5695, A.TRAINER, 4616, A.TRAINER, 7949, A.TRAINER, 5157, A.TRAINER, 19540, A.TRAINER, 18753, A.TRAINER, 16160)

	-- Enchant Boots - Lesser Stamina -- 13644
	AddRecipe(13644, 170, nil, R_COMMON, GAME_ORIG, 170, 190, 210, 230)
	self:addTradeFlags(RecipeDB, 13644, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOE)
	self:addTradeAcquire(RecipeDB, 13644, A.TRAINER, 11072, A.TRAINER, 11073, A.TRAINER, 11074, A.TRAINER, 19251, A.TRAINER, 19252, A.TRAINER, 33610, A.TRAINER, 16633, A.TRAINER, 1317, A.TRAINER, 3606, A.TRAINER, 4213, A.TRAINER, 16725, A.TRAINER, 3345, A.TRAINER, 3011, A.TRAINER, 33676, A.TRAINER, 18773, A.TRAINER, 5695, A.TRAINER, 4616, A.TRAINER, 7949, A.TRAINER, 5157, A.TRAINER, 19540, A.TRAINER, 18753, A.TRAINER, 16160)

	-- Enchant Bracer - Lesser Deflection -- 13646
	AddRecipe(13646, 170, nil, R_COMMON, GAME_ORIG, 170, 190, 210, 230)
	self:addTradeFlags(RecipeDB, 13646, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOE, F.TANK)
	self:addTradeAcquire(RecipeDB, 13646, A.VENDOR, 2381, A.VENDOR, 2821)

	-- Enchant Bracer - Stamina -- 13648
	AddRecipe(13648, 170, nil, R_COMMON, GAME_ORIG, 170, 190, 210, 230)
	self:addTradeFlags(RecipeDB, 13648, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOE)
	self:addTradeAcquire(RecipeDB, 13648, A.TRAINER, 11072, A.TRAINER, 11073, A.TRAINER, 11074, A.TRAINER, 19251, A.TRAINER, 19252, A.TRAINER, 33610, A.TRAINER, 16633, A.TRAINER, 1317, A.TRAINER, 3606, A.TRAINER, 4213, A.TRAINER, 16725, A.TRAINER, 3345, A.TRAINER, 3011, A.TRAINER, 33676, A.TRAINER, 18773, A.TRAINER, 5695, A.TRAINER, 4616, A.TRAINER, 7949, A.TRAINER, 5157, A.TRAINER, 19540, A.TRAINER, 18753, A.TRAINER, 16160)

	-- Enchant Weapon - Lesser Beastslayer -- 13653
	AddRecipe(13653, 175, nil, R_COMMON, GAME_ORIG, 175, 195, 215, 235)
	self:addTradeFlags(RecipeDB, 13653, F.ALLIANCE, F.HORDE, F.WORLD_DROP, F.IBOE, F.RBOE, F.ONE_HAND, F.TWO_HAND)
	self:addTradeAcquire(RecipeDB, 13653, A.WORLD_DROP, 1)

	-- Enchant Weapon - Lesser Elemental Slayer -- 13655
	AddRecipe(13655, 175, nil, R_COMMON, GAME_ORIG, 175, 195, 215, 235)
	self:addTradeFlags(RecipeDB, 13655, F.ALLIANCE, F.HORDE, F.WORLD_DROP, F.IBOE, F.RBOE, F.ONE_HAND, F.TWO_HAND)
	self:addTradeAcquire(RecipeDB, 13655, A.WORLD_DROP, 1)

	-- Enchant Cloak - Fire Resistance -- 13657
	AddRecipe(13657, 175, nil, R_COMMON, GAME_ORIG, 175, 195, 215, 235)
	self:addTradeFlags(RecipeDB, 13657, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOE, F.CLOAK)
	self:addTradeAcquire(RecipeDB, 13657, A.TRAINER, 11072, A.TRAINER, 11073, A.TRAINER, 11074, A.TRAINER, 19251, A.TRAINER, 19252, A.TRAINER, 33610, A.TRAINER, 16633, A.TRAINER, 1317, A.TRAINER, 3606, A.TRAINER, 4213, A.TRAINER, 16725, A.TRAINER, 3345, A.TRAINER, 3011, A.TRAINER, 33676, A.TRAINER, 18773, A.TRAINER, 5695, A.TRAINER, 4616, A.TRAINER, 7949, A.TRAINER, 5157, A.TRAINER, 19540, A.TRAINER, 18753, A.TRAINER, 16160)

	-- Enchant Shield - Spirit -- 13659
	AddRecipe(13659, 180, nil, R_COMMON, GAME_ORIG, 180, 200, 220, 240)
	self:addTradeFlags(RecipeDB, 13659, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOE, F.HEALER, F.CASTER, F.SHIELD)
	self:addTradeAcquire(RecipeDB, 13659, A.TRAINER, 11072, A.TRAINER, 11073, A.TRAINER, 11074, A.TRAINER, 19251, A.TRAINER, 19252, A.TRAINER, 33610, A.TRAINER, 16633, A.TRAINER, 1317, A.TRAINER, 3606, A.TRAINER, 4213, A.TRAINER, 16725, A.TRAINER, 3345, A.TRAINER, 3011, A.TRAINER, 33676, A.TRAINER, 18773, A.TRAINER, 5695, A.TRAINER, 4616, A.TRAINER, 7949, A.TRAINER, 5157, A.TRAINER, 19540, A.TRAINER, 18753, A.TRAINER, 16160)

	-- Enchant Bracer - Strength -- 13661
	AddRecipe(13661, 180, nil, R_COMMON, GAME_ORIG, 180, 200, 220, 240)
	self:addTradeFlags(RecipeDB, 13661, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOE, F.DPS)
	self:addTradeAcquire(RecipeDB, 13661, A.TRAINER, 11072, A.TRAINER, 11073, A.TRAINER, 11074, A.TRAINER, 19251, A.TRAINER, 19252, A.TRAINER, 33610, A.TRAINER, 16633, A.TRAINER, 1317, A.TRAINER, 3606, A.TRAINER, 4213, A.TRAINER, 16725, A.TRAINER, 3345, A.TRAINER, 3011, A.TRAINER, 33676, A.TRAINER, 18773, A.TRAINER, 5695, A.TRAINER, 4616, A.TRAINER, 7949, A.TRAINER, 5157, A.TRAINER, 19540, A.TRAINER, 18753, A.TRAINER, 16160)

	-- Enchant Chest - Greater Mana -- 13663
	AddRecipe(13663, 185, nil, R_COMMON, GAME_ORIG, 185, 205, 225, 245)
	self:addTradeFlags(RecipeDB, 13663, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOE)
	self:addTradeAcquire(RecipeDB, 13663, A.TRAINER, 11072, A.TRAINER, 11073, A.TRAINER, 11074, A.TRAINER, 19251, A.TRAINER, 19252, A.TRAINER, 33610, A.TRAINER, 16633, A.TRAINER, 1317, A.TRAINER, 3606, A.TRAINER, 4213, A.TRAINER, 16725, A.TRAINER, 3345, A.TRAINER, 3011, A.TRAINER, 33676, A.TRAINER, 18773, A.TRAINER, 5695, A.TRAINER, 4616, A.TRAINER, 7949, A.TRAINER, 5157, A.TRAINER, 19540, A.TRAINER, 18753, A.TRAINER, 16160)

	-- Enchant Boots - Lesser Spirit -- 13687
	AddRecipe(13687, 190, nil, R_COMMON, GAME_ORIG, 190, 210, 230, 250)
	self:addTradeFlags(RecipeDB, 13687, F.ALLIANCE, F.HORDE, F.WORLD_DROP, F.IBOE, F.RBOE, F.HEALER, F.CASTER)
	self:addTradeAcquire(RecipeDB, 13687, A.WORLD_DROP, 1)

	-- Enchant Shield - Lesser Block -- 13689
	AddRecipe(13689, 195, nil, R_COMMON, GAME_ORIG, 195, 215, 235, 255)
	self:addTradeFlags(RecipeDB, 13689, F.ALLIANCE, F.HORDE, F.INSTANCE, F.WORLD_DROP, F.IBOE, F.RBOE, F.TANK, F.SHIELD)
	self:addTradeAcquire(RecipeDB, 13689, A.WORLD_DROP, 2)

	-- Enchant Weapon - Striking -- 13693
	AddRecipe(13693, 195, nil, R_COMMON, GAME_ORIG, 195, 215, 235, 255)
	self:addTradeFlags(RecipeDB, 13693, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOE, F.ONE_HAND, F.TWO_HAND)
	self:addTradeAcquire(RecipeDB, 13693, A.TRAINER, 11072, A.TRAINER, 11073, A.TRAINER, 11074, A.TRAINER, 19251, A.TRAINER, 19252, A.TRAINER, 33610, A.TRAINER, 16633, A.TRAINER, 1317, A.TRAINER, 3606, A.TRAINER, 4213, A.TRAINER, 16725, A.TRAINER, 3345, A.TRAINER, 3011, A.TRAINER, 33676, A.TRAINER, 18773, A.TRAINER, 5695, A.TRAINER, 4616, A.TRAINER, 7949, A.TRAINER, 5157, A.TRAINER, 19540, A.TRAINER, 18753, A.TRAINER, 16160)

	-- Enchant 2H Weapon - Impact -- 13695
	AddRecipe(13695, 200, nil, R_COMMON, GAME_ORIG, 200, 220, 240, 260)
	self:addTradeFlags(RecipeDB, 13695, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOE, F.TWO_HAND)
	self:addTradeAcquire(RecipeDB, 13695, A.TRAINER, 11072, A.TRAINER, 11073, A.TRAINER, 11074, A.TRAINER, 19251, A.TRAINER, 19252, A.TRAINER, 33610, A.TRAINER, 16633, A.TRAINER, 1317, A.TRAINER, 3606, A.TRAINER, 4213, A.TRAINER, 16725, A.TRAINER, 3345, A.TRAINER, 3011, A.TRAINER, 33676, A.TRAINER, 18773, A.TRAINER, 5695, A.TRAINER, 4616, A.TRAINER, 7949, A.TRAINER, 5157, A.TRAINER, 19540, A.TRAINER, 18753, A.TRAINER, 16160)

	-- Enchant Gloves - Skinning -- 13698
	AddRecipe(13698, 200, nil, R_COMMON, GAME_ORIG, 200, 220, 240, 260)
	self:addTradeFlags(RecipeDB, 13698, F.ALLIANCE, F.HORDE, F.MOB_DROP, F.IBOE, F.RBOE)
	self:addTradeAcquire(RecipeDB, 13698, A.MOB, 2556, A.MOB, 2557, A.MOB, 2558, A.MOB, 2606)

	-- Enchant Chest - Lesser Stats -- 13700
	AddRecipe(13700, 200, nil, R_COMMON, GAME_ORIG, 200, 220, 240, 260)
	self:addTradeFlags(RecipeDB, 13700, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOE)
	self:addTradeAcquire(RecipeDB, 13700, A.TRAINER, 11072, A.TRAINER, 11073, A.TRAINER, 11074, A.TRAINER, 19251, A.TRAINER, 19252, A.TRAINER, 33610, A.TRAINER, 16633, A.TRAINER, 1317, A.TRAINER, 3606, A.TRAINER, 4213, A.TRAINER, 16725, A.TRAINER, 3345, A.TRAINER, 3011, A.TRAINER, 33676, A.TRAINER, 18773, A.TRAINER, 5695, A.TRAINER, 4616, A.TRAINER, 7949, A.TRAINER, 5157, A.TRAINER, 19540, A.TRAINER, 18753, A.TRAINER, 16160)

	-- Runed Truesilver Rod -- 13702
	AddRecipe(13702, 200, 11145, R_COMMON, GAME_ORIG, 200, 220, 240, 260)
	self:addTradeFlags(RecipeDB, 13702, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOP, F.RBOP)
	self:addTradeAcquire(RecipeDB, 13702, A.TRAINER, 11072, A.TRAINER, 11073, A.TRAINER, 11074, A.TRAINER, 19251, A.TRAINER, 19252, A.TRAINER, 33610, A.TRAINER, 16633, A.TRAINER, 1317, A.TRAINER, 3606, A.TRAINER, 4213, A.TRAINER, 16725, A.TRAINER, 3345, A.TRAINER, 3011, A.TRAINER, 33676, A.TRAINER, 18773, A.TRAINER, 5695, A.TRAINER, 4616, A.TRAINER, 7949, A.TRAINER, 5157, A.TRAINER, 19540, A.TRAINER, 18753, A.TRAINER, 16160)

	-- Enchant Cloak - Greater Defense -- 13746
	AddRecipe(13746, 205, nil, R_COMMON, GAME_ORIG, 205, 225, 245, 265)
	self:addTradeFlags(RecipeDB, 13746, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOE, F.TANK, F.CLOAK)
	self:addTradeAcquire(RecipeDB, 13746, A.TRAINER, 11072, A.TRAINER, 11073, A.TRAINER, 11074, A.TRAINER, 19251, A.TRAINER, 19252, A.TRAINER, 33610, A.TRAINER, 16633, A.TRAINER, 1317, A.TRAINER, 3606, A.TRAINER, 4213, A.TRAINER, 16725, A.TRAINER, 3345, A.TRAINER, 3011, A.TRAINER, 33676, A.TRAINER, 18773, A.TRAINER, 5695, A.TRAINER, 4616, A.TRAINER, 7949, A.TRAINER, 5157, A.TRAINER, 19540, A.TRAINER, 18753, A.TRAINER, 16160)

	-- Enchant Cloak - Resistance -- 13794
	AddRecipe(13794, 205, nil, R_COMMON, GAME_ORIG, 205, 225, 245, 265)
	self:addTradeFlags(RecipeDB, 13794, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOE, F.CLOAK)
	self:addTradeAcquire(RecipeDB, 13794, A.TRAINER, 11072, A.TRAINER, 11073, A.TRAINER, 11074, A.TRAINER, 19251, A.TRAINER, 19252, A.TRAINER, 33610, A.TRAINER, 16633, A.TRAINER, 1317, A.TRAINER, 3606, A.TRAINER, 4213, A.TRAINER, 16725, A.TRAINER, 3345, A.TRAINER, 3011, A.TRAINER, 33676, A.TRAINER, 18773, A.TRAINER, 5695, A.TRAINER, 4616, A.TRAINER, 7949, A.TRAINER, 5157, A.TRAINER, 19540, A.TRAINER, 18753, A.TRAINER, 16160)

	-- Enchant Gloves - Agility -- 13815
	AddRecipe(13815, 210, nil, R_COMMON, GAME_ORIG, 210, 230, 250, 270)
	self:addTradeFlags(RecipeDB, 13815, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOE, F.DPS)
	self:addTradeAcquire(RecipeDB, 13815, A.TRAINER, 11072, A.TRAINER, 11073, A.TRAINER, 11074, A.TRAINER, 19251, A.TRAINER, 19252, A.TRAINER, 33610, A.TRAINER, 16633, A.TRAINER, 1317, A.TRAINER, 3606, A.TRAINER, 4213, A.TRAINER, 16725, A.TRAINER, 3345, A.TRAINER, 3011, A.TRAINER, 33676, A.TRAINER, 18773, A.TRAINER, 5695, A.TRAINER, 4616, A.TRAINER, 7949, A.TRAINER, 5157, A.TRAINER, 19540, A.TRAINER, 18753, A.TRAINER, 16160)

	-- Enchant Shield - Stamina -- 13817
	AddRecipe(13817, 210, nil, R_COMMON, GAME_ORIG, 210, 230, 250, 270)
	self:addTradeFlags(RecipeDB, 13817, F.ALLIANCE, F.HORDE, F.WORLD_DROP, F.IBOE, F.RBOE, F.SHIELD)
	self:addTradeAcquire(RecipeDB, 13817, A.WORLD_DROP, 1)

	-- Enchant Bracer - Intellect -- 13822
	AddRecipe(13822, 210, nil, R_COMMON, GAME_ORIG, 210, 230, 250, 270)
	self:addTradeFlags(RecipeDB, 13822, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOE)
	self:addTradeAcquire(RecipeDB, 13822, A.TRAINER, 11072, A.TRAINER, 11073, A.TRAINER, 11074, A.TRAINER, 19251, A.TRAINER, 19252, A.TRAINER, 33610, A.TRAINER, 16633, A.TRAINER, 1317, A.TRAINER, 3606, A.TRAINER, 4213, A.TRAINER, 16725, A.TRAINER, 3345, A.TRAINER, 3011, A.TRAINER, 33676, A.TRAINER, 18773, A.TRAINER, 5695, A.TRAINER, 4616, A.TRAINER, 7949, A.TRAINER, 5157, A.TRAINER, 19540, A.TRAINER, 18753, A.TRAINER, 16160)

	-- Enchant Boots - Stamina -- 13836
	AddRecipe(13836, 215, nil, R_COMMON, GAME_ORIG, 215, 235, 255, 275)
	self:addTradeFlags(RecipeDB, 13836, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOE)
	self:addTradeAcquire(RecipeDB, 13836, A.TRAINER, 11072, A.TRAINER, 11073, A.TRAINER, 11074, A.TRAINER, 19251, A.TRAINER, 19252, A.TRAINER, 33610, A.TRAINER, 16633, A.TRAINER, 1317, A.TRAINER, 3606, A.TRAINER, 4213, A.TRAINER, 16725, A.TRAINER, 3345, A.TRAINER, 3011, A.TRAINER, 33676, A.TRAINER, 18773, A.TRAINER, 5695, A.TRAINER, 4616, A.TRAINER, 7949, A.TRAINER, 5157, A.TRAINER, 19540, A.TRAINER, 18753, A.TRAINER, 16160)

	-- Enchant Gloves - Advanced Mining -- 13841
	AddRecipe(13841, 215, nil, R_COMMON, GAME_ORIG, 215, 235, 255, 275)
	self:addTradeFlags(RecipeDB, 13841, F.ALLIANCE, F.HORDE, F.MOB_DROP, F.IBOE, F.RBOE)
	self:addTradeAcquire(RecipeDB, 13841, A.MOB, 674)

	-- Enchant Bracer - Greater Spirit -- 13846
	AddRecipe(13846, 220, nil, R_COMMON, GAME_ORIG, 220, 240, 260, 280)
	self:addTradeFlags(RecipeDB, 13846, F.ALLIANCE, F.HORDE, F.WORLD_DROP, F.IBOE, F.RBOE, F.HEALER, F.CASTER)
	self:addTradeAcquire(RecipeDB, 13846, A.WORLD_DROP, 1)

	-- Enchant Chest - Superior Health -- 13858
	AddRecipe(13858, 220, nil, R_COMMON, GAME_ORIG, 220, 240, 260, 280)
	self:addTradeFlags(RecipeDB, 13858, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOE)
	self:addTradeAcquire(RecipeDB, 13858, A.TRAINER, 11072, A.TRAINER, 11073, A.TRAINER, 11074, A.TRAINER, 19251, A.TRAINER, 19252, A.TRAINER, 33610, A.TRAINER, 16633, A.TRAINER, 1317, A.TRAINER, 3606, A.TRAINER, 4213, A.TRAINER, 16725, A.TRAINER, 3345, A.TRAINER, 3011, A.TRAINER, 33676, A.TRAINER, 18773, A.TRAINER, 5695, A.TRAINER, 4616, A.TRAINER, 7949, A.TRAINER, 5157, A.TRAINER, 19540, A.TRAINER, 18753, A.TRAINER, 16160)

	-- Enchant Gloves - Advanced Herbalism -- 13868
	AddRecipe(13868, 225, nil, R_COMMON, GAME_ORIG, 225, 245, 265, 285)
	self:addTradeFlags(RecipeDB, 13868, F.ALLIANCE, F.HORDE, F.MOB_DROP, F.IBOE, F.RBOE)
	self:addTradeAcquire(RecipeDB, 13868, A.MOB, 764, A.MOB, 765, A.MOB, 766, A.MOB, 1081, A.MOB, 14448)

	-- Enchant Cloak - Lesser Agility -- 13882
	AddRecipe(13882, 225, nil, R_COMMON, GAME_ORIG, 225, 245, 265, 285)
	self:addTradeFlags(RecipeDB, 13882, F.ALLIANCE, F.HORDE, F.MOB_DROP, F.IBOE, F.RBOE, F.DPS, F.CLOAK)
	self:addTradeAcquire(RecipeDB, 13882, A.MOB, 2246, A.MOB, 5623, A.MOB, 7805)

	-- Enchant Gloves - Strength -- 13887
	AddRecipe(13887, 225, nil, R_COMMON, GAME_ORIG, 225, 245, 265, 285)
	self:addTradeFlags(RecipeDB, 13887, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOE, F.DPS)
	self:addTradeAcquire(RecipeDB, 13887, A.TRAINER, 11072, A.TRAINER, 11073, A.TRAINER, 11074, A.TRAINER, 19251, A.TRAINER, 19252, A.TRAINER, 33610, A.TRAINER, 16633, A.TRAINER, 1317, A.TRAINER, 3606, A.TRAINER, 4213, A.TRAINER, 16725, A.TRAINER, 3345, A.TRAINER, 3011, A.TRAINER, 33676, A.TRAINER, 18773, A.TRAINER, 5695, A.TRAINER, 4616, A.TRAINER, 7949, A.TRAINER, 5157, A.TRAINER, 19540, A.TRAINER, 18753, A.TRAINER, 16160)

	-- Enchant Boots - Minor Speed -- 13890
	AddRecipe(13890, 225, nil, R_COMMON, GAME_ORIG, 225, 245, 265, 285)
	self:addTradeFlags(RecipeDB, 13890, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOE)
	self:addTradeAcquire(RecipeDB, 13890, A.TRAINER, 11072, A.TRAINER, 11073, A.TRAINER, 11074, A.TRAINER, 19251, A.TRAINER, 19252, A.TRAINER, 33610, A.TRAINER, 16633, A.TRAINER, 1317, A.TRAINER, 3606, A.TRAINER, 4213, A.TRAINER, 16725, A.TRAINER, 3345, A.TRAINER, 3011, A.TRAINER, 33676, A.TRAINER, 18773, A.TRAINER, 5695, A.TRAINER, 4616, A.TRAINER, 7949, A.TRAINER, 5157, A.TRAINER, 19540, A.TRAINER, 18753, A.TRAINER, 16160)

	-- Enchant Weapon - Fiery Weapon -- 13898
	AddRecipe(13898, 265, nil, R_COMMON, GAME_ORIG, 265, 285, 305, 325)
	self:addTradeFlags(RecipeDB, 13898, F.ALLIANCE, F.HORDE, F.INSTANCE, F.IBOE, F.RBOE, F.ONE_HAND, F.TWO_HAND)
	self:addTradeAcquire(RecipeDB, 13898, A.MOB, 9024)

	-- Enchant Shield - Greater Spirit -- 13905
	AddRecipe(13905, 230, nil, R_COMMON, GAME_ORIG, 230, 250, 270, 290)
	self:addTradeFlags(RecipeDB, 13905, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOE, F.HEALER, F.CASTER, F.SHIELD)
	self:addTradeAcquire(RecipeDB, 13905, A.TRAINER, 11073, A.TRAINER, 19251, A.TRAINER, 19252, A.TRAINER, 33610, A.TRAINER, 16633, A.TRAINER, 11072, A.TRAINER, 1317, A.TRAINER, 3606, A.TRAINER, 4213, A.TRAINER, 16725, A.TRAINER, 3345, A.TRAINER, 3011, A.TRAINER, 11074, A.TRAINER, 33676, A.TRAINER, 18773, A.TRAINER, 5695, A.TRAINER, 4616, A.TRAINER, 7949, A.TRAINER, 5157, A.TRAINER, 19540, A.TRAINER, 18753, A.TRAINER, 16160)

	-- Enchant Weapon - Demonslaying -- 13915
	AddRecipe(13915, 230, nil, R_COMMON, GAME_ORIG, 230, 250, 270, 290)
	self:addTradeFlags(RecipeDB, 13915, F.ALLIANCE, F.HORDE, F.WORLD_DROP, F.IBOE, F.RBOE, F.ONE_HAND, F.TWO_HAND)
	self:addTradeAcquire(RecipeDB, 13915, A.WORLD_DROP, 1)

	-- Enchant Chest - Superior Mana -- 13917
	AddRecipe(13917, 230, nil, R_COMMON, GAME_ORIG, 230, 250, 270, 290)
	self:addTradeFlags(RecipeDB, 13917, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOE)
	self:addTradeAcquire(RecipeDB, 13917, A.TRAINER, 11073, A.TRAINER, 19251, A.TRAINER, 19252, A.TRAINER, 33610, A.TRAINER, 16633, A.TRAINER, 11072, A.TRAINER, 1317, A.TRAINER, 3606, A.TRAINER, 4213, A.TRAINER, 16725, A.TRAINER, 3345, A.TRAINER, 3011, A.TRAINER, 11074, A.TRAINER, 33676, A.TRAINER, 18773, A.TRAINER, 5695, A.TRAINER, 4616, A.TRAINER, 7949, A.TRAINER, 5157, A.TRAINER, 19540, A.TRAINER, 18753, A.TRAINER, 16160)

	-- Enchant Bracer - Deflection -- 13931
	AddRecipe(13931, 235, nil, R_COMMON, GAME_ORIG, 235, 255, 275, 295)
	self:addTradeFlags(RecipeDB, 13931, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOE, F.TANK)
	self:addTradeAcquire(RecipeDB, 13931, A.VENDOR, 989, A.VENDOR, 4229)

	-- Enchant Shield - Frost Resistance -- 13933
	AddRecipe(13933, 235, nil, R_COMMON, GAME_ORIG, 235, 255, 275, 295)
	self:addTradeFlags(RecipeDB, 13933, F.ALLIANCE, F.HORDE, F.INSTANCE, F.RAID, F.MOB_DROP, F.IBOE, F.RBOE, F.SHIELD)
	self:addTradeAcquire(RecipeDB, 13933, A.WORLD_DROP, 2, A.CUSTOM, 33)

	-- Enchant Boots - Agility -- 13935
	AddRecipe(13935, 235, nil, R_COMMON, GAME_ORIG, 235, 255, 275, 295)
	self:addTradeFlags(RecipeDB, 13935, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOE, F.DPS)
	self:addTradeAcquire(RecipeDB, 13935, A.TRAINER, 11073, A.TRAINER, 19251, A.TRAINER, 19252, A.TRAINER, 33610, A.TRAINER, 16633, A.TRAINER, 11072, A.TRAINER, 1317, A.TRAINER, 3606, A.TRAINER, 4213, A.TRAINER, 16725, A.TRAINER, 3345, A.TRAINER, 3011, A.TRAINER, 11074, A.TRAINER, 33676, A.TRAINER, 18773, A.TRAINER, 5695, A.TRAINER, 4616, A.TRAINER, 7949, A.TRAINER, 5157, A.TRAINER, 19540, A.TRAINER, 18753, A.TRAINER, 16160)

	-- Enchant 2H Weapon - Greater Impact -- 13937
	AddRecipe(13937, 240, nil, R_COMMON, GAME_ORIG, 240, 260, 280, 300)
	self:addTradeFlags(RecipeDB, 13937, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOE, F.TWO_HAND)
	self:addTradeAcquire(RecipeDB, 13937, A.TRAINER, 1317, A.TRAINER, 3011, A.TRAINER, 3345, A.TRAINER, 3606, A.TRAINER, 4213, A.TRAINER, 4616, A.TRAINER, 5157, A.TRAINER, 5695, A.TRAINER, 11072, A.TRAINER, 11073, A.TRAINER, 11074, A.TRAINER, 16160, A.TRAINER, 16633, A.TRAINER, 16725, A.TRAINER, 19251, A.TRAINER, 19252, A.TRAINER, 33610, A.TRAINER, 33676, A.TRAINER, 18773, A.TRAINER, 7949, A.TRAINER, 19540, A.TRAINER, 18753)

	-- Enchant Bracer - Greater Strength -- 13939
	AddRecipe(13939, 240, nil, R_COMMON, GAME_ORIG, 240, 260, 280, 300)
	self:addTradeFlags(RecipeDB, 13939, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOE, F.DPS)
	self:addTradeAcquire(RecipeDB, 13939, A.TRAINER, 11073, A.TRAINER, 19251, A.TRAINER, 19252, A.TRAINER, 33610, A.TRAINER, 16633, A.TRAINER, 11072, A.TRAINER, 1317, A.TRAINER, 3606, A.TRAINER, 4213, A.TRAINER, 16725, A.TRAINER, 3345, A.TRAINER, 3011, A.TRAINER, 11074, A.TRAINER, 33676, A.TRAINER, 18773, A.TRAINER, 5695, A.TRAINER, 4616, A.TRAINER, 7949, A.TRAINER, 5157, A.TRAINER, 19540, A.TRAINER, 18753, A.TRAINER, 16160)

	-- Enchant Chest - Stats -- 13941
	AddRecipe(13941, 245, nil, R_COMMON, GAME_ORIG, 245, 265, 285, 305)
	self:addTradeFlags(RecipeDB, 13941, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOE)
	self:addTradeAcquire(RecipeDB, 13941, A.TRAINER, 11073, A.TRAINER, 19251, A.TRAINER, 19252, A.TRAINER, 33610, A.TRAINER, 16633, A.TRAINER, 11072, A.TRAINER, 1317, A.TRAINER, 3606, A.TRAINER, 4213, A.TRAINER, 16725, A.TRAINER, 3345, A.TRAINER, 3011, A.TRAINER, 11074, A.TRAINER, 33676, A.TRAINER, 18773, A.TRAINER, 5695, A.TRAINER, 4616, A.TRAINER, 7949, A.TRAINER, 5157, A.TRAINER, 19540, A.TRAINER, 18753, A.TRAINER, 16160)

	-- Enchant Weapon - Greater Striking -- 13943
	AddRecipe(13943, 245, nil, R_COMMON, GAME_ORIG, 245, 265, 285, 305)
	self:addTradeFlags(RecipeDB, 13943, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOE, F.ONE_HAND, F.TWO_HAND)
	self:addTradeAcquire(RecipeDB, 13943, A.TRAINER, 11073, A.TRAINER, 19251, A.TRAINER, 19252, A.TRAINER, 33610, A.TRAINER, 16633, A.TRAINER, 11072, A.TRAINER, 1317, A.TRAINER, 3606, A.TRAINER, 4213, A.TRAINER, 16725, A.TRAINER, 3345, A.TRAINER, 3011, A.TRAINER, 11074, A.TRAINER, 33676, A.TRAINER, 18773, A.TRAINER, 5695, A.TRAINER, 4616, A.TRAINER, 7949, A.TRAINER, 5157, A.TRAINER, 19540, A.TRAINER, 18753, A.TRAINER, 16160)

	-- Enchant Bracer - Greater Stamina -- 13945
	AddRecipe(13945, 245, nil, R_COMMON, GAME_ORIG, 245, 265, 285, 305)
	self:addTradeFlags(RecipeDB, 13945, F.ALLIANCE, F.HORDE, F.WORLD_DROP, F.IBOE, F.RBOE)
	self:addTradeAcquire(RecipeDB, 13945, A.WORLD_DROP, 1)

	-- Enchant Gloves - Riding Skill -- 13947
	AddRecipe(13947, 250, nil, R_COMMON, GAME_ORIG, 250, 270, 290, 310)
	self:addTradeFlags(RecipeDB, 13947, F.ALLIANCE, F.HORDE, F.WORLD_DROP, F.IBOE, F.RBOE)
	self:addTradeAcquire(RecipeDB, 13947, A.WORLD_DROP, 2)

	-- Enchant Gloves - Minor Haste -- 13948
	AddRecipe(13948, 250, nil, R_COMMON, GAME_ORIG, 250, 270, 290, 310)
	self:addTradeFlags(RecipeDB, 13948, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOE)
	self:addTradeAcquire(RecipeDB, 13948, A.TRAINER, 11073, A.TRAINER, 19251, A.TRAINER, 19252, A.TRAINER, 33610, A.TRAINER, 16633, A.TRAINER, 11072, A.TRAINER, 1317, A.TRAINER, 3606, A.TRAINER, 4213, A.TRAINER, 16725, A.TRAINER, 3345, A.TRAINER, 3011, A.TRAINER, 11074, A.TRAINER, 33676, A.TRAINER, 18773, A.TRAINER, 5695, A.TRAINER, 4616, A.TRAINER, 7949, A.TRAINER, 5157, A.TRAINER, 19540, A.TRAINER, 18753, A.TRAINER, 16160)

	-- Lesser Magic Wand -- 14293
	AddRecipe(14293, 10, 11287, R_COMMON, GAME_ORIG, 10, 75, 95, 115)
	self:addTradeFlags(RecipeDB, 14293, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.WAND)
	self:addTradeAcquire(RecipeDB, 14293, A.TRAINER, 1317, A.TRAINER, 3011, A.TRAINER, 3345, A.TRAINER, 3606, A.TRAINER, 4213, A.TRAINER, 4616, A.TRAINER, 5157, A.TRAINER, 5695, A.TRAINER, 11072, A.TRAINER, 11073, A.TRAINER, 11074, A.TRAINER, 16160, A.TRAINER, 16633, A.TRAINER, 16725, A.TRAINER, 19251, A.TRAINER, 19252, A.TRAINER, 33610, A.TRAINER, 33676, A.TRAINER, 18773, A.TRAINER, 7949, A.TRAINER, 19540, A.TRAINER, 18753)

	-- Greater Magic Wand -- 14807
	AddRecipe(14807, 70, 11288, R_COMMON, GAME_ORIG, 70, 110, 130, 150)
	self:addTradeFlags(RecipeDB, 14807, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.WAND)
	self:addTradeAcquire(RecipeDB, 14807, A.TRAINER, 1317, A.TRAINER, 3011, A.TRAINER, 3345, A.TRAINER, 3606, A.TRAINER, 4213, A.TRAINER, 4616, A.TRAINER, 5157, A.TRAINER, 5695, A.TRAINER, 11072, A.TRAINER, 11073, A.TRAINER, 11074, A.TRAINER, 16160, A.TRAINER, 16633, A.TRAINER, 16725, A.TRAINER, 19251, A.TRAINER, 19252, A.TRAINER, 33610, A.TRAINER, 33676, A.TRAINER, 18773, A.TRAINER, 7949, A.TRAINER, 19540, A.TRAINER, 18753)

	-- Lesser Mystic Wand -- 14809
	AddRecipe(14809, 155, 11289, R_COMMON, GAME_ORIG, 155, 175, 195, 215)
	self:addTradeFlags(RecipeDB, 14809, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.WAND)
	self:addTradeAcquire(RecipeDB, 14809, A.TRAINER, 11072, A.TRAINER, 11073, A.TRAINER, 11074, A.TRAINER, 19251, A.TRAINER, 19252, A.TRAINER, 33610, A.TRAINER, 16633, A.TRAINER, 1317, A.TRAINER, 3606, A.TRAINER, 4213, A.TRAINER, 16725, A.TRAINER, 3345, A.TRAINER, 3011, A.TRAINER, 33676, A.TRAINER, 18773, A.TRAINER, 5695, A.TRAINER, 4616, A.TRAINER, 7949, A.TRAINER, 5157, A.TRAINER, 19540, A.TRAINER, 18753, A.TRAINER, 16160)

	-- Greater Mystic Wand -- 14810
	AddRecipe(14810, 175, 11290, R_COMMON, GAME_ORIG, 175, 195, 215, 235)
	self:addTradeFlags(RecipeDB, 14810, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.WAND)
	self:addTradeAcquire(RecipeDB, 14810, A.TRAINER, 11072, A.TRAINER, 11073, A.TRAINER, 11074, A.TRAINER, 19251, A.TRAINER, 19252, A.TRAINER, 33610, A.TRAINER, 16633, A.TRAINER, 1317, A.TRAINER, 3606, A.TRAINER, 4213, A.TRAINER, 16725, A.TRAINER, 3345, A.TRAINER, 3011, A.TRAINER, 33676, A.TRAINER, 18773, A.TRAINER, 5695, A.TRAINER, 4616, A.TRAINER, 7949, A.TRAINER, 5157, A.TRAINER, 19540, A.TRAINER, 18753, A.TRAINER, 16160)

	-- Smoking Heart of the Mountain -- 15596
	AddRecipe(15596, 265, 45050, R_UNCOMMON, GAME_ORIG, 265, 285, 305, 325)
	self:addTradeFlags(RecipeDB, 15596, F.ALLIANCE, F.HORDE, F.INSTANCE, F.MOB_DROP, F.IBOP, F.RBOP, F.TRINKET)
	self:addTradeAcquire(RecipeDB, 15596, A.MOB, 9025)

	-- Enchanted Thorium -- 17180
	AddRecipe(17180, 250, 12655, R_COMMON, GAME_ORIG, 250, 250, 255, 260)
	self:addTradeFlags(RecipeDB, 17180, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP)
	self:addTradeAcquire(RecipeDB, 17180, A.TRAINER, 11073, A.TRAINER, 19251, A.TRAINER, 19252, A.TRAINER, 33610, A.TRAINER, 16633, A.TRAINER, 11072, A.TRAINER, 1317, A.TRAINER, 3606, A.TRAINER, 4213, A.TRAINER, 16725, A.TRAINER, 3345, A.TRAINER, 3011, A.TRAINER, 11074, A.TRAINER, 33676, A.TRAINER, 18773, A.TRAINER, 5695, A.TRAINER, 4616, A.TRAINER, 7949, A.TRAINER, 5157, A.TRAINER, 19540, A.TRAINER, 18753, A.TRAINER, 16160)

	-- Enchanted Leather -- 17181
	AddRecipe(17181, 250, 12810, R_COMMON, GAME_ORIG, 250, 250, 255, 260)
	self:addTradeFlags(RecipeDB, 17181, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.LEATHER)
	self:addTradeAcquire(RecipeDB, 17181, A.TRAINER, 11073, A.TRAINER, 19251, A.TRAINER, 19252, A.TRAINER, 33610, A.TRAINER, 16633, A.TRAINER, 11072, A.TRAINER, 1317, A.TRAINER, 3606, A.TRAINER, 4213, A.TRAINER, 16725, A.TRAINER, 3345, A.TRAINER, 3011, A.TRAINER, 11074, A.TRAINER, 33676, A.TRAINER, 18773, A.TRAINER, 5695, A.TRAINER, 4616, A.TRAINER, 7949, A.TRAINER, 5157, A.TRAINER, 19540, A.TRAINER, 18753, A.TRAINER, 16160)

	-- Enchant Bracer - Greater Intellect -- 20008
	AddRecipe(20008, 255, nil, R_COMMON, GAME_ORIG, 255, 275, 295, 315)
	self:addTradeFlags(RecipeDB, 20008, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOE)
	self:addTradeAcquire(RecipeDB, 20008, A.TRAINER, 11073, A.TRAINER, 19251, A.TRAINER, 19252, A.TRAINER, 33610, A.TRAINER, 16633, A.TRAINER, 11072, A.TRAINER, 1317, A.TRAINER, 3606, A.TRAINER, 4213, A.TRAINER, 16725, A.TRAINER, 3345, A.TRAINER, 3011, A.TRAINER, 11074, A.TRAINER, 33676, A.TRAINER, 18773, A.TRAINER, 5695, A.TRAINER, 4616, A.TRAINER, 7949, A.TRAINER, 5157, A.TRAINER, 19540, A.TRAINER, 18753, A.TRAINER, 16160)

	-- Enchant Bracer - Superior Spirit -- 20009
	AddRecipe(20009, 270, nil, R_COMMON, GAME_ORIG, 270, 290, 310, 330)
	self:addTradeFlags(RecipeDB, 20009, F.ALLIANCE, F.HORDE, F.WORLD_DROP, F.IBOE, F.RBOE, F.HEALER, F.CASTER)
	self:addTradeAcquire(RecipeDB, 20009, A.WORLD_DROP, 1)

	-- Enchant Bracer - Superior Strength -- 20010
	AddRecipe(20010, 295, nil, R_COMMON, GAME_ORIG, 295, 310, 325, 340)
	self:addTradeFlags(RecipeDB, 20010, F.ALLIANCE, F.HORDE, F.MOB_DROP, F.IBOE, F.RBOE, F.DPS)
	self:addTradeAcquire(RecipeDB, 20010, A.MOB, 7372)

	-- Enchant Bracer - Superior Stamina -- 20011
	AddRecipe(20011, 300, nil, R_COMMON, GAME_ORIG, 300, 310, 325, 340)
	self:addTradeFlags(RecipeDB, 20011, F.ALLIANCE, F.HORDE, F.WORLD_DROP, F.IBOE, F.RBOE)
	self:addTradeAcquire(RecipeDB, 20011, A.WORLD_DROP, 1)

	-- Enchant Gloves - Greater Agility -- 20012
	AddRecipe(20012, 270, nil, R_COMMON, GAME_ORIG, 270, 290, 310, 330)
	self:addTradeFlags(RecipeDB, 20012, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOE, F.DPS)
	self:addTradeAcquire(RecipeDB, 20012, A.TRAINER, 11073, A.TRAINER, 19251, A.TRAINER, 19252, A.TRAINER, 33610, A.TRAINER, 16633, A.TRAINER, 11072, A.TRAINER, 1317, A.TRAINER, 3606, A.TRAINER, 4213, A.TRAINER, 16725, A.TRAINER, 3345, A.TRAINER, 3011, A.TRAINER, 11074, A.TRAINER, 33676, A.TRAINER, 18773, A.TRAINER, 5695, A.TRAINER, 4616, A.TRAINER, 7949, A.TRAINER, 5157, A.TRAINER, 19540, A.TRAINER, 18753, A.TRAINER, 16160)

	-- Enchant Gloves - Greater Strength -- 20013
	AddRecipe(20013, 295, nil, R_COMMON, GAME_ORIG, 295, 310, 325, 340)
	self:addTradeFlags(RecipeDB, 20013, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOE, F.DPS)
	self:addTradeAcquire(RecipeDB, 20013, A.TRAINER, 11073, A.TRAINER, 19251, A.TRAINER, 19252, A.TRAINER, 33610, A.TRAINER, 16633, A.TRAINER, 11072, A.TRAINER, 1317, A.TRAINER, 4213, A.TRAINER, 16725, A.TRAINER, 3345, A.TRAINER, 3011, A.TRAINER, 3606, A.TRAINER, 11074, A.TRAINER, 33676, A.TRAINER, 18773, A.TRAINER, 5695, A.TRAINER, 4616, A.TRAINER, 7949, A.TRAINER, 5157, A.TRAINER, 19540, A.TRAINER, 18753, A.TRAINER, 16160)

	-- Enchant Cloak - Greater Resistance -- 20014
	AddRecipe(20014, 265, nil, R_COMMON, GAME_ORIG, 265, 285, 305, 325)
	self:addTradeFlags(RecipeDB, 20014, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOE, F.CLOAK)
	self:addTradeAcquire(RecipeDB, 20014, A.TRAINER, 11073, A.TRAINER, 19251, A.TRAINER, 19252, A.TRAINER, 33610, A.TRAINER, 16633, A.TRAINER, 11072, A.TRAINER, 1317, A.TRAINER, 3606, A.TRAINER, 4213, A.TRAINER, 16725, A.TRAINER, 3345, A.TRAINER, 3011, A.TRAINER, 11074, A.TRAINER, 33676, A.TRAINER, 18773, A.TRAINER, 5695, A.TRAINER, 4616, A.TRAINER, 7949, A.TRAINER, 5157, A.TRAINER, 19540, A.TRAINER, 18753, A.TRAINER, 16160)

	-- Enchant Cloak - Superior Defense -- 20015
	AddRecipe(20015, 285, nil, R_COMMON, GAME_ORIG, 285, 300, 317, 335)
	self:addTradeFlags(RecipeDB, 20015, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOP, F.TANK, F.CLOAK)
	self:addTradeAcquire(RecipeDB, 20015, A.VENDOR, 12022)

	-- Enchant Shield - Vitality -- 20016
	AddRecipe(20016, 280, nil, R_COMMON, GAME_ORIG, 280, 300, 320, 340)
	self:addTradeFlags(RecipeDB, 20016, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOE, F.HEALER, F.CASTER, F.SHIELD)
	self:addTradeAcquire(RecipeDB, 20016, A.TRAINER, 11073, A.TRAINER, 19251, A.TRAINER, 19252, A.TRAINER, 33610, A.TRAINER, 16633, A.TRAINER, 11072, A.TRAINER, 1317, A.TRAINER, 3606, A.TRAINER, 4213, A.TRAINER, 16725, A.TRAINER, 3345, A.TRAINER, 3011, A.TRAINER, 11074, A.TRAINER, 33676, A.TRAINER, 18773, A.TRAINER, 5695, A.TRAINER, 4616, A.TRAINER, 7949, A.TRAINER, 5157, A.TRAINER, 19540, A.TRAINER, 18753, A.TRAINER, 16160)

	-- Enchant Shield - Greater Stamina -- 20017
	AddRecipe(20017, 265, nil, R_COMMON, GAME_ORIG, 265, 285, 305, 325)
	self:addTradeFlags(RecipeDB, 20017, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOP, F.SHIELD)
	self:addTradeAcquire(RecipeDB, 20017, A.VENDOR, 4229, A.VENDOR, 4561)

	-- Enchant Boots - Greater Stamina -- 20020
	AddRecipe(20020, 260, nil, R_COMMON, GAME_ORIG, 260, 280, 300, 320)
	self:addTradeFlags(RecipeDB, 20020, F.ALLIANCE, F.HORDE, F.WORLD_DROP, F.IBOE, F.RBOE)
	self:addTradeAcquire(RecipeDB, 20020, A.WORLD_DROP, 1)

	-- Enchant Boots - Greater Agility -- 20023
	AddRecipe(20023, 295, nil, R_COMMON, GAME_ORIG, 295, 310, 325, 340)
	self:addTradeFlags(RecipeDB, 20023, F.ALLIANCE, F.HORDE, F.TRAINER, F.MOB_DROP, F.IBOE, F.RBOE, F.DPS)
	self:addTradeAcquire(RecipeDB, 20023, A.TRAINER, 11073, A.TRAINER, 19251, A.TRAINER, 19252, A.TRAINER, 33610, A.TRAINER, 16633, A.TRAINER, 11072, A.TRAINER, 1317, A.TRAINER, 3606, A.TRAINER, 4213, A.TRAINER, 16725, A.TRAINER, 3345, A.TRAINER, 3011, A.TRAINER, 11074, A.TRAINER, 33676, A.TRAINER, 18773, A.TRAINER, 5695, A.TRAINER, 4616, A.TRAINER, 7949, A.TRAINER, 5157, A.TRAINER, 19540, A.TRAINER, 18753, A.TRAINER, 16160)

	-- Enchant Boots - Spirit -- 20024
	AddRecipe(20024, 275, nil, R_COMMON, GAME_ORIG, 275, 295, 315, 335)
	self:addTradeFlags(RecipeDB, 20024, F.ALLIANCE, F.HORDE, F.WORLD_DROP, F.IBOE, F.RBOE, F.HEALER, F.CASTER)
	self:addTradeAcquire(RecipeDB, 20024, A.WORLD_DROP, 1)

	-- Enchant Chest - Greater Stats -- 20025
	AddRecipe(20025, 300, nil, R_COMMON, GAME_ORIG, 300, 310, 325, 340)
	self:addTradeFlags(RecipeDB, 20025, F.ALLIANCE, F.HORDE, F.WORLD_DROP, F.IBOE, F.RBOE)
	self:addTradeAcquire(RecipeDB, 20025, A.WORLD_DROP, 1)

	-- Enchant Chest - Major Health -- 20026
	AddRecipe(20026, 275, nil, R_COMMON, GAME_ORIG, 275, 295, 315, 335)
	self:addTradeFlags(RecipeDB, 20026, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOP)
	self:addTradeAcquire(RecipeDB, 20026, A.VENDOR, 11189)

	-- Enchant Chest - Major Mana -- 20028
	AddRecipe(20028, 290, nil, R_COMMON, GAME_ORIG, 290, 305, 322, 340)
	self:addTradeFlags(RecipeDB, 20028, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOE)
	self:addTradeAcquire(RecipeDB, 20028, A.TRAINER, 11073, A.TRAINER, 19251, A.TRAINER, 19252, A.TRAINER, 33610, A.TRAINER, 16633, A.TRAINER, 11072, A.TRAINER, 1317, A.TRAINER, 3606, A.TRAINER, 4213, A.TRAINER, 16725, A.TRAINER, 3345, A.TRAINER, 3011, A.TRAINER, 11074, A.TRAINER, 33676, A.TRAINER, 18773, A.TRAINER, 5695, A.TRAINER, 4616, A.TRAINER, 7949, A.TRAINER, 5157, A.TRAINER, 19540, A.TRAINER, 18753, A.TRAINER, 16160)

	-- Enchant Weapon - Icy Chill -- 20029
	AddRecipe(20029, 285, nil, R_COMMON, GAME_ORIG, 285, 300, 317, 335)
	self:addTradeFlags(RecipeDB, 20029, F.ALLIANCE, F.HORDE, F.MOB_DROP, F.IBOE, F.RBOE, F.ONE_HAND, F.TWO_HAND)
	self:addTradeAcquire(RecipeDB, 20029, A.MOB, 7524)

	-- Enchant 2H Weapon - Superior Impact -- 20030
	AddRecipe(20030, 295, nil, R_COMMON, GAME_ORIG, 295, 310, 325, 340)
	self:addTradeFlags(RecipeDB, 20030, F.ALLIANCE, F.HORDE, F.INSTANCE, F.IBOE, F.RBOE, F.TWO_HAND)
	self:addTradeAcquire(RecipeDB, 20030, A.MOB, 10317)

	-- Enchant Weapon - Superior Striking -- 20031
	AddRecipe(20031, 300, nil, R_COMMON, GAME_ORIG, 300, 310, 325, 340)
	self:addTradeFlags(RecipeDB, 20031, F.ALLIANCE, F.HORDE, F.INSTANCE, F.IBOE, F.RBOE, F.ONE_HAND, F.TWO_HAND)
	self:addTradeAcquire(RecipeDB, 20031, A.MOB, 9216)

	-- Enchant Weapon - Lifestealing -- 20032
	AddRecipe(20032, 300, nil, R_COMMON, GAME_ORIG, 300, 310, 325, 340)
	self:addTradeFlags(RecipeDB, 20032, F.ALLIANCE, F.HORDE, F.INSTANCE, F.IBOE, F.RBOE, F.ONE_HAND, F.TWO_HAND)
	self:addTradeAcquire(RecipeDB, 20032, A.MOB, 10499)

	-- Enchant Weapon - Unholy Weapon -- 20033
	AddRecipe(20033, 295, nil, R_COMMON, GAME_ORIG, 295, 310, 325, 340)
	self:addTradeFlags(RecipeDB, 20033, F.ALLIANCE, F.HORDE, F.INSTANCE, F.MOB_DROP, F.IBOE, F.RBOE, F.ONE_HAND, F.TWO_HAND)
	self:addTradeAcquire(RecipeDB, 20033, A.MOB, 10398, A.MOB, 16810)

	-- Enchant Weapon - Crusader -- 20034
	AddRecipe(20034, 300, nil, R_COMMON, GAME_ORIG, 300, 310, 325, 340)
	self:addTradeFlags(RecipeDB, 20034, F.ALLIANCE, F.HORDE, F.MOB_DROP, F.IBOE, F.RBOE, F.DPS, F.ONE_HAND, F.TWO_HAND)
	self:addTradeAcquire(RecipeDB, 20034, A.MOB, 4494, A.MOB, 9451)

	-- Enchant 2H Weapon - Major Spirit -- 20035
	AddRecipe(20035, 300, nil, R_COMMON, GAME_ORIG, 300, 310, 325, 340)
	self:addTradeFlags(RecipeDB, 20035, F.ALLIANCE, F.HORDE, F.INSTANCE, F.IBOE, F.RBOE, F.HEALER, F.CASTER, F.TWO_HAND)
	self:addTradeAcquire(RecipeDB, 20035, A.MOB, 10469)

	-- Enchant 2H Weapon - Major Intellect -- 20036
	AddRecipe(20036, 300, nil, R_COMMON, GAME_ORIG, 300, 310, 325, 340)
	self:addTradeFlags(RecipeDB, 20036, F.ALLIANCE, F.HORDE, F.INSTANCE, F.IBOE, F.RBOE, F.TWO_HAND)
	self:addTradeAcquire(RecipeDB, 20036, A.MOB, 10422)

	-- Runed Arcanite Rod -- 20051
	AddRecipe(20051, 290, 16207, R_COMMON, GAME_ORIG, 290, 305, 322, 340)
	self:addTradeFlags(RecipeDB, 20051, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOP, F.RBOP)
	self:addTradeAcquire(RecipeDB, 20051, A.VENDOR, 12022)

	-- Enchant Weapon - Winter's Might -- 21931
	AddRecipe(21931, 190, nil, R_COMMON, GAME_ORIG, 190, 210, 230, 250)
	self:addTradeFlags(RecipeDB, 21931, F.ALLIANCE, F.HORDE, F.SEASONAL, F.MOB_DROP, F.IBOE, F.RBOE, F.HEALER, F.CASTER, F.ONE_HAND, F.TWO_HAND)
	self:addTradeAcquire(RecipeDB, 21931, A.SEASONAL, 1)

	-- Enchant Weapon - Spellpower -- 22749
	AddRecipe(22749, 300, nil, R_COMMON, GAME_ORIG, 300, 310, 325, 340)
	self:addTradeFlags(RecipeDB, 22749, F.ALLIANCE, F.HORDE, F.RAID, F.IBOE, F.RBOE, F.HEALER, F.CASTER, F.ONE_HAND, F.TWO_HAND)
	self:addTradeAcquire(RecipeDB, 22749, A.CUSTOM, 26)

	-- Enchant Weapon - Healing Power -- 22750
	AddRecipe(22750, 300, nil, R_COMMON, GAME_ORIG, 300, 310, 325, 340)
	self:addTradeFlags(RecipeDB, 22750, F.ALLIANCE, F.HORDE, F.RAID, F.IBOE, F.RBOE, F.HEALER, F.CASTER, F.ONE_HAND, F.TWO_HAND)
	self:addTradeAcquire(RecipeDB, 22750, A.CUSTOM, 26)

	-- Enchant Weapon - Strength -- 23799
	AddRecipe(23799, 290, nil, R_COMMON, GAME_ORIG, 290, 305, 322, 340)
	self:addTradeFlags(RecipeDB, 23799, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOE, F.DPS, F.ONE_HAND, F.TWO_HAND, F.THORIUM_BROTHERHOOD)
	self:addTradeAcquire(RecipeDB, 23799, A.REPUTATION, FAC.THORIUM_BROTHERHOOD, REP.FRIENDLY, 12944)

	-- Enchant Weapon - Agility -- 23800
	AddRecipe(23800, 290, nil, R_COMMON, GAME_ORIG, 290, 305, 322, 340)
	self:addTradeFlags(RecipeDB, 23800, F.HORDE, F.VENDOR, F.IBOE, F.RBOE, F.DPS, F.ONE_HAND, F.TWO_HAND, F.TIMBERMAW_HOLD)
	self:addTradeAcquire(RecipeDB, 23800, A.REPUTATION, FAC.TIMBERMAW_HOLD, REP.HONORED, 11557)

	-- Enchant Bracer - Mana Regeneration -- 23801
	AddRecipe(23801, 290, nil, R_COMMON, GAME_ORIG, 290, 305, 322, 340)
	self:addTradeFlags(RecipeDB, 23801, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOE, F.HEALER, F.CASTER, F.ARGENTDAWN)
	self:addTradeAcquire(RecipeDB, 23801, A.REPUTATION, FAC.ARGENTDAWN, REP.HONORED, 10856, A.REPUTATION, FAC.ARGENTDAWN, REP.HONORED, 10857, A.REPUTATION, FAC.ARGENTDAWN, REP.HONORED, 11536)

	-- Enchant Bracer - Healing Power -- 23802
	AddRecipe(23802, 300, nil, R_COMMON, GAME_ORIG, 300, 310, 325, 340)
	self:addTradeFlags(RecipeDB, 23802, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOE, F.HEALER, F.CASTER, F.ARGENTDAWN)
	self:addTradeAcquire(RecipeDB, 23802, A.REPUTATION, FAC.ARGENTDAWN, REP.REVERED, 10856, A.REPUTATION, FAC.ARGENTDAWN, REP.REVERED, 10857, A.REPUTATION, FAC.ARGENTDAWN, REP.REVERED, 11536)

	-- Enchant Weapon - Mighty Spirit -- 23803
	AddRecipe(23803, 300, nil, R_COMMON, GAME_ORIG, 300, 310, 325, 340)
	self:addTradeFlags(RecipeDB, 23803, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOP, F.HEALER, F.CASTER, F.ONE_HAND, F.TWO_HAND, F.THORIUM_BROTHERHOOD)
	self:addTradeAcquire(RecipeDB, 23803, A.REPUTATION, FAC.THORIUM_BROTHERHOOD, REP.HONORED, 12944)

	-- Enchant Weapon - Mighty Intellect -- 23804
	AddRecipe(23804, 300, nil, R_COMMON, GAME_ORIG, 300, 310, 325, 340)
	self:addTradeFlags(RecipeDB, 23804, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOP, F.ONE_HAND, F.TWO_HAND, F.THORIUM_BROTHERHOOD)
	self:addTradeAcquire(RecipeDB, 23804, A.REPUTATION, FAC.THORIUM_BROTHERHOOD, REP.REVERED, 12944)

	-- Enchant Gloves - Threat -- 25072
	AddRecipe(25072, 300, nil, R_RARE, GAME_ORIG, 300, 310, 325, 340)
	self:addTradeFlags(RecipeDB, 25072, F.ALLIANCE, F.HORDE, F.VENDOR, F.RAID, F.MOB_DROP, F.IBOE, F.RBOE, F.TANK, F.SHATAR)
	self:addTradeAcquire(RecipeDB, 25072, A.MOB, 15275, A.REPUTATION, FAC.SHATAR, REP.EXALTED, 21432)

	-- Enchant Gloves - Shadow Power -- 25073
	AddRecipe(25073, 300, nil, R_COMMON, GAME_ORIG, 300, 310, 325, 340)
	self:addTradeFlags(RecipeDB, 25073, F.ALLIANCE, F.HORDE, F.RAID, F.IBOE, F.RBOE, F.HEALER, F.CASTER)
	self:addTradeAcquire(RecipeDB, 25073, A.CUSTOM, 22)

	-- Enchant Gloves - Frost Power -- 25074
	AddRecipe(25074, 300, nil, R_COMMON, GAME_ORIG, 300, 310, 325, 340)
	self:addTradeFlags(RecipeDB, 25074, F.ALLIANCE, F.HORDE, F.RAID, F.IBOE, F.RBOE, F.HEALER, F.CASTER)
	self:addTradeAcquire(RecipeDB, 25074, A.CUSTOM, 22)

	-- Enchant Gloves - Fire Power -- 25078
	AddRecipe(25078, 300, nil, R_COMMON, GAME_ORIG, 300, 310, 325, 340)
	self:addTradeFlags(RecipeDB, 25078, F.ALLIANCE, F.HORDE, F.RAID, F.IBOE, F.RBOE, F.HEALER, F.CASTER)
	self:addTradeAcquire(RecipeDB, 25078, A.CUSTOM, 22)

	-- Enchant Gloves - Healing Power -- 25079
	AddRecipe(25079, 300, nil, R_COMMON, GAME_ORIG, 300, 310, 325, 340)
	self:addTradeFlags(RecipeDB, 25079, F.ALLIANCE, F.HORDE, F.RAID, F.IBOE, F.RBOE, F.HEALER, F.CASTER)
	self:addTradeAcquire(RecipeDB, 25079, A.CUSTOM, 22)

	-- Enchant Gloves - Superior Agility -- 25080
	AddRecipe(25080, 300, nil, R_COMMON, GAME_TBC, 300, 310, 325, 340)
	self:addTradeFlags(RecipeDB, 25080, F.ALLIANCE, F.HORDE, F.VENDOR, F.RAID, F.IBOE, F.RBOE, F.DPS, F.KOT)
	self:addTradeAcquire(RecipeDB, 25080, A.CUSTOM, 22, A.REPUTATION, FAC.KEEPERS_OF_TIME, REP.EXALTED, 21643)

	-- Enchant Cloak - Greater Fire Resistance -- 25081
	AddRecipe(25081, 300, nil, R_COMMON, GAME_ORIG, 300, 310, 325, 340)
	self:addTradeFlags(RecipeDB, 25081, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOE, F.CLOAK, F.CENARION_CIRCLE)
	self:addTradeAcquire(RecipeDB, 25081, A.REPUTATION, FAC.CENARION_CIRCLE, REP.FRIENDLY, 15419)

	-- Enchant Cloak - Greater Nature Resistance -- 25082
	AddRecipe(25082, 300, nil, R_COMMON, GAME_ORIG, 300, 310, 325, 340)
	self:addTradeFlags(RecipeDB, 25082, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOE, F.CLOAK, F.CENARION_CIRCLE)
	self:addTradeAcquire(RecipeDB, 25082, A.REPUTATION, FAC.CENARION_CIRCLE, REP.HONORED, 15419)

	-- Enchant Cloak - Stealth -- 25083
	AddRecipe(25083, 300, nil, R_COMMON, GAME_TBC, 300, 310, 325, 340)
	self:addTradeFlags(RecipeDB, 25083, F.ALLIANCE, F.HORDE, F.VENDOR, F.RAID, F.WORLD_DROP, F.IBOE, F.RBOE, F.CLOAK)
	self:addTradeAcquire(RecipeDB, 25083, A.CUSTOM, 22, A.REPUTATION, FAC.CENARION_EXPEDITION, REP.EXALTED, 17904)

	-- Enchant Cloak - Subtlety -- 25084
	AddRecipe(25084, 300, nil, R_COMMON, GAME_TBC, 300, 310, 325, 340)
	self:addTradeFlags(RecipeDB, 25084, F.ALLIANCE, F.HORDE, F.VENDOR, F.RAID, F.IBOE, F.RBOE, F.CLOAK, F.HELLFIRE)
	self:addTradeAcquire(RecipeDB, 25084, A.MOB, 15276, A.REPUTATION, FAC.HONOR_HOLD, REP.EXALTED, 17657, A.REPUTATION, FAC.THRALLMAR, REP.EXALTED, 17585)

	-- Enchant Cloak - Dodge -- 25086
	AddRecipe(25086, 300, nil, R_COMMON, GAME_TBC, 300, 310, 325, 340)
	self:addTradeFlags(RecipeDB, 25086, F.ALLIANCE, F.HORDE, F.VENDOR, F.RAID, F.WORLD_DROP, F.IBOE, F.RBOE, F.TANK, F.CLOAK, F.LOWERCITY)
	self:addTradeAcquire(RecipeDB, 25086, A.CUSTOM, 22, A.REPUTATION, FAC.LOWERCITY, REP.EXALTED, 21655)

	-- Minor Wizard Oil -- 25124
	AddRecipe(25124, 45, 20744, R_COMMON, GAME_ORIG, 45, 55, 65, 75)
	self:addTradeFlags(RecipeDB, 25124, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOE, F.HEALER, F.CASTER)
	self:addTradeAcquire(RecipeDB, 25124, A.VENDOR, 1318, A.VENDOR, 3012, A.VENDOR, 3346, A.VENDOR, 4228, A.VENDOR, 4617, A.VENDOR, 5158, A.VENDOR, 5757, A.VENDOR, 5758, A.VENDOR, 15419, A.VENDOR, 16635, A.VENDOR, 16722, A.VENDOR, 18753, A.VENDOR, 18773, A.VENDOR, 18951, A.VENDOR, 19234, A.VENDOR, 19537, A.VENDOR, 19540, A.VENDOR, 19663, A.VENDOR, 26569, A.VENDOR, 27030, A.VENDOR, 27054, A.VENDOR, 27147, A.VENDOR, 28714)

	-- Minor Mana Oil -- 25125
	AddRecipe(25125, 150, 20745, R_COMMON, GAME_ORIG, 150, 160, 170, 180)
	self:addTradeFlags(RecipeDB, 25125, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOE)
	self:addTradeAcquire(RecipeDB, 25125, A.VENDOR, 1318, A.VENDOR, 3012, A.VENDOR, 3346, A.VENDOR, 4228, A.VENDOR, 4617, A.VENDOR, 5158, A.VENDOR, 5757, A.VENDOR, 5758, A.VENDOR, 15419, A.VENDOR, 16635, A.VENDOR, 16722, A.VENDOR, 18753, A.VENDOR, 18773, A.VENDOR, 18951, A.VENDOR, 19234, A.VENDOR, 19537, A.VENDOR, 19540, A.VENDOR, 19663, A.VENDOR, 26569, A.VENDOR, 27030, A.VENDOR, 27054, A.VENDOR, 27147, A.VENDOR, 28714)

	-- Lesser Wizard Oil -- 25126
	AddRecipe(25126, 200, 20746, R_COMMON, GAME_ORIG, 200, 210, 220, 230)
	self:addTradeFlags(RecipeDB, 25126, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOE, F.HEALER, F.CASTER)
	self:addTradeAcquire(RecipeDB, 25126, A.VENDOR, 1318, A.VENDOR, 3012, A.VENDOR, 3346, A.VENDOR, 4228, A.VENDOR, 4617, A.VENDOR, 5158, A.VENDOR, 5757, A.VENDOR, 5758, A.VENDOR, 15419, A.VENDOR, 16635, A.VENDOR, 16722, A.VENDOR, 18753, A.VENDOR, 18773, A.VENDOR, 18951, A.VENDOR, 19234, A.VENDOR, 19537, A.VENDOR, 19540, A.VENDOR, 19663, A.VENDOR, 26569, A.VENDOR, 27030, A.VENDOR, 27054, A.VENDOR, 27147, A.VENDOR, 28714)

	-- Lesser Mana Oil -- 25127
	AddRecipe(25127, 250, 20747, R_COMMON, GAME_ORIG, 250, 260, 270, 280)
	self:addTradeFlags(RecipeDB, 25127, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOE)
	self:addTradeAcquire(RecipeDB, 25127, A.VENDOR, 15419)

	-- Wizard Oil -- 25128
	AddRecipe(25128, 275, 20750, R_COMMON, GAME_ORIG, 275, 285, 295, 305)
	self:addTradeFlags(RecipeDB, 25128, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOE, F.HEALER, F.CASTER)
	self:addTradeAcquire(RecipeDB, 25128, A.VENDOR, 15419)

	-- Brilliant Wizard Oil -- 25129
	AddRecipe(25129, 300, 20749, R_COMMON, GAME_ORIG, 300, 310, 320, 330)
	self:addTradeFlags(RecipeDB, 25129, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOP, F.HEALER, F.CASTER, F.ZANDALAR)
	self:addTradeAcquire(RecipeDB, 25129, A.REPUTATION, FAC.ZANDALAR, REP.HONORED, 14921)

	-- Brilliant Mana Oil -- 25130
	AddRecipe(25130, 300, 20748, R_COMMON, GAME_ORIG, 300, 310, 320, 330)
	self:addTradeFlags(RecipeDB, 25130, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOP, F.HEALER, F.CASTER, F.ZANDALAR)
	self:addTradeAcquire(RecipeDB, 25130, A.REPUTATION, FAC.ZANDALAR, REP.FRIENDLY, 14921)

	-- Enchant 2H Weapon - Agility -- 27837
	AddRecipe(27837, 290, nil, R_COMMON, GAME_ORIG, 290, 305, 322, 340)
	self:addTradeFlags(RecipeDB, 27837, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOE, F.DPS, F.TWO_HAND, F.TIMBERMAW_HOLD)
	self:addTradeAcquire(RecipeDB, 27837, A.REPUTATION, FAC.TIMBERMAW_HOLD, REP.FRIENDLY, 11557)

	-- Enchant Bracer - Brawn -- 27899
	AddRecipe(27899, 305, nil, R_COMMON, GAME_TBC, 305, 315, 330, 345)
	self:addTradeFlags(RecipeDB, 27899, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOE, F.DPS)
	self:addTradeAcquire(RecipeDB, 27899, A.TRAINER, 18753, A.TRAINER, 18773, A.TRAINER, 19252, A.TRAINER, 19540, A.TRAINER, 33610, A.TRAINER, 33676)

	-- Enchant Bracer - Stats -- 27905
	AddRecipe(27905, 315, nil, R_COMMON, GAME_TBC, 315, 325, 340, 355)
	self:addTradeFlags(RecipeDB, 27905, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOE)
	self:addTradeAcquire(RecipeDB, 27905, A.TRAINER, 18753, A.TRAINER, 18773, A.TRAINER, 19252, A.TRAINER, 19540, A.TRAINER, 33610, A.TRAINER, 33676)

	-- Enchant Bracer - Major Defense -- 27906
	AddRecipe(27906, 320, nil, R_COMMON, GAME_TBC, 320, 330, 345, 360)
	self:addTradeFlags(RecipeDB, 27906, F.ALLIANCE, F.HORDE, F.MOB_DROP, F.IBOE, F.RBOE, F.TANK)
	self:addTradeAcquire(RecipeDB, 27906, A.MOB, 22822, A.MOB, 23008)

	-- Enchant Bracer - Superior Healing -- 27911
	AddRecipe(27911, 325, nil, R_COMMON, GAME_TBC, 325, 335, 350, 365)
	self:addTradeFlags(RecipeDB, 27911, F.HORDE, F.VENDOR, F.IBOE, F.RBOE, F.HEALER, F.CASTER, F.HELLFIRE)
	self:addTradeAcquire(RecipeDB, 27911, A.REPUTATION, FAC.HONOR_HOLD, REP.FRIENDLY, 17657, A.REPUTATION, FAC.THRALLMAR, REP.FRIENDLY, 17585)

	-- Enchant Bracer - Restore Mana Prime -- 27913
	AddRecipe(27913, 335, nil, R_COMMON, GAME_TBC, 335, 345, 360, 375)
	self:addTradeFlags(RecipeDB, 27913, F.ALLIANCE, F.HORDE, F.WORLD_DROP, F.IBOE, F.RBOE, F.HEALER, F.CASTER)
	self:addTradeAcquire(RecipeDB, 27913, A.WORLD_DROP, 1)

	-- Enchant Bracer - Fortitude -- 27914
	AddRecipe(27914, 350, nil, R_COMMON, GAME_TBC, 350, 370, 375, 380)
	self:addTradeFlags(RecipeDB, 27914, F.ALLIANCE, F.HORDE, F.INSTANCE, F.IBOE, F.RBOE)
	self:addTradeAcquire(RecipeDB, 27914, A.MOB, 17803)

	-- Enchant Bracer - Spellpower -- 27917
	AddRecipe(27917, 360, nil, R_COMMON, GAME_TBC, 360, 370, 385, 400)
	self:addTradeFlags(RecipeDB, 27917, F.ALLIANCE, F.HORDE, F.MOB_DROP, F.IBOE, F.RBOE, F.HEALER, F.CASTER)
	self:addTradeAcquire(RecipeDB, 27917, A.MOB, 19952)

	-- Enchant Ring - Striking -- 27920
	AddRecipe(27920, 360, nil, R_COMMON, GAME_TBC, 360, 370, 377, 385)
	self:addTradeFlags(RecipeDB, 27920, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOP, F.RING, F.CONSORTIUM)
	self:addTradeAcquire(RecipeDB, 27920, A.REPUTATION, FAC.CONSORTIUM, REP.REVERED, 17518)

	-- Enchant Ring - Spellpower -- 27924
	AddRecipe(27924, 360, nil, R_COMMON, GAME_TBC, 360, 370, 377, 385)
	self:addTradeFlags(RecipeDB, 27924, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOP, F.HEALER, F.CASTER, F.RING, F.KOT)
	self:addTradeAcquire(RecipeDB, 27924, A.REPUTATION, FAC.KEEPERS_OF_TIME, REP.HONORED, 21643)

	-- Enchant Ring - Healing Power -- 27926
	AddRecipe(27926, 370, nil, R_COMMON, GAME_TBC, 370, 380, 385, 390)
	self:addTradeFlags(RecipeDB, 27926, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOP, F.RBOP, F.HEALER, F.CASTER, F.RING, F.SHATAR)
	self:addTradeAcquire(RecipeDB, 27926, A.REPUTATION, FAC.SHATAR, REP.REVERED, 21432)

	-- Enchant Ring - Stats -- 27927
	AddRecipe(27927, 375, nil, R_COMMON, GAME_TBC, 375, 380, 385, 390)
	self:addTradeFlags(RecipeDB, 27927, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOP, F.RING, F.LOWERCITY)
	self:addTradeAcquire(RecipeDB, 27927, A.REPUTATION, FAC.LOWERCITY, REP.HONORED, 21655)

	-- Enchant Shield - Tough Shield -- 27944
	AddRecipe(27944, 310, nil, R_COMMON, GAME_TBC, 310, 320, 335, 350)
	self:addTradeFlags(RecipeDB, 27944, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOE, F.TANK, F.SHIELD)
	self:addTradeAcquire(RecipeDB, 27944, A.TRAINER, 18753, A.TRAINER, 18773, A.TRAINER, 19252, A.TRAINER, 19540, A.TRAINER, 33610, A.TRAINER, 33676)

	-- Enchant Shield - Intellect -- 27945
	AddRecipe(27945, 325, nil, R_COMMON, GAME_TBC, 325, 335, 350, 365)
	self:addTradeFlags(RecipeDB, 27945, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOE, F.SHIELD)
	self:addTradeAcquire(RecipeDB, 27945, A.VENDOR, 18664)

	-- Enchant Shield - Shield Block -- 27946
	AddRecipe(27946, 340, nil, R_COMMON, GAME_TBC, 340, 350, 365, 380)
	self:addTradeFlags(RecipeDB, 27946, F.ALLIANCE, F.HORDE, F.WORLD_DROP, F.IBOE, F.RBOE, F.TANK, F.SHIELD)
	self:addTradeAcquire(RecipeDB, 27946, A.WORLD_DROP, 1)

	-- Enchant Shield - Resistance -- 27947
	AddRecipe(27947, 360, nil, R_COMMON, GAME_TBC, 360, 370, 375, 380)
	self:addTradeFlags(RecipeDB, 27947, F.ALLIANCE, F.HORDE, F.WORLD_DROP, F.IBOE, F.RBOE, F.SHIELD)
	self:addTradeAcquire(RecipeDB, 27947, A.WORLD_DROP, 1)

	-- Enchant Boots - Vitality -- 27948
	AddRecipe(27948, 305, nil, R_COMMON, GAME_TBC, 305, 315, 330, 345)
	self:addTradeFlags(RecipeDB, 27948, F.ALLIANCE, F.HORDE, F.MOB_DROP, F.IBOE, F.RBOE, F.HEALER, F.CASTER)
	self:addTradeAcquire(RecipeDB, 27948, A.MOB, 24664)

	-- Enchant Boots - Fortitude -- 27950
	AddRecipe(27950, 320, nil, R_COMMON, GAME_TBC, 320, 330, 345, 360)
	self:addTradeFlags(RecipeDB, 27950, F.ALLIANCE, F.HORDE, F.INSTANCE, F.MOB_DROP, F.IBOE, F.RBOE)
	self:addTradeAcquire(RecipeDB, 27950, A.MOB, 18317)

	-- Enchant Boots - Dexterity -- 27951
	AddRecipe(27951, 340, nil, R_COMMON, GAME_TBC, 340, 350, 365, 380)
	self:addTradeFlags(RecipeDB, 27951, F.ALLIANCE, F.HORDE, F.INSTANCE, F.IBOE, F.RBOE, F.DPS)
	self:addTradeAcquire(RecipeDB, 27951, A.MOB, 18521)

	-- Enchant Boots - Surefooted -- 27954
	AddRecipe(27954, 370, nil, R_COMMON, GAME_TBC, 370, 380, 385, 390)
	self:addTradeFlags(RecipeDB, 27954, F.ALLIANCE, F.HORDE, F.RAID, F.IBOE, F.RBOP, F.DPS, F.CASTER)
	self:addTradeAcquire(RecipeDB, 27954, A.MOB, 16472)

	-- Enchant Chest - Exceptional Health -- 27957
	AddRecipe(27957, 315, nil, R_COMMON, GAME_TBC, 315, 325, 340, 355)
	self:addTradeFlags(RecipeDB, 27957, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOE)
	self:addTradeAcquire(RecipeDB, 27957, A.TRAINER, 18753, A.TRAINER, 18773, A.TRAINER, 19252, A.TRAINER, 19540, A.TRAINER, 33610, A.TRAINER, 33676)

	-- Enchant Chest - Exceptional Mana -- 27958
	AddRecipe(27958, 350, nil, R_COMMON, GAME_WOTLK, 350, 360, 370, 380)
	self:addTradeFlags(RecipeDB, 27958, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP)
	self:addTradeAcquire(RecipeDB, 27958, A.TRAINER, 28693, A.TRAINER, 33583, A.TRAINER, 26990, A.TRAINER, 26980, A.TRAINER, 26954, A.TRAINER, 26906)

	-- Enchant Chest - Exceptional Stats -- 27960
	AddRecipe(27960, 345, nil, R_COMMON, GAME_TBC, 345, 355, 367, 380)
	self:addTradeFlags(RecipeDB, 27960, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOE, F.HELLFIRE)
	self:addTradeAcquire(RecipeDB, 27960, A.REPUTATION, FAC.HONOR_HOLD, REP.REVERED, 17657, A.REPUTATION, FAC.THRALLMAR, REP.REVERED, 17585)

	-- Enchant Cloak - Major Armor -- 27961
	AddRecipe(27961, 310, nil, R_COMMON, GAME_TBC, 310, 320, 335, 350)
	self:addTradeFlags(RecipeDB, 27961, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOE, F.CLOAK)
	self:addTradeAcquire(RecipeDB, 27961, A.TRAINER, 18753, A.TRAINER, 18773, A.TRAINER, 19252, A.TRAINER, 19540, A.TRAINER, 33610, A.TRAINER, 33676)

	-- Enchant Cloak - Major Resistance -- 27962
	AddRecipe(27962, 330, nil, R_COMMON, GAME_TBC, 330, 340, 355, 370)
	self:addTradeFlags(RecipeDB, 27962, F.ALLIANCE, F.HORDE, F.WORLD_DROP, F.IBOE, F.RBOE, F.CLOAK)
	self:addTradeAcquire(RecipeDB, 27962, A.WORLD_DROP, 1)

	-- Enchant Weapon - Major Striking -- 27967
	AddRecipe(27967, 340, nil, R_COMMON, GAME_TBC, 340, 350, 365, 380)
	self:addTradeFlags(RecipeDB, 27967, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOE, F.ONE_HAND, F.TWO_HAND, F.CONSORTIUM)
	self:addTradeAcquire(RecipeDB, 27967, A.REPUTATION, FAC.CONSORTIUM, REP.HONORED, 20242, A.REPUTATION, FAC.CONSORTIUM, REP.HONORED, 23007)

	-- Enchant Weapon - Major Intellect -- 27968
	AddRecipe(27968, 340, nil, R_COMMON, GAME_TBC, 340, 350, 365, 380)
	self:addTradeFlags(RecipeDB, 27968, F.ALLIANCE, F.HORDE, F.MOB_DROP, F.IBOE, F.RBOE, F.ONE_HAND, F.TWO_HAND)
	self:addTradeAcquire(RecipeDB, 27968, A.MOB, 20136)

	-- Enchant 2H Weapon - Savagery -- 27971
	AddRecipe(27971, 350, nil, R_COMMON, GAME_TBC, 350, 370, 375, 380)
	self:addTradeFlags(RecipeDB, 27971, F.ALLIANCE, F.HORDE, F.INSTANCE, F.IBOE, F.RBOE, F.DPS, F.TWO_HAND)
	self:addTradeAcquire(RecipeDB, 27971, A.MOB, 17465)

	-- Enchant Weapon - Potency -- 27972
	AddRecipe(27972, 350, nil, R_COMMON, GAME_TBC, 350, 370, 375, 380)
	self:addTradeFlags(RecipeDB, 27972, F.ALLIANCE, F.HORDE, F.WORLD_DROP, F.IBOE, F.RBOE, F.DPS, F.ONE_HAND, F.TWO_HAND)
	self:addTradeAcquire(RecipeDB, 27972, A.WORLD_DROP, 1)

	-- Enchant Weapon - Major Spellpower -- 27975
	AddRecipe(27975, 350, nil, R_COMMON, GAME_TBC, 350, 370, 375, 380)
	self:addTradeFlags(RecipeDB, 27975, F.ALLIANCE, F.HORDE, F.MOB_DROP, F.IBOE, F.RBOE, F.HEALER, F.CASTER, F.ONE_HAND, F.TWO_HAND)
	self:addTradeAcquire(RecipeDB, 27975, A.MOB, 22242)

	-- Enchant 2H Weapon - Major Agility -- 27977
	AddRecipe(27977, 360, nil, R_COMMON, GAME_TBC, 360, 370, 377, 385)
	self:addTradeFlags(RecipeDB, 27977, F.ALLIANCE, F.HORDE, F.INSTANCE, F.IBOE, F.RBOE, F.DPS, F.TWO_HAND)
	self:addTradeAcquire(RecipeDB, 27977, A.MOB, 20880)

	-- Enchant Weapon - Sunfire -- 27981
	AddRecipe(27981, 375, nil, R_COMMON, GAME_TBC, 375, 375, 375, 390)
	self:addTradeFlags(RecipeDB, 27981, F.ALLIANCE, F.HORDE, F.RAID, F.MOB_DROP, F.IBOE, F.RBOE, F.HEALER, F.CASTER, F.ONE_HAND, F.TWO_HAND)
	self:addTradeAcquire(RecipeDB, 27981, A.MOB, 16524)

	-- Enchant Weapon - Soulfrost -- 27982
	AddRecipe(27982, 375, nil, R_COMMON, GAME_TBC, 375, 380, 385, 390)
	self:addTradeFlags(RecipeDB, 27982, F.ALLIANCE, F.HORDE, F.RAID, F.IBOE, F.RBOE, F.HEALER, F.CASTER, F.ONE_HAND, F.TWO_HAND)
	self:addTradeAcquire(RecipeDB, 27982, A.MOB, 15688)

	-- Enchant Weapon - Mongoose -- 27984
	AddRecipe(27984, 375, nil, R_RARE, GAME_TBC, 375, 380, 385, 390)
	self:addTradeFlags(RecipeDB, 27984, F.ALLIANCE, F.HORDE, F.RAID, F.MOB_DROP, F.IBOE, F.RBOE, F.DPS, F.ONE_HAND, F.TWO_HAND)
	self:addTradeAcquire(RecipeDB, 27984, A.MOB, 15687)

	-- Enchant Weapon - Spellsurge -- 28003
	AddRecipe(28003, 360, nil, R_COMMON, GAME_TBC, 360, 370, 377, 385)
	self:addTradeFlags(RecipeDB, 28003, F.ALLIANCE, F.HORDE, F.INSTANCE, F.RAID, F.MOB_DROP, F.IBOE, F.RBOE, F.ONE_HAND, F.TWO_HAND)
	self:addTradeAcquire(RecipeDB, 28003, A.WORLD_DROP, 2)

	-- Enchant Weapon - Battlemaster -- 28004
	AddRecipe(28004, 360, nil, R_COMMON, GAME_TBC, 360, 370, 377, 385)
	self:addTradeFlags(RecipeDB, 28004, F.ALLIANCE, F.HORDE, F.INSTANCE, F.RAID, F.MOB_DROP, F.IBOE, F.RBOE, F.ONE_HAND, F.TWO_HAND)
	self:addTradeAcquire(RecipeDB, 28004, A.WORLD_DROP, 2)

	-- Superior Mana Oil -- 28016
	AddRecipe(28016, 310, 22521, R_COMMON, GAME_TBC, 310, 310, 320, 330)
	self:addTradeFlags(RecipeDB, 28016, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOE)
	self:addTradeAcquire(RecipeDB, 28016, A.VENDOR, 16635, A.VENDOR, 16722, A.VENDOR, 19663)

	-- Superior Wizard Oil -- 28019
	AddRecipe(28019, 340, 22522, R_COMMON, GAME_TBC, 340, 340, 350, 360)
	self:addTradeFlags(RecipeDB, 28019, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOE, F.HEALER, F.CASTER)
	self:addTradeAcquire(RecipeDB, 28019, A.VENDOR, 16635, A.VENDOR, 16722, A.VENDOR, 19663)

	-- Large Prismatic Shard -- 28022
	AddRecipe(28022, 335, 22449, R_COMMON, GAME_TBC, 335, 335, 335, 335)
	self:addTradeFlags(RecipeDB, 28022, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOE)
	self:addTradeAcquire(RecipeDB, 28022, A.VENDOR, 16635, A.VENDOR, 16722, A.VENDOR, 19663)

	-- Prismatic Sphere -- 28027
	AddRecipe(28027, 325, 22460, R_COMMON, GAME_TBC, 325, 325, 330, 335)
	self:addTradeFlags(RecipeDB, 28027, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP)
	self:addTradeAcquire(RecipeDB, 28027, A.TRAINER, 18753, A.TRAINER, 18773, A.TRAINER, 19252, A.TRAINER, 19540, A.TRAINER, 33610, A.TRAINER, 33676)

	-- Void Sphere -- 28028
	AddRecipe(28028, 350, 22459, R_COMMON, GAME_TBC, 350, 370, 375, 380)
	self:addTradeFlags(RecipeDB, 28028, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP)
	self:addTradeAcquire(RecipeDB, 28028, A.TRAINER, 18753, A.TRAINER, 18773, A.TRAINER, 19252, A.TRAINER, 19540, A.TRAINER, 33610, A.TRAINER, 33676)

	-- Runed Fel Iron Rod -- 32664
	AddRecipe(32664, 300, 22461, R_COMMON, GAME_TBC, 300, 310, 325, 340)
	self:addTradeFlags(RecipeDB, 32664, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOP, F.RBOP)
	self:addTradeAcquire(RecipeDB, 32664, A.TRAINER, 18753, A.TRAINER, 18773, A.TRAINER, 19252, A.TRAINER, 19540, A.TRAINER, 33610, A.TRAINER, 33676)

	-- Runed Adamantite Rod -- 32665
	AddRecipe(32665, 350, 22462, R_COMMON, GAME_TBC, 350, 370, 375, 380)
	self:addTradeFlags(RecipeDB, 32665, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOP, F.RBOP)
	self:addTradeAcquire(RecipeDB, 32665, A.VENDOR, 18960, A.VENDOR, 19004)

	-- Runed Eternium Rod -- 32667
	AddRecipe(32667, 375, 22463, R_COMMON, GAME_TBC, 375, 375, 377, 385)
	self:addTradeFlags(RecipeDB, 32667, F.ALLIANCE, F.HORDE, F.TRAINER, F.VENDOR, F.IBOP, F.RBOP)
	self:addTradeAcquire(RecipeDB, 32667, A.VENDOR, 19663, A.TRAINER, 28693, A.TRAINER, 33583, A.TRAINER, 26990, A.TRAINER, 26980, A.TRAINER, 26954, A.TRAINER, 26906)

	-- Enchant Chest - Major Spirit -- 33990
	AddRecipe(33990, 320, nil, R_COMMON, GAME_TBC, 320, 330, 345, 360)
	self:addTradeFlags(RecipeDB, 33990, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOE, F.HEALER, F.CASTER)
	self:addTradeAcquire(RecipeDB, 33990, A.TRAINER, 18753, A.TRAINER, 18773, A.TRAINER, 19252, A.TRAINER, 19540, A.TRAINER, 33610, A.TRAINER, 33676)

	-- Enchant Chest - Restore Mana Prime -- 33991
	AddRecipe(33991, 300, nil, R_COMMON, GAME_TBC, 300, 310, 325, 340)
	self:addTradeFlags(RecipeDB, 33991, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOE, F.HEALER, F.CASTER)
	self:addTradeAcquire(RecipeDB, 33991, A.TRAINER, 18753, A.TRAINER, 18773, A.TRAINER, 19252, A.TRAINER, 19540, A.TRAINER, 33610, A.TRAINER, 33676)

	-- Enchant Chest - Major Resilience -- 33992
	AddRecipe(33992, 345, nil, R_COMMON, GAME_TBC, 345, 355, 367, 380)
	self:addTradeFlags(RecipeDB, 33992, F.ALLIANCE, F.HORDE, F.WORLD_DROP, F.IBOE, F.RBOE)
	self:addTradeAcquire(RecipeDB, 33992, A.WORLD_DROP, 1)

	-- Enchant Gloves - Blasting -- 33993
	AddRecipe(33993, 305, nil, R_COMMON, GAME_TBC, 305, 315, 330, 345)
	self:addTradeFlags(RecipeDB, 33993, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOE)
	self:addTradeAcquire(RecipeDB, 33993, A.TRAINER, 18753, A.TRAINER, 18773, A.TRAINER, 19252, A.TRAINER, 19540, A.TRAINER, 33610, A.TRAINER, 33676)

	-- Enchant Gloves - Precise Strikes -- 33994
	AddRecipe(33994, 360, nil, R_COMMON, GAME_TBC, 360, 370, 377, 385)
	self:addTradeFlags(RecipeDB, 33994, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOE, F.CENARION_EXPEDITION)
	self:addTradeAcquire(RecipeDB, 33994, A.REPUTATION, FAC.CENARION_EXPEDITION, REP.REVERED, 17904)

	-- Enchant Gloves - Major Strength -- 33995
	AddRecipe(33995, 340, nil, R_COMMON, GAME_TBC, 340, 350, 365, 380)
	self:addTradeFlags(RecipeDB, 33995, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOE, F.DPS)
	self:addTradeAcquire(RecipeDB, 33995, A.TRAINER, 18753, A.TRAINER, 18773, A.TRAINER, 19252, A.TRAINER, 19540, A.TRAINER, 33610, A.TRAINER, 33676)

	-- Enchant Gloves - Assault -- 33996
	AddRecipe(33996, 310, nil, R_COMMON, GAME_TBC, 310, 320, 335, 350)
	self:addTradeFlags(RecipeDB, 33996, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOE, F.DPS)
	self:addTradeAcquire(RecipeDB, 33996, A.TRAINER, 18753, A.TRAINER, 18773, A.TRAINER, 19252, A.TRAINER, 19540, A.TRAINER, 33610, A.TRAINER, 33676)

	-- Enchant Gloves - Major Spellpower -- 33997
	AddRecipe(33997, 360, nil, R_COMMON, GAME_TBC, 360, 370, 377, 385)
	self:addTradeFlags(RecipeDB, 33997, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOE, F.HEALER, F.CASTER, F.KOT)
	self:addTradeAcquire(RecipeDB, 33997, A.REPUTATION, FAC.KEEPERS_OF_TIME, REP.HONORED, 21643)

	-- Enchant Gloves - Major Healing -- 33999
	AddRecipe(33999, 350, nil, R_COMMON, GAME_TBC, 350, 370, 375, 380)
	self:addTradeFlags(RecipeDB, 33999, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOE, F.HEALER, F.CASTER, F.SHATAR)
	self:addTradeAcquire(RecipeDB, 33999, A.REPUTATION, FAC.SHATAR, REP.HONORED, 21432)

	-- Enchant Bracer - Major Intellect -- 34001
	AddRecipe(34001, 305, nil, R_COMMON, GAME_TBC, 305, 315, 330, 345)
	self:addTradeFlags(RecipeDB, 34001, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOE)
	self:addTradeAcquire(RecipeDB, 34001, A.TRAINER, 18753, A.TRAINER, 18773, A.TRAINER, 19252, A.TRAINER, 19540, A.TRAINER, 33610, A.TRAINER, 33676)

	-- Enchant Bracer - Assault -- 34002
	AddRecipe(34002, 300, nil, R_COMMON, GAME_TBC, 300, 310, 325, 340)
	self:addTradeFlags(RecipeDB, 34002, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOE, F.DPS)
	self:addTradeAcquire(RecipeDB, 34002, A.TRAINER, 18753, A.TRAINER, 18773, A.TRAINER, 19252, A.TRAINER, 19540, A.TRAINER, 33610, A.TRAINER, 33676)

	-- Enchant Cloak - Spell Penetration -- 34003
	AddRecipe(34003, 325, nil, R_COMMON, GAME_TBC, 325, 335, 350, 365)
	self:addTradeFlags(RecipeDB, 34003, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOE, F.CASTER, F.CLOAK, F.CONSORTIUM)
	self:addTradeAcquire(RecipeDB, 34003, A.REPUTATION, FAC.CONSORTIUM, REP.FRIENDLY, 20242, A.REPUTATION, FAC.CONSORTIUM, REP.FRIENDLY, 23007)

	-- Enchant Cloak - Greater Agility -- 34004
	AddRecipe(34004, 310, nil, R_COMMON, GAME_TBC, 310, 320, 335, 350)
	self:addTradeFlags(RecipeDB, 34004, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOE, F.DPS, F.CLOAK)
	self:addTradeAcquire(RecipeDB, 34004, A.TRAINER, 18753, A.TRAINER, 18773, A.TRAINER, 19252, A.TRAINER, 19540, A.TRAINER, 33610, A.TRAINER, 33676)

	-- Enchant Cloak - Greater Arcane Resistance -- 34005
	AddRecipe(34005, 350, nil, R_COMMON, GAME_TBC, 350, 370, 375, 380)
	self:addTradeFlags(RecipeDB, 34005, F.ALLIANCE, F.HORDE, F.MOB_DROP, F.IBOE, F.RBOE, F.CLOAK)
	self:addTradeAcquire(RecipeDB, 34005, A.MOB, 19796)

	-- Enchant Cloak - Greater Shadow Resistance -- 34006
	AddRecipe(34006, 350, nil, R_COMMON, GAME_TBC, 350, 370, 375, 380)
	self:addTradeFlags(RecipeDB, 34006, F.ALLIANCE, F.HORDE, F.MOB_DROP, F.IBOE, F.RBOE, F.CLOAK)
	self:addTradeAcquire(RecipeDB, 34006, A.MOB, 18870)

	-- Enchant Boots - Cat's Swiftness -- 34007
	AddRecipe(34007, 360, nil, R_COMMON, GAME_TBC, 360, 370, 377, 385)
	self:addTradeFlags(RecipeDB, 34007, F.ALLIANCE, F.HORDE, F.MOB_DROP, F.IBOE, F.RBOE, F.DPS)
	self:addTradeAcquire(RecipeDB, 34007, A.MOB, 24664)

	-- Enchant Boots - Boar's Speed -- 34008
	AddRecipe(34008, 360, nil, R_COMMON, GAME_TBC, 360, 370, 377, 385)
	self:addTradeFlags(RecipeDB, 34008, F.ALLIANCE, F.HORDE, F.MOB_DROP, F.IBOE, F.RBOE)
	self:addTradeAcquire(RecipeDB, 34008, A.MOB, 24664)

	-- Enchant Shield - Major Stamina -- 34009
	AddRecipe(34009, 325, nil, R_COMMON, GAME_TBC, 325, 335, 350, 365)
	self:addTradeFlags(RecipeDB, 34009, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOE, F.SHIELD)
	self:addTradeAcquire(RecipeDB, 34009, A.VENDOR, 19663)

	-- Enchant Weapon - Major Healing -- 34010
	AddRecipe(34010, 350, nil, R_COMMON, GAME_TBC, 350, 370, 375, 380)
	self:addTradeFlags(RecipeDB, 34010, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOE, F.HEALER, F.CASTER, F.ONE_HAND, F.TWO_HAND, F.SHATAR)
	self:addTradeAcquire(RecipeDB, 34010, A.REPUTATION, FAC.SHATAR, REP.REVERED, 21432)

	-- Nexus Transformation -- 42613
	AddRecipe(42613, 300, 22448, R_COMMON, GAME_TBC, 300, 300, 300, 305)
	self:addTradeFlags(RecipeDB, 42613, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP)
	self:addTradeAcquire(RecipeDB, 42613, A.TRAINER, 18753, A.TRAINER, 18773, A.TRAINER, 19252, A.TRAINER, 33610, A.TRAINER, 33676, A.TRAINER, 19540)

	-- Small Prismatic Shard -- 42615
	AddRecipe(42615, 335, 22448, R_COMMON, GAME_TBC, 335, 335, 335, 335)
	self:addTradeFlags(RecipeDB, 42615, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP)
	self:addTradeAcquire(RecipeDB, 42615, A.TRAINER, 18753, A.TRAINER, 18773, A.TRAINER, 19252, A.TRAINER, 19540, A.TRAINER, 33610, A.TRAINER, 33676)

	-- Enchant Weapon - Greater Agility -- 42620
	AddRecipe(42620, 350, nil, R_COMMON, GAME_TBC, 350, 360, 367, 375)
	self:addTradeFlags(RecipeDB, 42620, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOE, F.DPS, F.ONE_HAND, F.TWO_HAND, F.VIOLETEYE)
	self:addTradeAcquire(RecipeDB, 42620, A.REPUTATION, FAC.VIOLETEYE, REP.EXALTED, 18255)

	-- Enchant Weapon - Executioner -- 42974
	AddRecipe(42974, 375, nil, R_COMMON, GAME_TBC, 375, 380, 385, 390)
	self:addTradeFlags(RecipeDB, 42974, F.ALLIANCE, F.HORDE, F.RAID, F.IBOE, F.RBOE, F.DPS, F.ONE_HAND, F.TWO_HAND)
	self:addTradeAcquire(RecipeDB, 42974, A.CUSTOM, 29)

	-- Enchant Shield - Resilience -- 44383
	AddRecipe(44383, 330, nil, R_COMMON, GAME_TBC, 330, 340, 355, 370)
	self:addTradeFlags(RecipeDB, 44383, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.SHIELD)
	self:addTradeAcquire(RecipeDB, 44383, A.TRAINER, 18753, A.TRAINER, 18773, A.TRAINER, 19252, A.TRAINER, 19540, A.TRAINER, 33610, A.TRAINER, 33676)

	-- Enchant Cloak - Superior Frost Resistance -- 44483
	AddRecipe(44483, 400, nil, R_COMMON, GAME_WOTLK, 400, 415, 425, 435)
	self:addTradeFlags(RecipeDB, 44483, F.ALLIANCE, F.HORDE, F.MOB_DROP, F.IBOE, F.RBOE, F.CLOAK)
	self:addTradeAcquire(RecipeDB, 44483, A.MOB, 32289)

	-- Enchant Gloves - Expertise -- 44484
	AddRecipe(44484, 405, nil, R_COMMON, GAME_WOTLK, 405, 415, 425, 435)
	self:addTradeFlags(RecipeDB, 44484, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.DPS, F.TANK)
	self:addTradeAcquire(RecipeDB, 44484, A.TRAINER, 26906, A.TRAINER, 26954, A.TRAINER, 26980, A.TRAINER, 26990, A.TRAINER, 28693, A.TRAINER, 33583)

	-- Enchant Gloves - Precision -- 44488
	AddRecipe(44488, 410, nil, R_COMMON, GAME_WOTLK, 410, 420, 430, 440)
	self:addTradeFlags(RecipeDB, 44488, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP)
	self:addTradeAcquire(RecipeDB, 44488, A.TRAINER, 26906, A.TRAINER, 26954, A.TRAINER, 26980, A.TRAINER, 26990, A.TRAINER, 28693, A.TRAINER, 33583)

	-- Enchant Shield - Defense -- 44489
	AddRecipe(44489, 420, nil, R_COMMON, GAME_WOTLK, 420, 430, 440, 450)
	self:addTradeFlags(RecipeDB, 44489, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.TANK, F.SHIELD)
	self:addTradeAcquire(RecipeDB, 44489, A.TRAINER, 26906, A.TRAINER, 26954, A.TRAINER, 26980, A.TRAINER, 26990, A.TRAINER, 28693, A.TRAINER, 33583)

	-- Enchant Chest - Mighty Health -- 44492
	AddRecipe(44492, 395, nil, R_COMMON, GAME_WOTLK, 395, 405, 415, 425)
	self:addTradeFlags(RecipeDB, 44492, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP)
	self:addTradeAcquire(RecipeDB, 44492, A.TRAINER, 26906, A.TRAINER, 26954, A.TRAINER, 26980, A.TRAINER, 26990, A.TRAINER, 28693, A.TRAINER, 33583)

	-- Enchant Cloak - Superior Nature Resistance -- 44494
	AddRecipe(44494, 400, nil, R_COMMON, GAME_WOTLK, 400, 415, 425, 435)
	self:addTradeFlags(RecipeDB, 44494, F.ALLIANCE, F.HORDE, F.MOB_DROP, F.IBOE, F.RBOE, F.CLOAK)
	self:addTradeAcquire(RecipeDB, 44494, A.MOB, 32290)

	-- Enchant Cloak - Superior Agility -- 44500
	AddRecipe(44500, 395, nil, R_COMMON, GAME_WOTLK, 395, 405, 415, 425)
	self:addTradeFlags(RecipeDB, 44500, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.DPS, F.CLOAK)
	self:addTradeAcquire(RecipeDB, 44500, A.TRAINER, 26906, A.TRAINER, 26954, A.TRAINER, 26980, A.TRAINER, 26990, A.TRAINER, 28693, A.TRAINER, 33583)

	-- Enchant Gloves - Gatherer -- 44506
	AddRecipe(44506, 375, nil, R_COMMON, GAME_WOTLK, 375, 375, 380, 390)
	self:addTradeFlags(RecipeDB, 44506, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP)
	self:addTradeAcquire(RecipeDB, 44506, A.TRAINER, 26906, A.TRAINER, 26954, A.TRAINER, 26980, A.TRAINER, 26990, A.TRAINER, 28693, A.TRAINER, 33583)

	-- Enchant Boots - Greater Spirit -- 44508
	AddRecipe(44508, 410, nil, R_COMMON, GAME_WOTLK, 410, 420, 430, 440)
	self:addTradeFlags(RecipeDB, 44508, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.HEALER, F.CASTER)
	self:addTradeAcquire(RecipeDB, 44508, A.TRAINER, 26906, A.TRAINER, 26954, A.TRAINER, 26980, A.TRAINER, 26990, A.TRAINER, 28693, A.TRAINER, 33583)

	-- Enchant Chest - Greater Mana Restoration -- 44509
	AddRecipe(44509, 420, nil, R_COMMON, GAME_WOTLK, 420, 430, 440, 450)
	self:addTradeFlags(RecipeDB, 44509, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.HEALER, F.CASTER)
	self:addTradeAcquire(RecipeDB, 44509, A.TRAINER, 26906, A.TRAINER, 26954, A.TRAINER, 26980, A.TRAINER, 26990, A.TRAINER, 28693, A.TRAINER, 33583)

	-- Enchant Weapon - Exceptional Spirit -- 44510
	AddRecipe(44510, 410, nil, R_COMMON, GAME_WOTLK, 410, 420, 430, 440)
	self:addTradeFlags(RecipeDB, 44510, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.HEALER, F.CASTER, F.ONE_HAND, F.TWO_HAND)
	self:addTradeAcquire(RecipeDB, 44510, A.TRAINER, 26906, A.TRAINER, 26954, A.TRAINER, 26980, A.TRAINER, 26990, A.TRAINER, 28693, A.TRAINER, 33583)

	-- Enchant Gloves - Greater Assault -- 44513
	AddRecipe(44513, 395, nil, R_COMMON, GAME_WOTLK, 395, 405, 415, 425)
	self:addTradeFlags(RecipeDB, 44513, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.DPS)
	self:addTradeAcquire(RecipeDB, 44513, A.TRAINER, 26906, A.TRAINER, 26954, A.TRAINER, 26980, A.TRAINER, 26990, A.TRAINER, 28693, A.TRAINER, 33583)

	-- Enchant Weapon - Icebreaker -- 44524
	AddRecipe(44524, 425, nil, R_COMMON, GAME_WOTLK, 425, 435, 445, 455)
	self:addTradeFlags(RecipeDB, 44524, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOE, F.ONE_HAND, F.TWO_HAND)
	self:addTradeAcquire(RecipeDB, 44524, A.VENDOR, 32514)

	-- Enchant Boots - Greater Fortitude -- 44528
	AddRecipe(44528, 385, nil, R_COMMON, GAME_WOTLK, 385, 385, 390, 400)
	self:addTradeFlags(RecipeDB, 44528, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP)
	self:addTradeAcquire(RecipeDB, 44528, A.TRAINER, 26906, A.TRAINER, 26954, A.TRAINER, 26980, A.TRAINER, 26990, A.TRAINER, 28693, A.TRAINER, 33583)

	-- Enchant Gloves - Major Agility -- 44529
	AddRecipe(44529, 415, nil, R_COMMON, GAME_WOTLK, 415, 425, 435, 445)
	self:addTradeFlags(RecipeDB, 44529, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.DPS)
	self:addTradeAcquire(RecipeDB, 44529, A.TRAINER, 26906, A.TRAINER, 26954, A.TRAINER, 26980, A.TRAINER, 26990, A.TRAINER, 28693, A.TRAINER, 33583)

	-- Enchant Bracers - Exceptional Intellect -- 44555
	AddRecipe(44555, 375, nil, R_COMMON, GAME_WOTLK, 375, 385, 392, 400)
	self:addTradeFlags(RecipeDB, 44555, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP)
	self:addTradeAcquire(RecipeDB, 44555, A.TRAINER, 26906, A.TRAINER, 26954, A.TRAINER, 26980, A.TRAINER, 26990, A.TRAINER, 28693, A.TRAINER, 33583)

	-- Enchant Cloak - Superior Fire Resistance -- 44556
	AddRecipe(44556, 400, nil, R_COMMON, GAME_WOTLK, 400, 415, 425, 435)
	self:addTradeFlags(RecipeDB, 44556, F.ALLIANCE, F.HORDE, F.MOB_DROP, F.IBOE, F.RBOE, F.CLOAK)
	self:addTradeAcquire(RecipeDB, 44556, A.MOB, 30921)

	-- Enchant Bracers - Greater Assault -- 44575
	AddRecipe(44575, 430, nil, R_COMMON, GAME_WOTLK, 430, 440, 450, 460)
	self:addTradeFlags(RecipeDB, 44575, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOE, F.DPS)
	self:addTradeAcquire(RecipeDB, 44575, A.VENDOR, 32514)

	-- Enchant Weapon - Lifeward -- 44576
	AddRecipe(44576, 425, nil, R_RARE, GAME_WOTLK, 425, 435, 445, 455)
	self:addTradeFlags(RecipeDB, 44576, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOP, F.ONE_HAND, F.TWO_HAND)
	self:addTradeAcquire(RecipeDB, 44576, A.VENDOR, 32514)

	-- Enchant Cloak - Spell Piercing -- 44582
	AddRecipe(44582, 395, nil, R_COMMON, GAME_WOTLK, 395, 395, 402, 410)
	self:addTradeFlags(RecipeDB, 44582, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.CASTER, F.CLOAK)
	self:addTradeAcquire(RecipeDB, 44582, A.TRAINER, 26906, A.TRAINER, 26954, A.TRAINER, 26980, A.TRAINER, 26990, A.TRAINER, 28693, A.TRAINER, 33583)

	-- Enchant Boots - Greater Vitality -- 44584
	AddRecipe(44584, 405, nil, R_COMMON, GAME_WOTLK, 405, 415, 425, 435)
	self:addTradeFlags(RecipeDB, 44584, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP)
	self:addTradeAcquire(RecipeDB, 44584, A.TRAINER, 26906, A.TRAINER, 26954, A.TRAINER, 26980, A.TRAINER, 26990, A.TRAINER, 28693, A.TRAINER, 33583)

	-- Enchant Chest - Exceptional Resilience -- 44588
	AddRecipe(44588, 410, nil, R_UNCOMMON, GAME_WOTLK, 410, 435, 445, 455)
	self:addTradeFlags(RecipeDB, 44588, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOP)
	self:addTradeAcquire(RecipeDB, 44588, A.VENDOR, 32514)

	-- Enchant Boots - Superior Agility -- 44589
	AddRecipe(44589, 415, nil, R_COMMON, GAME_WOTLK, 415, 425, 435, 445)
	self:addTradeFlags(RecipeDB, 44589, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.DPS)
	self:addTradeAcquire(RecipeDB, 44589, A.TRAINER, 26906, A.TRAINER, 26954, A.TRAINER, 26980, A.TRAINER, 26990, A.TRAINER, 28693, A.TRAINER, 33583)

	-- Enchant Cloak - Superior Shadow Resistance -- 44590
	AddRecipe(44590, 400, nil, R_COMMON, GAME_WOTLK, 400, 415, 425, 435)
	self:addTradeFlags(RecipeDB, 44590, F.ALLIANCE, F.HORDE, F.MOB_DROP, F.IBOE, F.RBOE, F.CLOAK)
	self:addTradeAcquire(RecipeDB, 44590, A.MOB, 32349)

	-- Enchant Cloak - Titanweave -- 44591
	AddRecipe(44591, 435, nil, R_COMMON, GAME_WOTLK, 435, 445, 455, 465)
	self:addTradeFlags(RecipeDB, 44591, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOE, F.TANK, F.CLOAK)
	self:addTradeAcquire(RecipeDB, 44591, A.VENDOR, 32514)

	-- Enchant Gloves - Exceptional Spellpower -- 44592
	AddRecipe(44592, 360, nil, R_COMMON, GAME_WOTLK, 360, 370, 380, 390)
	self:addTradeFlags(RecipeDB, 44592, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.HEALER, F.CASTER)
	self:addTradeAcquire(RecipeDB, 44592, A.TRAINER, 26906, A.TRAINER, 26954, A.TRAINER, 26980, A.TRAINER, 26990, A.TRAINER, 28693, A.TRAINER, 33583)

	-- Enchant Bracers - Major Spirit -- 44593
	AddRecipe(44593, 420, nil, R_COMMON, GAME_WOTLK, 420, 430, 440, 450)
	self:addTradeFlags(RecipeDB, 44593, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.HEALER, F.CASTER)
	self:addTradeAcquire(RecipeDB, 44593, A.TRAINER, 26906, A.TRAINER, 26954, A.TRAINER, 26980, A.TRAINER, 26990, A.TRAINER, 28693, A.TRAINER, 33583)

	-- Enchant 2H Weapon - Scourgebane -- 44595
	AddRecipe(44595, 430, nil, R_RARE, GAME_WOTLK, 430, 440, 450, 460)
	self:addTradeFlags(RecipeDB, 44595, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOP, F.DPS, F.ONE_HAND, F.TWO_HAND)
	self:addTradeAcquire(RecipeDB, 44595, A.VENDOR, 32514)

	-- Enchant Cloak - Superior Arcane Resistance -- 44596
	AddRecipe(44596, 400, nil, R_COMMON, GAME_WOTLK, 400, 415, 425, 435)
	self:addTradeFlags(RecipeDB, 44596, F.ALLIANCE, F.HORDE, F.MOB_DROP, F.IBOE, F.RBOE, F.CLOAK)
	self:addTradeAcquire(RecipeDB, 44596, A.MOB, 31702, A.MOB, 32297)

	-- Enchant Bracers - Expertise -- 44598
	AddRecipe(44598, 415, nil, R_COMMON, GAME_WOTLK, 415, 425, 435, 445)
	self:addTradeFlags(RecipeDB, 44598, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.DPS, F.TANK)
	self:addTradeAcquire(RecipeDB, 44598, A.TRAINER, 26906, A.TRAINER, 26954, A.TRAINER, 26980, A.TRAINER, 26990, A.TRAINER, 28693, A.TRAINER, 33583)

	-- Enchant Bracers - Greater Stats -- 44616
	AddRecipe(44616, 400, nil, R_COMMON, GAME_WOTLK, 400, 410, 420, 430)
	self:addTradeFlags(RecipeDB, 44616, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP)
	self:addTradeAcquire(RecipeDB, 44616, A.TRAINER, 26906, A.TRAINER, 26954, A.TRAINER, 26980, A.TRAINER, 26990, A.TRAINER, 28693, A.TRAINER, 33583)

	-- Enchant Weapon - Giant Slayer -- 44621
	AddRecipe(44621, 430, nil, R_COMMON, GAME_WOTLK, 430, 440, 450, 460)
	self:addTradeFlags(RecipeDB, 44621, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOE, F.ONE_HAND, F.TWO_HAND)
	self:addTradeAcquire(RecipeDB, 44621, A.VENDOR, 32514)

	-- Enchant Chest - Super Stats -- 44623
	AddRecipe(44623, 370, nil, R_COMMON, GAME_WOTLK, 370, 380, 390, 400)
	self:addTradeFlags(RecipeDB, 44623, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP)
	self:addTradeAcquire(RecipeDB, 44623, A.TRAINER, 26906, A.TRAINER, 26954, A.TRAINER, 26980, A.TRAINER, 26990, A.TRAINER, 28693, A.TRAINER, 33583)

	-- Enchant Gloves - Armsman -- 44625
	AddRecipe(44625, 435, nil, R_UNCOMMON, GAME_WOTLK, 435, 445, 455, 465)
	self:addTradeFlags(RecipeDB, 44625, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOP, F.TANK)
	self:addTradeAcquire(RecipeDB, 44625, A.VENDOR, 32514)

	-- Enchant Weapon - Exceptional Spellpower -- 44629
	AddRecipe(44629, 395, nil, R_COMMON, GAME_WOTLK, 395, 405, 415, 425)
	self:addTradeFlags(RecipeDB, 44629, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.HEALER, F.CASTER, F.ONE_HAND, F.TWO_HAND)
	self:addTradeAcquire(RecipeDB, 44629, A.TRAINER, 26906, A.TRAINER, 26954, A.TRAINER, 26980, A.TRAINER, 26990, A.TRAINER, 28693, A.TRAINER, 33583)

	-- Enchant 2H Weapon - Greater Savagery -- 44630
	AddRecipe(44630, 390, nil, R_COMMON, GAME_WOTLK, 390, 400, 410, 420)
	self:addTradeFlags(RecipeDB, 44630, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.DPS, F.TWO_HAND)
	self:addTradeAcquire(RecipeDB, 44630, A.TRAINER, 26906, A.TRAINER, 26954, A.TRAINER, 26980, A.TRAINER, 26990, A.TRAINER, 28693, A.TRAINER, 33583)

	-- Enchant Cloak - Shadow Armor -- 44631
	AddRecipe(44631, 440, nil, R_COMMON, GAME_WOTLK, 440, 450, 460, 470)
	self:addTradeFlags(RecipeDB, 44631, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOE, F.DPS, F.CLOAK)
	self:addTradeAcquire(RecipeDB, 44631, A.VENDOR, 32514)

	-- Enchant Weapon - Exceptional Agility -- 44633
	AddRecipe(44633, 410, nil, R_COMMON, GAME_WOTLK, 410, 420, 430, 440)
	self:addTradeFlags(RecipeDB, 44633, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.DPS, F.ONE_HAND, F.TWO_HAND)
	self:addTradeAcquire(RecipeDB, 44633, A.TRAINER, 26906, A.TRAINER, 26954, A.TRAINER, 26980, A.TRAINER, 26990, A.TRAINER, 28693, A.TRAINER, 33583)

	-- Enchant Bracers - Greater Spellpower -- 44635
	AddRecipe(44635, 395, nil, R_COMMON, GAME_WOTLK, 395, 405, 415, 425)
	self:addTradeFlags(RecipeDB, 44635, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.HEALER, F.CASTER)
	self:addTradeAcquire(RecipeDB, 44635, A.TRAINER, 26906, A.TRAINER, 26954, A.TRAINER, 26980, A.TRAINER, 26990, A.TRAINER, 28693, A.TRAINER, 33583)

	-- Enchant Ring - Greater Spellpower -- 44636
	AddRecipe(44636, 400, nil, R_COMMON, GAME_WOTLK, 400, 400, 407, 415)
	self:addTradeFlags(RecipeDB, 44636, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.HEALER, F.CASTER, F.RING)
	self:addTradeAcquire(RecipeDB, 44636, A.TRAINER, 26906, A.TRAINER, 26954, A.TRAINER, 26980, A.TRAINER, 26990, A.TRAINER, 28693, A.TRAINER, 33583)

	-- Enchant Ring - Assault -- 44645
	AddRecipe(44645, 400, nil, R_COMMON, GAME_WOTLK, 400, 400, 407, 415)
	self:addTradeFlags(RecipeDB, 44645, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.DPS, F.RING)
	self:addTradeAcquire(RecipeDB, 44645, A.TRAINER, 26906, A.TRAINER, 26954, A.TRAINER, 26980, A.TRAINER, 26990, A.TRAINER, 28693, A.TRAINER, 33583)

	-- Void Shatter -- 45765
	AddRecipe(45765, 375, 22449, R_COMMON, GAME_TBC, 375, 375, 375, 375)
	self:addTradeFlags(RecipeDB, 45765, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOP, F.SHATTEREDSUN)
	self:addTradeAcquire(RecipeDB, 45765, A.REPUTATION, FAC.SHATTEREDSUN, REP.HONORED, 25032)

	-- Enchant Weapon - Deathfrost -- 46578
	AddRecipe(46578, 350, nil, R_COMMON, GAME_TBC, 350, 350, 357, 365)
	self:addTradeFlags(RecipeDB, 46578, F.ALLIANCE, F.HORDE, F.SEASONAL, F.IBOE, F.RBOE, F.ONE_HAND, F.TWO_HAND)
	self:addTradeAcquire(RecipeDB, 46578, A.SEASONAL, 4)

	-- Enchant Chest - Defense -- 46594
	AddRecipe(46594, 360, nil, R_COMMON, GAME_WOTLK, 360, 370, 385, 400)
	self:addTradeFlags(RecipeDB, 46594, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOE, F.TANK, F.SHATTEREDSUN)
	self:addTradeAcquire(RecipeDB, 46594, A.REPUTATION, FAC.SHATTEREDSUN, REP.HONORED, 25032)

	-- Enchant Cloak - Steelweave -- 47051
	AddRecipe(47051, 375, nil, R_COMMON, GAME_WOTLK, 375, 380, 385, 390)
	self:addTradeFlags(RecipeDB, 47051, F.ALLIANCE, F.HORDE, F.INSTANCE, F.IBOE, F.RBOE, F.TANK, F.CLOAK)
	self:addTradeAcquire(RecipeDB, 47051, A.MOB, 24560)

	-- Enchant Cloak - Mighty Armor -- 47672
	AddRecipe(47672, 430, nil, R_UNCOMMON, GAME_WOTLK, 430, 440, 450, 460)
	self:addTradeFlags(RecipeDB, 47672, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOP, F.CLOAK)
	self:addTradeAcquire(RecipeDB, 47672, A.VENDOR, 32514)

	-- Enchant Chest - Greater Defense -- 47766
	AddRecipe(47766, 400, nil, R_COMMON, GAME_WOTLK, 400, 410, 420, 430)
	self:addTradeFlags(RecipeDB, 47766, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.TANK)
	self:addTradeAcquire(RecipeDB, 47766, A.TRAINER, 26906, A.TRAINER, 26954, A.TRAINER, 26980, A.TRAINER, 26990, A.TRAINER, 28693, A.TRAINER, 33583)

	-- Enchant Cloak - Greater Speed -- 47898
	AddRecipe(47898, 430, nil, R_UNCOMMON, GAME_WOTLK, 430, 440, 450, 460)
	self:addTradeFlags(RecipeDB, 47898, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOP, F.CLOAK)
	self:addTradeAcquire(RecipeDB, 47898, A.VENDOR, 32514)

	-- Enchant Cloak - Wisdom -- 47899
	AddRecipe(47899, 440, nil, R_UNCOMMON, GAME_WOTLK, 440, 450, 460, 470)
	self:addTradeFlags(RecipeDB, 47899, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOP, F.HEALER, F.CASTER, F.CLOAK)
	self:addTradeAcquire(RecipeDB, 47899, A.VENDOR, 32514)

	-- Enchant Chest - Super Health -- 47900
	AddRecipe(47900, 425, nil, R_COMMON, GAME_WOTLK, 425, 435, 445, 455)
	self:addTradeFlags(RecipeDB, 47900, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP)
	self:addTradeAcquire(RecipeDB, 47900, A.TRAINER, 26906, A.TRAINER, 26954, A.TRAINER, 26980, A.TRAINER, 26990, A.TRAINER, 28693, A.TRAINER, 33583)

	-- Enchant Boots - Tuskarr's Vitality -- 47901
	AddRecipe(47901, 440, nil, R_UNCOMMON, GAME_WOTLK, 440, 450, 460, 470)
	self:addTradeFlags(RecipeDB, 47901, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOP)
	self:addTradeAcquire(RecipeDB, 47901, A.VENDOR, 32514)

	-- Enchant Weapon - Accuracy -- 59619
	AddRecipe(59619, 440, nil, R_COMMON, GAME_WOTLK, 440, 450, 460, 470)
	self:addTradeFlags(RecipeDB, 59619, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOE, F.ONE_HAND, F.TWO_HAND)
	self:addTradeAcquire(RecipeDB, 59619, A.VENDOR, 32514)

	-- Enchant Weapon - Berserking -- 59621
	AddRecipe(59621, 440, nil, R_COMMON, GAME_WOTLK, 440, 450, 460, 470)
	self:addTradeFlags(RecipeDB, 59621, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOE, F.DPS, F.ONE_HAND, F.TWO_HAND)
	self:addTradeAcquire(RecipeDB, 59621, A.VENDOR, 32514)

	-- Enchant Weapon - Black Magic -- 59625
	AddRecipe(59625, 440, nil, R_RARE, GAME_WOTLK, 440, 450, 460, 470)
	self:addTradeFlags(RecipeDB, 59625, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOP, F.ONE_HAND, F.TWO_HAND)
	self:addTradeAcquire(RecipeDB, 59625, A.VENDOR, 32514)

	-- Enchant Ring - Stamina -- 59636
	AddRecipe(59636, 400, nil, R_COMMON, GAME_WOTLK, 400, 400, 407, 415)
	self:addTradeFlags(RecipeDB, 59636, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.RING)
	self:addTradeAcquire(RecipeDB, 59636, A.TRAINER, 26906, A.TRAINER, 26954, A.TRAINER, 26980, A.TRAINER, 26990, A.TRAINER, 28693, A.TRAINER, 33583)

	-- Enchant Boots - Assault -- 60606
	AddRecipe(60606, 375, nil, R_COMMON, GAME_WOTLK, 375, 385, 395, 405)
	self:addTradeFlags(RecipeDB, 60606, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.DPS)
	self:addTradeAcquire(RecipeDB, 60606, A.TRAINER, 26906, A.TRAINER, 26954, A.TRAINER, 26980, A.TRAINER, 26990, A.TRAINER, 28693, A.TRAINER, 33583)

	-- Enchant Cloak - Speed -- 60609
	AddRecipe(60609, 350, nil, R_COMMON, GAME_WOTLK, 350, 360, 370, 380)
	self:addTradeFlags(RecipeDB, 60609, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.CLOAK)
	self:addTradeAcquire(RecipeDB, 60609, A.TRAINER, 26906, A.TRAINER, 26954, A.TRAINER, 26980, A.TRAINER, 26990, A.TRAINER, 28693, A.TRAINER, 33583)

	-- Enchant Bracers - Striking -- 60616
	AddRecipe(60616, 360, nil, R_COMMON, GAME_WOTLK, 360, 370, 380, 390)
	self:addTradeFlags(RecipeDB, 60616, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.DPS)
	self:addTradeAcquire(RecipeDB, 60616, A.TRAINER, 26906, A.TRAINER, 26954, A.TRAINER, 26980, A.TRAINER, 26990, A.TRAINER, 28693, A.TRAINER, 33583)

	-- Runed Titanium Rod -- 60619
	AddRecipe(60619, 425, 44452, R_RARE, GAME_WOTLK, 425, 435, 445, 455)
	self:addTradeFlags(RecipeDB, 60619, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOP, F.RBOP)
	self:addTradeAcquire(RecipeDB, 60619, A.TRAINER, 26906, A.TRAINER, 26954, A.TRAINER, 26980, A.TRAINER, 26990, A.TRAINER, 28693, A.TRAINER, 33583)

	-- Enchant Weapon - Greater Potency -- 60621
	AddRecipe(60621, 380, nil, R_COMMON, GAME_WOTLK, 380, 390, 400, 410)
	self:addTradeFlags(RecipeDB, 60621, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.DPS, F.ONE_HAND, F.TWO_HAND)
	self:addTradeAcquire(RecipeDB, 60621, A.TRAINER, 26906, A.TRAINER, 26954, A.TRAINER, 26980, A.TRAINER, 26990, A.TRAINER, 28693, A.TRAINER, 33583)

	-- Enchant Boots - Icewalker -- 60623
	AddRecipe(60623, 385, nil, R_COMMON, GAME_WOTLK, 385, 395, 405, 415)
	self:addTradeFlags(RecipeDB, 60623, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP)
	self:addTradeAcquire(RecipeDB, 60623, A.TRAINER, 26906, A.TRAINER, 26954, A.TRAINER, 26980, A.TRAINER, 26990, A.TRAINER, 28693, A.TRAINER, 33583)

	-- Enchant Shield - Greater Intellect -- 60653
	AddRecipe(60653, 395, nil, R_COMMON, GAME_WOTLK, 395, 405, 415, 425)
	self:addTradeFlags(RecipeDB, 60653, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.SHIELD)
	self:addTradeAcquire(RecipeDB, 60653, A.TRAINER, 26906, A.TRAINER, 26954, A.TRAINER, 26980, A.TRAINER, 26990, A.TRAINER, 28693, A.TRAINER, 33583)

	-- Enchant Cloak - Major Agility -- 60663
	AddRecipe(60663, 420, nil, R_COMMON, GAME_WOTLK, 420, 430, 440, 450)
	self:addTradeFlags(RecipeDB, 60663, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.DPS, F.CLOAK)
	self:addTradeAcquire(RecipeDB, 60663, A.TRAINER, 26906, A.TRAINER, 26954, A.TRAINER, 26980, A.TRAINER, 26990, A.TRAINER, 28693, A.TRAINER, 33583)

	-- Enchant Gloves - Crusher -- 60668
	AddRecipe(60668, 425, nil, R_COMMON, GAME_WOTLK, 425, 435, 445, 455)
	self:addTradeFlags(RecipeDB, 60668, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.DPS)
	self:addTradeAcquire(RecipeDB, 60668, A.TRAINER, 26906, A.TRAINER, 26954, A.TRAINER, 26980, A.TRAINER, 26990, A.TRAINER, 28693, A.TRAINER, 33583)

	-- Enchant 2H Weapon - Massacre -- 60691
	AddRecipe(60691, 430, nil, R_RARE, GAME_WOTLK, 430, 440, 450, 460)
	self:addTradeFlags(RecipeDB, 60691, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOP, F.DPS, F.TWO_HAND)
	self:addTradeAcquire(RecipeDB, 60691, A.VENDOR, 32514)

	-- Enchant Chest - Powerful Stats -- 60692
	AddRecipe(60692, 440, nil, R_UNCOMMON, GAME_WOTLK, 440, 450, 460, 470)
	self:addTradeFlags(RecipeDB, 60692, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOP)
	self:addTradeAcquire(RecipeDB, 60692, A.VENDOR, 32514)

	-- Enchant Weapon - Superior Potency -- 60707
	AddRecipe(60707, 435, nil, R_RARE, GAME_WOTLK, 435, 445, 455, 465)
	self:addTradeFlags(RecipeDB, 60707, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOP, F.DPS, F.ONE_HAND, F.TWO_HAND)
	self:addTradeAcquire(RecipeDB, 60707, A.VENDOR, 32514)

	-- Enchant Weapon - Mighty Spellpower -- 60714
	AddRecipe(60714, 435, nil, R_RARE, GAME_WOTLK, 435, 445, 455, 465)
	self:addTradeFlags(RecipeDB, 60714, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOP, F.HEALER, F.CASTER, F.ONE_HAND, F.TWO_HAND)
	self:addTradeAcquire(RecipeDB, 60714, A.VENDOR, 32514)

	-- Enchant Boots - Greater Assault -- 60763
	AddRecipe(60763, 440, nil, R_UNCOMMON, GAME_WOTLK, 440, 450, 460, 470)
	self:addTradeFlags(RecipeDB, 60763, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOP, F.DPS)
	self:addTradeAcquire(RecipeDB, 60763, A.VENDOR, 32514)

	-- Enchant Bracers - Superior Spellpower -- 60767
	AddRecipe(60767, 440, nil, R_UNCOMMON, GAME_WOTLK, 440, 450, 460, 470)
	self:addTradeFlags(RecipeDB, 60767, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOP, F.HEALER, F.CASTER)
	self:addTradeAcquire(RecipeDB, 60767, A.VENDOR, 32514)

	-- Enchant Bracers - Major Stamina -- 62256
	AddRecipe(62256, 450, nil, R_UNCOMMON, GAME_WOTLK, 450, 460, 470, 480)
	self:addTradeFlags(RecipeDB, 62256, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOP)
	self:addTradeAcquire(RecipeDB, 62256, A.VENDOR, 32514)

	-- Enchant Staff - Greater Spellpower -- 62948
	AddRecipe(62948, 450, nil, R_RARE, GAME_WOTLK, 450, 455, 460, 465)
	self:addTradeFlags(RecipeDB, 62948, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOP, F.HEALER, F.CASTER, F.STAFF)
	self:addTradeAcquire(RecipeDB, 62948, A.VENDOR, 32514)

	-- Enchant Staff - Spellpower -- 62959
	AddRecipe(62959, 385, nil, R_COMMON, GAME_WOTLK, 385, 395, 405, 415)
	self:addTradeFlags(RecipeDB, 62959, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.HEALER, F.CASTER, F.STAFF)
	self:addTradeAcquire(RecipeDB, 62959, A.TRAINER, 26906, A.TRAINER, 26954, A.TRAINER, 26980, A.TRAINER, 26990, A.TRAINER, 28693, A.TRAINER, 33583)

	-- Enchant Boots - Lesser Accuracy -- 63746
	AddRecipe(63746, 225, nil, R_UNCOMMON, GAME_WOTLK, 225, 245, 265, 285)
	self:addTradeFlags(RecipeDB, 63746, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.DPS)
	self:addTradeAcquire(RecipeDB, 63746, A.TRAINER, 1317, A.TRAINER, 3011, A.TRAINER, 3345, A.TRAINER, 3606, A.TRAINER, 4213, A.TRAINER, 4616, A.TRAINER, 5157, A.TRAINER, 5695, A.TRAINER, 11072, A.TRAINER, 11073, A.TRAINER, 11074, A.TRAINER, 16160, A.TRAINER, 16633, A.TRAINER, 16725, A.TRAINER, 19251, A.TRAINER, 19252, A.TRAINER, 33610, A.TRAINER, 33676, A.TRAINER, 18773, A.TRAINER, 7949, A.TRAINER, 19540, A.TRAINER, 18753)

	-- Enchant Weapon - Blade Ward -- 64441
	AddRecipe(64441, 450, nil, R_RARE, GAME_WOTLK, 450, 455, 460, 465)
	self:addTradeFlags(RecipeDB, 64441, F.ALLIANCE, F.HORDE, F.RAID, F.MOB_DROP, F.IBOE, F.RBOP, F.TANK, F.ONE_HAND, F.TWO_HAND)
	self:addTradeAcquire(RecipeDB, 64441, A.CUSTOM, 39)

	-- Enchant Weapon - Blood Draining -- 64579
	AddRecipe(64579, 450, nil, R_RARE, GAME_WOTLK, 450, 455, 460, 465)
	self:addTradeFlags(RecipeDB, 64579, F.ALLIANCE, F.HORDE, F.RAID, F.MOB_DROP, F.IBOE, F.RBOP, F.ONE_HAND, F.TWO_HAND)
	self:addTradeAcquire(RecipeDB, 64579, A.CUSTOM, 39)

	-- Abyssal Shatter -- 69412
	AddRecipe(69412, 445, 49640, R_COMMON, GAME_WOTLK, 445, 445, 447, 450)
	self:addTradeFlags(RecipeDB, 69412, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP)
	self:addTradeAcquire(RecipeDB, 69412, A.TRAINER, 28693, A.TRAINER, 26990, A.TRAINER, 26906, A.TRAINER, 26954, A.TRAINER, 26980, A.TRAINER, 33583)

	-- Enchant Gloves - Angler -- 71692
	AddRecipe(71692, 375, nil, R_UNCOMMON, GAME_WOTLK, 375, 385, 392, 400)
	self:addTradeFlags(RecipeDB, 71692, F.ALLIANCE, F.HORDE, F.MOB_DROP, F.IBOP, F.RBOP)
	self:addTradeAcquire(RecipeDB, 71692, A.MOB, 26343)

	return num_recipes

end
