--[[
************************************************************************
Engineering.lua
Engineering data for all of Ackis Recipe List
************************************************************************
File date: 2010-02-06T07:24:17Z 
File revision: 2852 
Project revision: 2853
Project version: r2853
************************************************************************
Please see http://www.wowace.com/addons/arl/ for more information.
************************************************************************
This source code is released under All Rights Reserved.
************************************************************************
]]--

-------------------------------------------------------------------------------
-- AddOn namespace.
-------------------------------------------------------------------------------
local MODNAME	= "Ackis Recipe List"
local addon	= LibStub("AceAddon-3.0"):GetAddon(MODNAME)
local L		= LibStub("AceLocale-3.0"):GetLocale(MODNAME)

local private	= select(2, ...)

-------------------------------------------------------------------------------
-- Item "rarity"
-------------------------------------------------------------------------------
local R_COMMON, R_UNCOMMON, R_RARE, R_EPIC, R_LEGENDARY, R_ARTIFACT = 1, 2, 3, 4, 5, 6

-------------------------------------------------------------------------------
-- Origin
-------------------------------------------------------------------------------
local GAME_ORIG, GAME_TBC, GAME_WOTLK = 0, 1, 2

-------------------------------------------------------------------------------
-- Filter flags. Acquire types, and Reputation levels.
-------------------------------------------------------------------------------
local F		= private.filter_flags
local A		= private.acquire_types
local REP	= private.rep_levels
local FAC	= private.faction_ids

local FRIENDLY	= 1
local HONORED	= 2
local REVERED	= 3
local EXALTED	= 4

local initialized = false
local num_recipes = 0

function addon:InitEngineering(RecipeDB)
	if initialized then
		return num_recipes
	end
	initialized = true

	--------------------------------------------------------------------------------------------------------------------
	-- Counter and wrapper function
	--------------------------------------------------------------------------------------------------------------------
	local function AddRecipe(SpellID, Skill, ItemID, Rarity, Game, Orange, Yellow, Green, Gray, Specialty)
		num_recipes = num_recipes + 1
		self:addTradeSkill(RecipeDB, SpellID, Skill, ItemID, Rarity, 4036, Specialty, Game, Orange, Yellow, Green, Gray)
	end

	-- Rough Blasting Powder -- 3918
	AddRecipe(3918, 1, 4357, R_COMMON, GAME_ORIG, 1, 20, 30, 40)
	self:addTradeFlags(RecipeDB, 3918, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP)
	self:addTradeAcquire(RecipeDB, 3918, A.CUSTOM, 8)

	-- Rough Dynamite -- 3919
	AddRecipe(3919, 1, 4358, R_COMMON, GAME_ORIG, 1, 30, 45, 60)
	self:addTradeFlags(RecipeDB, 3919, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP)
	self:addTradeAcquire(RecipeDB, 3919, A.CUSTOM, 8)

	-- Crafted Light Shot -- 3920
	AddRecipe(3920, 1, 8067, R_COMMON, GAME_ORIG, 1, 30, 45, 60)
	self:addTradeFlags(RecipeDB, 3920, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.AMMO)
	self:addTradeAcquire(RecipeDB, 3920, A.CUSTOM, 8)

	-- Handful of Copper Bolts -- 3922
	AddRecipe(3922, 30, 4359, R_COMMON, GAME_ORIG, 30, 45, 52, 60)
	self:addTradeFlags(RecipeDB, 3922, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP)
	self:addTradeAcquire(RecipeDB, 3922, A.TRAINER, 1702, A.TRAINER, 3290, A.TRAINER, 3494, A.TRAINER, 5174, A.TRAINER, 5518, A.TRAINER, 8736, A.TRAINER, 11017, A.TRAINER, 11025, A.TRAINER, 11037, A.TRAINER, 16726, A.TRAINER, 17222, A.TRAINER, 17634, A.TRAINER, 17637, A.TRAINER, 18752, A.TRAINER, 18775, A.TRAINER, 19576, A.TRAINER, 16667, A.TRAINER, 28697, A.TRAINER, 33586, A.TRAINER, 26991, A.TRAINER, 33611, A.TRAINER, 33634, A.TRAINER, 1676, A.TRAINER, 25277, A.TRAINER, 26907, A.TRAINER, 11031, A.TRAINER, 26955)

	-- Rough Copper Bomb -- 3923
	AddRecipe(3923, 30, 4360, R_COMMON, GAME_ORIG, 30, 60, 75, 90)
	self:addTradeFlags(RecipeDB, 3923, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP)
	self:addTradeAcquire(RecipeDB, 3923, A.TRAINER, 1702, A.TRAINER, 3290, A.TRAINER, 3494, A.TRAINER, 5174, A.TRAINER, 5518, A.TRAINER, 8736, A.TRAINER, 11017, A.TRAINER, 11025, A.TRAINER, 11031, A.TRAINER, 11037, A.TRAINER, 16726, A.TRAINER, 17222, A.TRAINER, 17634, A.TRAINER, 17637, A.TRAINER, 18752, A.TRAINER, 18775, A.TRAINER, 19576, A.TRAINER, 16667, A.TRAINER, 28697, A.TRAINER, 33586, A.TRAINER, 26991, A.TRAINER, 33611, A.TRAINER, 33634, A.TRAINER, 1676, A.TRAINER, 25277, A.TRAINER, 26907, A.TRAINER, 26955)

	-- Copper Tube -- 3924
	AddRecipe(3924, 50, 4361, R_COMMON, GAME_ORIG, 50, 80, 95, 110)
	self:addTradeFlags(RecipeDB, 3924, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP)
	self:addTradeAcquire(RecipeDB, 3924, A.TRAINER, 1702, A.TRAINER, 3290, A.TRAINER, 3494, A.TRAINER, 5174, A.TRAINER, 5518, A.TRAINER, 8736, A.TRAINER, 11017, A.TRAINER, 11025, A.TRAINER, 11031, A.TRAINER, 11037, A.TRAINER, 16726, A.TRAINER, 17222, A.TRAINER, 17634, A.TRAINER, 17637, A.TRAINER, 18752, A.TRAINER, 18775, A.TRAINER, 19576, A.TRAINER, 16667, A.TRAINER, 28697, A.TRAINER, 33586, A.TRAINER, 26991, A.TRAINER, 33611, A.TRAINER, 33634, A.TRAINER, 1676, A.TRAINER, 25277, A.TRAINER, 26907, A.TRAINER, 26955)

	-- Rough Boomstick -- 3925
	AddRecipe(3925, 50, 4362, R_COMMON, GAME_ORIG, 50, 80, 95, 110)
	self:addTradeFlags(RecipeDB, 3925, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.GUN)
	self:addTradeAcquire(RecipeDB, 3925, A.TRAINER, 1702, A.TRAINER, 3290, A.TRAINER, 3494, A.TRAINER, 5174, A.TRAINER, 5518, A.TRAINER, 8736, A.TRAINER, 11017, A.TRAINER, 11025, A.TRAINER, 11031, A.TRAINER, 11037, A.TRAINER, 16726, A.TRAINER, 17222, A.TRAINER, 17634, A.TRAINER, 17637, A.TRAINER, 18752, A.TRAINER, 18775, A.TRAINER, 19576, A.TRAINER, 16667, A.TRAINER, 28697, A.TRAINER, 33586, A.TRAINER, 26991, A.TRAINER, 33611, A.TRAINER, 33634, A.TRAINER, 1676, A.TRAINER, 25277, A.TRAINER, 26907, A.TRAINER, 26955)

	-- Copper Modulator -- 3926
	AddRecipe(3926, 65, 4363, R_COMMON, GAME_ORIG, 65, 95, 110, 125)
	self:addTradeFlags(RecipeDB, 3926, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP)
	self:addTradeAcquire(RecipeDB, 3926, A.TRAINER, 1702, A.TRAINER, 3290, A.TRAINER, 3494, A.TRAINER, 5174, A.TRAINER, 5518, A.TRAINER, 8736, A.TRAINER, 11017, A.TRAINER, 11025, A.TRAINER, 11031, A.TRAINER, 11037, A.TRAINER, 16726, A.TRAINER, 17222, A.TRAINER, 17634, A.TRAINER, 17637, A.TRAINER, 18752, A.TRAINER, 18775, A.TRAINER, 19576, A.TRAINER, 16667, A.TRAINER, 28697, A.TRAINER, 33586, A.TRAINER, 26991, A.TRAINER, 33611, A.TRAINER, 33634, A.TRAINER, 1676, A.TRAINER, 25277, A.TRAINER, 26907, A.TRAINER, 26955)

	-- Mechanical Squirrel Box -- 3928
	AddRecipe(3928, 75, 4401, R_UNCOMMON, GAME_ORIG, 75, 105, 120, 135)
	self:addTradeFlags(RecipeDB, 3928, F.ALLIANCE, F.HORDE, F.WORLD_DROP, F.IBOE, F.RBOE)
	self:addTradeAcquire(RecipeDB, 3928, A.WORLD_DROP, 2)

	-- Coarse Blasting Powder -- 3929
	AddRecipe(3929, 75, 4364, R_COMMON, GAME_ORIG, 75, 85, 90, 95)
	self:addTradeFlags(RecipeDB, 3929, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP)
	self:addTradeAcquire(RecipeDB, 3929, A.TRAINER, 1702, A.TRAINER, 3290, A.TRAINER, 3494, A.TRAINER, 5174, A.TRAINER, 5518, A.TRAINER, 8736, A.TRAINER, 11017, A.TRAINER, 11025, A.TRAINER, 11031, A.TRAINER, 11037, A.TRAINER, 16726, A.TRAINER, 17222, A.TRAINER, 17634, A.TRAINER, 17637, A.TRAINER, 18752, A.TRAINER, 18775, A.TRAINER, 19576, A.TRAINER, 16667, A.TRAINER, 28697, A.TRAINER, 33586, A.TRAINER, 26991, A.TRAINER, 33611, A.TRAINER, 33634, A.TRAINER, 1676, A.TRAINER, 25277, A.TRAINER, 26907, A.TRAINER, 26955)

	-- Crafted Heavy Shot -- 3930
	AddRecipe(3930, 75, 8068, R_COMMON, GAME_ORIG, 75, 85, 90, 95)
	self:addTradeFlags(RecipeDB, 3930, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.AMMO)
	self:addTradeAcquire(RecipeDB, 3930, A.TRAINER, 1702, A.TRAINER, 3290, A.TRAINER, 3494, A.TRAINER, 5174, A.TRAINER, 5518, A.TRAINER, 8736, A.TRAINER, 11017, A.TRAINER, 11025, A.TRAINER, 11031, A.TRAINER, 11037, A.TRAINER, 16726, A.TRAINER, 17222, A.TRAINER, 17634, A.TRAINER, 17637, A.TRAINER, 18752, A.TRAINER, 18775, A.TRAINER, 19576, A.TRAINER, 16667, A.TRAINER, 28697, A.TRAINER, 33586, A.TRAINER, 26991, A.TRAINER, 33611, A.TRAINER, 33634, A.TRAINER, 1676, A.TRAINER, 25277, A.TRAINER, 26907, A.TRAINER, 26955)

	-- Coarse Dynamite -- 3931
	AddRecipe(3931, 75, 4365, R_COMMON, GAME_ORIG, 75, 90, 97, 105)
	self:addTradeFlags(RecipeDB, 3931, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP)
	self:addTradeAcquire(RecipeDB, 3931, A.TRAINER, 1702, A.TRAINER, 3290, A.TRAINER, 3494, A.TRAINER, 5174, A.TRAINER, 5518, A.TRAINER, 8736, A.TRAINER, 11017, A.TRAINER, 11025, A.TRAINER, 11031, A.TRAINER, 11037, A.TRAINER, 16726, A.TRAINER, 17222, A.TRAINER, 17634, A.TRAINER, 17637, A.TRAINER, 18752, A.TRAINER, 18775, A.TRAINER, 19576, A.TRAINER, 16667, A.TRAINER, 28697, A.TRAINER, 33586, A.TRAINER, 26991, A.TRAINER, 33611, A.TRAINER, 33634, A.TRAINER, 1676, A.TRAINER, 25277, A.TRAINER, 26907, A.TRAINER, 26955)

	-- Target Dummy -- 3932
	AddRecipe(3932, 85, 4366, R_COMMON, GAME_ORIG, 85, 115, 130, 145)
	self:addTradeFlags(RecipeDB, 3932, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP)
	self:addTradeAcquire(RecipeDB, 3932, A.TRAINER, 5174, A.TRAINER, 5518, A.TRAINER, 8736, A.TRAINER, 11017, A.TRAINER, 11031, A.TRAINER, 16726, A.TRAINER, 17634, A.TRAINER, 17637, A.TRAINER, 18752, A.TRAINER, 18775, A.TRAINER, 19576, A.TRAINER, 16667, A.TRAINER, 28697, A.TRAINER, 1702, A.TRAINER, 33586, A.TRAINER, 3494, A.TRAINER, 3290, A.TRAINER, 26991, A.TRAINER, 33611, A.TRAINER, 33634, A.TRAINER, 1676, A.TRAINER, 25277, A.TRAINER, 26907, A.TRAINER, 11025, A.TRAINER, 26955, A.TRAINER, 11037, A.TRAINER, 17222)

	-- Small Seaforium Charge -- 3933
	AddRecipe(3933, 100, 4367, R_UNCOMMON, GAME_ORIG, 100, 130, 145, 160)
	self:addTradeFlags(RecipeDB, 3933, F.ALLIANCE, F.HORDE, F.WORLD_DROP, F.IBOE, F.RBOE)
	self:addTradeAcquire(RecipeDB, 3933, A.WORLD_DROP, 2)

	-- Flying Tiger Goggles -- 3934
	AddRecipe(3934, 100, 4368, R_COMMON, GAME_ORIG, 100, 130, 145, 160)
	self:addTradeFlags(RecipeDB, 3934, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.HEALER, F.CASTER, F.CLOTH)
	self:addTradeAcquire(RecipeDB, 3934, A.TRAINER, 5174, A.TRAINER, 5518, A.TRAINER, 8736, A.TRAINER, 11017, A.TRAINER, 11031, A.TRAINER, 16726, A.TRAINER, 17634, A.TRAINER, 17637, A.TRAINER, 18752, A.TRAINER, 18775, A.TRAINER, 19576, A.TRAINER, 16667, A.TRAINER, 28697, A.TRAINER, 1702, A.TRAINER, 33586, A.TRAINER, 3494, A.TRAINER, 3290, A.TRAINER, 26991, A.TRAINER, 33611, A.TRAINER, 33634, A.TRAINER, 1676, A.TRAINER, 25277, A.TRAINER, 26907, A.TRAINER, 11025, A.TRAINER, 26955, A.TRAINER, 11037, A.TRAINER, 17222)

	-- Deadly Blunderbuss -- 3936
	AddRecipe(3936, 105, 4369, R_COMMON, GAME_ORIG, 105, 130, 142, 155)
	self:addTradeFlags(RecipeDB, 3936, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.GUN)
	self:addTradeAcquire(RecipeDB, 3936, A.TRAINER, 1676, A.TRAINER, 5174, A.TRAINER, 5518, A.TRAINER, 8736, A.TRAINER, 11017, A.TRAINER, 11031, A.TRAINER, 16726, A.TRAINER, 17634, A.TRAINER, 17637, A.TRAINER, 18752, A.TRAINER, 18775, A.TRAINER, 19576, A.TRAINER, 16667, A.TRAINER, 28697, A.TRAINER, 1702, A.TRAINER, 33586, A.TRAINER, 3494, A.TRAINER, 3290, A.TRAINER, 26991, A.TRAINER, 33611, A.TRAINER, 33634, A.TRAINER, 25277, A.TRAINER, 26907, A.TRAINER, 11025, A.TRAINER, 26955, A.TRAINER, 11037, A.TRAINER, 17222)

	-- Large Copper Bomb -- 3937
	AddRecipe(3937, 105, 4370, R_COMMON, GAME_ORIG, 105, 105, 130, 155)
	self:addTradeFlags(RecipeDB, 3937, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP)
	self:addTradeAcquire(RecipeDB, 3937, A.TRAINER, 1676, A.TRAINER, 5174, A.TRAINER, 5518, A.TRAINER, 8736, A.TRAINER, 11017, A.TRAINER, 11031, A.TRAINER, 16726, A.TRAINER, 17634, A.TRAINER, 17637, A.TRAINER, 18752, A.TRAINER, 18775, A.TRAINER, 19576, A.TRAINER, 16667, A.TRAINER, 28697, A.TRAINER, 1702, A.TRAINER, 33586, A.TRAINER, 3494, A.TRAINER, 3290, A.TRAINER, 26991, A.TRAINER, 33611, A.TRAINER, 33634, A.TRAINER, 25277, A.TRAINER, 26907, A.TRAINER, 11025, A.TRAINER, 26955, A.TRAINER, 11037, A.TRAINER, 17222)

	-- Bronze Tube -- 3938
	AddRecipe(3938, 105, 4371, R_COMMON, GAME_ORIG, 105, 105, 130, 155)
	self:addTradeFlags(RecipeDB, 3938, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP)
	self:addTradeAcquire(RecipeDB, 3938, A.TRAINER, 1676, A.TRAINER, 5174, A.TRAINER, 5518, A.TRAINER, 8736, A.TRAINER, 11017, A.TRAINER, 11031, A.TRAINER, 16726, A.TRAINER, 17634, A.TRAINER, 17637, A.TRAINER, 18752, A.TRAINER, 18775, A.TRAINER, 19576, A.TRAINER, 16667, A.TRAINER, 28697, A.TRAINER, 1702, A.TRAINER, 33586, A.TRAINER, 3494, A.TRAINER, 3290, A.TRAINER, 26991, A.TRAINER, 33611, A.TRAINER, 33634, A.TRAINER, 25277, A.TRAINER, 26907, A.TRAINER, 11025, A.TRAINER, 26955, A.TRAINER, 11037, A.TRAINER, 17222)

	-- Lovingly Crafted Boomstick -- 3939
	AddRecipe(3939, 120, 4372, R_COMMON, GAME_ORIG, 120, 145, 157, 170)
	self:addTradeFlags(RecipeDB, 3939, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOP, F.GUN)
	self:addTradeAcquire(RecipeDB, 3939, A.VENDOR, 2682, A.VENDOR, 6730)

	-- Shadow Goggles -- 3940
	AddRecipe(3940, 120, 4373, R_UNCOMMON, GAME_ORIG, 120, 145, 157, 170)
	self:addTradeFlags(RecipeDB, 3940, F.ALLIANCE, F.HORDE, F.WORLD_DROP, F.IBOE, F.RBOE, F.HEALER, F.CASTER, F.CLOTH)
	self:addTradeAcquire(RecipeDB, 3940, A.WORLD_DROP, 2)

	-- Small Bronze Bomb -- 3941
	AddRecipe(3941, 120, 4374, R_COMMON, GAME_ORIG, 120, 120, 145, 170)
	self:addTradeFlags(RecipeDB, 3941, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP)
	self:addTradeAcquire(RecipeDB, 3941, A.TRAINER, 1676, A.TRAINER, 5174, A.TRAINER, 5518, A.TRAINER, 8736, A.TRAINER, 11017, A.TRAINER, 11031, A.TRAINER, 16726, A.TRAINER, 17634, A.TRAINER, 17637, A.TRAINER, 18752, A.TRAINER, 18775, A.TRAINER, 19576, A.TRAINER, 16667, A.TRAINER, 28697, A.TRAINER, 1702, A.TRAINER, 33586, A.TRAINER, 3494, A.TRAINER, 3290, A.TRAINER, 26991, A.TRAINER, 33611, A.TRAINER, 33634, A.TRAINER, 25277, A.TRAINER, 26907, A.TRAINER, 11025, A.TRAINER, 26955, A.TRAINER, 11037, A.TRAINER, 17222)

	-- Whirring Bronze Gizmo -- 3942
	AddRecipe(3942, 125, 4375, R_COMMON, GAME_ORIG, 125, 125, 150, 175)
	self:addTradeFlags(RecipeDB, 3942, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP)
	self:addTradeAcquire(RecipeDB, 3942, A.TRAINER, 1676, A.TRAINER, 5174, A.TRAINER, 5518, A.TRAINER, 8736, A.TRAINER, 11017, A.TRAINER, 11031, A.TRAINER, 16726, A.TRAINER, 17634, A.TRAINER, 17637, A.TRAINER, 18752, A.TRAINER, 18775, A.TRAINER, 19576, A.TRAINER, 16667, A.TRAINER, 28697, A.TRAINER, 1702, A.TRAINER, 33586, A.TRAINER, 3494, A.TRAINER, 3290, A.TRAINER, 26991, A.TRAINER, 33611, A.TRAINER, 33634, A.TRAINER, 25277, A.TRAINER, 26907, A.TRAINER, 11025, A.TRAINER, 26955, A.TRAINER, 11037, A.TRAINER, 17222)

	-- Flame Deflector -- 3944
	AddRecipe(3944, 125, 4376, R_UNCOMMON, GAME_ORIG, 125, 125, 150, 175)
	self:addTradeFlags(RecipeDB, 3944, F.ALLIANCE, F.HORDE, F.INSTANCE, F.IBOE, F.RBOE)
	self:addTradeAcquire(RecipeDB, 3944, A.MOB, 7800)

	-- Heavy Blasting Powder -- 3945
	AddRecipe(3945, 125, 4377, R_COMMON, GAME_ORIG, 125, 125, 135, 145)
	self:addTradeFlags(RecipeDB, 3945, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP)
	self:addTradeAcquire(RecipeDB, 3945, A.TRAINER, 1676, A.TRAINER, 5174, A.TRAINER, 5518, A.TRAINER, 8736, A.TRAINER, 11017, A.TRAINER, 11031, A.TRAINER, 16726, A.TRAINER, 17634, A.TRAINER, 17637, A.TRAINER, 18752, A.TRAINER, 18775, A.TRAINER, 19576, A.TRAINER, 16667, A.TRAINER, 28697, A.TRAINER, 1702, A.TRAINER, 33586, A.TRAINER, 3494, A.TRAINER, 3290, A.TRAINER, 26991, A.TRAINER, 33611, A.TRAINER, 33634, A.TRAINER, 25277, A.TRAINER, 26907, A.TRAINER, 11025, A.TRAINER, 26955, A.TRAINER, 11037, A.TRAINER, 17222)

	-- Heavy Dynamite -- 3946
	AddRecipe(3946, 125, 4378, R_COMMON, GAME_ORIG, 125, 125, 135, 145)
	self:addTradeFlags(RecipeDB, 3946, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP)
	self:addTradeAcquire(RecipeDB, 3946, A.TRAINER, 1676, A.TRAINER, 5174, A.TRAINER, 5518, A.TRAINER, 8736, A.TRAINER, 11017, A.TRAINER, 11031, A.TRAINER, 16726, A.TRAINER, 17634, A.TRAINER, 17637, A.TRAINER, 18752, A.TRAINER, 18775, A.TRAINER, 19576, A.TRAINER, 16667, A.TRAINER, 28697, A.TRAINER, 1702, A.TRAINER, 33586, A.TRAINER, 3494, A.TRAINER, 3290, A.TRAINER, 26991, A.TRAINER, 33611, A.TRAINER, 33634, A.TRAINER, 25277, A.TRAINER, 26907, A.TRAINER, 11025, A.TRAINER, 26955, A.TRAINER, 11037, A.TRAINER, 17222)

	-- Crafted Solid Shot -- 3947
	AddRecipe(3947, 125, 8069, R_COMMON, GAME_ORIG, 125, 125, 135, 145)
	self:addTradeFlags(RecipeDB, 3947, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.AMMO)
	self:addTradeAcquire(RecipeDB, 3947, A.TRAINER, 1676, A.TRAINER, 5174, A.TRAINER, 5518, A.TRAINER, 8736, A.TRAINER, 11017, A.TRAINER, 11031, A.TRAINER, 16726, A.TRAINER, 17634, A.TRAINER, 17637, A.TRAINER, 18752, A.TRAINER, 18775, A.TRAINER, 19576, A.TRAINER, 16667, A.TRAINER, 28697, A.TRAINER, 1702, A.TRAINER, 33586, A.TRAINER, 3494, A.TRAINER, 3290, A.TRAINER, 26991, A.TRAINER, 33611, A.TRAINER, 33634, A.TRAINER, 25277, A.TRAINER, 26907, A.TRAINER, 11025, A.TRAINER, 26955, A.TRAINER, 11037, A.TRAINER, 17222)

	-- Silver-plated Shotgun -- 3949
	AddRecipe(3949, 130, 4379, R_COMMON, GAME_ORIG, 130, 155, 167, 180)
	self:addTradeFlags(RecipeDB, 3949, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.GUN)
	self:addTradeAcquire(RecipeDB, 3949, A.TRAINER, 1676, A.TRAINER, 5174, A.TRAINER, 5518, A.TRAINER, 8736, A.TRAINER, 11017, A.TRAINER, 11031, A.TRAINER, 16726, A.TRAINER, 17634, A.TRAINER, 17637, A.TRAINER, 18752, A.TRAINER, 18775, A.TRAINER, 19576, A.TRAINER, 16667, A.TRAINER, 28697, A.TRAINER, 1702, A.TRAINER, 33586, A.TRAINER, 3494, A.TRAINER, 3290, A.TRAINER, 26991, A.TRAINER, 33611, A.TRAINER, 33634, A.TRAINER, 25277, A.TRAINER, 26907, A.TRAINER, 11025, A.TRAINER, 26955, A.TRAINER, 11037, A.TRAINER, 17222)

	-- Big Bronze Bomb -- 3950
	AddRecipe(3950, 140, 4380, R_COMMON, GAME_ORIG, 140, 140, 165, 190)
	self:addTradeFlags(RecipeDB, 3950, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP)
	self:addTradeAcquire(RecipeDB, 3950, A.TRAINER, 1676, A.TRAINER, 5174, A.TRAINER, 5518, A.TRAINER, 8736, A.TRAINER, 11017, A.TRAINER, 11031, A.TRAINER, 16726, A.TRAINER, 17634, A.TRAINER, 17637, A.TRAINER, 18752, A.TRAINER, 18775, A.TRAINER, 19576, A.TRAINER, 16667, A.TRAINER, 28697, A.TRAINER, 1702, A.TRAINER, 33586, A.TRAINER, 3494, A.TRAINER, 3290, A.TRAINER, 26991, A.TRAINER, 33611, A.TRAINER, 33634, A.TRAINER, 25277, A.TRAINER, 26907, A.TRAINER, 11025, A.TRAINER, 26955, A.TRAINER, 11037, A.TRAINER, 17222)

	-- Minor Recombobulator -- 3952
	AddRecipe(3952, 140, 4381, R_COMMON, GAME_ORIG, 140, 165, 177, 190)
	self:addTradeFlags(RecipeDB, 3952, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOE, F.TRINKET)
	self:addTradeAcquire(RecipeDB, 3952, A.VENDOR, 2682, A.VENDOR, 3495, A.VENDOR, 2683)

	-- Bronze Framework -- 3953
	AddRecipe(3953, 145, 4382, R_COMMON, GAME_ORIG, 145, 145, 170, 195)
	self:addTradeFlags(RecipeDB, 3953, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP)
	self:addTradeAcquire(RecipeDB, 3953, A.TRAINER, 1676, A.TRAINER, 5174, A.TRAINER, 5518, A.TRAINER, 8736, A.TRAINER, 11017, A.TRAINER, 11031, A.TRAINER, 16726, A.TRAINER, 17634, A.TRAINER, 17637, A.TRAINER, 18752, A.TRAINER, 18775, A.TRAINER, 19576, A.TRAINER, 16667, A.TRAINER, 28697, A.TRAINER, 1702, A.TRAINER, 33586, A.TRAINER, 3494, A.TRAINER, 3290, A.TRAINER, 26991, A.TRAINER, 33611, A.TRAINER, 33634, A.TRAINER, 25277, A.TRAINER, 26907, A.TRAINER, 11025, A.TRAINER, 26955, A.TRAINER, 11037, A.TRAINER, 17222)

	-- Moonsight Rifle -- 3954
	AddRecipe(3954, 145, 4383, R_UNCOMMON, GAME_ORIG, 145, 170, 182, 195)
	self:addTradeFlags(RecipeDB, 3954, F.ALLIANCE, F.HORDE, F.WORLD_DROP, F.IBOE, F.RBOE, F.GUN)
	self:addTradeAcquire(RecipeDB, 3954, A.WORLD_DROP, 2)

	-- Explosive Sheep -- 3955
	AddRecipe(3955, 150, 4384, R_COMMON, GAME_ORIG, 150, 175, 187, 200)
	self:addTradeFlags(RecipeDB, 3955, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP)
	self:addTradeAcquire(RecipeDB, 3955, A.TRAINER, 1676, A.TRAINER, 5174, A.TRAINER, 5518, A.TRAINER, 8736, A.TRAINER, 11017, A.TRAINER, 11031, A.TRAINER, 16726, A.TRAINER, 17634, A.TRAINER, 17637, A.TRAINER, 18752, A.TRAINER, 18775, A.TRAINER, 19576, A.TRAINER, 16667, A.TRAINER, 28697, A.TRAINER, 1702, A.TRAINER, 33586, A.TRAINER, 3494, A.TRAINER, 3290, A.TRAINER, 26991, A.TRAINER, 33611, A.TRAINER, 33634, A.TRAINER, 25277, A.TRAINER, 26907, A.TRAINER, 11025, A.TRAINER, 26955, A.TRAINER, 11037, A.TRAINER, 17222)

	-- Green Tinted Goggles -- 3956
	AddRecipe(3956, 150, 4385, R_COMMON, GAME_ORIG, 150, 175, 187, 200)
	self:addTradeFlags(RecipeDB, 3956, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.HEALER, F.CASTER, F.CLOTH)
	self:addTradeAcquire(RecipeDB, 3956, A.TRAINER, 1676, A.TRAINER, 5174, A.TRAINER, 5518, A.TRAINER, 8736, A.TRAINER, 11017, A.TRAINER, 11031, A.TRAINER, 16726, A.TRAINER, 17634, A.TRAINER, 17637, A.TRAINER, 18752, A.TRAINER, 18775, A.TRAINER, 19576, A.TRAINER, 16667, A.TRAINER, 28697, A.TRAINER, 1702, A.TRAINER, 33586, A.TRAINER, 3494, A.TRAINER, 3290, A.TRAINER, 26991, A.TRAINER, 33611, A.TRAINER, 33634, A.TRAINER, 25277, A.TRAINER, 26907, A.TRAINER, 11025, A.TRAINER, 26955, A.TRAINER, 11037, A.TRAINER, 17222)

	-- Ice Deflector -- 3957
	AddRecipe(3957, 155, 4386, R_COMMON, GAME_ORIG, 155, 175, 185, 195)
	self:addTradeFlags(RecipeDB, 3957, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOP)
	self:addTradeAcquire(RecipeDB, 3957, A.VENDOR, 2684)

	-- Iron Strut -- 3958
	AddRecipe(3958, 160, 4387, R_COMMON, GAME_ORIG, 160, 160, 170, 180)
	self:addTradeFlags(RecipeDB, 3958, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP)
	self:addTradeAcquire(RecipeDB, 3958, A.TRAINER, 5174, A.TRAINER, 8736, A.TRAINER, 11017, A.TRAINER, 17634, A.TRAINER, 17637, A.TRAINER, 18752, A.TRAINER, 18775, A.TRAINER, 19576, A.TRAINER, 16667, A.TRAINER, 28697, A.TRAINER, 1702, A.TRAINER, 16726, A.TRAINER, 33586, A.TRAINER, 3494, A.TRAINER, 3290, A.TRAINER, 5518, A.TRAINER, 26991, A.TRAINER, 33611, A.TRAINER, 33634, A.TRAINER, 1676, A.TRAINER, 25277, A.TRAINER, 26907, A.TRAINER, 11031, A.TRAINER, 11025, A.TRAINER, 26955, A.TRAINER, 11037, A.TRAINER, 17222)

	-- Discombobulator Ray -- 3959
	AddRecipe(3959, 160, 4388, R_UNCOMMON, GAME_ORIG, 160, 180, 190, 200)
	self:addTradeFlags(RecipeDB, 3959, F.ALLIANCE, F.HORDE, F.INSTANCE, F.IBOE, F.RBOE)
	self:addTradeAcquire(RecipeDB, 3959, A.MOB, 7800)

	-- Portable Bronze Mortar -- 3960
	AddRecipe(3960, 165, 4403, R_UNCOMMON, GAME_ORIG, 165, 185, 195, 210)
	self:addTradeFlags(RecipeDB, 3960, F.ALLIANCE, F.HORDE, F.WORLD_DROP, F.IBOE, F.RBOE)
	self:addTradeAcquire(RecipeDB, 3960, A.WORLD_DROP, 2)

	-- Gyrochronatom -- 3961
	AddRecipe(3961, 170, 4389, R_COMMON, GAME_ORIG, 170, 170, 190, 210)
	self:addTradeFlags(RecipeDB, 3961, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP)
	self:addTradeAcquire(RecipeDB, 3961, A.TRAINER, 5174, A.TRAINER, 8736, A.TRAINER, 11017, A.TRAINER, 17634, A.TRAINER, 17637, A.TRAINER, 18752, A.TRAINER, 18775, A.TRAINER, 19576, A.TRAINER, 16667, A.TRAINER, 28697, A.TRAINER, 1702, A.TRAINER, 16726, A.TRAINER, 33586, A.TRAINER, 3494, A.TRAINER, 3290, A.TRAINER, 5518, A.TRAINER, 26991, A.TRAINER, 33611, A.TRAINER, 33634, A.TRAINER, 1676, A.TRAINER, 25277, A.TRAINER, 26907, A.TRAINER, 11031, A.TRAINER, 11025, A.TRAINER, 26955, A.TRAINER, 11037, A.TRAINER, 17222)

	-- Iron Grenade -- 3962
	AddRecipe(3962, 175, 4390, R_COMMON, GAME_ORIG, 175, 175, 195, 215)
	self:addTradeFlags(RecipeDB, 3962, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP)
	self:addTradeAcquire(RecipeDB, 3962, A.TRAINER, 5174, A.TRAINER, 8736, A.TRAINER, 11017, A.TRAINER, 17634, A.TRAINER, 17637, A.TRAINER, 18752, A.TRAINER, 18775, A.TRAINER, 19576, A.TRAINER, 16667, A.TRAINER, 28697, A.TRAINER, 1702, A.TRAINER, 16726, A.TRAINER, 33586, A.TRAINER, 3494, A.TRAINER, 3290, A.TRAINER, 5518, A.TRAINER, 26991, A.TRAINER, 33611, A.TRAINER, 33634, A.TRAINER, 1676, A.TRAINER, 25277, A.TRAINER, 26907, A.TRAINER, 11031, A.TRAINER, 11025, A.TRAINER, 26955, A.TRAINER, 11037, A.TRAINER, 17222)

	-- Compact Harvest Reaper Kit -- 3963
	AddRecipe(3963, 175, 4391, R_COMMON, GAME_ORIG, 175, 175, 195, 215)
	self:addTradeFlags(RecipeDB, 3963, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP)
	self:addTradeAcquire(RecipeDB, 3963, A.TRAINER, 5174, A.TRAINER, 8736, A.TRAINER, 11017, A.TRAINER, 17634, A.TRAINER, 17637, A.TRAINER, 18752, A.TRAINER, 18775, A.TRAINER, 19576, A.TRAINER, 16667, A.TRAINER, 28697, A.TRAINER, 1702, A.TRAINER, 16726, A.TRAINER, 33586, A.TRAINER, 3494, A.TRAINER, 3290, A.TRAINER, 5518, A.TRAINER, 26991, A.TRAINER, 33611, A.TRAINER, 33634, A.TRAINER, 1676, A.TRAINER, 25277, A.TRAINER, 26907, A.TRAINER, 11031, A.TRAINER, 11025, A.TRAINER, 26955, A.TRAINER, 11037, A.TRAINER, 17222)

	-- Advanced Target Dummy -- 3965
	AddRecipe(3965, 185, 4392, R_COMMON, GAME_ORIG, 185, 185, 205, 225)
	self:addTradeFlags(RecipeDB, 3965, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP)
	self:addTradeAcquire(RecipeDB, 3965, A.TRAINER, 5174, A.TRAINER, 8736, A.TRAINER, 11017, A.TRAINER, 17634, A.TRAINER, 17637, A.TRAINER, 18752, A.TRAINER, 18775, A.TRAINER, 19576, A.TRAINER, 16667, A.TRAINER, 28697, A.TRAINER, 1702, A.TRAINER, 16726, A.TRAINER, 33586, A.TRAINER, 3494, A.TRAINER, 3290, A.TRAINER, 5518, A.TRAINER, 26991, A.TRAINER, 33611, A.TRAINER, 33634, A.TRAINER, 1676, A.TRAINER, 25277, A.TRAINER, 26907, A.TRAINER, 11031, A.TRAINER, 11025, A.TRAINER, 26955, A.TRAINER, 11037, A.TRAINER, 17222)

	-- Craftsman's Monocle -- 3966
	AddRecipe(3966, 185, 4393, R_RARE, GAME_ORIG, 185, 205, 215, 225)
	self:addTradeFlags(RecipeDB, 3966, F.ALLIANCE, F.HORDE, F.WORLD_DROP, F.IBOE, F.RBOE, F.CLOTH)
	self:addTradeAcquire(RecipeDB, 3966, A.WORLD_DROP, 3)

	-- Big Iron Bomb -- 3967
	AddRecipe(3967, 190, 4394, R_COMMON, GAME_ORIG, 190, 190, 210, 230)
	self:addTradeFlags(RecipeDB, 3967, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP)
	self:addTradeAcquire(RecipeDB, 3967, A.TRAINER, 5174, A.TRAINER, 8736, A.TRAINER, 11017, A.TRAINER, 17634, A.TRAINER, 17637, A.TRAINER, 18752, A.TRAINER, 18775, A.TRAINER, 19576, A.TRAINER, 16667, A.TRAINER, 28697, A.TRAINER, 1702, A.TRAINER, 16726, A.TRAINER, 33586, A.TRAINER, 3494, A.TRAINER, 3290, A.TRAINER, 5518, A.TRAINER, 26991, A.TRAINER, 33611, A.TRAINER, 33634, A.TRAINER, 1676, A.TRAINER, 26907, A.TRAINER, 11031, A.TRAINER, 11025, A.TRAINER, 26955, A.TRAINER, 11037, A.TRAINER, 17222)

	-- Goblin Land Mine -- 3968
	AddRecipe(3968, 195, 4395, R_UNCOMMON, GAME_ORIG, 195, 215, 225, 235)
	self:addTradeFlags(RecipeDB, 3968, F.ALLIANCE, F.HORDE, F.WORLD_DROP, F.IBOE, F.RBOE)
	self:addTradeAcquire(RecipeDB, 3968, A.WORLD_DROP, 2)

	-- Mechanical Dragonling -- 3969
	AddRecipe(3969, 200, 4396, R_COMMON, GAME_ORIG, 200, 220, 230, 240)
	self:addTradeFlags(RecipeDB, 3969, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOE, F.TRINKET)
	self:addTradeAcquire(RecipeDB, 3969, A.VENDOR, 2687)

	-- Gnomish Cloaking Device -- 3971
	AddRecipe(3971, 200, 4397, R_COMMON, GAME_ORIG, 200, 220, 230, 240)
	self:addTradeFlags(RecipeDB, 3971, F.ALLIANCE, F.HORDE, F.VENDOR, F.INSTANCE, F.IBOE, F.RBOE, F.TRINKET)
	self:addTradeAcquire(RecipeDB, 3971, A.MOB, 7800, A.VENDOR, 6777)

	-- Large Seaforium Charge -- 3972
	AddRecipe(3972, 200, 4398, R_UNCOMMON, GAME_ORIG, 200, 200, 220, 240)
	self:addTradeFlags(RecipeDB, 3972, F.ALLIANCE, F.HORDE, F.WORLD_DROP, F.IBOE, F.RBOE)
	self:addTradeAcquire(RecipeDB, 3972, A.WORLD_DROP, 2)

	-- Silver Contact -- 3973
	AddRecipe(3973, 90, 4404, R_COMMON, GAME_ORIG, 90, 110, 125, 140)
	self:addTradeFlags(RecipeDB, 3973, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP)
	self:addTradeAcquire(RecipeDB, 3973, A.TRAINER, 5174, A.TRAINER, 5518, A.TRAINER, 8736, A.TRAINER, 11017, A.TRAINER, 11031, A.TRAINER, 16726, A.TRAINER, 17634, A.TRAINER, 17637, A.TRAINER, 18752, A.TRAINER, 18775, A.TRAINER, 19576, A.TRAINER, 16667, A.TRAINER, 28697, A.TRAINER, 1702, A.TRAINER, 33586, A.TRAINER, 3494, A.TRAINER, 3290, A.TRAINER, 26991, A.TRAINER, 33611, A.TRAINER, 33634, A.TRAINER, 1676, A.TRAINER, 25277, A.TRAINER, 26907, A.TRAINER, 11025, A.TRAINER, 26955, A.TRAINER, 11037, A.TRAINER, 17222)

	-- Crude Scope -- 3977
	AddRecipe(3977, 60, 4405, R_COMMON, GAME_ORIG, 60, 90, 105, 120)
	self:addTradeFlags(RecipeDB, 3977, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP)
	self:addTradeAcquire(RecipeDB, 3977, A.TRAINER, 1702, A.TRAINER, 3290, A.TRAINER, 3494, A.TRAINER, 5174, A.TRAINER, 5518, A.TRAINER, 8736, A.TRAINER, 11017, A.TRAINER, 11025, A.TRAINER, 11031, A.TRAINER, 11037, A.TRAINER, 16726, A.TRAINER, 17222, A.TRAINER, 17634, A.TRAINER, 17637, A.TRAINER, 18752, A.TRAINER, 18775, A.TRAINER, 19576, A.TRAINER, 16667, A.TRAINER, 28697, A.TRAINER, 33586, A.TRAINER, 26991, A.TRAINER, 33611, A.TRAINER, 33634, A.TRAINER, 1676, A.TRAINER, 25277, A.TRAINER, 26907, A.TRAINER, 26955)

	-- Standard Scope -- 3978
	AddRecipe(3978, 110, 4406, R_COMMON, GAME_ORIG, 110, 135, 147, 160)
	self:addTradeFlags(RecipeDB, 3978, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP)
	self:addTradeAcquire(RecipeDB, 3978, A.TRAINER, 1676, A.TRAINER, 5174, A.TRAINER, 5518, A.TRAINER, 8736, A.TRAINER, 11017, A.TRAINER, 11031, A.TRAINER, 16726, A.TRAINER, 17634, A.TRAINER, 17637, A.TRAINER, 18752, A.TRAINER, 18775, A.TRAINER, 19576, A.TRAINER, 16667, A.TRAINER, 28697, A.TRAINER, 1702, A.TRAINER, 33586, A.TRAINER, 3494, A.TRAINER, 3290, A.TRAINER, 26991, A.TRAINER, 33611, A.TRAINER, 33634, A.TRAINER, 25277, A.TRAINER, 26907, A.TRAINER, 11025, A.TRAINER, 26955, A.TRAINER, 11037, A.TRAINER, 17222)

	-- Accurate Scope -- 3979
	AddRecipe(3979, 180, 4407, R_COMMON, GAME_ORIG, 180, 200, 210, 220)
	self:addTradeFlags(RecipeDB, 3979, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOE)
	self:addTradeAcquire(RecipeDB, 3979, A.VENDOR, 2685)

	-- Ornate Spyglass -- 6458
	AddRecipe(6458, 135, 5507, R_COMMON, GAME_ORIG, 135, 160, 172, 185)
	self:addTradeFlags(RecipeDB, 6458, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP)
	self:addTradeAcquire(RecipeDB, 6458, A.TRAINER, 1676, A.TRAINER, 5174, A.TRAINER, 5518, A.TRAINER, 8736, A.TRAINER, 11017, A.TRAINER, 11031, A.TRAINER, 16726, A.TRAINER, 17634, A.TRAINER, 17637, A.TRAINER, 18752, A.TRAINER, 18775, A.TRAINER, 19576, A.TRAINER, 16667, A.TRAINER, 28697, A.TRAINER, 1702, A.TRAINER, 33586, A.TRAINER, 3494, A.TRAINER, 3290, A.TRAINER, 26991, A.TRAINER, 33611, A.TRAINER, 33634, A.TRAINER, 25277, A.TRAINER, 26907, A.TRAINER, 11025, A.TRAINER, 26955, A.TRAINER, 11037, A.TRAINER, 17222)

	-- Arclight Spanner -- 7430
	AddRecipe(7430, 50, 6219, R_COMMON, GAME_ORIG, 50, 70, 80, 90)
	self:addTradeFlags(RecipeDB, 7430, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.ONE_HAND)
	self:addTradeAcquire(RecipeDB, 7430, A.TRAINER, 1702, A.TRAINER, 3290, A.TRAINER, 3494, A.TRAINER, 5174, A.TRAINER, 5518, A.TRAINER, 8736, A.TRAINER, 11017, A.TRAINER, 11025, A.TRAINER, 11031, A.TRAINER, 11037, A.TRAINER, 16726, A.TRAINER, 17222, A.TRAINER, 17634, A.TRAINER, 17637, A.TRAINER, 18752, A.TRAINER, 18775, A.TRAINER, 19576, A.TRAINER, 16667, A.TRAINER, 28697, A.TRAINER, 33586, A.TRAINER, 26991, A.TRAINER, 33611, A.TRAINER, 33634, A.TRAINER, 1676, A.TRAINER, 25277, A.TRAINER, 26907, A.TRAINER, 26955)

	-- Flash Bomb -- 8243
	AddRecipe(8243, 185, 4852, R_UNCOMMON, GAME_ORIG, 185, 185, 205, 225)
	self:addTradeFlags(RecipeDB, 8243, F.ALLIANCE, F.HORDE, F.INSTANCE, F.QUEST, F.IBOE, F.RBOE)
	self:addTradeAcquire(RecipeDB, 8243, A.MOB, 7800, A.QUEST, 1559)

	-- Practice Lock -- 8334
	AddRecipe(8334, 100, 6712, R_COMMON, GAME_ORIG, 100, 115, 122, 130)
	self:addTradeFlags(RecipeDB, 8334, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP)
	self:addTradeAcquire(RecipeDB, 8334, A.TRAINER, 5174, A.TRAINER, 5518, A.TRAINER, 8736, A.TRAINER, 11017, A.TRAINER, 11031, A.TRAINER, 16726, A.TRAINER, 17634, A.TRAINER, 17637, A.TRAINER, 18752, A.TRAINER, 18775, A.TRAINER, 19576, A.TRAINER, 16667, A.TRAINER, 28697, A.TRAINER, 1702, A.TRAINER, 33586, A.TRAINER, 3494, A.TRAINER, 3290, A.TRAINER, 26991, A.TRAINER, 33611, A.TRAINER, 33634, A.TRAINER, 1676, A.TRAINER, 25277, A.TRAINER, 26907, A.TRAINER, 11025, A.TRAINER, 26955, A.TRAINER, 11037, A.TRAINER, 17222)

	-- EZ-Thro Dynamite -- 8339
	AddRecipe(8339, 100, 6714, R_UNCOMMON, GAME_ORIG, 100, 115, 122, 130)
	self:addTradeFlags(RecipeDB, 8339, F.ALLIANCE, F.HORDE, F.WORLD_DROP, F.IBOE, F.RBOE)
	self:addTradeAcquire(RecipeDB, 8339, A.WORLD_DROP, 2)

	-- Goblin Rocket Boots -- 8895
	AddRecipe(8895, 225, 7189, R_COMMON, GAME_ORIG, 225, 245, 255, 265, 20222)
	self:addTradeFlags(RecipeDB, 8895, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.CLOTH)
	self:addTradeAcquire(RecipeDB, 8895, A.TRAINER, 8126, A.TRAINER, 29513)

	-- Gnomish Universal Remote -- 9269
	AddRecipe(9269, 125, 7506, R_COMMON, GAME_ORIG, 125, 150, 162, 175)
	self:addTradeFlags(RecipeDB, 9269, F.ALLIANCE, F.HORDE, F.VENDOR, F.INSTANCE, F.IBOE, F.RBOE, F.TRINKET)
	self:addTradeAcquire(RecipeDB, 9269, A.MOB, 7800, A.VENDOR, 5175, A.VENDOR, 6730)

	-- Aquadynamic Fish Attractor -- 9271
	AddRecipe(9271, 150, 6533, R_COMMON, GAME_ORIG, 150, 150, 160, 170)
	self:addTradeFlags(RecipeDB, 9271, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP)
	self:addTradeAcquire(RecipeDB, 9271, A.TRAINER, 1676, A.TRAINER, 5174, A.TRAINER, 5518, A.TRAINER, 8736, A.TRAINER, 11017, A.TRAINER, 11031, A.TRAINER, 16726, A.TRAINER, 17634, A.TRAINER, 17637, A.TRAINER, 18752, A.TRAINER, 18775, A.TRAINER, 19576, A.TRAINER, 16667, A.TRAINER, 28697, A.TRAINER, 1702, A.TRAINER, 33586, A.TRAINER, 3494, A.TRAINER, 3290, A.TRAINER, 26991, A.TRAINER, 33611, A.TRAINER, 33634, A.TRAINER, 25277, A.TRAINER, 26907, A.TRAINER, 11025, A.TRAINER, 26955, A.TRAINER, 11037, A.TRAINER, 17222)

	-- Goblin Jumper Cables -- 9273
	AddRecipe(9273, 165, 7148, R_COMMON, GAME_ORIG, 165, 165, 180, 200)
	self:addTradeFlags(RecipeDB, 9273, F.ALLIANCE, F.HORDE, F.VENDOR, F.INSTANCE, F.IBOE, F.RBOE)
	self:addTradeAcquire(RecipeDB, 9273, A.MOB, 7800, A.VENDOR, 3537, A.VENDOR, 4086, A.VENDOR, 3134)

	-- Gold Power Core -- 12584
	AddRecipe(12584, 150, 10558, R_COMMON, GAME_ORIG, 150, 150, 170, 190)
	self:addTradeFlags(RecipeDB, 12584, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP)
	self:addTradeAcquire(RecipeDB, 12584, A.TRAINER, 1676, A.TRAINER, 5174, A.TRAINER, 5518, A.TRAINER, 8736, A.TRAINER, 11017, A.TRAINER, 11031, A.TRAINER, 16726, A.TRAINER, 17634, A.TRAINER, 17637, A.TRAINER, 18752, A.TRAINER, 18775, A.TRAINER, 19576, A.TRAINER, 16667, A.TRAINER, 28697, A.TRAINER, 1702, A.TRAINER, 33586, A.TRAINER, 3494, A.TRAINER, 3290, A.TRAINER, 26991, A.TRAINER, 33611, A.TRAINER, 33634, A.TRAINER, 25277, A.TRAINER, 26907, A.TRAINER, 11025, A.TRAINER, 26955, A.TRAINER, 11037, A.TRAINER, 17222)

	-- Solid Blasting Powder -- 12585
	AddRecipe(12585, 175, 10505, R_COMMON, GAME_ORIG, 175, 175, 185, 195)
	self:addTradeFlags(RecipeDB, 12585, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP)
	self:addTradeAcquire(RecipeDB, 12585, A.TRAINER, 5174, A.TRAINER, 8736, A.TRAINER, 11017, A.TRAINER, 17634, A.TRAINER, 17637, A.TRAINER, 18752, A.TRAINER, 18775, A.TRAINER, 19576, A.TRAINER, 16667, A.TRAINER, 28697, A.TRAINER, 1702, A.TRAINER, 16726, A.TRAINER, 33586, A.TRAINER, 3494, A.TRAINER, 3290, A.TRAINER, 5518, A.TRAINER, 26991, A.TRAINER, 33611, A.TRAINER, 33634, A.TRAINER, 1676, A.TRAINER, 25277, A.TRAINER, 26907, A.TRAINER, 11031, A.TRAINER, 11025, A.TRAINER, 26955, A.TRAINER, 11037, A.TRAINER, 17222)

	-- Solid Dynamite -- 12586
	AddRecipe(12586, 175, 10507, R_COMMON, GAME_ORIG, 175, 175, 185, 195)
	self:addTradeFlags(RecipeDB, 12586, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP)
	self:addTradeAcquire(RecipeDB, 12586, A.TRAINER, 5174, A.TRAINER, 8736, A.TRAINER, 11017, A.TRAINER, 17634, A.TRAINER, 17637, A.TRAINER, 18752, A.TRAINER, 18775, A.TRAINER, 19576, A.TRAINER, 16667, A.TRAINER, 28697, A.TRAINER, 1702, A.TRAINER, 16726, A.TRAINER, 33586, A.TRAINER, 3494, A.TRAINER, 3290, A.TRAINER, 5518, A.TRAINER, 26991, A.TRAINER, 33611, A.TRAINER, 33634, A.TRAINER, 1676, A.TRAINER, 25277, A.TRAINER, 26907, A.TRAINER, 11031, A.TRAINER, 11025, A.TRAINER, 26955, A.TRAINER, 11037, A.TRAINER, 17222)

	-- Bright-Eye Goggles -- 12587
	AddRecipe(12587, 175, 10499, R_UNCOMMON, GAME_ORIG, 175, 195, 205, 215)
	self:addTradeFlags(RecipeDB, 12587, F.ALLIANCE, F.HORDE, F.WORLD_DROP, F.IBOE, F.RBOE, F.HEALER, F.CASTER, F.CLOTH)
	self:addTradeAcquire(RecipeDB, 12587, A.WORLD_DROP, 2)

	-- Mithril Tube -- 12589
	AddRecipe(12589, 195, 10559, R_COMMON, GAME_ORIG, 195, 195, 215, 235)
	self:addTradeFlags(RecipeDB, 12589, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP)
	self:addTradeAcquire(RecipeDB, 12589, A.TRAINER, 5174, A.TRAINER, 8736, A.TRAINER, 11017, A.TRAINER, 17634, A.TRAINER, 17637, A.TRAINER, 18752, A.TRAINER, 18775, A.TRAINER, 19576, A.TRAINER, 16667, A.TRAINER, 28697, A.TRAINER, 1702, A.TRAINER, 16726, A.TRAINER, 33586, A.TRAINER, 3494, A.TRAINER, 3290, A.TRAINER, 5518, A.TRAINER, 26991, A.TRAINER, 33611, A.TRAINER, 33634, A.TRAINER, 1676, A.TRAINER, 25277, A.TRAINER, 26907, A.TRAINER, 11031, A.TRAINER, 11025, A.TRAINER, 26955, A.TRAINER, 11037, A.TRAINER, 17222)

	-- Gyromatic Micro-Adjustor -- 12590
	AddRecipe(12590, 175, 10498, R_COMMON, GAME_ORIG, 175, 175, 195, 215)
	self:addTradeFlags(RecipeDB, 12590, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP)
	self:addTradeAcquire(RecipeDB, 12590, A.TRAINER, 5174, A.TRAINER, 8736, A.TRAINER, 11017, A.TRAINER, 17634, A.TRAINER, 17637, A.TRAINER, 18752, A.TRAINER, 18775, A.TRAINER, 19576, A.TRAINER, 16667, A.TRAINER, 28697, A.TRAINER, 1702, A.TRAINER, 16726, A.TRAINER, 33586, A.TRAINER, 3494, A.TRAINER, 3290, A.TRAINER, 5518, A.TRAINER, 26991, A.TRAINER, 33611, A.TRAINER, 33634, A.TRAINER, 1676, A.TRAINER, 25277, A.TRAINER, 26907, A.TRAINER, 11031, A.TRAINER, 11025, A.TRAINER, 26955, A.TRAINER, 11037, A.TRAINER, 17222)

	-- Unstable Trigger -- 12591
	AddRecipe(12591, 200, 10560, R_COMMON, GAME_ORIG, 200, 200, 220, 240)
	self:addTradeFlags(RecipeDB, 12591, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP)
	self:addTradeAcquire(RecipeDB, 12591, A.TRAINER, 5174, A.TRAINER, 8736, A.TRAINER, 11017, A.TRAINER, 17634, A.TRAINER, 17637, A.TRAINER, 18752, A.TRAINER, 18775, A.TRAINER, 19576, A.TRAINER, 16667, A.TRAINER, 28697, A.TRAINER, 1702, A.TRAINER, 16726, A.TRAINER, 33586, A.TRAINER, 3494, A.TRAINER, 3290, A.TRAINER, 5518, A.TRAINER, 26991, A.TRAINER, 33611, A.TRAINER, 33634, A.TRAINER, 1676, A.TRAINER, 25277, A.TRAINER, 26907, A.TRAINER, 11031, A.TRAINER, 11025, A.TRAINER, 26955, A.TRAINER, 11037, A.TRAINER, 17222)

	-- Fire Goggles -- 12594
	AddRecipe(12594, 205, 10500, R_COMMON, GAME_ORIG, 205, 225, 235, 245)
	self:addTradeFlags(RecipeDB, 12594, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.CLOTH)
	self:addTradeAcquire(RecipeDB, 12594, A.TRAINER, 5174, A.TRAINER, 8736, A.TRAINER, 11017, A.TRAINER, 17634, A.TRAINER, 17637, A.TRAINER, 18752, A.TRAINER, 18775, A.TRAINER, 19576, A.TRAINER, 16667, A.TRAINER, 28697, A.TRAINER, 1702, A.TRAINER, 16726, A.TRAINER, 33586, A.TRAINER, 3494, A.TRAINER, 3290, A.TRAINER, 5518, A.TRAINER, 26991, A.TRAINER, 33611, A.TRAINER, 33634, A.TRAINER, 1676, A.TRAINER, 25277, A.TRAINER, 26907, A.TRAINER, 11031, A.TRAINER, 11025, A.TRAINER, 26955, A.TRAINER, 11037, A.TRAINER, 17222)

	-- Mithril Blunderbuss -- 12595
	AddRecipe(12595, 205, 10508, R_COMMON, GAME_ORIG, 205, 225, 235, 245)
	self:addTradeFlags(RecipeDB, 12595, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.DPS, F.GUN)
	self:addTradeAcquire(RecipeDB, 12595, A.TRAINER, 5174, A.TRAINER, 8736, A.TRAINER, 11017, A.TRAINER, 17634, A.TRAINER, 17637, A.TRAINER, 18752, A.TRAINER, 18775, A.TRAINER, 19576, A.TRAINER, 16667, A.TRAINER, 28697, A.TRAINER, 1702, A.TRAINER, 16726, A.TRAINER, 33586, A.TRAINER, 3494, A.TRAINER, 3290, A.TRAINER, 5518, A.TRAINER, 26991, A.TRAINER, 33611, A.TRAINER, 33634, A.TRAINER, 1676, A.TRAINER, 25277, A.TRAINER, 26907, A.TRAINER, 11031, A.TRAINER, 11025, A.TRAINER, 26955, A.TRAINER, 11037, A.TRAINER, 17222)

	-- Hi-Impact Mithril Slugs -- 12596
	AddRecipe(12596, 210, 10512, R_COMMON, GAME_ORIG, 210, 210, 230, 250)
	self:addTradeFlags(RecipeDB, 12596, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.AMMO)
	self:addTradeAcquire(RecipeDB, 12596, A.TRAINER, 5174, A.TRAINER, 8736, A.TRAINER, 11017, A.TRAINER, 17634, A.TRAINER, 17637, A.TRAINER, 18752, A.TRAINER, 18775, A.TRAINER, 19576, A.TRAINER, 16667, A.TRAINER, 28697, A.TRAINER, 1702, A.TRAINER, 16726, A.TRAINER, 33586, A.TRAINER, 3494, A.TRAINER, 3290, A.TRAINER, 5518, A.TRAINER, 26991, A.TRAINER, 33611, A.TRAINER, 33634, A.TRAINER, 1676, A.TRAINER, 25277, A.TRAINER, 26907, A.TRAINER, 11031, A.TRAINER, 11025, A.TRAINER, 26955, A.TRAINER, 11037, A.TRAINER, 17222)

	-- Deadly Scope -- 12597
	AddRecipe(12597, 210, 10546, R_COMMON, GAME_ORIG, 210, 230, 240, 250)
	self:addTradeFlags(RecipeDB, 12597, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOE)
	self:addTradeAcquire(RecipeDB, 12597, A.VENDOR, 8679, A.VENDOR, 9544)

	-- Mithril Casing -- 12599
	AddRecipe(12599, 215, 10561, R_COMMON, GAME_ORIG, 215, 215, 235, 255)
	self:addTradeFlags(RecipeDB, 12599, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP)
	self:addTradeAcquire(RecipeDB, 12599, A.TRAINER, 5174, A.TRAINER, 8736, A.TRAINER, 11017, A.TRAINER, 17634, A.TRAINER, 17637, A.TRAINER, 18752, A.TRAINER, 18775, A.TRAINER, 19576, A.TRAINER, 16667, A.TRAINER, 28697, A.TRAINER, 1702, A.TRAINER, 16726, A.TRAINER, 33586, A.TRAINER, 3494, A.TRAINER, 3290, A.TRAINER, 5518, A.TRAINER, 26991, A.TRAINER, 33611, A.TRAINER, 33634, A.TRAINER, 1676, A.TRAINER, 25277, A.TRAINER, 26907, A.TRAINER, 11031, A.TRAINER, 11025, A.TRAINER, 26955, A.TRAINER, 11037, A.TRAINER, 17222)

	-- Mithril Frag Bomb -- 12603
	AddRecipe(12603, 215, 10514, R_COMMON, GAME_ORIG, 215, 215, 235, 255)
	self:addTradeFlags(RecipeDB, 12603, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP)
	self:addTradeAcquire(RecipeDB, 12603, A.TRAINER, 5174, A.TRAINER, 8736, A.TRAINER, 11017, A.TRAINER, 17634, A.TRAINER, 17637, A.TRAINER, 18752, A.TRAINER, 18775, A.TRAINER, 19576, A.TRAINER, 16667, A.TRAINER, 28697, A.TRAINER, 1702, A.TRAINER, 16726, A.TRAINER, 33586, A.TRAINER, 3494, A.TRAINER, 3290, A.TRAINER, 5518, A.TRAINER, 26991, A.TRAINER, 33611, A.TRAINER, 33634, A.TRAINER, 1676, A.TRAINER, 25277, A.TRAINER, 26907, A.TRAINER, 11031, A.TRAINER, 11025, A.TRAINER, 26955, A.TRAINER, 11037, A.TRAINER, 17222)

	-- Catseye Ultra Goggles -- 12607
	AddRecipe(12607, 220, 10501, R_UNCOMMON, GAME_ORIG, 220, 240, 250, 260)
	self:addTradeFlags(RecipeDB, 12607, F.ALLIANCE, F.HORDE, F.WORLD_DROP, F.IBOE, F.RBOE, F.CLOTH)
	self:addTradeAcquire(RecipeDB, 12607, A.WORLD_DROP, 2)

	-- Mithril Heavy-bore Rifle -- 12614
	AddRecipe(12614, 220, 10510, R_UNCOMMON, GAME_ORIG, 220, 240, 250, 260)
	self:addTradeFlags(RecipeDB, 12614, F.ALLIANCE, F.HORDE, F.WORLD_DROP, F.IBOE, F.RBOE, F.DPS, F.GUN)
	self:addTradeAcquire(RecipeDB, 12614, A.WORLD_DROP, 2)

	-- Spellpower Goggles Xtreme -- 12615
	AddRecipe(12615, 225, 10502, R_RARE, GAME_ORIG, 225, 245, 255, 265)
	self:addTradeFlags(RecipeDB, 12615, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOE, F.HEALER, F.CASTER, F.CLOTH)
	self:addTradeAcquire(RecipeDB, 12615, A.TRAINER, 8736, A.TRAINER, 17634, A.TRAINER, 17637, A.TRAINER, 18752, A.TRAINER, 18775, A.TRAINER, 19576, A.TRAINER, 16667, A.TRAINER, 28697, A.TRAINER, 1702, A.TRAINER, 16726, A.TRAINER, 11017, A.TRAINER, 33586, A.TRAINER, 3494, A.TRAINER, 5174, A.TRAINER, 3290, A.TRAINER, 5518, A.TRAINER, 26991, A.TRAINER, 33611, A.TRAINER, 33634, A.TRAINER, 1676, A.TRAINER, 25277, A.TRAINER, 26907, A.TRAINER, 11031, A.TRAINER, 11025, A.TRAINER, 26955, A.TRAINER, 11037, A.TRAINER, 17222)

	-- Parachute Cloak -- 12616
	AddRecipe(12616, 225, 10518, R_UNCOMMON, GAME_ORIG, 225, 245, 255, 265)
	self:addTradeFlags(RecipeDB, 12616, F.ALLIANCE, F.HORDE, F.WORLD_DROP, F.IBOE, F.RBOE, F.DPS, F.CLOAK)
	self:addTradeAcquire(RecipeDB, 12616, A.WORLD_DROP, 2)

	-- Deepdive Helmet -- 12617
	AddRecipe(12617, 230, 10506, R_COMMON, GAME_ORIG, 230, 250, 260, 270)
	self:addTradeFlags(RecipeDB, 12617, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOE, F.CLOTH)
	self:addTradeAcquire(RecipeDB, 12617, A.VENDOR, 8678)

	-- Rose Colored Goggles -- 12618
	AddRecipe(12618, 230, 10503, R_COMMON, GAME_ORIG, 230, 250, 260, 270)
	self:addTradeFlags(RecipeDB, 12618, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.HEALER, F.CASTER, F.CLOTH)
	self:addTradeAcquire(RecipeDB, 12618, A.TRAINER, 8736, A.TRAINER, 17634, A.TRAINER, 17637, A.TRAINER, 18752, A.TRAINER, 18775, A.TRAINER, 19576, A.TRAINER, 16667, A.TRAINER, 28697, A.TRAINER, 1702, A.TRAINER, 16726, A.TRAINER, 11017, A.TRAINER, 33586, A.TRAINER, 3494, A.TRAINER, 5174, A.TRAINER, 3290, A.TRAINER, 5518, A.TRAINER, 26991, A.TRAINER, 33611, A.TRAINER, 33634, A.TRAINER, 1676, A.TRAINER, 25277, A.TRAINER, 26907, A.TRAINER, 11031, A.TRAINER, 11025, A.TRAINER, 26955, A.TRAINER, 11037, A.TRAINER, 17222)

	-- Hi-Explosive Bomb -- 12619
	AddRecipe(12619, 235, 10562, R_COMMON, GAME_ORIG, 235, 235, 255, 275)
	self:addTradeFlags(RecipeDB, 12619, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP)
	self:addTradeAcquire(RecipeDB, 12619, A.TRAINER, 8736, A.TRAINER, 17634, A.TRAINER, 17637, A.TRAINER, 18752, A.TRAINER, 18775, A.TRAINER, 19576, A.TRAINER, 16667, A.TRAINER, 28697, A.TRAINER, 1702, A.TRAINER, 16726, A.TRAINER, 11017, A.TRAINER, 33586, A.TRAINER, 3494, A.TRAINER, 5174, A.TRAINER, 3290, A.TRAINER, 5518, A.TRAINER, 26991, A.TRAINER, 33611, A.TRAINER, 33634, A.TRAINER, 1676, A.TRAINER, 25277, A.TRAINER, 26907, A.TRAINER, 11031, A.TRAINER, 11025, A.TRAINER, 26955, A.TRAINER, 11037, A.TRAINER, 17222)

	-- Sniper Scope -- 12620
	AddRecipe(12620, 240, 10548, R_RARE, GAME_ORIG, 240, 260, 270, 280)
	self:addTradeFlags(RecipeDB, 12620, F.ALLIANCE, F.HORDE, F.WORLD_DROP, F.IBOE, F.RBOE)
	self:addTradeAcquire(RecipeDB, 12620, A.WORLD_DROP, 3)

	-- Mithril Gyro-Shot -- 12621
	AddRecipe(12621, 245, 10513, R_COMMON, GAME_ORIG, 245, 245, 265, 285)
	self:addTradeFlags(RecipeDB, 12621, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.AMMO)
	self:addTradeAcquire(RecipeDB, 12621, A.TRAINER, 8736, A.TRAINER, 17634, A.TRAINER, 17637, A.TRAINER, 18752, A.TRAINER, 18775, A.TRAINER, 19576, A.TRAINER, 16667, A.TRAINER, 28697, A.TRAINER, 1702, A.TRAINER, 16726, A.TRAINER, 11017, A.TRAINER, 33586, A.TRAINER, 3494, A.TRAINER, 5174, A.TRAINER, 3290, A.TRAINER, 5518, A.TRAINER, 26991, A.TRAINER, 33611, A.TRAINER, 33634, A.TRAINER, 1676, A.TRAINER, 25277, A.TRAINER, 26907, A.TRAINER, 11031, A.TRAINER, 11025, A.TRAINER, 26955, A.TRAINER, 11037, A.TRAINER, 17222)

	-- Green Lens -- 12622
	AddRecipe(12622, 245, 10504, R_COMMON, GAME_ORIG, 245, 265, 275, 285)
	self:addTradeFlags(RecipeDB, 12622, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.CLOTH)
	self:addTradeAcquire(RecipeDB, 12622, A.TRAINER, 8736, A.TRAINER, 17634, A.TRAINER, 17637, A.TRAINER, 18752, A.TRAINER, 18775, A.TRAINER, 19576, A.TRAINER, 16667, A.TRAINER, 28697, A.TRAINER, 1702, A.TRAINER, 16726, A.TRAINER, 11017, A.TRAINER, 33586, A.TRAINER, 3494, A.TRAINER, 5174, A.TRAINER, 3290, A.TRAINER, 5518, A.TRAINER, 26991, A.TRAINER, 33611, A.TRAINER, 33634, A.TRAINER, 1676, A.TRAINER, 25277, A.TRAINER, 26907, A.TRAINER, 11031, A.TRAINER, 11025, A.TRAINER, 26955, A.TRAINER, 11037, A.TRAINER, 17222)

	-- Mithril Mechanical Dragonling -- 12624
	AddRecipe(12624, 250, 10576, R_COMMON, GAME_ORIG, 250, 270, 280, 290)
	self:addTradeFlags(RecipeDB, 12624, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOP, F.TRINKET)
	self:addTradeAcquire(RecipeDB, 12624, A.VENDOR, 2688)

	-- Goblin Rocket Fuel Recipe -- 12715
	AddRecipe(12715, 205, 10644, R_COMMON, GAME_ORIG, 205, 205, 205, 205, 20222)
	self:addTradeFlags(RecipeDB, 12715, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP)
	self:addTradeAcquire(RecipeDB, 12715, A.TRAINER, 8126, A.TRAINER, 29513)

	-- Goblin Mortar -- 12716
	AddRecipe(12716, 205, 10577, R_COMMON, GAME_ORIG, 205, 225, 235, 245, 20222)
	self:addTradeFlags(RecipeDB, 12716, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.TRINKET)
	self:addTradeAcquire(RecipeDB, 12716, A.TRAINER, 8126, A.TRAINER, 8738, A.TRAINER, 29513)

	-- Goblin Mining Helmet -- 12717
	AddRecipe(12717, 205, 10542, R_COMMON, GAME_ORIG, 205, 225, 235, 245, 20222)
	self:addTradeFlags(RecipeDB, 12717, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOP, F.RBOP, F.MAIL)
	self:addTradeAcquire(RecipeDB, 12717, A.TRAINER, 8126, A.TRAINER, 8738, A.TRAINER, 29513)

	-- Goblin Construction Helmet -- 12718
	AddRecipe(12718, 205, 10543, R_COMMON, GAME_ORIG, 205, 225, 235, 245, 20222)
	self:addTradeFlags(RecipeDB, 12718, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOP, F.RBOP, F.CLOTH)
	self:addTradeAcquire(RecipeDB, 12718, A.TRAINER, 8126, A.TRAINER, 8738, A.TRAINER, 29513)

	-- The Big One -- 12754
	AddRecipe(12754, 235, 10586, R_COMMON, GAME_ORIG, 235, 235, 255, 275, 20222)
	self:addTradeFlags(RecipeDB, 12754, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP)
	self:addTradeAcquire(RecipeDB, 12754, A.TRAINER, 8126, A.TRAINER, 8738, A.TRAINER, 29513)

	-- Goblin Bomb Dispenser -- 12755
	AddRecipe(12755, 230, 10587, R_COMMON, GAME_ORIG, 230, 230, 250, 270, 20222)
	self:addTradeFlags(RecipeDB, 12755, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOP, F.RBOP, F.TRINKET)
	self:addTradeAcquire(RecipeDB, 12755, A.TRAINER, 8126, A.TRAINER, 8738, A.TRAINER, 29513)

	-- Goblin Rocket Helmet -- 12758
	AddRecipe(12758, 245, 10588, R_COMMON, GAME_ORIG, 245, 265, 275, 285, 20222)
	self:addTradeFlags(RecipeDB, 12758, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.CLOTH)
	self:addTradeAcquire(RecipeDB, 12758, A.TRAINER, 8126, A.TRAINER, 8738, A.TRAINER, 29513)

	-- Gnomish Death Ray -- 12759
	AddRecipe(12759, 240, 10645, R_COMMON, GAME_ORIG, 240, 260, 270, 280, 20219)
	self:addTradeFlags(RecipeDB, 12759, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOP, F.RBOP, F.TRINKET)
	self:addTradeAcquire(RecipeDB, 12759, A.TRAINER, 7406, A.TRAINER, 7944, A.TRAINER, 29514)

	-- Goblin Sapper Charge -- 12760
	AddRecipe(12760, 205, 10646, R_COMMON, GAME_ORIG, 205, 205, 225, 245, 20222)
	self:addTradeFlags(RecipeDB, 12760, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP)
	self:addTradeAcquire(RecipeDB, 12760, A.TRAINER, 8126, A.TRAINER, 29513)

	-- Inlaid Mithril Cylinder Plans -- 12895
	AddRecipe(12895, 205, 10713, R_COMMON, GAME_ORIG, 205, 205, 205, 205, 20219)
	self:addTradeFlags(RecipeDB, 12895, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP)
	self:addTradeAcquire(RecipeDB, 12895, A.TRAINER, 7406, A.TRAINER, 7944, A.TRAINER, 29514)

	-- Gnomish Goggles -- 12897
	AddRecipe(12897, 210, 10545, R_COMMON, GAME_ORIG, 210, 230, 240, 250, 20219)
	self:addTradeFlags(RecipeDB, 12897, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOP, F.RBOP, F.HEALER, F.CASTER, F.CLOTH)
	self:addTradeAcquire(RecipeDB, 12897, A.TRAINER, 7406, A.TRAINER, 7944, A.TRAINER, 29514)

	-- Gnomish Shrink Ray -- 12899
	AddRecipe(12899, 205, 10716, R_COMMON, GAME_ORIG, 205, 225, 235, 245, 20219)
	self:addTradeFlags(RecipeDB, 12899, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.DPS, F.TRINKET)
	self:addTradeAcquire(RecipeDB, 12899, A.TRAINER, 7406, A.TRAINER, 7944, A.TRAINER, 29514)

	-- Gnomish Net-o-Matic Projector -- 12902
	AddRecipe(12902, 210, 10720, R_COMMON, GAME_ORIG, 210, 230, 240, 250, 20219)
	self:addTradeFlags(RecipeDB, 12902, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.TRINKET)
	self:addTradeAcquire(RecipeDB, 12902, A.TRAINER, 7406, A.TRAINER, 7944, A.TRAINER, 29514)

	-- Gnomish Harm Prevention Belt -- 12903
	AddRecipe(12903, 215, 10721, R_COMMON, GAME_ORIG, 215, 235, 245, 255, 20219)
	self:addTradeFlags(RecipeDB, 12903, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.LEATHER)
	self:addTradeAcquire(RecipeDB, 12903, A.TRAINER, 7406, A.TRAINER, 7944, A.TRAINER, 29514)

	-- Gnomish Rocket Boots -- 12905
	AddRecipe(12905, 225, 10724, R_COMMON, GAME_ORIG, 225, 245, 255, 265, 20219)
	self:addTradeFlags(RecipeDB, 12905, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.CLOTH)
	self:addTradeAcquire(RecipeDB, 12905, A.TRAINER, 7406, A.TRAINER, 7944, A.TRAINER, 29514)

	-- Gnomish Battle Chicken -- 12906
	AddRecipe(12906, 230, 10725, R_COMMON, GAME_ORIG, 230, 250, 260, 270, 20219)
	self:addTradeFlags(RecipeDB, 12906, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOP, F.RBOP, F.TRINKET)
	self:addTradeAcquire(RecipeDB, 12906, A.TRAINER, 7406, A.TRAINER, 7944, A.TRAINER, 29514)

	-- Gnomish Mind Control Cap -- 12907
	AddRecipe(12907, 235, 10726, R_COMMON, GAME_ORIG, 235, 255, 265, 275, 20219)
	self:addTradeFlags(RecipeDB, 12907, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.HEALER, F.CASTER, F.CLOTH)
	self:addTradeAcquire(RecipeDB, 12907, A.TRAINER, 7406, A.TRAINER, 7944, A.TRAINER, 29514)

	-- Goblin Dragon Gun -- 12908
	AddRecipe(12908, 240, 10727, R_COMMON, GAME_ORIG, 240, 260, 270, 280, 20222)
	self:addTradeFlags(RecipeDB, 12908, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOP, F.RBOP, F.TRINKET)
	self:addTradeAcquire(RecipeDB, 12908, A.TRAINER, 8126, A.TRAINER, 8738, A.TRAINER, 29513)

	-- The Mortar: Reloaded -- 13240
	AddRecipe(13240, 205, 10577, R_COMMON, GAME_ORIG, 205, 205, 205, 205, 20222)
	self:addTradeFlags(RecipeDB, 13240, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.TRINKET)
	self:addTradeAcquire(RecipeDB, 13240, A.TRAINER, 8126, A.TRAINER, 8738)

	-- Mechanical Repair Kit -- 15255
	AddRecipe(15255, 200, 11590, R_COMMON, GAME_ORIG, 200, 200, 220, 240)
	self:addTradeFlags(RecipeDB, 15255, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP)
	self:addTradeAcquire(RecipeDB, 15255, A.TRAINER, 5174, A.TRAINER, 8736, A.TRAINER, 11017, A.TRAINER, 17634, A.TRAINER, 17637, A.TRAINER, 18752, A.TRAINER, 18775, A.TRAINER, 19576, A.TRAINER, 16667, A.TRAINER, 28697, A.TRAINER, 1702, A.TRAINER, 16726, A.TRAINER, 33586, A.TRAINER, 3494, A.TRAINER, 3290, A.TRAINER, 5518, A.TRAINER, 26991, A.TRAINER, 33611, A.TRAINER, 33634, A.TRAINER, 1676, A.TRAINER, 25277, A.TRAINER, 26907, A.TRAINER, 11031, A.TRAINER, 11025, A.TRAINER, 26955, A.TRAINER, 11037, A.TRAINER, 17222)

	-- Pet Bombling -- 15628
	AddRecipe(15628, 205, 11825, R_UNCOMMON, GAME_ORIG, 205, 205, 205, 205)
	self:addTradeFlags(RecipeDB, 15628, F.ALLIANCE, F.HORDE, F.INSTANCE, F.IBOP, F.RBOP)
	self:addTradeAcquire(RecipeDB, 15628, A.CUSTOM, 16)

	-- Lil' Smoky -- 15633
	AddRecipe(15633, 205, 11826, R_UNCOMMON, GAME_ORIG, 205, 205, 205, 205)
	self:addTradeFlags(RecipeDB, 15633, F.ALLIANCE, F.HORDE, F.INSTANCE, F.IBOP, F.RBOP)
	self:addTradeAcquire(RecipeDB, 15633, A.CUSTOM, 16)

	-- Salt Shaker -- 19567
	AddRecipe(19567, 250, 15846, R_COMMON, GAME_ORIG, 250, 270, 280, 290)
	self:addTradeFlags(RecipeDB, 19567, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP)
	self:addTradeAcquire(RecipeDB, 19567, A.TRAINER, 8736, A.TRAINER, 17634, A.TRAINER, 17637, A.TRAINER, 18752, A.TRAINER, 18775, A.TRAINER, 19576, A.TRAINER, 16667, A.TRAINER, 28697, A.TRAINER, 1702, A.TRAINER, 16726, A.TRAINER, 11017, A.TRAINER, 33586, A.TRAINER, 3494, A.TRAINER, 5174, A.TRAINER, 3290, A.TRAINER, 5518, A.TRAINER, 26991, A.TRAINER, 33611, A.TRAINER, 33634, A.TRAINER, 1676, A.TRAINER, 25277, A.TRAINER, 26907, A.TRAINER, 11031, A.TRAINER, 11025, A.TRAINER, 26955, A.TRAINER, 11037, A.TRAINER, 17222)

	-- Dense Blasting Powder -- 19788
	AddRecipe(19788, 250, 15992, R_COMMON, GAME_ORIG, 250, 250, 255, 260)
	self:addTradeFlags(RecipeDB, 19788, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP)
	self:addTradeAcquire(RecipeDB, 19788, A.TRAINER, 8736, A.TRAINER, 17634, A.TRAINER, 17637, A.TRAINER, 18752, A.TRAINER, 18775, A.TRAINER, 19576, A.TRAINER, 16667, A.TRAINER, 28697, A.TRAINER, 1702, A.TRAINER, 16726, A.TRAINER, 11017, A.TRAINER, 33586, A.TRAINER, 3494, A.TRAINER, 5174, A.TRAINER, 3290, A.TRAINER, 5518, A.TRAINER, 26991, A.TRAINER, 33611, A.TRAINER, 33634, A.TRAINER, 1676, A.TRAINER, 25277, A.TRAINER, 26907, A.TRAINER, 11031, A.TRAINER, 11025, A.TRAINER, 26955, A.TRAINER, 11037, A.TRAINER, 17222)

	-- Thorium Grenade -- 19790
	AddRecipe(19790, 260, 15993, R_COMMON, GAME_ORIG, 260, 280, 290, 300)
	self:addTradeFlags(RecipeDB, 19790, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOE)
	self:addTradeAcquire(RecipeDB, 19790, A.TRAINER, 8736, A.TRAINER, 17634, A.TRAINER, 17637, A.TRAINER, 18752, A.TRAINER, 18775, A.TRAINER, 19576, A.TRAINER, 16667, A.TRAINER, 28697, A.TRAINER, 1702, A.TRAINER, 16726, A.TRAINER, 11017, A.TRAINER, 33586, A.TRAINER, 3494, A.TRAINER, 5174, A.TRAINER, 3290, A.TRAINER, 5518, A.TRAINER, 26991, A.TRAINER, 33611, A.TRAINER, 33634, A.TRAINER, 1676, A.TRAINER, 25277, A.TRAINER, 26907, A.TRAINER, 11031, A.TRAINER, 11025, A.TRAINER, 26955, A.TRAINER, 11037, A.TRAINER, 17222)

	-- Thorium Widget -- 19791
	AddRecipe(19791, 260, 15994, R_COMMON, GAME_ORIG, 260, 280, 290, 300)
	self:addTradeFlags(RecipeDB, 19791, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOE)
	self:addTradeAcquire(RecipeDB, 19791, A.TRAINER, 8736, A.TRAINER, 17634, A.TRAINER, 17637, A.TRAINER, 18752, A.TRAINER, 18775, A.TRAINER, 19576, A.TRAINER, 16667, A.TRAINER, 28697, A.TRAINER, 1702, A.TRAINER, 16726, A.TRAINER, 11017, A.TRAINER, 33586, A.TRAINER, 3494, A.TRAINER, 5174, A.TRAINER, 3290, A.TRAINER, 5518, A.TRAINER, 26991, A.TRAINER, 33611, A.TRAINER, 33634, A.TRAINER, 1676, A.TRAINER, 25277, A.TRAINER, 26907, A.TRAINER, 11031, A.TRAINER, 11025, A.TRAINER, 26955, A.TRAINER, 11037, A.TRAINER, 17222)

	-- Thorium Rifle -- 19792
	AddRecipe(19792, 260, 15995, R_UNCOMMON, GAME_ORIG, 260, 280, 290, 300)
	self:addTradeFlags(RecipeDB, 19792, F.ALLIANCE, F.HORDE, F.TRAINER, F.MOB_DROP, F.IBOE, F.RBOE, F.DPS, F.GUN)
	self:addTradeAcquire(RecipeDB, 19792, A.TRAINER, 8736, A.TRAINER, 17634, A.TRAINER, 17637, A.TRAINER, 18752, A.TRAINER, 18775, A.TRAINER, 19576, A.TRAINER, 16667, A.TRAINER, 28697, A.TRAINER, 1702, A.TRAINER, 16726, A.TRAINER, 11017, A.TRAINER, 33586, A.TRAINER, 3494, A.TRAINER, 5174, A.TRAINER, 3290, A.TRAINER, 5518, A.TRAINER, 26991, A.TRAINER, 33611, A.TRAINER, 33634, A.TRAINER, 1676, A.TRAINER, 25277, A.TRAINER, 26907, A.TRAINER, 11031, A.TRAINER, 11025, A.TRAINER, 26955, A.TRAINER, 11037, A.TRAINER, 17222)

	-- Lifelike Mechanical Toad -- 19793
	AddRecipe(19793, 265, 15996, R_UNCOMMON, GAME_ORIG, 265, 285, 295, 305)
	self:addTradeFlags(RecipeDB, 19793, F.ALLIANCE, F.HORDE, F.WORLD_DROP, F.IBOE, F.RBOE)
	self:addTradeAcquire(RecipeDB, 19793, A.WORLD_DROP, 2)

	-- Spellpower Goggles Xtreme Plus -- 19794
	AddRecipe(19794, 270, 15999, R_UNCOMMON, GAME_ORIG, 270, 290, 300, 310)
	self:addTradeFlags(RecipeDB, 19794, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOE, F.HEALER, F.CASTER, F.CLOTH)
	self:addTradeAcquire(RecipeDB, 19794, A.TRAINER, 8736, A.TRAINER, 17634, A.TRAINER, 17637, A.TRAINER, 18752, A.TRAINER, 18775, A.TRAINER, 19576, A.TRAINER, 16667, A.TRAINER, 28697, A.TRAINER, 1702, A.TRAINER, 16726, A.TRAINER, 11017, A.TRAINER, 33586, A.TRAINER, 3494, A.TRAINER, 5174, A.TRAINER, 3290, A.TRAINER, 5518, A.TRAINER, 26991, A.TRAINER, 33611, A.TRAINER, 33634, A.TRAINER, 1676, A.TRAINER, 25277, A.TRAINER, 26907, A.TRAINER, 11031, A.TRAINER, 11025, A.TRAINER, 26955, A.TRAINER, 11037, A.TRAINER, 17222)

	-- Thorium Tube -- 19795
	AddRecipe(19795, 275, 16000, R_COMMON, GAME_ORIG, 275, 295, 305, 315)
	self:addTradeFlags(RecipeDB, 19795, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOE)
	self:addTradeAcquire(RecipeDB, 19795, A.TRAINER, 8736, A.TRAINER, 17634, A.TRAINER, 17637, A.TRAINER, 18752, A.TRAINER, 18775, A.TRAINER, 19576, A.TRAINER, 16667, A.TRAINER, 28697, A.TRAINER, 1702, A.TRAINER, 16726, A.TRAINER, 11017, A.TRAINER, 33586, A.TRAINER, 3494, A.TRAINER, 5174, A.TRAINER, 3290, A.TRAINER, 5518, A.TRAINER, 26991, A.TRAINER, 33611, A.TRAINER, 33634, A.TRAINER, 1676, A.TRAINER, 25277, A.TRAINER, 26907, A.TRAINER, 11031, A.TRAINER, 11025, A.TRAINER, 26955, A.TRAINER, 11037, A.TRAINER, 17222)

	-- Dark Iron Rifle -- 19796
	AddRecipe(19796, 275, 16004, R_UNCOMMON, GAME_ORIG, 275, 295, 305, 315)
	self:addTradeFlags(RecipeDB, 19796, F.ALLIANCE, F.HORDE, F.INSTANCE, F.IBOE, F.RBOE, F.GUN)
	self:addTradeAcquire(RecipeDB, 19796, A.MOB, 8897)

	-- Dark Iron Bomb -- 19799
	AddRecipe(19799, 285, 16005, R_UNCOMMON, GAME_ORIG, 285, 305, 315, 325)
	self:addTradeFlags(RecipeDB, 19799, F.ALLIANCE, F.HORDE, F.INSTANCE, F.MOB_DROP, F.IBOE, F.RBOE)
	self:addTradeAcquire(RecipeDB, 19799, A.MOB, 8920)

	-- Thorium Shells -- 19800
	AddRecipe(19800, 285, 15997, R_UNCOMMON, GAME_ORIG, 285, 295, 300, 305)
	self:addTradeFlags(RecipeDB, 19800, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOE, F.AMMO)
	self:addTradeAcquire(RecipeDB, 19800, A.TRAINER, 8736, A.TRAINER, 17634, A.TRAINER, 17637, A.TRAINER, 18752, A.TRAINER, 18775, A.TRAINER, 19576, A.TRAINER, 16667, A.TRAINER, 28697, A.TRAINER, 1702, A.TRAINER, 16726, A.TRAINER, 11017, A.TRAINER, 33586, A.TRAINER, 3494, A.TRAINER, 5174, A.TRAINER, 3290, A.TRAINER, 5518, A.TRAINER, 26991, A.TRAINER, 33611, A.TRAINER, 33634, A.TRAINER, 1676, A.TRAINER, 25277, A.TRAINER, 26907, A.TRAINER, 11031, A.TRAINER, 11025, A.TRAINER, 26955, A.TRAINER, 11037, A.TRAINER, 17222)

	-- Masterwork Target Dummy -- 19814
	AddRecipe(19814, 275, 16023, R_COMMON, GAME_ORIG, 275, 295, 305, 315)
	self:addTradeFlags(RecipeDB, 19814, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOE)
	self:addTradeAcquire(RecipeDB, 19814, A.VENDOR, 11185)

	-- Delicate Arcanite Converter -- 19815
	AddRecipe(19815, 285, 16006, R_COMMON, GAME_ORIG, 285, 305, 315, 325)
	self:addTradeFlags(RecipeDB, 19815, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOE)
	self:addTradeAcquire(RecipeDB, 19815, A.VENDOR, 11185)

	-- Voice Amplification Modulator -- 19819
	AddRecipe(19819, 290, 16009, R_UNCOMMON, GAME_ORIG, 290, 310, 320, 330)
	self:addTradeFlags(RecipeDB, 19819, F.ALLIANCE, F.HORDE, F.INSTANCE, F.IBOE, F.RBOE, F.NECK)
	self:addTradeAcquire(RecipeDB, 19819, A.MOB, 10426)

	-- Master Engineer's Goggles -- 19825
	AddRecipe(19825, 290, 16008, R_UNCOMMON, GAME_ORIG, 290, 310, 320, 330)
	self:addTradeFlags(RecipeDB, 19825, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOE, F.HEALER, F.CASTER, F.CLOTH)
	self:addTradeAcquire(RecipeDB, 19825, A.TRAINER, 8736, A.TRAINER, 17634, A.TRAINER, 17637, A.TRAINER, 18752, A.TRAINER, 18775, A.TRAINER, 19576, A.TRAINER, 16667, A.TRAINER, 28697, A.TRAINER, 1702, A.TRAINER, 16726, A.TRAINER, 11017, A.TRAINER, 33586, A.TRAINER, 3494, A.TRAINER, 5174, A.TRAINER, 3290, A.TRAINER, 5518, A.TRAINER, 26991, A.TRAINER, 33611, A.TRAINER, 33634, A.TRAINER, 1676, A.TRAINER, 25277, A.TRAINER, 26907, A.TRAINER, 11031, A.TRAINER, 11025, A.TRAINER, 26955, A.TRAINER, 11037, A.TRAINER, 17222)

	-- Arcanite Dragonling -- 19830
	AddRecipe(19830, 300, 16022, R_UNCOMMON, GAME_ORIG, 300, 320, 330, 340)
	self:addTradeFlags(RecipeDB, 19830, F.ALLIANCE, F.HORDE, F.MOB_DROP, F.IBOE, F.RBOE, F.TRINKET)
	self:addTradeAcquire(RecipeDB, 19830, A.MOB, 7437)

	-- Arcane Bomb -- 19831
	AddRecipe(19831, 300, 16040, R_UNCOMMON, GAME_ORIG, 300, 320, 330, 340)
	self:addTradeFlags(RecipeDB, 19831, F.ALLIANCE, F.HORDE, F.WORLD_DROP, F.IBOE, F.RBOE)
	self:addTradeAcquire(RecipeDB, 19831, A.WORLD_DROP, 2)

	-- Flawless Arcanite Rifle -- 19833
	AddRecipe(19833, 300, 16007, R_UNCOMMON, GAME_ORIG, 300, 320, 330, 340)
	self:addTradeFlags(RecipeDB, 19833, F.ALLIANCE, F.HORDE, F.MOB_DROP, F.IBOE, F.RBOE, F.DPS, F.GUN)
	self:addTradeAcquire(RecipeDB, 19833, A.MOB, 8561)

	-- Snowmaster 9000 -- 21940
	AddRecipe(21940, 190, 17716, R_UNCOMMON, GAME_ORIG, 190, 190, 210, 230)
	self:addTradeFlags(RecipeDB, 21940, F.ALLIANCE, F.HORDE, F.SEASONAL, F.MOB_DROP, F.IBOE, F.RBOE)
	self:addTradeAcquire(RecipeDB, 21940, A.SEASONAL, 1)

	-- Field Repair Bot 74A -- 22704
	AddRecipe(22704, 300, 18232, R_COMMON, GAME_ORIG, 300, 320, 330, 340)
	self:addTradeFlags(RecipeDB, 22704, F.ALLIANCE, F.HORDE, F.INSTANCE, F.IBOE, F.RBOP)
	self:addTradeAcquire(RecipeDB, 22704, A.CUSTOM, 17)

	-- Biznicks 247x128 Accurascope -- 22793
	AddRecipe(22793, 300, 18283, R_RARE, GAME_ORIG, 300, 320, 330, 340)
	self:addTradeFlags(RecipeDB, 22793, F.ALLIANCE, F.HORDE, F.RAID, F.IBOE, F.RBOP, F.DPS)
	self:addTradeAcquire(RecipeDB, 22793, A.CUSTOM, 26)

	-- Core Marksman Rifle -- 22795
	AddRecipe(22795, 300, 18282, R_RARE, GAME_ORIG, 300, 320, 330, 340)
	self:addTradeFlags(RecipeDB, 22795, F.ALLIANCE, F.HORDE, F.RAID, F.IBOE, F.RBOP, F.DPS, F.GUN)
	self:addTradeAcquire(RecipeDB, 22795, A.CUSTOM, 26)

	-- Force Reactive Disk -- 22797
	AddRecipe(22797, 300, 18168, R_RARE, GAME_ORIG, 300, 320, 330, 340)
	self:addTradeFlags(RecipeDB, 22797, F.ALLIANCE, F.HORDE, F.RAID, F.IBOE, F.RBOP, F.TANK, F.SHIELD, F.ONE_HAND)
	self:addTradeAcquire(RecipeDB, 22797, A.CUSTOM, 26)

	-- Red Firework -- 23066
	AddRecipe(23066, 150, 9318, R_COMMON, GAME_ORIG, 150, 150, 162, 175)
	self:addTradeFlags(RecipeDB, 23066, F.HORDE, F.VENDOR, F.IBOE, F.RBOE)
	self:addTradeAcquire(RecipeDB, 23066, A.VENDOR, 3413)

	-- Blue Firework -- 23067
	AddRecipe(23067, 150, 9312, R_COMMON, GAME_ORIG, 150, 150, 162, 175)
	self:addTradeFlags(RecipeDB, 23067, F.ALLIANCE, F.VENDOR, F.IBOE, F.RBOE)
	self:addTradeAcquire(RecipeDB, 23067, A.VENDOR, 5175)

	-- Green Firework -- 23068
	AddRecipe(23068, 150, 9313, R_COMMON, GAME_ORIG, 150, 150, 162, 175)
	self:addTradeFlags(RecipeDB, 23068, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOP)
	self:addTradeAcquire(RecipeDB, 23068, A.VENDOR, 2838, A.VENDOR, 3495)

	-- EZ-Thro Dynamite II -- 23069
	AddRecipe(23069, 200, 18588, R_COMMON, GAME_ORIG, 200, 200, 210, 220)
	self:addTradeFlags(RecipeDB, 23069, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOE)
	self:addTradeAcquire(RecipeDB, 23069, A.VENDOR, 8131)

	-- Dense Dynamite -- 23070
	AddRecipe(23070, 250, 18641, R_COMMON, GAME_ORIG, 250, 250, 260, 270)
	self:addTradeFlags(RecipeDB, 23070, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP)
	self:addTradeAcquire(RecipeDB, 23070, A.TRAINER, 8736, A.TRAINER, 17634, A.TRAINER, 17637, A.TRAINER, 18752, A.TRAINER, 18775, A.TRAINER, 19576, A.TRAINER, 16667, A.TRAINER, 28697, A.TRAINER, 1702, A.TRAINER, 16726, A.TRAINER, 11017, A.TRAINER, 33586, A.TRAINER, 3494, A.TRAINER, 5174, A.TRAINER, 3290, A.TRAINER, 5518, A.TRAINER, 26991, A.TRAINER, 33611, A.TRAINER, 33634, A.TRAINER, 1676, A.TRAINER, 25277, A.TRAINER, 26907, A.TRAINER, 11031, A.TRAINER, 11025, A.TRAINER, 26955, A.TRAINER, 11037, A.TRAINER, 17222)

	-- Truesilver Transformer -- 23071
	AddRecipe(23071, 260, 18631, R_COMMON, GAME_ORIG, 260, 270, 275, 280)
	self:addTradeFlags(RecipeDB, 23071, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOE)
	self:addTradeAcquire(RecipeDB, 23071, A.TRAINER, 8736, A.TRAINER, 17634, A.TRAINER, 17637, A.TRAINER, 18752, A.TRAINER, 18775, A.TRAINER, 19576, A.TRAINER, 16667, A.TRAINER, 28697, A.TRAINER, 1702, A.TRAINER, 16726, A.TRAINER, 11017, A.TRAINER, 33586, A.TRAINER, 3494, A.TRAINER, 5174, A.TRAINER, 3290, A.TRAINER, 5518, A.TRAINER, 26991, A.TRAINER, 33611, A.TRAINER, 33634, A.TRAINER, 1676, A.TRAINER, 25277, A.TRAINER, 26907, A.TRAINER, 11031, A.TRAINER, 11025, A.TRAINER, 26955, A.TRAINER, 11037, A.TRAINER, 17222)

	-- Gyrofreeze Ice Reflector -- 23077
	AddRecipe(23077, 260, 18634, R_COMMON, GAME_ORIG, 260, 280, 290, 300)
	self:addTradeFlags(RecipeDB, 23077, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOE, F.TRINKET)
	self:addTradeAcquire(RecipeDB, 23077, A.VENDOR, 11185)

	-- Goblin Jumper Cables XL -- 23078
	AddRecipe(23078, 265, 18587, R_UNCOMMON, GAME_ORIG, 265, 285, 295, 305, 20222)
	self:addTradeFlags(RecipeDB, 23078, F.ALLIANCE, F.HORDE, F.INSTANCE, F.IBOE, F.RBOE)
	self:addTradeAcquire(RecipeDB, 23078, A.MOB, 9499)

	-- Major Recombobulator -- 23079
	AddRecipe(23079, 275, 18637, R_UNCOMMON, GAME_ORIG, 275, 285, 290, 295)
	self:addTradeFlags(RecipeDB, 23079, F.ALLIANCE, F.HORDE, F.INSTANCE, F.IBOE, F.RBOE, F.TRINKET)
	self:addTradeAcquire(RecipeDB, 23079, A.CUSTOM, 32)

	-- Powerful Seaforium Charge -- 23080
	AddRecipe(23080, 275, 18594, R_COMMON, GAME_ORIG, 275, 275, 285, 295)
	self:addTradeFlags(RecipeDB, 23080, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOE)
	self:addTradeAcquire(RecipeDB, 23080, A.VENDOR, 11185)

	-- Hyper-Radiant Flame Reflector -- 23081
	AddRecipe(23081, 290, 18638, R_UNCOMMON, GAME_ORIG, 290, 310, 320, 330)
	self:addTradeFlags(RecipeDB, 23081, F.ALLIANCE, F.HORDE, F.INSTANCE, F.IBOE, F.RBOE, F.TRINKET)
	self:addTradeAcquire(RecipeDB, 23081, A.MOB, 10264)

	-- Ultra-Flash Shadow Reflector -- 23082
	AddRecipe(23082, 300, 18639, R_UNCOMMON, GAME_ORIG, 300, 320, 330, 340)
	self:addTradeFlags(RecipeDB, 23082, F.ALLIANCE, F.HORDE, F.INSTANCE, F.IBOE, F.RBOE, F.TRINKET)
	self:addTradeAcquire(RecipeDB, 23082, A.MOB, 10426)

	-- Gnomish Alarm-o-Bot -- 23096
	AddRecipe(23096, 265, 18645, R_UNCOMMON, GAME_ORIG, 265, 275, 280, 285, 20219)
	self:addTradeFlags(RecipeDB, 23096, F.ALLIANCE, F.HORDE, F.INSTANCE, F.MOB_DROP, F.IBOE, F.RBOE)
	self:addTradeAcquire(RecipeDB, 23096, A.MOB, 8920)

	-- World Enlarger -- 23129
	AddRecipe(23129, 260, 18660, R_UNCOMMON, GAME_ORIG, 260, 260, 265, 270, 20219)
	self:addTradeFlags(RecipeDB, 23129, F.ALLIANCE, F.HORDE, F.INSTANCE, F.MOB_DROP, F.IBOE, F.RBOE)
	self:addTradeAcquire(RecipeDB, 23129, A.MOB, 8920)

	-- Dimensional Ripper - Everlook -- 23486
	AddRecipe(23486, 260, 18984, R_UNCOMMON, GAME_ORIG, 260, 285, 295, 305, 20222)
	self:addTradeFlags(RecipeDB, 23486, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP)
	self:addTradeAcquire(RecipeDB, 23486, A.CUSTOM, 20)

	-- Ultrasafe Transporter - Gadgetzan -- 23489
	AddRecipe(23489, 260, 18986, R_UNCOMMON, GAME_ORIG, 260, 285, 295, 305, 20219)
	self:addTradeFlags(RecipeDB, 23489, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP)
	self:addTradeAcquire(RecipeDB, 23489, A.CUSTOM, 20)

	-- Snake Burst Firework -- 23507
	AddRecipe(23507, 250, 19026, R_COMMON, GAME_ORIG, 250, 250, 260, 270)
	self:addTradeFlags(RecipeDB, 23507, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOP)
	self:addTradeAcquire(RecipeDB, 23507, A.VENDOR, 14637)

	-- Bloodvine Goggles -- 24356
	AddRecipe(24356, 300, 19999, R_COMMON, GAME_ORIG, 300, 320, 330, 340)
	self:addTradeFlags(RecipeDB, 24356, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOP, F.CLOTH, F.ZANDALAR)
	self:addTradeAcquire(RecipeDB, 24356, A.REPUTATION, FAC.ZANDALAR, REP.HONORED, 14921)

	-- Bloodvine Lens -- 24357
	AddRecipe(24357, 300, 19998, R_COMMON, GAME_ORIG, 300, 320, 330, 340)
	self:addTradeFlags(RecipeDB, 24357, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOP, F.LEATHER, F.ZANDALAR)
	self:addTradeAcquire(RecipeDB, 24357, A.REPUTATION, FAC.ZANDALAR, REP.FRIENDLY, 14921)

	-- Tranquil Mechanical Yeti -- 26011
	AddRecipe(26011, 250, 21277, R_COMMON, GAME_ORIG, 250, 320, 330, 340)
	self:addTradeFlags(RecipeDB, 26011, F.ALLIANCE, F.HORDE, F.QUEST, F.IBOE, F.RBOP)
	self:addTradeAcquire(RecipeDB, 26011, A.QUEST, 8798)

	-- Small Blue Rocket -- 26416
	AddRecipe(26416, 125, 21558, R_UNCOMMON, GAME_ORIG, 125, 125, 137, 150)
	self:addTradeFlags(RecipeDB, 26416, F.ALLIANCE, F.HORDE, F.VENDOR, F.SEASONAL, F.IBOE, F.RBOP)
	self:addTradeAcquire(RecipeDB, 26416, A.SEASONAL, 2, A.VENDOR, 15909)

	-- Small Green Rocket -- 26417
	AddRecipe(26417, 125, 21559, R_UNCOMMON, GAME_ORIG, 125, 125, 137, 150)
	self:addTradeFlags(RecipeDB, 26417, F.ALLIANCE, F.HORDE, F.VENDOR, F.SEASONAL, F.IBOE, F.RBOP)
	self:addTradeAcquire(RecipeDB, 26417, A.SEASONAL, 2, A.VENDOR, 15909)

	-- Small Red Rocket -- 26418
	AddRecipe(26418, 125, 21557, R_UNCOMMON, GAME_ORIG, 125, 125, 137, 150)
	self:addTradeFlags(RecipeDB, 26418, F.ALLIANCE, F.HORDE, F.VENDOR, F.SEASONAL, F.IBOE, F.RBOP)
	self:addTradeAcquire(RecipeDB, 26418, A.SEASONAL, 2, A.VENDOR, 15909)

	-- Large Blue Rocket -- 26420
	AddRecipe(26420, 175, 21589, R_UNCOMMON, GAME_ORIG, 175, 175, 187, 200)
	self:addTradeFlags(RecipeDB, 26420, F.ALLIANCE, F.HORDE, F.VENDOR, F.SEASONAL, F.IBOE, F.RBOP)
	self:addTradeAcquire(RecipeDB, 26420, A.SEASONAL, 2, A.VENDOR, 15909)

	-- Large Green Rocket -- 26421
	AddRecipe(26421, 175, 21590, R_UNCOMMON, GAME_ORIG, 175, 175, 187, 200)
	self:addTradeFlags(RecipeDB, 26421, F.ALLIANCE, F.HORDE, F.VENDOR, F.SEASONAL, F.IBOE, F.RBOP)
	self:addTradeAcquire(RecipeDB, 26421, A.SEASONAL, 2, A.VENDOR, 15909)

	-- Large Red Rocket -- 26422
	AddRecipe(26422, 175, 21592, R_UNCOMMON, GAME_ORIG, 175, 175, 187, 200)
	self:addTradeFlags(RecipeDB, 26422, F.ALLIANCE, F.HORDE, F.VENDOR, F.SEASONAL, F.IBOE, F.RBOP)
	self:addTradeAcquire(RecipeDB, 26422, A.SEASONAL, 2, A.VENDOR, 15909)

	-- Blue Rocket Cluster -- 26423
	AddRecipe(26423, 225, 21571, R_UNCOMMON, GAME_ORIG, 225, 225, 237, 250)
	self:addTradeFlags(RecipeDB, 26423, F.ALLIANCE, F.HORDE, F.VENDOR, F.SEASONAL, F.IBOE, F.RBOP)
	self:addTradeAcquire(RecipeDB, 26423, A.SEASONAL, 2, A.VENDOR, 15909)

	-- Green Rocket Cluster -- 26424
	AddRecipe(26424, 225, 21574, R_UNCOMMON, GAME_ORIG, 225, 225, 237, 250)
	self:addTradeFlags(RecipeDB, 26424, F.ALLIANCE, F.HORDE, F.VENDOR, F.SEASONAL, F.IBOE, F.RBOP)
	self:addTradeAcquire(RecipeDB, 26424, A.SEASONAL, 2, A.VENDOR, 15909)

	-- Red Rocket Cluster -- 26425
	AddRecipe(26425, 225, 21576, R_UNCOMMON, GAME_ORIG, 225, 225, 237, 250)
	self:addTradeFlags(RecipeDB, 26425, F.ALLIANCE, F.HORDE, F.VENDOR, F.SEASONAL, F.IBOE, F.RBOP)
	self:addTradeAcquire(RecipeDB, 26425, A.SEASONAL, 2, A.VENDOR, 15909)

	-- Large Blue Rocket Cluster -- 26426
	AddRecipe(26426, 275, 21714, R_UNCOMMON, GAME_ORIG, 275, 275, 280, 285)
	self:addTradeFlags(RecipeDB, 26426, F.ALLIANCE, F.HORDE, F.VENDOR, F.SEASONAL, F.IBOE, F.RBOP)
	self:addTradeAcquire(RecipeDB, 26426, A.SEASONAL, 2, A.VENDOR, 15909)

	-- Large Green Rocket Cluster -- 26427
	AddRecipe(26427, 275, 21716, R_UNCOMMON, GAME_ORIG, 275, 275, 280, 285)
	self:addTradeFlags(RecipeDB, 26427, F.ALLIANCE, F.HORDE, F.VENDOR, F.SEASONAL, F.IBOE, F.RBOP)
	self:addTradeAcquire(RecipeDB, 26427, A.SEASONAL, 2, A.VENDOR, 15909)

	-- Large Red Rocket Cluster -- 26428
	AddRecipe(26428, 275, 21718, R_UNCOMMON, GAME_ORIG, 275, 275, 280, 285)
	self:addTradeFlags(RecipeDB, 26428, F.ALLIANCE, F.HORDE, F.VENDOR, F.SEASONAL, F.IBOE, F.RBOP)
	self:addTradeAcquire(RecipeDB, 26428, A.SEASONAL, 2, A.VENDOR, 15909)

	-- Firework Launcher -- 26442
	AddRecipe(26442, 225, 21569, R_UNCOMMON, GAME_ORIG, 225, 245, 255, 265)
	self:addTradeFlags(RecipeDB, 26442, F.ALLIANCE, F.HORDE, F.VENDOR, F.SEASONAL, F.IBOE, F.RBOP)
	self:addTradeAcquire(RecipeDB, 26442, A.SEASONAL, 2, A.VENDOR, 15909)

	-- Firework Cluster Launcher -- 26443
	AddRecipe(26443, 275, 21570, R_UNCOMMON, GAME_ORIG, 275, 295, 305, 315)
	self:addTradeFlags(RecipeDB, 26443, F.ALLIANCE, F.HORDE, F.VENDOR, F.SEASONAL, F.IBOE, F.RBOP)
	self:addTradeAcquire(RecipeDB, 26443, A.SEASONAL, 2, A.VENDOR, 15909)

	-- Steam Tonk Controller -- 28327
	AddRecipe(28327, 275, 22728, R_COMMON, GAME_ORIG, 275, 275, 280, 285)
	self:addTradeFlags(RecipeDB, 28327, F.ALLIANCE, F.HORDE, F.VENDOR, F.QUEST, F.IBOE, F.RBOP)
	self:addTradeAcquire(RecipeDB, 28327, A.QUEST, 9249, A.VENDOR, 3413, A.VENDOR, 5175)

	-- Elemental Blasting Powder -- 30303
	AddRecipe(30303, 300, 23781, R_COMMON, GAME_TBC, 300, 300, 310, 320)
	self:addTradeFlags(RecipeDB, 30303, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP)
	self:addTradeAcquire(RecipeDB, 30303, A.TRAINER, 17634, A.TRAINER, 17637, A.TRAINER, 18752, A.TRAINER, 18775, A.TRAINER, 19576, A.TRAINER, 28697, A.TRAINER, 33586, A.TRAINER, 26991, A.TRAINER, 33611, A.TRAINER, 33634, A.TRAINER, 25277, A.TRAINER, 26907, A.TRAINER, 26955)

	-- Fel Iron Casing -- 30304
	AddRecipe(30304, 300, 23782, R_COMMON, GAME_TBC, 300, 300, 310, 320)
	self:addTradeFlags(RecipeDB, 30304, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP)
	self:addTradeAcquire(RecipeDB, 30304, A.TRAINER, 17634, A.TRAINER, 17637, A.TRAINER, 18752, A.TRAINER, 18775, A.TRAINER, 19576, A.TRAINER, 28697, A.TRAINER, 33586, A.TRAINER, 26991, A.TRAINER, 33611, A.TRAINER, 33634, A.TRAINER, 25277, A.TRAINER, 26907, A.TRAINER, 26955)

	-- Handful of Fel Iron Bolts -- 30305
	AddRecipe(30305, 300, 23783, R_COMMON, GAME_TBC, 300, 300, 305, 310)
	self:addTradeFlags(RecipeDB, 30305, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP)
	self:addTradeAcquire(RecipeDB, 30305, A.TRAINER, 17634, A.TRAINER, 17637, A.TRAINER, 18752, A.TRAINER, 18775, A.TRAINER, 19576, A.TRAINER, 28697, A.TRAINER, 33586, A.TRAINER, 26991, A.TRAINER, 33611, A.TRAINER, 33634, A.TRAINER, 25277, A.TRAINER, 26907, A.TRAINER, 26955)

	-- Adamantite Frame -- 30306
	AddRecipe(30306, 325, 23784, R_COMMON, GAME_TBC, 325, 325, 330, 335)
	self:addTradeFlags(RecipeDB, 30306, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP)
	self:addTradeAcquire(RecipeDB, 30306, A.TRAINER, 17634, A.TRAINER, 17637, A.TRAINER, 18752, A.TRAINER, 18775, A.TRAINER, 19576, A.TRAINER, 28697, A.TRAINER, 33586, A.TRAINER, 26991, A.TRAINER, 33611, A.TRAINER, 33634, A.TRAINER, 25277, A.TRAINER, 26907, A.TRAINER, 26955)

	-- Hardened Adamantite Tube -- 30307
	AddRecipe(30307, 340, 23785, R_COMMON, GAME_TBC, 340, 350, 360, 370)
	self:addTradeFlags(RecipeDB, 30307, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP)
	self:addTradeAcquire(RecipeDB, 30307, A.TRAINER, 17634, A.TRAINER, 17637, A.TRAINER, 18752, A.TRAINER, 18775, A.TRAINER, 19576, A.TRAINER, 28697, A.TRAINER, 33586, A.TRAINER, 26991, A.TRAINER, 33611, A.TRAINER, 33634, A.TRAINER, 25277, A.TRAINER, 26907, A.TRAINER, 26955)

	-- Khorium Power Core -- 30308
	AddRecipe(30308, 340, 23786, R_COMMON, GAME_TBC, 340, 350, 360, 370)
	self:addTradeFlags(RecipeDB, 30308, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP)
	self:addTradeAcquire(RecipeDB, 30308, A.TRAINER, 17634, A.TRAINER, 17637, A.TRAINER, 18752, A.TRAINER, 18775, A.TRAINER, 19576, A.TRAINER, 28697, A.TRAINER, 33586, A.TRAINER, 26991, A.TRAINER, 33611, A.TRAINER, 33634, A.TRAINER, 25277, A.TRAINER, 26907, A.TRAINER, 26955)

	-- Felsteel Stabilizer -- 30309
	AddRecipe(30309, 340, 23787, R_COMMON, GAME_TBC, 340, 350, 360, 370)
	self:addTradeFlags(RecipeDB, 30309, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP)
	self:addTradeAcquire(RecipeDB, 30309, A.TRAINER, 17634, A.TRAINER, 17637, A.TRAINER, 18752, A.TRAINER, 18775, A.TRAINER, 19576, A.TRAINER, 28697, A.TRAINER, 33586, A.TRAINER, 26991, A.TRAINER, 33611, A.TRAINER, 33634, A.TRAINER, 25277, A.TRAINER, 26907, A.TRAINER, 26955)

	-- Fel Iron Bomb -- 30310
	AddRecipe(30310, 300, 23736, R_COMMON, GAME_TBC, 300, 320, 330, 340)
	self:addTradeFlags(RecipeDB, 30310, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP)
	self:addTradeAcquire(RecipeDB, 30310, A.TRAINER, 17634, A.TRAINER, 17637, A.TRAINER, 18752, A.TRAINER, 18775, A.TRAINER, 19576, A.TRAINER, 28697, A.TRAINER, 33586, A.TRAINER, 26991, A.TRAINER, 33611, A.TRAINER, 33634, A.TRAINER, 25277, A.TRAINER, 26907, A.TRAINER, 26955)

	-- Adamantite Grenade -- 30311
	AddRecipe(30311, 325, 23737, R_COMMON, GAME_TBC, 325, 335, 345, 355)
	self:addTradeFlags(RecipeDB, 30311, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP)
	self:addTradeAcquire(RecipeDB, 30311, A.TRAINER, 17634, A.TRAINER, 17637, A.TRAINER, 18752, A.TRAINER, 18775, A.TRAINER, 19576, A.TRAINER, 28697, A.TRAINER, 33586, A.TRAINER, 26991, A.TRAINER, 33611, A.TRAINER, 33634, A.TRAINER, 25277, A.TRAINER, 26907, A.TRAINER, 26955)

	-- Fel Iron Musket -- 30312
	AddRecipe(30312, 320, 23742, R_COMMON, GAME_TBC, 320, 330, 340, 350)
	self:addTradeFlags(RecipeDB, 30312, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.GUN)
	self:addTradeAcquire(RecipeDB, 30312, A.TRAINER, 17634, A.TRAINER, 17637, A.TRAINER, 18752, A.TRAINER, 18775, A.TRAINER, 19576, A.TRAINER, 28697, A.TRAINER, 33586, A.TRAINER, 26991, A.TRAINER, 33611, A.TRAINER, 33634, A.TRAINER, 25277, A.TRAINER, 26907, A.TRAINER, 26955)

	-- Adamantite Rifle -- 30313
	AddRecipe(30313, 350, 23746, R_COMMON, GAME_TBC, 350, 360, 370, 380)
	self:addTradeFlags(RecipeDB, 30313, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOE, F.DPS, F.GUN)
	self:addTradeAcquire(RecipeDB, 30313, A.VENDOR, 16657, A.VENDOR, 16782, A.VENDOR, 19661)

	-- Felsteel Boomstick -- 30314
	AddRecipe(30314, 360, 23747, R_RARE, GAME_TBC, 360, 370, 380, 390)
	self:addTradeFlags(RecipeDB, 30314, F.ALLIANCE, F.HORDE, F.MOB_DROP, F.IBOE, F.RBOP, F.GUN)
	self:addTradeAcquire(RecipeDB, 30314, A.MOB, 19960)

	-- Ornate Khorium Rifle -- 30315
	AddRecipe(30315, 375, 23748, R_RARE, GAME_TBC, 375, 385, 395, 405)
	self:addTradeFlags(RecipeDB, 30315, F.ALLIANCE, F.HORDE, F.WORLD_DROP, F.IBOE, F.RBOE, F.DPS, F.GUN)
	self:addTradeAcquire(RecipeDB, 30315, A.WORLD_DROP, 3)

	-- Cogspinner Goggles -- 30316
	AddRecipe(30316, 340, 23758, R_COMMON, GAME_TBC, 340, 350, 360, 370)
	self:addTradeFlags(RecipeDB, 30316, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOE, F.LEATHER)
	self:addTradeAcquire(RecipeDB, 30316, A.VENDOR, 18775, A.VENDOR, 19836)

	-- Power Amplification Goggles -- 30317
	AddRecipe(30317, 340, 23761, R_RARE, GAME_TBC, 340, 350, 360, 370)
	self:addTradeFlags(RecipeDB, 30317, F.ALLIANCE, F.HORDE, F.WORLD_DROP, F.IBOE, F.RBOE, F.HEALER, F.CASTER, F.CLOTH)
	self:addTradeAcquire(RecipeDB, 30317, A.WORLD_DROP, 3)

	-- Ultra-Spectropic Detection Goggles -- 30318
	AddRecipe(30318, 350, 23762, R_COMMON, GAME_TBC, 350, 360, 370, 380)
	self:addTradeFlags(RecipeDB, 30318, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOE, F.CLOTH)
	self:addTradeAcquire(RecipeDB, 30318, A.VENDOR, 18775, A.VENDOR, 19383)

	-- Hyper-Vision Goggles -- 30325
	AddRecipe(30325, 360, 23763, R_RARE, GAME_TBC, 360, 370, 380, 390)
	self:addTradeFlags(RecipeDB, 30325, F.ALLIANCE, F.HORDE, F.MOB_DROP, F.IBOE, F.RBOP, F.DPS, F.LEATHER)
	self:addTradeAcquire(RecipeDB, 30325, A.MOB, 19755)

	-- Adamantite Scope -- 30329
	AddRecipe(30329, 335, 23764, R_COMMON, GAME_TBC, 335, 345, 355, 365)
	self:addTradeFlags(RecipeDB, 30329, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOE)
	self:addTradeAcquire(RecipeDB, 30329, A.VENDOR, 19351, A.VENDOR, 19836)

	-- Khorium Scope -- 30332
	AddRecipe(30332, 360, 23765, R_RARE, GAME_TBC, 360, 370, 380, 390)
	self:addTradeFlags(RecipeDB, 30332, F.ALLIANCE, F.HORDE, F.MOB_DROP, F.IBOE, F.RBOP)
	self:addTradeAcquire(RecipeDB, 30332, A.MOB, 20207)

	-- Stabilized Eternium Scope -- 30334
	AddRecipe(30334, 375, 23766, R_RARE, GAME_TBC, 375, 385, 395, 405)
	self:addTradeFlags(RecipeDB, 30334, F.ALLIANCE, F.HORDE, F.RAID, F.MOB_DROP, F.IBOE, F.RBOP)
	self:addTradeAcquire(RecipeDB, 30334, A.MOB, 16152)

	-- Crashin' Thrashin' Robot -- 30337
	AddRecipe(30337, 325, 23767, R_UNCOMMON, GAME_TBC, 325, 335, 345, 355)
	self:addTradeFlags(RecipeDB, 30337, F.ALLIANCE, F.HORDE, F.WORLD_DROP, F.IBOE, F.RBOE)
	self:addTradeAcquire(RecipeDB, 30337, A.WORLD_DROP, 2)

	-- White Smoke Flare -- 30341
	AddRecipe(30341, 335, 23768, R_COMMON, GAME_TBC, 335, 335, 345, 355)
	self:addTradeFlags(RecipeDB, 30341, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOE)
	self:addTradeAcquire(RecipeDB, 30341, A.VENDOR, 16657, A.VENDOR, 16782, A.VENDOR, 18484, A.VENDOR, 19383)

	-- Green Smoke Flare -- 30344
	AddRecipe(30344, 335, 23771, R_COMMON, GAME_TBC, 335, 335, 345, 355)
	self:addTradeFlags(RecipeDB, 30344, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOP, F.CENARION_EXPEDITION)
	self:addTradeAcquire(RecipeDB, 30344, A.REPUTATION, FAC.CENARION_EXPEDITION, REP.FRIENDLY, 17904)

	-- Fel Iron Shells -- 30346
	AddRecipe(30346, 310, 23772, R_COMMON, GAME_TBC, 310, 310, 320, 330)
	self:addTradeFlags(RecipeDB, 30346, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.AMMO)
	self:addTradeAcquire(RecipeDB, 30346, A.TRAINER, 17634, A.TRAINER, 17637, A.TRAINER, 18752, A.TRAINER, 18775, A.TRAINER, 19576, A.TRAINER, 28697, A.TRAINER, 33586, A.TRAINER, 26991, A.TRAINER, 33611, A.TRAINER, 33634, A.TRAINER, 25277, A.TRAINER, 26907, A.TRAINER, 26955)

	-- Adamantite Shell Machine -- 30347
	AddRecipe(30347, 335, 34504, R_COMMON, GAME_TBC, 335, 335, 345, 355)
	self:addTradeFlags(RecipeDB, 30347, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOE, F.AMMO)
	self:addTradeAcquire(RecipeDB, 30347, A.VENDOR, 16657, A.VENDOR, 16782, A.VENDOR, 18484)

	-- Fel Iron Toolbox -- 30348
	AddRecipe(30348, 325, 23774, R_COMMON, GAME_TBC, 325, 325, 335, 345)
	self:addTradeFlags(RecipeDB, 30348, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOE)
	self:addTradeAcquire(RecipeDB, 30348, A.VENDOR, 16657, A.VENDOR, 16782, A.VENDOR, 18484)

	-- Titanium Toolbox -- 30349
	AddRecipe(30349, 405, 23775, R_RARE, GAME_WOTLK, 405, 425, 432, 440)
	self:addTradeFlags(RecipeDB, 30349, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOP)
	self:addTradeAcquire(RecipeDB, 30349, A.VENDOR, 28722)

	-- Elemental Seaforium Charge -- 30547
	AddRecipe(30547, 350, 23819, R_COMMON, GAME_TBC, 350, 350, 355, 360)
	self:addTradeFlags(RecipeDB, 30547, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOP, F.CONSORTIUM)
	self:addTradeAcquire(RecipeDB, 30547, A.REPUTATION, FAC.CONSORTIUM, REP.REVERED, 20242, A.REPUTATION, FAC.CONSORTIUM, REP.REVERED, 23007)

	-- Zapthrottle Mote Extractor -- 30548
	AddRecipe(30548, 305, 23821, R_COMMON, GAME_TBC, 305, 305, 315, 325)
	self:addTradeFlags(RecipeDB, 30548, F.ALLIANCE, F.HORDE, F.QUEST, F.IBOE, F.RBOP)
	self:addTradeAcquire(RecipeDB, 30548, A.QUEST, 9635, A.QUEST, 9636)

	-- Healing Potion Injector -- 30551
	AddRecipe(30551, 330, 33092, R_RARE, GAME_TBC, 330, 330, 340, 350)
	self:addTradeFlags(RecipeDB, 30551, F.ALLIANCE, F.HORDE, F.MOB_DROP, F.IBOE, F.RBOP)
	self:addTradeAcquire(RecipeDB, 30551, A.MOB, 24664)

	-- Mana Potion Injector -- 30552
	AddRecipe(30552, 345, 33093, R_RARE, GAME_TBC, 345, 345, 355, 365)
	self:addTradeFlags(RecipeDB, 30552, F.ALLIANCE, F.HORDE, F.MOB_DROP, F.IBOE, F.RBOP)
	self:addTradeAcquire(RecipeDB, 30552, A.MOB, 24664)

	-- Rocket Boots Xtreme -- 30556
	AddRecipe(30556, 355, 23824, R_RARE, GAME_TBC, 355, 365, 375, 385)
	self:addTradeFlags(RecipeDB, 30556, F.ALLIANCE, F.HORDE, F.INSTANCE, F.IBOE, F.RBOP, F.DPS, F.LEATHER)
	self:addTradeAcquire(RecipeDB, 30556, A.MOB, 17796)

	-- The Bigger One -- 30558
	AddRecipe(30558, 325, 23826, R_COMMON, GAME_TBC, 325, 325, 335, 345, 20222)
	self:addTradeFlags(RecipeDB, 30558, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP)
	self:addTradeAcquire(RecipeDB, 30558, A.TRAINER, 8126, A.TRAINER, 8738, A.TRAINER, 29513)

	-- Super Sapper Charge -- 30560
	AddRecipe(30560, 340, 23827, R_COMMON, GAME_TBC, 340, 340, 350, 360, 20222)
	self:addTradeFlags(RecipeDB, 30560, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP)
	self:addTradeAcquire(RecipeDB, 30560, A.TRAINER, 8126, A.TRAINER, 8738, A.TRAINER, 29513)

	-- Goblin Rocket Launcher -- 30563
	AddRecipe(30563, 350, 23836, R_COMMON, GAME_TBC, 350, 360, 370, 380, 20222)
	self:addTradeFlags(RecipeDB, 30563, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.TRINKET)
	self:addTradeAcquire(RecipeDB, 30563, A.TRAINER, 8126, A.TRAINER, 8738, A.TRAINER, 29513)

	-- Foreman's Enchanted Helmet -- 30565
	AddRecipe(30565, 375, 23838, R_COMMON, GAME_TBC, 375, 375, 385, 395, 20222)
	self:addTradeFlags(RecipeDB, 30565, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOP, F.RBOP, F.HEALER, F.CASTER, F.CLOTH)
	self:addTradeAcquire(RecipeDB, 30565, A.TRAINER, 8126, A.TRAINER, 8738, A.TRAINER, 29513)

	-- Foreman's Reinforced Helmet -- 30566
	AddRecipe(30566, 375, 23839, R_COMMON, GAME_TBC, 375, 375, 385, 395, 20222)
	self:addTradeFlags(RecipeDB, 30566, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOP, F.RBOP, F.DPS, F.MAIL)
	self:addTradeAcquire(RecipeDB, 30566, A.TRAINER, 8126, A.TRAINER, 8738, A.TRAINER, 29513)

	-- Gnomish Flame Turret -- 30568
	AddRecipe(30568, 325, 23841, R_COMMON, GAME_TBC, 325, 335, 345, 355, 20219)
	self:addTradeFlags(RecipeDB, 30568, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP)
	self:addTradeAcquire(RecipeDB, 30568, A.TRAINER, 7406, A.TRAINER, 7944, A.TRAINER, 29514)

	-- Gnomish Poultryizer -- 30569
	AddRecipe(30569, 340, 23835, R_COMMON, GAME_TBC, 340, 360, 370, 380, 20219)
	self:addTradeFlags(RecipeDB, 30569, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.TRINKET)
	self:addTradeAcquire(RecipeDB, 30569, A.TRAINER, 7406, A.TRAINER, 7944, A.TRAINER, 29514)

	-- Nigh-Invulnerability Belt -- 30570
	AddRecipe(30570, 350, 23825, R_COMMON, GAME_TBC, 350, 360, 370, 380, 20219)
	self:addTradeFlags(RecipeDB, 30570, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.CLOTH)
	self:addTradeAcquire(RecipeDB, 30570, A.TRAINER, 7406, A.TRAINER, 7944, A.TRAINER, 29514)

	-- Gnomish Power Goggles -- 30574
	AddRecipe(30574, 375, 23828, R_COMMON, GAME_TBC, 375, 375, 385, 395, 20219)
	self:addTradeFlags(RecipeDB, 30574, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOP, F.RBOP, F.HEALER, F.CASTER, F.CLOTH)
	self:addTradeAcquire(RecipeDB, 30574, A.TRAINER, 7406, A.TRAINER, 7944, A.TRAINER, 29514)

	-- Gnomish Battle Goggles -- 30575
	AddRecipe(30575, 375, 23829, R_COMMON, GAME_TBC, 375, 375, 385, 395, 20219)
	self:addTradeFlags(RecipeDB, 30575, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOP, F.RBOP, F.DPS, F.LEATHER)
	self:addTradeAcquire(RecipeDB, 30575, A.TRAINER, 7406, A.TRAINER, 7944, A.TRAINER, 29514)

	-- Purple Smoke Flare -- 32814
	AddRecipe(32814, 335, 25886, R_UNCOMMON, GAME_TBC, 335, 335, 345, 355)
	self:addTradeFlags(RecipeDB, 32814, F.ALLIANCE, F.HORDE, F.WORLD_DROP, F.IBOE, F.RBOE)
	self:addTradeAcquire(RecipeDB, 32814, A.WORLD_DROP, 2)

	-- Dimensional Ripper - Area 52 -- 36954
	AddRecipe(36954, 350, 30542, R_UNCOMMON, GAME_TBC, 350, 350, 360, 370, 20222)
	self:addTradeFlags(RecipeDB, 36954, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP)
	self:addTradeAcquire(RecipeDB, 36954, A.CUSTOM, 20)

	-- Ultrasafe Transporter - Toshley's Station -- 36955
	AddRecipe(36955, 350, 30544, R_UNCOMMON, GAME_TBC, 350, 350, 360, 370, 20219)
	self:addTradeFlags(RecipeDB, 36955, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP)
	self:addTradeAcquire(RecipeDB, 36955, A.CUSTOM, 21)

	-- Fused Wiring -- 39895
	AddRecipe(39895, 275, 7191, R_COMMON, GAME_TBC, 275, 275, 280, 285)
	self:addTradeFlags(RecipeDB, 39895, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOE)
	self:addTradeAcquire(RecipeDB, 39895, A.VENDOR, 11185, A.VENDOR, 19661)

	-- Icy Blasting Primers -- 39971
	AddRecipe(39971, 335, 32423, R_COMMON, GAME_TBC, 335, 335, 340, 345)
	self:addTradeFlags(RecipeDB, 39971, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP)
	self:addTradeAcquire(RecipeDB, 39971, A.TRAINER, 17634, A.TRAINER, 17637, A.TRAINER, 18752, A.TRAINER, 18775, A.TRAINER, 19576, A.TRAINER, 28697, A.TRAINER, 33586, A.TRAINER, 26991, A.TRAINER, 33611, A.TRAINER, 33634, A.TRAINER, 25277, A.TRAINER, 26907, A.TRAINER, 26955)

	-- Frost Grenades -- 39973
	AddRecipe(39973, 335, 32413, R_COMMON, GAME_TBC, 335, 345, 355, 365)
	self:addTradeFlags(RecipeDB, 39973, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP)
	self:addTradeAcquire(RecipeDB, 39973, A.TRAINER, 17634, A.TRAINER, 17637, A.TRAINER, 18752, A.TRAINER, 18775, A.TRAINER, 19576, A.TRAINER, 28697, A.TRAINER, 33586, A.TRAINER, 26991, A.TRAINER, 33611, A.TRAINER, 33634, A.TRAINER, 25277, A.TRAINER, 26907, A.TRAINER, 26955)

	-- Furious Gizmatic Goggles -- 40274
	AddRecipe(40274, 350, 32461, R_COMMON, GAME_TBC, 350, 370, 380, 390)
	self:addTradeFlags(RecipeDB, 40274, F.ALLIANCE, F.HORDE, F.TRAINER, F.PALADIN, F.WARRIOR, F.IBOP, F.RBOP, F.DPS, F.PLATE)
	self:addTradeAcquire(RecipeDB, 40274, A.TRAINER, 17634, A.TRAINER, 17637, A.TRAINER, 18752, A.TRAINER, 18775, A.TRAINER, 19576, A.TRAINER, 33586, A.TRAINER, 28697, A.TRAINER, 25277, A.TRAINER, 26955)

	-- Gyro-balanced Khorium Destroyer -- 41307
	AddRecipe(41307, 375, 32756, R_COMMON, GAME_TBC, 375, 375, 392, 410)
	self:addTradeFlags(RecipeDB, 41307, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.GUN)
	self:addTradeAcquire(RecipeDB, 41307, A.TRAINER, 17634, A.TRAINER, 17637, A.TRAINER, 18752, A.TRAINER, 18775, A.TRAINER, 19576, A.TRAINER, 28697, A.TRAINER, 33586, A.TRAINER, 26991, A.TRAINER, 33611, A.TRAINER, 33634, A.TRAINER, 25277, A.TRAINER, 26907, A.TRAINER, 26955)

	-- Justicebringer 2000 Specs -- 41311
	AddRecipe(41311, 350, 32472, R_COMMON, GAME_TBC, 350, 370, 380, 390)
	self:addTradeFlags(RecipeDB, 41311, F.ALLIANCE, F.HORDE, F.TRAINER, F.PALADIN, F.IBOP, F.RBOP, F.PLATE)
	self:addTradeAcquire(RecipeDB, 41311, A.TRAINER, 17634, A.TRAINER, 17637, A.TRAINER, 18752, A.TRAINER, 18775, A.TRAINER, 19576, A.TRAINER, 25277, A.TRAINER, 26907, A.TRAINER, 26955, A.TRAINER, 26991, A.TRAINER, 33586, A.TRAINER, 28697)

	-- Tankatronic Goggles -- 41312
	AddRecipe(41312, 350, 32473, R_COMMON, GAME_TBC, 350, 370, 380, 390)
	self:addTradeFlags(RecipeDB, 41312, F.ALLIANCE, F.HORDE, F.TRAINER, F.PALADIN, F.WARRIOR, F.IBOP, F.RBOP, F.TANK, F.PLATE)
	self:addTradeAcquire(RecipeDB, 41312, A.TRAINER, 17634, A.TRAINER, 17637, A.TRAINER, 18752, A.TRAINER, 18775, A.TRAINER, 19576, A.TRAINER, 25277, A.TRAINER, 26907, A.TRAINER, 26955, A.TRAINER, 26991, A.TRAINER, 33586, A.TRAINER, 28697)

	-- Surestrike Goggles v2.0 -- 41314
	AddRecipe(41314, 350, 32474, R_COMMON, GAME_TBC, 350, 370, 380, 390)
	self:addTradeFlags(RecipeDB, 41314, F.ALLIANCE, F.HORDE, F.TRAINER, F.HUNTER, F.SHAMAN, F.IBOP, F.RBOP, F.MAIL)
	self:addTradeAcquire(RecipeDB, 41314, A.TRAINER, 17634, A.TRAINER, 17637, A.TRAINER, 18752, A.TRAINER, 18775, A.TRAINER, 19576, A.TRAINER, 25277, A.TRAINER, 26907, A.TRAINER, 26955, A.TRAINER, 26991, A.TRAINER, 33586, A.TRAINER, 28697)

	-- Gadgetstorm Goggles -- 41315
	AddRecipe(41315, 350, 32476, R_EPIC, GAME_TBC, 350, 370, 380, 390)
	self:addTradeFlags(RecipeDB, 41315, F.ALLIANCE, F.HORDE, F.TRAINER, F.SHAMAN, F.IBOP, F.RBOP, F.MAIL)
	self:addTradeAcquire(RecipeDB, 41315, A.TRAINER, 17634, A.TRAINER, 17637, A.TRAINER, 18752, A.TRAINER, 18775, A.TRAINER, 19576, A.TRAINER, 25277, A.TRAINER, 26907, A.TRAINER, 26955, A.TRAINER, 26991, A.TRAINER, 33586, A.TRAINER, 28697)

	-- Living Replicator Specs -- 41316
	AddRecipe(41316, 350, 32475, R_EPIC, GAME_TBC, 350, 370, 380, 390)
	self:addTradeFlags(RecipeDB, 41316, F.ALLIANCE, F.HORDE, F.TRAINER, F.SHAMAN, F.IBOP, F.RBOP, F.MAIL)
	self:addTradeAcquire(RecipeDB, 41316, A.TRAINER, 17634, A.TRAINER, 17637, A.TRAINER, 18752, A.TRAINER, 18775, A.TRAINER, 19576, A.TRAINER, 25277, A.TRAINER, 26907, A.TRAINER, 26955, A.TRAINER, 26991, A.TRAINER, 33586, A.TRAINER, 28697)

	-- Deathblow X11 Goggles -- 41317
	AddRecipe(41317, 350, 32478, R_COMMON, GAME_TBC, 350, 370, 380, 390)
	self:addTradeFlags(RecipeDB, 41317, F.ALLIANCE, F.HORDE, F.TRAINER, F.DRUID, F.ROGUE, F.IBOP, F.RBOP, F.LEATHER)
	self:addTradeAcquire(RecipeDB, 41317, A.TRAINER, 17634, A.TRAINER, 17637, A.TRAINER, 18752, A.TRAINER, 18775, A.TRAINER, 19576, A.TRAINER, 25277, A.TRAINER, 26907, A.TRAINER, 26955, A.TRAINER, 26991, A.TRAINER, 33586, A.TRAINER, 28697)

	-- Wonderheal XT40 Shades -- 41318
	AddRecipe(41318, 350, 32479, R_EPIC, GAME_TBC, 350, 370, 380, 390)
	self:addTradeFlags(RecipeDB, 41318, F.ALLIANCE, F.HORDE, F.TRAINER, F.DRUID, F.IBOP, F.RBOP, F.LEATHER)
	self:addTradeAcquire(RecipeDB, 41318, A.TRAINER, 17634, A.TRAINER, 17637, A.TRAINER, 18752, A.TRAINER, 18775, A.TRAINER, 19576, A.TRAINER, 25277, A.TRAINER, 26907, A.TRAINER, 26955, A.TRAINER, 26991, A.TRAINER, 33586, A.TRAINER, 28697)

	-- Magnified Moon Specs -- 41319
	AddRecipe(41319, 350, 32480, R_EPIC, GAME_TBC, 350, 370, 380, 390)
	self:addTradeFlags(RecipeDB, 41319, F.ALLIANCE, F.HORDE, F.TRAINER, F.DRUID, F.IBOP, F.RBOP, F.LEATHER)
	self:addTradeAcquire(RecipeDB, 41319, A.TRAINER, 17634, A.TRAINER, 17637, A.TRAINER, 18752, A.TRAINER, 18775, A.TRAINER, 19576, A.TRAINER, 25277, A.TRAINER, 26907, A.TRAINER, 26955, A.TRAINER, 26991, A.TRAINER, 33586, A.TRAINER, 28697)

	-- Destruction Holo-gogs -- 41320
	AddRecipe(41320, 350, 32494, R_COMMON, GAME_TBC, 350, 370, 380, 390)
	self:addTradeFlags(RecipeDB, 41320, F.ALLIANCE, F.HORDE, F.TRAINER, F.MAGE, F.PRIEST, F.WARLOCK, F.IBOP, F.RBOP, F.CLOTH)
	self:addTradeAcquire(RecipeDB, 41320, A.TRAINER, 17634, A.TRAINER, 17637, A.TRAINER, 18752, A.TRAINER, 18775, A.TRAINER, 19576, A.TRAINER, 25277, A.TRAINER, 26907, A.TRAINER, 26955, A.TRAINER, 26991, A.TRAINER, 33586, A.TRAINER, 28697)

	-- Powerheal 4000 Lens -- 41321
	AddRecipe(41321, 350, 32495, R_EPIC, GAME_TBC, 350, 370, 380, 390)
	self:addTradeFlags(RecipeDB, 41321, F.ALLIANCE, F.HORDE, F.TRAINER, F.PRIEST, F.IBOP, F.RBOP, F.CLOTH)
	self:addTradeAcquire(RecipeDB, 41321, A.TRAINER, 17634, A.TRAINER, 17637, A.TRAINER, 18752, A.TRAINER, 18775, A.TRAINER, 19576, A.TRAINER, 25277, A.TRAINER, 26907, A.TRAINER, 26955, A.TRAINER, 26991, A.TRAINER, 33586, A.TRAINER, 28697)

	-- Adamantite Arrow Maker -- 43676
	AddRecipe(43676, 335, 20475, R_UNCOMMON, GAME_TBC, 335, 335, 345, 355)
	self:addTradeFlags(RecipeDB, 43676, F.ALLIANCE, F.HORDE, F.MOB_DROP, F.IBOE, F.RBOP)
	self:addTradeAcquire(RecipeDB, 43676, A.MOB, 19707)

	-- Flying Machine -- 44155
	AddRecipe(44155, 300, 34060, R_RARE, GAME_TBC, 300, 330, 340, 350)
	self:addTradeFlags(RecipeDB, 44155, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP)
	self:addTradeAcquire(RecipeDB, 44155, A.TRAINER, 24868, A.TRAINER, 25099, A.TRAINER, 25277, A.TRAINER, 28697, A.TRAINER, 26955, A.TRAINER, 33586)

	-- Turbo-Charged Flying Machine -- 44157
	AddRecipe(44157, 375, 34061, R_EPIC, GAME_TBC, 375, 385, 390, 395)
	self:addTradeFlags(RecipeDB, 44157, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP)
	self:addTradeAcquire(RecipeDB, 44157, A.TRAINER, 24868, A.TRAINER, 25099)

	-- Field Repair Bot 110G -- 44391
	AddRecipe(44391, 360, 34113, R_UNCOMMON, GAME_TBC, 360, 370, 380, 390)
	self:addTradeFlags(RecipeDB, 44391, F.ALLIANCE, F.HORDE, F.MOB_DROP, F.IBOE, F.RBOP)
	self:addTradeAcquire(RecipeDB, 44391, A.MOB, 23385, A.MOB, 23386)

	-- Wonderheal XT68 Shades -- 46106
	AddRecipe(46106, 375, 35183, R_EPIC, GAME_TBC, 375, 390, 410, 430)
	self:addTradeFlags(RecipeDB, 46106, F.ALLIANCE, F.HORDE, F.RAID, F.DRUID, F.IBOP, F.RBOP, F.LEATHER)
	self:addTradeAcquire(RecipeDB, 46106, A.CUSTOM, 33)

	-- Justicebringer 3000 Specs -- 46107
	AddRecipe(46107, 375, 35185, R_EPIC, GAME_TBC, 375, 390, 410, 430)
	self:addTradeFlags(RecipeDB, 46107, F.ALLIANCE, F.HORDE, F.RAID, F.PALADIN, F.IBOP, F.RBOP, F.PLATE)
	self:addTradeAcquire(RecipeDB, 46107, A.CUSTOM, 24)

	-- Powerheal 9000 Lens -- 46108
	AddRecipe(46108, 375, 35181, R_EPIC, GAME_TBC, 375, 390, 410, 430)
	self:addTradeFlags(RecipeDB, 46108, F.ALLIANCE, F.HORDE, F.RAID, F.PRIEST, F.IBOP, F.RBOP, F.CLOTH)
	self:addTradeAcquire(RecipeDB, 46108, A.CUSTOM, 24)

	-- Hyper-Magnified Moon Specs -- 46109
	AddRecipe(46109, 375, 35182, R_EPIC, GAME_TBC, 375, 390, 410, 430)
	self:addTradeFlags(RecipeDB, 46109, F.ALLIANCE, F.HORDE, F.RAID, F.DRUID, F.IBOP, F.RBOP, F.LEATHER)
	self:addTradeAcquire(RecipeDB, 46109, A.CUSTOM, 24)

	-- Primal-Attuned Goggles -- 46110
	AddRecipe(46110, 375, 35184, R_EPIC, GAME_TBC, 375, 390, 410, 430)
	self:addTradeFlags(RecipeDB, 46110, F.ALLIANCE, F.HORDE, F.RAID, F.SHAMAN, F.IBOP, F.RBOP, F.MAIL)
	self:addTradeAcquire(RecipeDB, 46110, A.CUSTOM, 24)

	-- Annihilator Holo-Gogs -- 46111
	AddRecipe(46111, 375, 34847, R_EPIC, GAME_TBC, 375, 390, 410, 430)
	self:addTradeFlags(RecipeDB, 46111, F.ALLIANCE, F.HORDE, F.RAID, F.MAGE, F.PRIEST, F.WARLOCK, F.IBOP, F.RBOP, F.CLOTH)
	self:addTradeAcquire(RecipeDB, 46111, A.CUSTOM, 24)

	-- Lightning Etched Specs -- 46112
	AddRecipe(46112, 375, 34355, R_EPIC, GAME_TBC, 375, 390, 410, 430)
	self:addTradeFlags(RecipeDB, 46112, F.ALLIANCE, F.HORDE, F.RAID, F.SHAMAN, F.IBOP, F.RBOP, F.MAIL)
	self:addTradeAcquire(RecipeDB, 46112, A.CUSTOM, 24)

	-- Surestrike Goggles v3.0 -- 46113
	AddRecipe(46113, 375, 34356, R_EPIC, GAME_TBC, 375, 390, 410, 430)
	self:addTradeFlags(RecipeDB, 46113, F.ALLIANCE, F.HORDE, F.RAID, F.HUNTER, F.SHAMAN, F.IBOP, F.RBOP, F.MAIL)
	self:addTradeAcquire(RecipeDB, 46113, A.CUSTOM, 24)

	-- Mayhem Projection Goggles -- 46114
	AddRecipe(46114, 375, 34354, R_EPIC, GAME_TBC, 375, 390, 410, 430)
	self:addTradeFlags(RecipeDB, 46114, F.ALLIANCE, F.HORDE, F.RAID, F.DK, F.PALADIN, F.WARRIOR, F.IBOP, F.RBOP, F.DPS, F.PLATE)
	self:addTradeAcquire(RecipeDB, 46114, A.CUSTOM, 24)

	-- Hard Khorium Goggles -- 46115
	AddRecipe(46115, 375, 34357, R_EPIC, GAME_TBC, 375, 390, 410, 430)
	self:addTradeFlags(RecipeDB, 46115, F.ALLIANCE, F.HORDE, F.RAID, F.PALADIN, F.WARRIOR, F.IBOP, F.RBOP, F.TANK, F.PLATE)
	self:addTradeAcquire(RecipeDB, 46115, A.CUSTOM, 24)

	-- Quad Deathblow X44 Goggles -- 46116
	AddRecipe(46116, 375, 34353, R_EPIC, GAME_TBC, 375, 390, 410, 430)
	self:addTradeFlags(RecipeDB, 46116, F.ALLIANCE, F.HORDE, F.RAID, F.DRUID, F.ROGUE, F.IBOP, F.RBOP, F.LEATHER)
	self:addTradeAcquire(RecipeDB, 46116, A.CUSTOM, 24)

	-- Rocket Boots Xtreme Lite -- 46697
	AddRecipe(46697, 355, 35581, R_RARE, GAME_TBC, 355, 365, 375, 385)
	self:addTradeFlags(RecipeDB, 46697, F.ALLIANCE, F.HORDE, F.INSTANCE, F.IBOE, F.RBOP, F.HEALER, F.CASTER, F.CLOTH)
	self:addTradeAcquire(RecipeDB, 46697, A.MOB, 19219)

	-- Volatile Blasting Trigger -- 53281
	AddRecipe(53281, 350, 39690, R_COMMON, GAME_TBC, 350, 366, 375, 385)
	self:addTradeFlags(RecipeDB, 53281, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP)
	self:addTradeAcquire(RecipeDB, 53281, A.TRAINER, 25277, A.TRAINER, 26907, A.TRAINER, 26955, A.TRAINER, 26991, A.TRAINER, 28697, A.TRAINER, 33586)

	-- Mark "S" Boomstick -- 54353
	AddRecipe(54353, 400, 39688, R_RARE, GAME_WOTLK, 400, 405, 410, 415)
	self:addTradeFlags(RecipeDB, 54353, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOP, F.RBOP, F.DPS, F.GUN)
	self:addTradeAcquire(RecipeDB, 54353, A.TRAINER, 25277, A.TRAINER, 26907, A.TRAINER, 26955, A.TRAINER, 26991, A.TRAINER, 28697, A.TRAINER, 33586)

	-- Personal Electromagnetic Pulse Generator -- 54736
	AddRecipe(54736, 390, nil, R_COMMON, GAME_WOTLK, 390, 390, 392, 395)
	self:addTradeFlags(RecipeDB, 54736, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP)
	self:addTradeAcquire(RecipeDB, 54736, A.TRAINER, 25277, A.TRAINER, 26907, A.TRAINER, 26955, A.TRAINER, 26991, A.TRAINER, 28697, A.TRAINER, 33586)

	-- Frag Belt -- 54793
	AddRecipe(54793, 380, nil, R_COMMON, GAME_WOTLK, 380, 380, 382, 385)
	self:addTradeFlags(RecipeDB, 54793, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP)
	self:addTradeAcquire(RecipeDB, 54793, A.TRAINER, 25277, A.TRAINER, 26907, A.TRAINER, 26955, A.TRAINER, 26991, A.TRAINER, 28697, A.TRAINER, 33586)

	-- Hand-Mounted Pyro Rocket -- 54998
	AddRecipe(54998, 400, nil, R_COMMON, GAME_WOTLK, 400, 400, 402, 405)
	self:addTradeFlags(RecipeDB, 54998, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP)
	self:addTradeAcquire(RecipeDB, 54998, A.TRAINER, 25277, A.TRAINER, 26907, A.TRAINER, 26955, A.TRAINER, 26991, A.TRAINER, 28697, A.TRAINER, 33586)

	-- Hyperspeed Accelerators -- 54999
	AddRecipe(54999, 400, nil, R_COMMON, GAME_WOTLK, 400, 400, 402, 405)
	self:addTradeFlags(RecipeDB, 54999, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP)
	self:addTradeAcquire(RecipeDB, 54999, A.TRAINER, 25277, A.TRAINER, 26907, A.TRAINER, 26955, A.TRAINER, 26991, A.TRAINER, 28697, A.TRAINER, 33586)

	-- Flexweave Underlay -- 55002
	AddRecipe(55002, 380, nil, R_COMMON, GAME_WOTLK, 380, 380, 382, 385)
	self:addTradeFlags(RecipeDB, 55002, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.DPS)
	self:addTradeAcquire(RecipeDB, 55002, A.TRAINER, 25277, A.TRAINER, 26907, A.TRAINER, 26955, A.TRAINER, 26991, A.TRAINER, 28697, A.TRAINER, 33586)

	-- Nitro Boosts -- 55016
	AddRecipe(55016, 405, nil, R_COMMON, GAME_WOTLK, 405, 405, 405, 410)
	self:addTradeFlags(RecipeDB, 55016, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP)
	self:addTradeAcquire(RecipeDB, 55016, A.TRAINER, 25277, A.TRAINER, 26907, A.TRAINER, 26955, A.TRAINER, 26991, A.TRAINER, 28697, A.TRAINER, 33586)

	-- Scrapbot Construction Kit -- 55252
	AddRecipe(55252, 415, 40769, R_COMMON, GAME_WOTLK, 415, 415, 417, 420)
	self:addTradeFlags(RecipeDB, 55252, F.ALLIANCE, F.HORDE, F.QUEST, F.IBOE, F.RBOP)
	self:addTradeAcquire(RecipeDB, 55252, A.QUEST, 12889)

	-- Handful of Cobalt Bolts -- 56349
	AddRecipe(56349, 350, 39681, R_COMMON, GAME_TBC, 350, 360, 370, 380)
	self:addTradeFlags(RecipeDB, 56349, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP)
	self:addTradeAcquire(RecipeDB, 56349, A.TRAINER, 25277, A.TRAINER, 26907, A.TRAINER, 26955, A.TRAINER, 26991, A.TRAINER, 28697, A.TRAINER, 33586)

	-- Hammer Pick -- 56459
	AddRecipe(56459, 375, 40892, R_COMMON, GAME_TBC, 375, 380, 385, 390)
	self:addTradeFlags(RecipeDB, 56459, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP)
	self:addTradeAcquire(RecipeDB, 56459, A.TRAINER, 25277, A.TRAINER, 26907, A.TRAINER, 26955, A.TRAINER, 26991, A.TRAINER, 28697, A.TRAINER, 33586)

	-- Cobalt Frag Bomb -- 56460
	AddRecipe(56460, 350, 40771, R_COMMON, GAME_TBC, 350, 375, 382, 390)
	self:addTradeFlags(RecipeDB, 56460, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP)
	self:addTradeAcquire(RecipeDB, 56460, A.TRAINER, 25277, A.TRAINER, 26907, A.TRAINER, 26955, A.TRAINER, 26991, A.TRAINER, 28697, A.TRAINER, 33586)

	-- Bladed Pickaxe -- 56461
	AddRecipe(56461, 375, 40893, R_COMMON, GAME_WOTLK, 375, 380, 385, 390)
	self:addTradeFlags(RecipeDB, 56461, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP)
	self:addTradeAcquire(RecipeDB, 56461, A.TRAINER, 25277, A.TRAINER, 26907, A.TRAINER, 26955, A.TRAINER, 26991, A.TRAINER, 28697, A.TRAINER, 33586)

	-- Gnomish Army Knife -- 56462
	AddRecipe(56462, 435, 40772, R_COMMON, GAME_WOTLK, 435, 440, 445, 450)
	self:addTradeFlags(RecipeDB, 56462, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP)
	self:addTradeAcquire(RecipeDB, 56462, A.TRAINER, 25277, A.TRAINER, 26907, A.TRAINER, 26955, A.TRAINER, 26991, A.TRAINER, 28697, A.TRAINER, 33586)

	-- Explosive Decoy -- 56463
	AddRecipe(56463, 375, 40536, R_COMMON, GAME_WOTLK, 375, 385, 390, 395)
	self:addTradeFlags(RecipeDB, 56463, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP)
	self:addTradeAcquire(RecipeDB, 56463, A.TRAINER, 25277, A.TRAINER, 26907, A.TRAINER, 26955, A.TRAINER, 26991, A.TRAINER, 28697, A.TRAINER, 33586)

	-- Overcharged Capacitor -- 56464
	AddRecipe(56464, 375, 39682, R_COMMON, GAME_WOTLK, 375, 380, 385, 390)
	self:addTradeFlags(RecipeDB, 56464, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP)
	self:addTradeAcquire(RecipeDB, 56464, A.TRAINER, 25277, A.TRAINER, 26907, A.TRAINER, 26955, A.TRAINER, 26991, A.TRAINER, 28697, A.TRAINER, 33586)

	-- Mechanized Snow Goggles -- 56465
	AddRecipe(56465, 420, 41112, R_RARE, GAME_WOTLK, 420, 425, 432, 440)
	self:addTradeFlags(RecipeDB, 56465, F.ALLIANCE, F.HORDE, F.TRAINER, F.MAGE, F.PRIEST, F.WARLOCK, F.IBOE, F.RBOP, F.CLOTH)
	self:addTradeAcquire(RecipeDB, 56465, A.TRAINER, 25277, A.TRAINER, 26907, A.TRAINER, 26955, A.TRAINER, 26991, A.TRAINER, 28697, A.TRAINER, 33586)

	-- Sonic Booster -- 56466
	AddRecipe(56466, 420, 40767, R_RARE, GAME_WOTLK, 420, 435, 440, 445)
	self:addTradeFlags(RecipeDB, 56466, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.DPS, F.TRINKET)
	self:addTradeAcquire(RecipeDB, 56466, A.TRAINER, 25277, A.TRAINER, 26907, A.TRAINER, 26955, A.TRAINER, 26991, A.TRAINER, 28697, A.TRAINER, 33586)

	-- Noise Machine -- 56467
	AddRecipe(56467, 420, 40865, R_RARE, GAME_WOTLK, 420, 435, 440, 445)
	self:addTradeFlags(RecipeDB, 56467, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.HEALER, F.CASTER, F.TRINKET)
	self:addTradeAcquire(RecipeDB, 56467, A.TRAINER, 25277, A.TRAINER, 26907, A.TRAINER, 26955, A.TRAINER, 26991, A.TRAINER, 28697, A.TRAINER, 33586)

	-- Box of Bombs -- 56468
	AddRecipe(56468, 405, 41119, R_COMMON, GAME_WOTLK, 405, 410, 415, 420)
	self:addTradeFlags(RecipeDB, 56468, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP)
	self:addTradeAcquire(RecipeDB, 56468, A.TRAINER, 25277, A.TRAINER, 26907, A.TRAINER, 26955, A.TRAINER, 26991, A.TRAINER, 28697, A.TRAINER, 33586)

	-- Gnomish Lightning Generator -- 56469
	AddRecipe(56469, 425, 41121, R_RARE, GAME_WOTLK, 425, 430, 435, 440)
	self:addTradeFlags(RecipeDB, 56469, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOP, F.RBOP, F.TRINKET)
	self:addTradeAcquire(RecipeDB, 56469, A.TRAINER, 25277, A.TRAINER, 26907, A.TRAINER, 26955, A.TRAINER, 26991, A.TRAINER, 28697, A.TRAINER, 33586)

	-- Sun Scope -- 56470
	AddRecipe(56470, 425, 41146, R_RARE, GAME_WOTLK, 425, 430, 432, 435)
	self:addTradeFlags(RecipeDB, 56470, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.DPS)
	self:addTradeAcquire(RecipeDB, 56470, A.TRAINER, 25277, A.TRAINER, 26907, A.TRAINER, 26955, A.TRAINER, 26991, A.TRAINER, 28697, A.TRAINER, 33586)

	-- Froststeel Tube -- 56471
	AddRecipe(56471, 390, 39683, R_COMMON, GAME_WOTLK, 390, 395, 400, 405)
	self:addTradeFlags(RecipeDB, 56471, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP)
	self:addTradeAcquire(RecipeDB, 56471, A.TRAINER, 25277, A.TRAINER, 26907, A.TRAINER, 26955, A.TRAINER, 26991, A.TRAINER, 28697, A.TRAINER, 33586)

	-- MOLL-E -- 56472
	AddRecipe(56472, 425, 40768, R_COMMON, GAME_WOTLK, 425, 430, 432, 435)
	self:addTradeFlags(RecipeDB, 56472, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP)
	self:addTradeAcquire(RecipeDB, 56472, A.TRAINER, 25277, A.TRAINER, 26907, A.TRAINER, 26955, A.TRAINER, 26991, A.TRAINER, 28697, A.TRAINER, 33586)

	-- Gnomish X-Ray Specs -- 56473
	AddRecipe(56473, 425, 40895, R_RARE, GAME_WOTLK, 425, 430, 435, 440, 20219)
	self:addTradeFlags(RecipeDB, 56473, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP)
	self:addTradeAcquire(RecipeDB, 56473, A.TRAINER, 26907, A.TRAINER, 26955, A.TRAINER, 29514)

	-- Mammoth Cutters -- 56474
	AddRecipe(56474, 410, 44507, R_COMMON, GAME_WOTLK, 410, 410, 415, 420)
	self:addTradeFlags(RecipeDB, 56474, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.AMMO)
	self:addTradeAcquire(RecipeDB, 56474, A.TRAINER, 25277, A.TRAINER, 26907, A.TRAINER, 26955, A.TRAINER, 26991, A.TRAINER, 28697, A.TRAINER, 33586)

	-- Saronite Razorheads -- 56475
	AddRecipe(56475, 415, 44506, R_COMMON, GAME_WOTLK, 415, 415, 417, 425)
	self:addTradeFlags(RecipeDB, 56475, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP)
	self:addTradeAcquire(RecipeDB, 56475, A.TRAINER, 25277, A.TRAINER, 26907, A.TRAINER, 26955, A.TRAINER, 26991, A.TRAINER, 28697, A.TRAINER, 33586)

	-- Healing Injector Kit -- 56476
	AddRecipe(56476, 410, 37567, R_COMMON, GAME_WOTLK, 410, 415, 420, 425)
	self:addTradeFlags(RecipeDB, 56476, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP)
	self:addTradeAcquire(RecipeDB, 56476, A.TRAINER, 25277, A.TRAINER, 26907, A.TRAINER, 26955, A.TRAINER, 26991, A.TRAINER, 28697, A.TRAINER, 33586)

	-- Mana Injector Kit -- 56477
	AddRecipe(56477, 415, 42546, R_COMMON, GAME_WOTLK, 415, 420, 425, 430)
	self:addTradeFlags(RecipeDB, 56477, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP)
	self:addTradeAcquire(RecipeDB, 56477, A.TRAINER, 25277, A.TRAINER, 26907, A.TRAINER, 26955, A.TRAINER, 26991, A.TRAINER, 28697, A.TRAINER, 33586)

	-- Heartseeker Scope -- 56478
	AddRecipe(56478, 430, 41167, R_RARE, GAME_WOTLK, 430, 435, 445, 455)
	self:addTradeFlags(RecipeDB, 56478, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.DPS)
	self:addTradeAcquire(RecipeDB, 56478, A.TRAINER, 25277, A.TRAINER, 26907, A.TRAINER, 26955, A.TRAINER, 26991, A.TRAINER, 28697, A.TRAINER, 33586)

	-- Armor Plated Combat Shotgun -- 56479
	AddRecipe(56479, 450, 41168, R_EPIC, GAME_WOTLK, 450, 455, 460, 465)
	self:addTradeFlags(RecipeDB, 56479, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.TANK, F.GUN)
	self:addTradeAcquire(RecipeDB, 56479, A.TRAINER, 25277, A.TRAINER, 26907, A.TRAINER, 26955, A.TRAINER, 26991, A.TRAINER, 28697, A.TRAINER, 33586)

	-- Armored Titanium Goggles -- 56480
	AddRecipe(56480, 440, 42549, R_RARE, GAME_WOTLK, 440, 450, 455, 460)
	self:addTradeFlags(RecipeDB, 56480, F.ALLIANCE, F.HORDE, F.TRAINER, F.DK, F.PALADIN, F.WARRIOR, F.IBOP, F.RBOP, F.DPS, F.TANK, F.PLATE)
	self:addTradeAcquire(RecipeDB, 56480, A.TRAINER, 25277, A.TRAINER, 26907, A.TRAINER, 26955, A.TRAINER, 26991, A.TRAINER, 33586, A.TRAINER, 28697)

	-- Weakness Spectralizers -- 56481
	AddRecipe(56481, 440, 42550, R_RARE, GAME_WOTLK, 440, 450, 455, 460)
	self:addTradeFlags(RecipeDB, 56481, F.ALLIANCE, F.HORDE, F.TRAINER, F.DRUID, F.IBOP, F.RBOP, F.LEATHER)
	self:addTradeAcquire(RecipeDB, 56481, A.TRAINER, 25277, A.TRAINER, 26907, A.TRAINER, 26955, A.TRAINER, 26991, A.TRAINER, 33586, A.TRAINER, 28697)

	-- Charged Titanium Specs -- 56483
	AddRecipe(56483, 440, 42552, R_RARE, GAME_WOTLK, 440, 450, 455, 460)
	self:addTradeFlags(RecipeDB, 56483, F.ALLIANCE, F.HORDE, F.TRAINER, F.DK, F.PALADIN, F.WARRIOR, F.IBOP, F.RBOP, F.DPS, F.PLATE)
	self:addTradeAcquire(RecipeDB, 56483, A.TRAINER, 25277, A.TRAINER, 26907, A.TRAINER, 26955, A.TRAINER, 26991, A.TRAINER, 33586, A.TRAINER, 28697)

	-- Visage Liquification Goggles -- 56484
	AddRecipe(56484, 440, 42553, R_RARE, GAME_WOTLK, 440, 450, 455, 460)
	self:addTradeFlags(RecipeDB, 56484, F.ALLIANCE, F.HORDE, F.TRAINER, F.MAGE, F.PRIEST, F.WARLOCK, F.IBOP, F.RBOP, F.HEALER, F.CASTER, F.CLOTH)
	self:addTradeAcquire(RecipeDB, 56484, A.TRAINER, 25277, A.TRAINER, 26907, A.TRAINER, 26955, A.TRAINER, 26991, A.TRAINER, 33586, A.TRAINER, 28697)

	-- Greensight Gogs -- 56486
	AddRecipe(56486, 440, 42554, R_RARE, GAME_WOTLK, 440, 450, 455, 460)
	self:addTradeFlags(RecipeDB, 56486, F.ALLIANCE, F.HORDE, F.TRAINER, F.DRUID, F.IBOP, F.RBOP, F.LEATHER)
	self:addTradeAcquire(RecipeDB, 56486, A.TRAINER, 25277, A.TRAINER, 26907, A.TRAINER, 26955, A.TRAINER, 26991, A.TRAINER, 33586, A.TRAINER, 28697)

	-- Electroflux Sight Enhancers -- 56487
	AddRecipe(56487, 440, 42555, R_RARE, GAME_WOTLK, 440, 450, 455, 460)
	self:addTradeFlags(RecipeDB, 56487, F.ALLIANCE, F.HORDE, F.TRAINER, F.SHAMAN, F.IBOP, F.RBOP, F.MAIL)
	self:addTradeAcquire(RecipeDB, 56487, A.TRAINER, 25277, A.TRAINER, 26907, A.TRAINER, 26955, A.TRAINER, 26991, A.TRAINER, 33586, A.TRAINER, 28697)

	-- Global Thermal Sapper Charge -- 56514
	AddRecipe(56514, 425, 42641, R_COMMON, GAME_WOTLK, 425, 425, 430, 435, 20222)
	self:addTradeFlags(RecipeDB, 56514, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP)
	self:addTradeAcquire(RecipeDB, 56514, A.TRAINER, 25277, A.TRAINER, 29513)

	-- Truesight Ice Blinders -- 56574
	AddRecipe(56574, 440, 42551, R_COMMON, GAME_WOTLK, 440, 450, 455, 460)
	self:addTradeFlags(RecipeDB, 56574, F.ALLIANCE, F.HORDE, F.TRAINER, F.HUNTER, F.SHAMAN, F.IBOP, F.RBOP, F.MAIL)
	self:addTradeAcquire(RecipeDB, 56574, A.TRAINER, 25277, A.TRAINER, 26907, A.TRAINER, 26955, A.TRAINER, 26991, A.TRAINER, 33586, A.TRAINER, 28697)

	-- Nesingwary 4000 -- 60874
	AddRecipe(60874, 450, 44504, R_EPIC, GAME_WOTLK, 450, 455, 460, 465)
	self:addTradeFlags(RecipeDB, 60874, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.DPS, F.GUN)
	self:addTradeAcquire(RecipeDB, 60874, A.TRAINER, 25277, A.TRAINER, 26907, A.TRAINER, 26955, A.TRAINER, 26991, A.TRAINER, 28697, A.TRAINER, 33586)

	-- Diamond-cut Refractor Scope -- 61471
	AddRecipe(61471, 390, 44739, R_COMMON, GAME_WOTLK, 390, 400, 407, 415)
	self:addTradeFlags(RecipeDB, 61471, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP)
	self:addTradeAcquire(RecipeDB, 61471, A.TRAINER, 25277, A.TRAINER, 26907, A.TRAINER, 26955, A.TRAINER, 26991, A.TRAINER, 28697, A.TRAINER, 33586)

	-- Mechanized Snow Goggles -- 61481
	AddRecipe(61481, 420, 44742, R_RARE, GAME_WOTLK, 420, 425, 432, 440)
	self:addTradeFlags(RecipeDB, 61481, F.ALLIANCE, F.HORDE, F.TRAINER, F.DRUID, F.ROGUE, F.IBOE, F.RBOP, F.LEATHER)
	self:addTradeAcquire(RecipeDB, 61481, A.TRAINER, 25277, A.TRAINER, 26907, A.TRAINER, 26955, A.TRAINER, 26991, A.TRAINER, 28697, A.TRAINER, 33586)

	-- Mechanized Snow Goggles -- 61482
	AddRecipe(61482, 420, 44742, R_RARE, GAME_WOTLK, 420, 425, 432, 440)
	self:addTradeFlags(RecipeDB, 61482, F.ALLIANCE, F.HORDE, F.TRAINER, F.HUNTER, F.SHAMAN, F.IBOE, F.RBOP, F.MAIL)
	self:addTradeAcquire(RecipeDB, 61482, A.TRAINER, 25277, A.TRAINER, 26907, A.TRAINER, 26955, A.TRAINER, 26991, A.TRAINER, 28697, A.TRAINER, 33586)

	-- Mechanized Snow Goggles -- 61483
	AddRecipe(61483, 420, 44742, R_RARE, GAME_WOTLK, 420, 425, 432, 440)
	self:addTradeFlags(RecipeDB, 61483, F.ALLIANCE, F.HORDE, F.TRAINER, F.DK, F.PALADIN, F.WARRIOR, F.IBOE, F.RBOP, F.PLATE)
	self:addTradeAcquire(RecipeDB, 61483, A.TRAINER, 25277, A.TRAINER, 26907, A.TRAINER, 26955, A.TRAINER, 26991, A.TRAINER, 28697, A.TRAINER, 33586)

	-- Unbreakable Healing Amplifiers -- 62271
	AddRecipe(62271, 440, 44949, R_RARE, GAME_WOTLK, 440, 450, 455, 460)
	self:addTradeFlags(RecipeDB, 62271, F.ALLIANCE, F.HORDE, F.TRAINER, F.PALADIN, F.IBOP, F.RBOP, F.HEALER, F.PLATE)
	self:addTradeAcquire(RecipeDB, 62271, A.TRAINER, 25277, A.TRAINER, 26907, A.TRAINER, 26955)

	-- High-powered Flashlight -- 63750
	AddRecipe(63750, 250, 45631, R_COMMON, GAME_WOTLK, 250, 270, 280, 290)
	self:addTradeFlags(RecipeDB, 63750, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.TRINKET)
	self:addTradeAcquire(RecipeDB, 63750, A.TRAINER, 25277, A.TRAINER, 26907, A.TRAINER, 26955, A.TRAINER, 26991, A.TRAINER, 28697, A.TRAINER, 16667, A.TRAINER, 1702, A.TRAINER, 16726, A.TRAINER, 11017, A.TRAINER, 33586, A.TRAINER, 3494, A.TRAINER, 5174, A.TRAINER, 3290, A.TRAINER, 5518, A.TRAINER, 33611, A.TRAINER, 33634, A.TRAINER, 1676, A.TRAINER, 8736, A.TRAINER, 17637, A.TRAINER, 17634, A.TRAINER, 11031, A.TRAINER, 11025, A.TRAINER, 11037, A.TRAINER, 17222)

	-- Springy Arachnoweave -- 63765
	AddRecipe(63765, 380, nil, R_COMMON, GAME_WOTLK, 380, 380, 382, 385)
	self:addTradeFlags(RecipeDB, 63765, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOP, F.RBOP, F.HEALER, F.CASTER)
	self:addTradeAcquire(RecipeDB, 63765, A.TRAINER, 25277, A.TRAINER, 26907, A.TRAINER, 26955, A.TRAINER, 26991, A.TRAINER, 28697, A.TRAINER, 33586)

	-- Reticulated Armor Webbing -- 63770
	AddRecipe(63770, 400, nil, R_COMMON, GAME_WOTLK, 400, 400, 402, 405)
	self:addTradeFlags(RecipeDB, 63770, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOP, F.RBOP, F.TANK)
	self:addTradeAcquire(RecipeDB, 63770, A.TRAINER, 25277, A.TRAINER, 26907, A.TRAINER, 26955, A.TRAINER, 26991, A.TRAINER, 28697, A.TRAINER, 33586)

	-- Goblin Beam Welder -- 67326
	AddRecipe(67326, 410, 47828, R_COMMON, GAME_WOTLK, 410, 415, 420, 425)
	self:addTradeFlags(RecipeDB, 67326, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOP, F.RBOP)
	self:addTradeAcquire(RecipeDB, 67326, A.TRAINER, 25277, A.TRAINER, 28697, A.TRAINER, 26955, A.TRAINER, 33586)

	-- Mind Amplification Dish -- 67839
	AddRecipe(67839, 410, nil, R_COMMON, GAME_WOTLK, 410, 410, 415, 420)
	self:addTradeFlags(RecipeDB, 67839, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOP, F.RBOP)
	self:addTradeAcquire(RecipeDB, 67839, A.TRAINER, 25277, A.TRAINER, 28697, A.TRAINER, 26955, A.TRAINER, 33586)

	-- Wormhole Generator: Northrend -- 67920
	AddRecipe(67920, 435, 48933, R_COMMON, GAME_WOTLK, 435, 450, 455, 460)
	self:addTradeFlags(RecipeDB, 67920, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOP, F.RBOP)
	self:addTradeAcquire(RecipeDB, 67920, A.TRAINER, 25277, A.TRAINER, 28697, A.TRAINER, 26955, A.TRAINER, 33586)

	-- Jeeves -- 68067
	AddRecipe(68067, 450, 49050, R_COMMON, GAME_WOTLK, 450, 480, 485, 490)
	self:addTradeFlags(RecipeDB, 68067, F.ALLIANCE, F.HORDE, F.WORLD_DROP, F.IBOP, F.RBOP)
	self:addTradeAcquire(RecipeDB, 68067, A.WORLD_DROP, 2)

	-- Shatter Rounds -- 72952
	AddRecipe(72952, 450, 52020, R_EPIC, GAME_WOTLK, 450, 450, 450, 460, 20222)
	self:addTradeFlags(RecipeDB, 72952, F.ALLIANCE, F.HORDE, F.VENDOR, F.AMMO, F.ASHEN_VERDICT)
	self:addTradeAcquire(RecipeDB, 72952, A.REPUTATION, FAC.ASHEN_VERDICT, REP.HONORED, 37687)

	-- Iceblade Arrow -- 72953
	AddRecipe(72953, 450, 52021, R_EPIC, GAME_WOTLK, 450, 450, 450, 460, 20219)
	self:addTradeFlags(RecipeDB, 72953, F.ALLIANCE, F.HORDE, F.VENDOR, F.ASHEN_VERDICT)
	self:addTradeAcquire(RecipeDB, 72953, A.REPUTATION, FAC.ASHEN_VERDICT, REP.HONORED, 37687)

	-- Some recipes are only availible to specific factions.
	-- We only add the faction specific recipes if the user is part of that faction
	local BFAC = LibStub("LibBabble-Faction-3.0"):GetLookupTable()
	local _, faction = UnitFactionGroup("player")

	if faction == BFAC["Alliance"] then

		-- Mekgineer's Chopper -- 60867
		AddRecipe(60867, 450, 44413, R_EPIC, GAME_WOTLK, 450, 480, 485, 490)
		self:addTradeFlags(RecipeDB, 60867, F.ALLIANCE, F.VENDOR, F.IBOE, F.RBOP, F.WRATHCOMMON1)
		self:addTradeAcquire(RecipeDB, 60867, A.REPUTATION, FAC.HORDE_EXPEDITION, REP.EXALTED, 32564, A.REPUTATION, FAC.HORDE_EXPEDITION, REP.EXALTED, 32773)

	elseif faction == BFAC["Horde"] then

		-- Mechano-hog -- 60866
		AddRecipe(60866, 450, 41508, R_EPIC, GAME_WOTLK, 450, 480, 485, 490)
		self:addTradeFlags(RecipeDB, 60866, F.HORDE, F.VENDOR, F.IBOE, F.RBOP, F.WRATHCOMMON1)
		self:addTradeAcquire(RecipeDB, 60866, A.REPUTATION, FAC.HORDE_EXPEDITION, REP.EXALTED, 32565, A.REPUTATION, FAC.HORDE_EXPEDITION, REP.EXALTED, 32774)

	end

	return num_recipes

end
