--[[
************************************************************************
Blacksmithing.lua
Blacksmithing data for all of Ackis Recipe List
************************************************************************
File date: 2010-02-06T07:24:17Z 
File revision: 2852 
Project revision: 2853
Project version: r2853
************************************************************************
Please see http://www.wowace.com/addons/arl/ for more information.
************************************************************************
This source code is released under All Rights Reserved.
************************************************************************
]]--

-------------------------------------------------------------------------------
-- AddOn namespace.
-------------------------------------------------------------------------------
local MODNAME	= "Ackis Recipe List"
local addon	= LibStub("AceAddon-3.0"):GetAddon(MODNAME)
local L		= LibStub("AceLocale-3.0"):GetLocale(MODNAME)

local private	= select(2, ...)

-------------------------------------------------------------------------------
-- Item "rarity"
-------------------------------------------------------------------------------
local R_COMMON, R_UNCOMMON, R_RARE, R_EPIC, R_LEGENDARY, R_ARTIFACT = 1, 2, 3, 4, 5, 6

-------------------------------------------------------------------------------
-- Origin
-------------------------------------------------------------------------------
local GAME_ORIG, GAME_TBC, GAME_WOTLK = 0, 1, 2

-------------------------------------------------------------------------------
-- Filter flags. Acquire types, and Reputation levels.
-------------------------------------------------------------------------------
local F		= private.filter_flags
local A		= private.acquire_types
local REP	= private.rep_levels
local FAC	= private.faction_ids

local FRIENDLY	= 1
local HONORED	= 2
local REVERED	= 3
local EXALTED	= 4

local initialized = false
local num_recipes = 0

function addon:InitBlacksmithing(RecipeDB)
	if initialized then
		return num_recipes
	end
	initialized = true

	--------------------------------------------------------------------------------------------------------------------
	-- Counter and wrapper function
	--------------------------------------------------------------------------------------------------------------------
	local function AddRecipe(SpellID, Skill, ItemID, Rarity, Game, Orange, Yellow, Green, Gray, Speciality)
		num_recipes = num_recipes + 1
		self:addTradeSkill(RecipeDB, SpellID, Skill, ItemID, Rarity, 2018, Speciality, Game, Orange, Yellow, Green, Gray)
	end

	-- Rough Sharpening Stone -- 2660
	AddRecipe(2660, 1, 2862, R_COMMON, GAME_ORIG, 1, 15, 35, 55)
	self:addTradeFlags(RecipeDB, 2660, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.DPS)
	self:addTradeAcquire(RecipeDB, 2660, A.CUSTOM, 8)

	-- Copper Chain Belt -- 2661
	AddRecipe(2661, 35, 2851, R_COMMON, GAME_ORIG, 35, 75, 95, 115)
	self:addTradeFlags(RecipeDB, 2661, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.MAIL)
	self:addTradeAcquire(RecipeDB, 2661, A.TRAINER, 514, A.TRAINER, 1241, A.TRAINER, 2836, A.TRAINER, 2998, A.TRAINER, 3136, A.TRAINER, 3174, A.TRAINER, 3355, A.TRAINER, 3478, A.TRAINER, 3557, A.TRAINER, 4258, A.TRAINER, 4596, A.TRAINER, 5511, A.TRAINER, 6299, A.TRAINER, 15400, A.TRAINER, 16583, A.TRAINER, 16669, A.TRAINER, 16724, A.TRAINER, 16823, A.TRAINER, 17245, A.TRAINER, 19341, A.TRAINER, 28694, A.TRAINER, 27034, A.TRAINER, 33591, A.TRAINER, 26988, A.TRAINER, 33609, A.TRAINER, 33631, A.TRAINER, 33675, A.TRAINER, 26981, A.TRAINER, 26564, A.TRAINER, 26952, A.TRAINER, 26904, A.TRAINER, 29924)

	-- Copper Chain Pants -- 2662
	AddRecipe(2662, 1, 2852, R_COMMON, GAME_ORIG, 1, 50, 70, 90)
	self:addTradeFlags(RecipeDB, 2662, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.MAIL)
	self:addTradeAcquire(RecipeDB, 2662, A.TRAINER, 514, A.TRAINER, 1241, A.TRAINER, 2836, A.TRAINER, 2998, A.TRAINER, 3136, A.TRAINER, 3174, A.TRAINER, 3355, A.TRAINER, 3557, A.TRAINER, 4258, A.TRAINER, 4596, A.TRAINER, 5511, A.TRAINER, 6299, A.TRAINER, 15400, A.TRAINER, 16583, A.TRAINER, 16669, A.TRAINER, 16724, A.TRAINER, 16823, A.TRAINER, 17245, A.TRAINER, 19341, A.TRAINER, 28694, A.TRAINER, 27034, A.TRAINER, 33591, A.TRAINER, 3478, A.TRAINER, 26988, A.TRAINER, 33609, A.TRAINER, 33631, A.TRAINER, 33675, A.TRAINER, 26981, A.TRAINER, 26564, A.TRAINER, 26952, A.TRAINER, 26904, A.TRAINER, 29924)

	-- Copper Bracers -- 2663
	AddRecipe(2663, 1, 2853, R_COMMON, GAME_ORIG, 1, 20, 40, 60)
	self:addTradeFlags(RecipeDB, 2663, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.MAIL)
	self:addTradeAcquire(RecipeDB, 2663, A.CUSTOM, 8)

	-- Runed Copper Bracers -- 2664
	AddRecipe(2664, 90, 2854, R_COMMON, GAME_ORIG, 90, 115, 127, 140)
	self:addTradeFlags(RecipeDB, 2664, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.DPS, F.MAIL)
	self:addTradeAcquire(RecipeDB, 2664, A.TRAINER, 2836, A.TRAINER, 2998, A.TRAINER, 3136, A.TRAINER, 3355, A.TRAINER, 3478, A.TRAINER, 4258, A.TRAINER, 4596, A.TRAINER, 5511, A.TRAINER, 16583, A.TRAINER, 16669, A.TRAINER, 16724, A.TRAINER, 16823, A.TRAINER, 19341, A.TRAINER, 28694, A.TRAINER, 27034, A.TRAINER, 514, A.TRAINER, 1241, A.TRAINER, 33591, A.TRAINER, 3174, A.TRAINER, 26988, A.TRAINER, 33609, A.TRAINER, 33631, A.TRAINER, 15400, A.TRAINER, 33675, A.TRAINER, 26981, A.TRAINER, 17245, A.TRAINER, 6299, A.TRAINER, 26564, A.TRAINER, 26952, A.TRAINER, 3557, A.TRAINER, 26904, A.TRAINER, 29924)

	-- Coarse Sharpening Stone -- 2665
	AddRecipe(2665, 65, 2863, R_COMMON, GAME_ORIG, 65, 65, 72, 80)
	self:addTradeFlags(RecipeDB, 2665, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.DPS)
	self:addTradeAcquire(RecipeDB, 2665, A.TRAINER, 514, A.TRAINER, 1241, A.TRAINER, 2836, A.TRAINER, 2998, A.TRAINER, 3136, A.TRAINER, 3174, A.TRAINER, 3355, A.TRAINER, 3478, A.TRAINER, 3557, A.TRAINER, 4258, A.TRAINER, 4596, A.TRAINER, 5511, A.TRAINER, 6299, A.TRAINER, 15400, A.TRAINER, 16583, A.TRAINER, 16669, A.TRAINER, 16724, A.TRAINER, 16823, A.TRAINER, 17245, A.TRAINER, 19341, A.TRAINER, 28694, A.TRAINER, 27034, A.TRAINER, 33591, A.TRAINER, 26988, A.TRAINER, 33609, A.TRAINER, 33631, A.TRAINER, 33675, A.TRAINER, 26981, A.TRAINER, 26564, A.TRAINER, 26952, A.TRAINER, 26904, A.TRAINER, 29924)

	-- Runed Copper Belt -- 2666
	AddRecipe(2666, 70, 2857, R_COMMON, GAME_ORIG, 70, 110, 130, 150)
	self:addTradeFlags(RecipeDB, 2666, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.DPS, F.MAIL)
	self:addTradeAcquire(RecipeDB, 2666, A.TRAINER, 514, A.TRAINER, 1241, A.TRAINER, 2836, A.TRAINER, 2998, A.TRAINER, 3136, A.TRAINER, 3174, A.TRAINER, 3355, A.TRAINER, 3478, A.TRAINER, 3557, A.TRAINER, 4258, A.TRAINER, 4596, A.TRAINER, 5511, A.TRAINER, 6299, A.TRAINER, 15400, A.TRAINER, 16583, A.TRAINER, 16669, A.TRAINER, 16724, A.TRAINER, 16823, A.TRAINER, 17245, A.TRAINER, 19341, A.TRAINER, 28694, A.TRAINER, 27034, A.TRAINER, 33591, A.TRAINER, 26988, A.TRAINER, 33609, A.TRAINER, 33631, A.TRAINER, 33675, A.TRAINER, 26981, A.TRAINER, 26564, A.TRAINER, 26952, A.TRAINER, 26904, A.TRAINER, 29924)

	-- Runed Copper Breastplate -- 2667
	AddRecipe(2667, 80, 2864, R_UNCOMMON, GAME_ORIG, 80, 120, 140, 160)
	self:addTradeFlags(RecipeDB, 2667, F.ALLIANCE, F.HORDE, F.WORLD_DROP, F.IBOE, F.RBOE, F.DPS, F.MAIL)
	self:addTradeAcquire(RecipeDB, 2667, A.WORLD_DROP, 2)

	-- Rough Bronze Leggings -- 2668
	AddRecipe(2668, 105, 2865, R_COMMON, GAME_ORIG, 105, 145, 160, 175)
	self:addTradeFlags(RecipeDB, 2668, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.DPS, F.MAIL)
	self:addTradeAcquire(RecipeDB, 2668, A.TRAINER, 2836, A.TRAINER, 2998, A.TRAINER, 3136, A.TRAINER, 3355, A.TRAINER, 3478, A.TRAINER, 4258, A.TRAINER, 4596, A.TRAINER, 5511, A.TRAINER, 16583, A.TRAINER, 16669, A.TRAINER, 16724, A.TRAINER, 16823, A.TRAINER, 28694, A.TRAINER, 27034, A.TRAINER, 514, A.TRAINER, 1241, A.TRAINER, 33591, A.TRAINER, 3174, A.TRAINER, 26988, A.TRAINER, 33609, A.TRAINER, 33631, A.TRAINER, 15400, A.TRAINER, 33675, A.TRAINER, 26981, A.TRAINER, 17245, A.TRAINER, 6299, A.TRAINER, 26564, A.TRAINER, 26952, A.TRAINER, 3557, A.TRAINER, 26904, A.TRAINER, 29924)

	-- Rough Bronze Cuirass -- 2670
	AddRecipe(2670, 105, 2866, R_COMMON, GAME_ORIG, 105, 145, 160, 175)
	self:addTradeFlags(RecipeDB, 2670, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.DPS, F.MAIL)
	self:addTradeAcquire(RecipeDB, 2670, A.TRAINER, 2836, A.TRAINER, 2998, A.TRAINER, 3136, A.TRAINER, 3355, A.TRAINER, 3478, A.TRAINER, 4258, A.TRAINER, 4596, A.TRAINER, 5511, A.TRAINER, 16583, A.TRAINER, 16669, A.TRAINER, 16724, A.TRAINER, 16823, A.TRAINER, 19341, A.TRAINER, 28694, A.TRAINER, 27034, A.TRAINER, 514, A.TRAINER, 1241, A.TRAINER, 33591, A.TRAINER, 3174, A.TRAINER, 26988, A.TRAINER, 33609, A.TRAINER, 33631, A.TRAINER, 15400, A.TRAINER, 33675, A.TRAINER, 26981, A.TRAINER, 17245, A.TRAINER, 6299, A.TRAINER, 26564, A.TRAINER, 26952, A.TRAINER, 3557, A.TRAINER, 26904, A.TRAINER, 29924)

	-- Patterned Bronze Bracers -- 2672
	AddRecipe(2672, 120, 2868, R_COMMON, GAME_ORIG, 120, 150, 165, 180)
	self:addTradeFlags(RecipeDB, 2672, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.DPS, F.MAIL)
	self:addTradeAcquire(RecipeDB, 2672, A.TRAINER, 2836, A.TRAINER, 2998, A.TRAINER, 3136, A.TRAINER, 3355, A.TRAINER, 3478, A.TRAINER, 4258, A.TRAINER, 4596, A.TRAINER, 5511, A.TRAINER, 16583, A.TRAINER, 16669, A.TRAINER, 16724, A.TRAINER, 16823, A.TRAINER, 19341, A.TRAINER, 28694, A.TRAINER, 27034, A.TRAINER, 514, A.TRAINER, 1241, A.TRAINER, 33591, A.TRAINER, 3174, A.TRAINER, 26988, A.TRAINER, 33609, A.TRAINER, 33631, A.TRAINER, 15400, A.TRAINER, 33675, A.TRAINER, 26981, A.TRAINER, 17245, A.TRAINER, 6299, A.TRAINER, 26564, A.TRAINER, 26952, A.TRAINER, 3557, A.TRAINER, 26904, A.TRAINER, 29924)

	-- Silvered Bronze Breastplate -- 2673
	AddRecipe(2673, 130, 2869, R_UNCOMMON, GAME_ORIG, 130, 160, 175, 190)
	self:addTradeFlags(RecipeDB, 2673, F.ALLIANCE, F.HORDE, F.WORLD_DROP, F.IBOE, F.RBOE, F.DPS, F.MAIL)
	self:addTradeAcquire(RecipeDB, 2673, A.WORLD_DROP, 2)

	-- Heavy Sharpening Stone -- 2674
	AddRecipe(2674, 125, 2871, R_COMMON, GAME_ORIG, 125, 125, 132, 140)
	self:addTradeFlags(RecipeDB, 2674, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.DPS)
	self:addTradeAcquire(RecipeDB, 2674, A.TRAINER, 2836, A.TRAINER, 2998, A.TRAINER, 3136, A.TRAINER, 3355, A.TRAINER, 3478, A.TRAINER, 4258, A.TRAINER, 4596, A.TRAINER, 5511, A.TRAINER, 16583, A.TRAINER, 16669, A.TRAINER, 16724, A.TRAINER, 16823, A.TRAINER, 19341, A.TRAINER, 28694, A.TRAINER, 27034, A.TRAINER, 514, A.TRAINER, 1241, A.TRAINER, 33591, A.TRAINER, 3174, A.TRAINER, 26988, A.TRAINER, 33609, A.TRAINER, 33631, A.TRAINER, 15400, A.TRAINER, 33675, A.TRAINER, 26981, A.TRAINER, 17245, A.TRAINER, 6299, A.TRAINER, 26564, A.TRAINER, 26952, A.TRAINER, 3557, A.TRAINER, 26904, A.TRAINER, 29924)

	-- Shining Silver Breastplate -- 2675
	AddRecipe(2675, 145, 2870, R_COMMON, GAME_ORIG, 145, 175, 190, 205)
	self:addTradeFlags(RecipeDB, 2675, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.DPS, F.MAIL)
	self:addTradeAcquire(RecipeDB, 2675, A.TRAINER, 2836, A.TRAINER, 2998, A.TRAINER, 3136, A.TRAINER, 3355, A.TRAINER, 3478, A.TRAINER, 4258, A.TRAINER, 4596, A.TRAINER, 5511, A.TRAINER, 16583, A.TRAINER, 16669, A.TRAINER, 16724, A.TRAINER, 16823, A.TRAINER, 19341, A.TRAINER, 28694, A.TRAINER, 27034, A.TRAINER, 514, A.TRAINER, 1241, A.TRAINER, 33591, A.TRAINER, 3174, A.TRAINER, 26988, A.TRAINER, 33609, A.TRAINER, 33631, A.TRAINER, 15400, A.TRAINER, 33675, A.TRAINER, 26981, A.TRAINER, 17245, A.TRAINER, 6299, A.TRAINER, 26564, A.TRAINER, 26952, A.TRAINER, 3557, A.TRAINER, 26904, A.TRAINER, 29924)

	-- Copper Mace -- 2737
	AddRecipe(2737, 15, 2844, R_COMMON, GAME_ORIG, 15, 55, 75, 95)
	self:addTradeFlags(RecipeDB, 2737, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.ONE_HAND, F.MACE)
	self:addTradeAcquire(RecipeDB, 2737, A.TRAINER, 514, A.TRAINER, 1241, A.TRAINER, 2836, A.TRAINER, 2998, A.TRAINER, 3136, A.TRAINER, 3174, A.TRAINER, 3355, A.TRAINER, 3478, A.TRAINER, 3557, A.TRAINER, 4258, A.TRAINER, 4596, A.TRAINER, 5511, A.TRAINER, 6299, A.TRAINER, 15400, A.TRAINER, 16583, A.TRAINER, 16669, A.TRAINER, 16724, A.TRAINER, 16823, A.TRAINER, 17245, A.TRAINER, 19341, A.TRAINER, 28694, A.TRAINER, 27034, A.TRAINER, 33591, A.TRAINER, 26988, A.TRAINER, 33609, A.TRAINER, 33631, A.TRAINER, 33675, A.TRAINER, 26981, A.TRAINER, 26564, A.TRAINER, 26952, A.TRAINER, 26904, A.TRAINER, 29924)

	-- Copper Axe -- 2738
	AddRecipe(2738, 20, 2845, R_COMMON, GAME_ORIG, 20, 60, 80, 100)
	self:addTradeFlags(RecipeDB, 2738, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.ONE_HAND, F.AXE)
	self:addTradeAcquire(RecipeDB, 2738, A.TRAINER, 514, A.TRAINER, 1241, A.TRAINER, 2836, A.TRAINER, 2998, A.TRAINER, 3136, A.TRAINER, 3174, A.TRAINER, 3355, A.TRAINER, 3478, A.TRAINER, 3557, A.TRAINER, 4258, A.TRAINER, 4596, A.TRAINER, 5511, A.TRAINER, 6299, A.TRAINER, 15400, A.TRAINER, 16583, A.TRAINER, 16669, A.TRAINER, 16724, A.TRAINER, 16823, A.TRAINER, 17245, A.TRAINER, 19341, A.TRAINER, 28694, A.TRAINER, 27034, A.TRAINER, 33591, A.TRAINER, 26988, A.TRAINER, 33609, A.TRAINER, 33631, A.TRAINER, 33675, A.TRAINER, 26981, A.TRAINER, 26564, A.TRAINER, 26952, A.TRAINER, 26904, A.TRAINER, 29924)

	-- Copper Shortsword -- 2739
	AddRecipe(2739, 25, 2847, R_COMMON, GAME_ORIG, 25, 65, 85, 105)
	self:addTradeFlags(RecipeDB, 2739, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.ONE_HAND, F.SWORD)
	self:addTradeAcquire(RecipeDB, 2739, A.TRAINER, 514, A.TRAINER, 1241, A.TRAINER, 2836, A.TRAINER, 2998, A.TRAINER, 3136, A.TRAINER, 3174, A.TRAINER, 3355, A.TRAINER, 3478, A.TRAINER, 3557, A.TRAINER, 4258, A.TRAINER, 4596, A.TRAINER, 5511, A.TRAINER, 6299, A.TRAINER, 15400, A.TRAINER, 16583, A.TRAINER, 16669, A.TRAINER, 16724, A.TRAINER, 16823, A.TRAINER, 17245, A.TRAINER, 19341, A.TRAINER, 28694, A.TRAINER, 27034, A.TRAINER, 33591, A.TRAINER, 26988, A.TRAINER, 33609, A.TRAINER, 33631, A.TRAINER, 33675, A.TRAINER, 26981, A.TRAINER, 26564, A.TRAINER, 26952, A.TRAINER, 26904, A.TRAINER, 29924)

	-- Bronze Mace -- 2740
	AddRecipe(2740, 110, 2848, R_COMMON, GAME_ORIG, 110, 140, 155, 170)
	self:addTradeFlags(RecipeDB, 2740, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.ONE_HAND, F.MACE)
	self:addTradeAcquire(RecipeDB, 2740, A.TRAINER, 2836, A.TRAINER, 2998, A.TRAINER, 3136, A.TRAINER, 3355, A.TRAINER, 3478, A.TRAINER, 4258, A.TRAINER, 4596, A.TRAINER, 5511, A.TRAINER, 16583, A.TRAINER, 16669, A.TRAINER, 16724, A.TRAINER, 16823, A.TRAINER, 19341, A.TRAINER, 28694, A.TRAINER, 27034, A.TRAINER, 514, A.TRAINER, 1241, A.TRAINER, 33591, A.TRAINER, 3174, A.TRAINER, 26988, A.TRAINER, 33609, A.TRAINER, 33631, A.TRAINER, 15400, A.TRAINER, 33675, A.TRAINER, 26981, A.TRAINER, 17245, A.TRAINER, 6299, A.TRAINER, 26564, A.TRAINER, 26952, A.TRAINER, 3557, A.TRAINER, 26904, A.TRAINER, 29924)

	-- Bronze Axe -- 2741
	AddRecipe(2741, 115, 2849, R_COMMON, GAME_ORIG, 115, 145, 160, 175)
	self:addTradeFlags(RecipeDB, 2741, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.ONE_HAND, F.AXE)
	self:addTradeAcquire(RecipeDB, 2741, A.TRAINER, 2836, A.TRAINER, 2998, A.TRAINER, 3136, A.TRAINER, 3355, A.TRAINER, 3478, A.TRAINER, 4258, A.TRAINER, 4596, A.TRAINER, 5511, A.TRAINER, 16583, A.TRAINER, 16669, A.TRAINER, 16724, A.TRAINER, 16823, A.TRAINER, 19341, A.TRAINER, 28694, A.TRAINER, 27034, A.TRAINER, 514, A.TRAINER, 1241, A.TRAINER, 33591, A.TRAINER, 3174, A.TRAINER, 26988, A.TRAINER, 33609, A.TRAINER, 33631, A.TRAINER, 15400, A.TRAINER, 33675, A.TRAINER, 26981, A.TRAINER, 17245, A.TRAINER, 6299, A.TRAINER, 26564, A.TRAINER, 26952, A.TRAINER, 3557, A.TRAINER, 26904, A.TRAINER, 29924)

	-- Bronze Shortsword -- 2742
	AddRecipe(2742, 120, 2850, R_COMMON, GAME_ORIG, 120, 150, 165, 180)
	self:addTradeFlags(RecipeDB, 2742, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.DPS, F.ONE_HAND, F.SWORD)
	self:addTradeAcquire(RecipeDB, 2742, A.TRAINER, 2836, A.TRAINER, 2998, A.TRAINER, 3136, A.TRAINER, 3355, A.TRAINER, 3478, A.TRAINER, 4258, A.TRAINER, 4596, A.TRAINER, 5511, A.TRAINER, 16583, A.TRAINER, 16669, A.TRAINER, 16724, A.TRAINER, 16823, A.TRAINER, 19341, A.TRAINER, 28694, A.TRAINER, 27034, A.TRAINER, 514, A.TRAINER, 1241, A.TRAINER, 33591, A.TRAINER, 3174, A.TRAINER, 26988, A.TRAINER, 33609, A.TRAINER, 33631, A.TRAINER, 15400, A.TRAINER, 33675, A.TRAINER, 26981, A.TRAINER, 17245, A.TRAINER, 6299, A.TRAINER, 26564, A.TRAINER, 26952, A.TRAINER, 3557, A.TRAINER, 26904, A.TRAINER, 29924)

	-- Rough Weightstone -- 3115
	AddRecipe(3115, 1, 3239, R_COMMON, GAME_ORIG, 1, 15, 35, 55)
	self:addTradeFlags(RecipeDB, 3115, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP)
	self:addTradeAcquire(RecipeDB, 3115, A.CUSTOM, 8)

	-- Coarse Weightstone -- 3116
	AddRecipe(3116, 65, 3240, R_COMMON, GAME_ORIG, 65, 65, 72, 80)
	self:addTradeFlags(RecipeDB, 3116, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP)
	self:addTradeAcquire(RecipeDB, 3116, A.TRAINER, 514, A.TRAINER, 1241, A.TRAINER, 2836, A.TRAINER, 2998, A.TRAINER, 3136, A.TRAINER, 3174, A.TRAINER, 3355, A.TRAINER, 3478, A.TRAINER, 3557, A.TRAINER, 4258, A.TRAINER, 4596, A.TRAINER, 5511, A.TRAINER, 6299, A.TRAINER, 15400, A.TRAINER, 16583, A.TRAINER, 16669, A.TRAINER, 16724, A.TRAINER, 16823, A.TRAINER, 17245, A.TRAINER, 19341, A.TRAINER, 28694, A.TRAINER, 27034, A.TRAINER, 33591, A.TRAINER, 26988, A.TRAINER, 33609, A.TRAINER, 33631, A.TRAINER, 33675, A.TRAINER, 26981, A.TRAINER, 26564, A.TRAINER, 26952, A.TRAINER, 26904, A.TRAINER, 29924)

	-- Heavy Weightstone -- 3117
	AddRecipe(3117, 125, 3241, R_COMMON, GAME_ORIG, 125, 125, 132, 140)
	self:addTradeFlags(RecipeDB, 3117, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP)
	self:addTradeAcquire(RecipeDB, 3117, A.TRAINER, 2836, A.TRAINER, 2998, A.TRAINER, 3136, A.TRAINER, 3355, A.TRAINER, 3478, A.TRAINER, 4258, A.TRAINER, 4596, A.TRAINER, 5511, A.TRAINER, 16583, A.TRAINER, 16669, A.TRAINER, 16724, A.TRAINER, 16823, A.TRAINER, 19341, A.TRAINER, 28694, A.TRAINER, 27034, A.TRAINER, 514, A.TRAINER, 1241, A.TRAINER, 33591, A.TRAINER, 3174, A.TRAINER, 26988, A.TRAINER, 33609, A.TRAINER, 33631, A.TRAINER, 15400, A.TRAINER, 33675, A.TRAINER, 26981, A.TRAINER, 17245, A.TRAINER, 6299, A.TRAINER, 26564, A.TRAINER, 26952, A.TRAINER, 3557, A.TRAINER, 26904, A.TRAINER, 29924)

	-- Heavy Copper Broadsword -- 3292
	AddRecipe(3292, 95, 3487, R_COMMON, GAME_ORIG, 95, 135, 155, 175)
	self:addTradeFlags(RecipeDB, 3292, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.TWO_HAND, F.SWORD)
	self:addTradeAcquire(RecipeDB, 3292, A.TRAINER, 2836, A.TRAINER, 2998, A.TRAINER, 3136, A.TRAINER, 3355, A.TRAINER, 3478, A.TRAINER, 4258, A.TRAINER, 4596, A.TRAINER, 5511, A.TRAINER, 16583, A.TRAINER, 16669, A.TRAINER, 16724, A.TRAINER, 16823, A.TRAINER, 19341, A.TRAINER, 28694, A.TRAINER, 27034, A.TRAINER, 514, A.TRAINER, 1241, A.TRAINER, 33591, A.TRAINER, 3174, A.TRAINER, 26988, A.TRAINER, 33609, A.TRAINER, 33631, A.TRAINER, 15400, A.TRAINER, 33675, A.TRAINER, 26981, A.TRAINER, 17245, A.TRAINER, 6299, A.TRAINER, 26564, A.TRAINER, 26952, A.TRAINER, 3557, A.TRAINER, 26904, A.TRAINER, 29924)

	-- Copper Battle Axe -- 3293
	AddRecipe(3293, 35, 3488, R_COMMON, GAME_ORIG, 35, 75, 95, 115)
	self:addTradeFlags(RecipeDB, 3293, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.TWO_HAND, F.AXE)
	self:addTradeAcquire(RecipeDB, 3293, A.TRAINER, 514, A.TRAINER, 1241, A.TRAINER, 2836, A.TRAINER, 2998, A.TRAINER, 3136, A.TRAINER, 3174, A.TRAINER, 3355, A.TRAINER, 3478, A.TRAINER, 3557, A.TRAINER, 4258, A.TRAINER, 4596, A.TRAINER, 5511, A.TRAINER, 6299, A.TRAINER, 15400, A.TRAINER, 16583, A.TRAINER, 16669, A.TRAINER, 16724, A.TRAINER, 16823, A.TRAINER, 17245, A.TRAINER, 19341, A.TRAINER, 28694, A.TRAINER, 27034, A.TRAINER, 33591, A.TRAINER, 26988, A.TRAINER, 33609, A.TRAINER, 33631, A.TRAINER, 33675, A.TRAINER, 26981, A.TRAINER, 26564, A.TRAINER, 26952, A.TRAINER, 26904, A.TRAINER, 29924)

	-- Thick War Axe -- 3294
	AddRecipe(3294, 70, 3489, R_COMMON, GAME_ORIG, 70, 110, 130, 150)
	self:addTradeFlags(RecipeDB, 3294, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.DPS, F.ONE_HAND, F.AXE)
	self:addTradeAcquire(RecipeDB, 3294, A.TRAINER, 514, A.TRAINER, 1241, A.TRAINER, 2836, A.TRAINER, 2998, A.TRAINER, 3136, A.TRAINER, 3174, A.TRAINER, 3355, A.TRAINER, 3478, A.TRAINER, 3557, A.TRAINER, 4258, A.TRAINER, 4596, A.TRAINER, 5511, A.TRAINER, 6299, A.TRAINER, 15400, A.TRAINER, 16583, A.TRAINER, 16669, A.TRAINER, 16724, A.TRAINER, 16823, A.TRAINER, 17245, A.TRAINER, 19341, A.TRAINER, 28694, A.TRAINER, 27034, A.TRAINER, 33591, A.TRAINER, 26988, A.TRAINER, 33609, A.TRAINER, 33631, A.TRAINER, 33675, A.TRAINER, 26981, A.TRAINER, 26564, A.TRAINER, 26952, A.TRAINER, 26904, A.TRAINER, 29924)

	-- Deadly Bronze Poniard -- 3295
	AddRecipe(3295, 125, 3490, R_UNCOMMON, GAME_ORIG, 125, 155, 170, 195)
	self:addTradeFlags(RecipeDB, 3295, F.ALLIANCE, F.HORDE, F.WORLD_DROP, F.IBOE, F.RBOE, F.DPS, F.ONE_HAND, F.DAGGER)
	self:addTradeAcquire(RecipeDB, 3295, A.WORLD_DROP, 2)

	-- Heavy Bronze Mace -- 3296
	AddRecipe(3296, 130, 3491, R_COMMON, GAME_ORIG, 130, 160, 175, 190)
	self:addTradeFlags(RecipeDB, 3296, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.DPS, F.ONE_HAND, F.MACE)
	self:addTradeAcquire(RecipeDB, 3296, A.TRAINER, 2836, A.TRAINER, 2998, A.TRAINER, 3136, A.TRAINER, 3355, A.TRAINER, 3478, A.TRAINER, 4258, A.TRAINER, 4596, A.TRAINER, 5511, A.TRAINER, 16583, A.TRAINER, 16669, A.TRAINER, 16724, A.TRAINER, 16823, A.TRAINER, 19341, A.TRAINER, 28694, A.TRAINER, 27034, A.TRAINER, 514, A.TRAINER, 1241, A.TRAINER, 33591, A.TRAINER, 3174, A.TRAINER, 26988, A.TRAINER, 33609, A.TRAINER, 33631, A.TRAINER, 15400, A.TRAINER, 33675, A.TRAINER, 26981, A.TRAINER, 17245, A.TRAINER, 6299, A.TRAINER, 26564, A.TRAINER, 26952, A.TRAINER, 3557, A.TRAINER, 26904, A.TRAINER, 29924)

	-- Mighty Iron Hammer -- 3297
	AddRecipe(3297, 145, 3492, R_UNCOMMON, GAME_ORIG, 145, 175, 190, 205)
	self:addTradeFlags(RecipeDB, 3297, F.ALLIANCE, F.HORDE, F.WORLD_DROP, F.IBOE, F.RBOE, F.DPS, F.ONE_HAND, F.MACE)
	self:addTradeAcquire(RecipeDB, 3297, A.WORLD_DROP, 2)

	-- Copper Chain Boots -- 3319
	AddRecipe(3319, 20, 3469, R_COMMON, GAME_ORIG, 20, 60, 80, 100)
	self:addTradeFlags(RecipeDB, 3319, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.MAIL)
	self:addTradeAcquire(RecipeDB, 3319, A.TRAINER, 514, A.TRAINER, 1241, A.TRAINER, 2836, A.TRAINER, 2998, A.TRAINER, 3136, A.TRAINER, 3174, A.TRAINER, 3355, A.TRAINER, 3557, A.TRAINER, 4258, A.TRAINER, 4596, A.TRAINER, 5511, A.TRAINER, 6299, A.TRAINER, 15400, A.TRAINER, 16583, A.TRAINER, 16669, A.TRAINER, 16724, A.TRAINER, 16823, A.TRAINER, 17245, A.TRAINER, 19341, A.TRAINER, 28694, A.TRAINER, 27034, A.TRAINER, 33591, A.TRAINER, 3478, A.TRAINER, 26988, A.TRAINER, 33609, A.TRAINER, 33631, A.TRAINER, 33675, A.TRAINER, 26981, A.TRAINER, 26564, A.TRAINER, 26952, A.TRAINER, 26904, A.TRAINER, 29924)

	-- Rough Grinding Stone -- 3320
	AddRecipe(3320, 25, 3470, R_COMMON, GAME_ORIG, 25, 45, 65, 85)
	self:addTradeFlags(RecipeDB, 3320, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP)
	self:addTradeAcquire(RecipeDB, 3320, A.TRAINER, 514, A.TRAINER, 1241, A.TRAINER, 2836, A.TRAINER, 2998, A.TRAINER, 3136, A.TRAINER, 3174, A.TRAINER, 3355, A.TRAINER, 3557, A.TRAINER, 4258, A.TRAINER, 4596, A.TRAINER, 5511, A.TRAINER, 6299, A.TRAINER, 15400, A.TRAINER, 16583, A.TRAINER, 16669, A.TRAINER, 16724, A.TRAINER, 16823, A.TRAINER, 17245, A.TRAINER, 28694, A.TRAINER, 27034, A.TRAINER, 33591, A.TRAINER, 3478, A.TRAINER, 26988, A.TRAINER, 33609, A.TRAINER, 33631, A.TRAINER, 33675, A.TRAINER, 26981, A.TRAINER, 26564, A.TRAINER, 26952, A.TRAINER, 26904, A.TRAINER, 29924)

	-- Copper Chain Vest -- 3321
	AddRecipe(3321, 35, 3471, R_UNCOMMON, GAME_ORIG, 35, 75, 95, 115)
	self:addTradeFlags(RecipeDB, 3321, F.ALLIANCE, F.HORDE, F.WORLD_DROP, F.IBOE, F.RBOE, F.DPS, F.MAIL)
	self:addTradeAcquire(RecipeDB, 3321, A.WORLD_DROP, 2)

	-- Runed Copper Gauntlets -- 3323
	AddRecipe(3323, 40, 3472, R_COMMON, GAME_ORIG, 40, 80, 100, 120)
	self:addTradeFlags(RecipeDB, 3323, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.DPS, F.MAIL)
	self:addTradeAcquire(RecipeDB, 3323, A.TRAINER, 514, A.TRAINER, 1241, A.TRAINER, 2836, A.TRAINER, 2998, A.TRAINER, 3136, A.TRAINER, 3174, A.TRAINER, 3355, A.TRAINER, 3478, A.TRAINER, 3557, A.TRAINER, 4258, A.TRAINER, 4596, A.TRAINER, 5511, A.TRAINER, 6299, A.TRAINER, 15400, A.TRAINER, 16583, A.TRAINER, 16669, A.TRAINER, 16724, A.TRAINER, 16823, A.TRAINER, 17245, A.TRAINER, 19341, A.TRAINER, 28694, A.TRAINER, 27034, A.TRAINER, 33591, A.TRAINER, 26988, A.TRAINER, 33609, A.TRAINER, 33631, A.TRAINER, 33675, A.TRAINER, 26981, A.TRAINER, 26564, A.TRAINER, 26952, A.TRAINER, 26904, A.TRAINER, 29924)

	-- Runed Copper Pants -- 3324
	AddRecipe(3324, 45, 3473, R_COMMON, GAME_ORIG, 45, 85, 105, 125)
	self:addTradeFlags(RecipeDB, 3324, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.DPS, F.MAIL)
	self:addTradeAcquire(RecipeDB, 3324, A.TRAINER, 514, A.TRAINER, 1241, A.TRAINER, 2836, A.TRAINER, 2998, A.TRAINER, 3136, A.TRAINER, 3174, A.TRAINER, 3355, A.TRAINER, 3478, A.TRAINER, 3557, A.TRAINER, 4258, A.TRAINER, 4596, A.TRAINER, 5511, A.TRAINER, 6299, A.TRAINER, 15400, A.TRAINER, 16583, A.TRAINER, 16669, A.TRAINER, 16724, A.TRAINER, 16823, A.TRAINER, 17245, A.TRAINER, 19341, A.TRAINER, 28694, A.TRAINER, 27034, A.TRAINER, 33591, A.TRAINER, 26988, A.TRAINER, 33609, A.TRAINER, 33631, A.TRAINER, 33675, A.TRAINER, 26981, A.TRAINER, 26564, A.TRAINER, 26952, A.TRAINER, 26904, A.TRAINER, 29924)

	-- Gemmed Copper Gauntlets -- 3325
	AddRecipe(3325, 60, 3474, R_UNCOMMON, GAME_ORIG, 60, 100, 120, 140)
	self:addTradeFlags(RecipeDB, 3325, F.ALLIANCE, F.HORDE, F.WORLD_DROP, F.IBOE, F.RBOE, F.MAIL)
	self:addTradeAcquire(RecipeDB, 3325, A.WORLD_DROP, 2)

	-- Coarse Grinding Stone -- 3326
	AddRecipe(3326, 75, 3478, R_COMMON, GAME_ORIG, 75, 75, 87, 100)
	self:addTradeFlags(RecipeDB, 3326, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP)
	self:addTradeAcquire(RecipeDB, 3326, A.TRAINER, 514, A.TRAINER, 1241, A.TRAINER, 2836, A.TRAINER, 2998, A.TRAINER, 3136, A.TRAINER, 3174, A.TRAINER, 3355, A.TRAINER, 3478, A.TRAINER, 3557, A.TRAINER, 4258, A.TRAINER, 4596, A.TRAINER, 5511, A.TRAINER, 6299, A.TRAINER, 15400, A.TRAINER, 16583, A.TRAINER, 16669, A.TRAINER, 16724, A.TRAINER, 16823, A.TRAINER, 17245, A.TRAINER, 28694, A.TRAINER, 27034, A.TRAINER, 33591, A.TRAINER, 26988, A.TRAINER, 33609, A.TRAINER, 33631, A.TRAINER, 33675, A.TRAINER, 26981, A.TRAINER, 26564, A.TRAINER, 26952, A.TRAINER, 26904, A.TRAINER, 29924)

	-- Rough Bronze Shoulders -- 3328
	AddRecipe(3328, 110, 3480, R_COMMON, GAME_ORIG, 110, 140, 155, 170)
	self:addTradeFlags(RecipeDB, 3328, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.DPS, F.MAIL)
	self:addTradeAcquire(RecipeDB, 3328, A.TRAINER, 2836, A.TRAINER, 2998, A.TRAINER, 3136, A.TRAINER, 3355, A.TRAINER, 3478, A.TRAINER, 4258, A.TRAINER, 4596, A.TRAINER, 5511, A.TRAINER, 16583, A.TRAINER, 16669, A.TRAINER, 16724, A.TRAINER, 16823, A.TRAINER, 19341, A.TRAINER, 28694, A.TRAINER, 27034, A.TRAINER, 514, A.TRAINER, 1241, A.TRAINER, 33591, A.TRAINER, 3174, A.TRAINER, 26988, A.TRAINER, 33609, A.TRAINER, 33631, A.TRAINER, 15400, A.TRAINER, 33675, A.TRAINER, 26981, A.TRAINER, 17245, A.TRAINER, 6299, A.TRAINER, 26564, A.TRAINER, 26952, A.TRAINER, 3557, A.TRAINER, 26904, A.TRAINER, 29924)

	-- Silvered Bronze Shoulders -- 3330
	AddRecipe(3330, 125, 3481, R_UNCOMMON, GAME_ORIG, 125, 155, 170, 185)
	self:addTradeFlags(RecipeDB, 3330, F.ALLIANCE, F.HORDE, F.WORLD_DROP, F.IBOE, F.RBOE, F.DPS, F.MAIL)
	self:addTradeAcquire(RecipeDB, 3330, A.WORLD_DROP, 2)

	-- Silvered Bronze Boots -- 3331
	AddRecipe(3331, 130, 3482, R_COMMON, GAME_ORIG, 130, 160, 175, 190)
	self:addTradeFlags(RecipeDB, 3331, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.DPS, F.MAIL)
	self:addTradeAcquire(RecipeDB, 3331, A.TRAINER, 2836, A.TRAINER, 2998, A.TRAINER, 3136, A.TRAINER, 3355, A.TRAINER, 3478, A.TRAINER, 4258, A.TRAINER, 4596, A.TRAINER, 5511, A.TRAINER, 16583, A.TRAINER, 16669, A.TRAINER, 16724, A.TRAINER, 16823, A.TRAINER, 19341, A.TRAINER, 28694, A.TRAINER, 27034, A.TRAINER, 514, A.TRAINER, 1241, A.TRAINER, 33591, A.TRAINER, 3174, A.TRAINER, 26988, A.TRAINER, 33609, A.TRAINER, 33631, A.TRAINER, 15400, A.TRAINER, 33675, A.TRAINER, 26981, A.TRAINER, 17245, A.TRAINER, 6299, A.TRAINER, 26564, A.TRAINER, 26952, A.TRAINER, 3557, A.TRAINER, 26904, A.TRAINER, 29924)

	-- Silvered Bronze Gauntlets -- 3333
	AddRecipe(3333, 135, 3483, R_COMMON, GAME_ORIG, 135, 165, 180, 195)
	self:addTradeFlags(RecipeDB, 3333, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.DPS, F.MAIL)
	self:addTradeAcquire(RecipeDB, 3333, A.TRAINER, 2836, A.TRAINER, 2998, A.TRAINER, 3136, A.TRAINER, 3355, A.TRAINER, 3478, A.TRAINER, 4258, A.TRAINER, 4596, A.TRAINER, 5511, A.TRAINER, 16583, A.TRAINER, 16669, A.TRAINER, 16724, A.TRAINER, 16823, A.TRAINER, 19341, A.TRAINER, 28694, A.TRAINER, 27034, A.TRAINER, 514, A.TRAINER, 1241, A.TRAINER, 33591, A.TRAINER, 3174, A.TRAINER, 26988, A.TRAINER, 33609, A.TRAINER, 33631, A.TRAINER, 15400, A.TRAINER, 33675, A.TRAINER, 26981, A.TRAINER, 17245, A.TRAINER, 6299, A.TRAINER, 26564, A.TRAINER, 26952, A.TRAINER, 3557, A.TRAINER, 26904, A.TRAINER, 29924)

	-- Green Iron Boots -- 3334
	AddRecipe(3334, 145, 3484, R_UNCOMMON, GAME_ORIG, 145, 175, 190, 205)
	self:addTradeFlags(RecipeDB, 3334, F.ALLIANCE, F.HORDE, F.WORLD_DROP, F.IBOE, F.RBOE, F.DPS, F.MAIL)
	self:addTradeAcquire(RecipeDB, 3334, A.WORLD_DROP, 2)

	-- Green Iron Gauntlets -- 3336
	AddRecipe(3336, 150, 3485, R_UNCOMMON, GAME_ORIG, 150, 180, 195, 210)
	self:addTradeFlags(RecipeDB, 3336, F.ALLIANCE, F.HORDE, F.WORLD_DROP, F.IBOE, F.RBOE, F.DPS, F.MAIL)
	self:addTradeAcquire(RecipeDB, 3336, A.WORLD_DROP, 2)

	-- Heavy Grinding Stone -- 3337
	AddRecipe(3337, 125, 3486, R_COMMON, GAME_ORIG, 125, 125, 137, 150)
	self:addTradeFlags(RecipeDB, 3337, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP)
	self:addTradeAcquire(RecipeDB, 3337, A.TRAINER, 2836, A.TRAINER, 2998, A.TRAINER, 3136, A.TRAINER, 3355, A.TRAINER, 3478, A.TRAINER, 4258, A.TRAINER, 4596, A.TRAINER, 5511, A.TRAINER, 16583, A.TRAINER, 16669, A.TRAINER, 16724, A.TRAINER, 16823, A.TRAINER, 28694, A.TRAINER, 27034, A.TRAINER, 514, A.TRAINER, 1241, A.TRAINER, 33591, A.TRAINER, 3174, A.TRAINER, 26988, A.TRAINER, 33609, A.TRAINER, 33631, A.TRAINER, 15400, A.TRAINER, 33675, A.TRAINER, 26981, A.TRAINER, 17245, A.TRAINER, 6299, A.TRAINER, 26564, A.TRAINER, 26952, A.TRAINER, 3557, A.TRAINER, 26904, A.TRAINER, 29924)

	-- Big Bronze Knife -- 3491
	AddRecipe(3491, 105, 3848, R_COMMON, GAME_ORIG, 105, 135, 150, 165)
	self:addTradeFlags(RecipeDB, 3491, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.ONE_HAND, F.DAGGER)
	self:addTradeAcquire(RecipeDB, 3491, A.TRAINER, 2836, A.TRAINER, 2998, A.TRAINER, 3136, A.TRAINER, 3355, A.TRAINER, 3478, A.TRAINER, 4258, A.TRAINER, 4596, A.TRAINER, 5511, A.TRAINER, 16583, A.TRAINER, 16669, A.TRAINER, 16724, A.TRAINER, 16823, A.TRAINER, 19341, A.TRAINER, 28694, A.TRAINER, 27034, A.TRAINER, 514, A.TRAINER, 1241, A.TRAINER, 33591, A.TRAINER, 3174, A.TRAINER, 26988, A.TRAINER, 33609, A.TRAINER, 33631, A.TRAINER, 15400, A.TRAINER, 33675, A.TRAINER, 26981, A.TRAINER, 17245, A.TRAINER, 6299, A.TRAINER, 26564, A.TRAINER, 26952, A.TRAINER, 3557, A.TRAINER, 26904, A.TRAINER, 29924)

	-- Hardened Iron Shortsword -- 3492
	AddRecipe(3492, 160, 3849, R_COMMON, GAME_ORIG, 160, 185, 197, 210)
	self:addTradeFlags(RecipeDB, 3492, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOE, F.DPS, F.ONE_HAND, F.SWORD)
	self:addTradeAcquire(RecipeDB, 3492, A.VENDOR, 2843, A.VENDOR, 5512)

	-- Jade Serpentblade -- 3493
	AddRecipe(3493, 175, 3850, R_UNCOMMON, GAME_ORIG, 175, 200, 212, 225)
	self:addTradeFlags(RecipeDB, 3493, F.ALLIANCE, F.HORDE, F.WORLD_DROP, F.IBOE, F.RBOE, F.DPS, F.ONE_HAND, F.SWORD)
	self:addTradeAcquire(RecipeDB, 3493, A.WORLD_DROP, 2)

	-- Solid Iron Maul -- 3494
	AddRecipe(3494, 155, 3851, R_COMMON, GAME_ORIG, 155, 180, 192, 205)
	self:addTradeFlags(RecipeDB, 3494, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOP, F.TWO_HAND, F.MACE)
	self:addTradeAcquire(RecipeDB, 3494, A.VENDOR, 1471, A.VENDOR, 8878, A.VENDOR, 9179)

	-- Golden Iron Destroyer -- 3495
	AddRecipe(3495, 170, 3852, R_UNCOMMON, GAME_ORIG, 170, 195, 207, 220)
	self:addTradeFlags(RecipeDB, 3495, F.ALLIANCE, F.HORDE, F.WORLD_DROP, F.IBOE, F.RBOE, F.DPS, F.TWO_HAND, F.MACE)
	self:addTradeAcquire(RecipeDB, 3495, A.WORLD_DROP, 2)

	-- Moonsteel Broadsword -- 3496
	AddRecipe(3496, 180, 3853, R_COMMON, GAME_ORIG, 180, 205, 217, 230)
	self:addTradeFlags(RecipeDB, 3496, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOP, F.TWO_HAND, F.SWORD)
	self:addTradeAcquire(RecipeDB, 3496, A.VENDOR, 2482)

	-- Frost Tiger Blade -- 3497
	AddRecipe(3497, 200, 3854, R_UNCOMMON, GAME_ORIG, 200, 210, 215, 220)
	self:addTradeFlags(RecipeDB, 3497, F.ALLIANCE, F.HORDE, F.WORLD_DROP, F.IBOE, F.RBOE, F.TWO_HAND, F.SWORD)
	self:addTradeAcquire(RecipeDB, 3497, A.WORLD_DROP, 2)

	-- Massive Iron Axe -- 3498
	AddRecipe(3498, 185, 3855, R_COMMON, GAME_ORIG, 185, 210, 222, 235)
	self:addTradeFlags(RecipeDB, 3498, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOE, F.DPS, F.TWO_HAND, F.AXE)
	self:addTradeAcquire(RecipeDB, 3498, A.VENDOR, 2483, A.VENDOR, 1146)

	-- Shadow Crescent Axe -- 3500
	AddRecipe(3500, 200, 3856, R_UNCOMMON, GAME_ORIG, 200, 225, 237, 250)
	self:addTradeFlags(RecipeDB, 3500, F.ALLIANCE, F.HORDE, F.WORLD_DROP, F.IBOE, F.RBOE, F.DPS, F.TWO_HAND, F.AXE)
	self:addTradeAcquire(RecipeDB, 3500, A.WORLD_DROP, 2)

	-- Green Iron Bracers -- 3501
	AddRecipe(3501, 165, 3835, R_COMMON, GAME_ORIG, 165, 190, 202, 215)
	self:addTradeFlags(RecipeDB, 3501, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.MAIL)
	self:addTradeAcquire(RecipeDB, 3501, A.TRAINER, 2836, A.TRAINER, 3355, A.TRAINER, 4258, A.TRAINER, 16583, A.TRAINER, 16669, A.TRAINER, 16823, A.TRAINER, 28694, A.TRAINER, 27034, A.TRAINER, 5511, A.TRAINER, 514, A.TRAINER, 1241, A.TRAINER, 16724, A.TRAINER, 33591, A.TRAINER, 2998, A.TRAINER, 3478, A.TRAINER, 3136, A.TRAINER, 4596, A.TRAINER, 3174, A.TRAINER, 26988, A.TRAINER, 33609, A.TRAINER, 33631, A.TRAINER, 15400, A.TRAINER, 33675, A.TRAINER, 26981, A.TRAINER, 17245, A.TRAINER, 6299, A.TRAINER, 26564, A.TRAINER, 26952, A.TRAINER, 3557, A.TRAINER, 26904, A.TRAINER, 29924)

	-- Green Iron Helm -- 3502
	AddRecipe(3502, 170, 3836, R_COMMON, GAME_ORIG, 170, 195, 207, 220)
	self:addTradeFlags(RecipeDB, 3502, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.DPS, F.MAIL)
	self:addTradeAcquire(RecipeDB, 3502, A.TRAINER, 2836, A.TRAINER, 3355, A.TRAINER, 4258, A.TRAINER, 16583, A.TRAINER, 16669, A.TRAINER, 16823, A.TRAINER, 19341, A.TRAINER, 28694, A.TRAINER, 27034, A.TRAINER, 5511, A.TRAINER, 514, A.TRAINER, 1241, A.TRAINER, 16724, A.TRAINER, 33591, A.TRAINER, 2998, A.TRAINER, 3478, A.TRAINER, 3136, A.TRAINER, 4596, A.TRAINER, 3174, A.TRAINER, 26988, A.TRAINER, 33609, A.TRAINER, 33631, A.TRAINER, 15400, A.TRAINER, 33675, A.TRAINER, 26981, A.TRAINER, 17245, A.TRAINER, 6299, A.TRAINER, 26564, A.TRAINER, 26952, A.TRAINER, 3557, A.TRAINER, 26904, A.TRAINER, 29924)

	-- Golden Scale Coif -- 3503
	AddRecipe(3503, 190, 3837, R_COMMON, GAME_ORIG, 190, 215, 227, 240)
	self:addTradeFlags(RecipeDB, 3503, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOP, F.DPS, F.MAIL)
	self:addTradeAcquire(RecipeDB, 3503, A.VENDOR, 5411)

	-- Green Iron Shoulders -- 3504
	AddRecipe(3504, 160, 3840, R_UNCOMMON, GAME_ORIG, 160, 185, 197, 210)
	self:addTradeFlags(RecipeDB, 3504, F.ALLIANCE, F.HORDE, F.WORLD_DROP, F.IBOE, F.RBOE, F.DPS, F.MAIL)
	self:addTradeAcquire(RecipeDB, 3504, A.WORLD_DROP, 2)

	-- Golden Scale Shoulders -- 3505
	AddRecipe(3505, 175, 3841, R_RARE, GAME_ORIG, 175, 200, 212, 225)
	self:addTradeFlags(RecipeDB, 3505, F.ALLIANCE, F.HORDE, F.WORLD_DROP, F.IBOE, F.RBOE, F.DPS, F.MAIL)
	self:addTradeAcquire(RecipeDB, 3505, A.WORLD_DROP, 3)

	-- Green Iron Leggings -- 3506
	AddRecipe(3506, 155, 3842, R_COMMON, GAME_ORIG, 155, 180, 192, 205)
	self:addTradeFlags(RecipeDB, 3506, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.DPS, F.MAIL)
	self:addTradeAcquire(RecipeDB, 3506, A.TRAINER, 2836, A.TRAINER, 3355, A.TRAINER, 4258, A.TRAINER, 16583, A.TRAINER, 16669, A.TRAINER, 16823, A.TRAINER, 19341, A.TRAINER, 28694, A.TRAINER, 27034, A.TRAINER, 5511, A.TRAINER, 514, A.TRAINER, 1241, A.TRAINER, 16724, A.TRAINER, 33591, A.TRAINER, 2998, A.TRAINER, 3478, A.TRAINER, 3136, A.TRAINER, 4596, A.TRAINER, 3174, A.TRAINER, 26988, A.TRAINER, 33609, A.TRAINER, 33631, A.TRAINER, 15400, A.TRAINER, 33675, A.TRAINER, 26981, A.TRAINER, 17245, A.TRAINER, 6299, A.TRAINER, 26564, A.TRAINER, 26952, A.TRAINER, 3557, A.TRAINER, 26904, A.TRAINER, 29924)

	-- Golden Scale Leggings -- 3507
	AddRecipe(3507, 170, 3843, R_UNCOMMON, GAME_ORIG, 170, 195, 207, 220)
	self:addTradeFlags(RecipeDB, 3507, F.ALLIANCE, F.HORDE, F.WORLD_DROP, F.IBOE, F.RBOE, F.DPS, F.MAIL)
	self:addTradeAcquire(RecipeDB, 3507, A.WORLD_DROP, 2)

	-- Green Iron Hauberk -- 3508
	AddRecipe(3508, 180, 3844, R_COMMON, GAME_ORIG, 180, 205, 217, 230)
	self:addTradeFlags(RecipeDB, 3508, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.DPS, F.MAIL)
	self:addTradeAcquire(RecipeDB, 3508, A.TRAINER, 2836, A.TRAINER, 3355, A.TRAINER, 4258, A.TRAINER, 16583, A.TRAINER, 16669, A.TRAINER, 16823, A.TRAINER, 19341, A.TRAINER, 28694, A.TRAINER, 27034, A.TRAINER, 5511, A.TRAINER, 514, A.TRAINER, 1241, A.TRAINER, 16724, A.TRAINER, 33591, A.TRAINER, 2998, A.TRAINER, 3478, A.TRAINER, 3136, A.TRAINER, 4596, A.TRAINER, 3174, A.TRAINER, 26988, A.TRAINER, 33609, A.TRAINER, 33631, A.TRAINER, 15400, A.TRAINER, 33675, A.TRAINER, 26981, A.TRAINER, 17245, A.TRAINER, 6299, A.TRAINER, 26564, A.TRAINER, 26952, A.TRAINER, 3557, A.TRAINER, 26904, A.TRAINER, 29924)

	-- Golden Scale Cuirass -- 3511
	AddRecipe(3511, 195, 3845, R_UNCOMMON, GAME_ORIG, 195, 220, 232, 245)
	self:addTradeFlags(RecipeDB, 3511, F.ALLIANCE, F.HORDE, F.WORLD_DROP, F.IBOE, F.RBOE, F.DPS, F.MAIL)
	self:addTradeAcquire(RecipeDB, 3511, A.WORLD_DROP, 2)

	-- Polished Steel Boots -- 3513
	AddRecipe(3513, 185, 3846, R_UNCOMMON, GAME_ORIG, 185, 210, 222, 235)
	self:addTradeFlags(RecipeDB, 3513, F.ALLIANCE, F.HORDE, F.WORLD_DROP, F.IBOE, F.RBOE, F.MAIL)
	self:addTradeAcquire(RecipeDB, 3513, A.WORLD_DROP, 2)

	-- Golden Scale Boots -- 3515
	AddRecipe(3515, 200, 3847, R_RARE, GAME_ORIG, 200, 210, 215, 220)
	self:addTradeFlags(RecipeDB, 3515, F.ALLIANCE, F.HORDE, F.INSTANCE, F.MOB_DROP, F.IBOE, F.RBOE, F.DPS, F.MAIL)
	self:addTradeAcquire(RecipeDB, 3515, A.WORLD_DROP, 2)

	-- Pearl-handled Dagger -- 6517
	AddRecipe(6517, 110, 5540, R_COMMON, GAME_ORIG, 110, 140, 155, 170)
	self:addTradeFlags(RecipeDB, 6517, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.DPS, F.ONE_HAND, F.DAGGER)
	self:addTradeAcquire(RecipeDB, 6517, A.TRAINER, 2836, A.TRAINER, 2998, A.TRAINER, 3136, A.TRAINER, 3355, A.TRAINER, 3478, A.TRAINER, 4258, A.TRAINER, 4596, A.TRAINER, 5511, A.TRAINER, 16583, A.TRAINER, 16669, A.TRAINER, 16724, A.TRAINER, 16823, A.TRAINER, 19341, A.TRAINER, 28694, A.TRAINER, 27034, A.TRAINER, 514, A.TRAINER, 1241, A.TRAINER, 33591, A.TRAINER, 3174, A.TRAINER, 26988, A.TRAINER, 33609, A.TRAINER, 33631, A.TRAINER, 15400, A.TRAINER, 33675, A.TRAINER, 26981, A.TRAINER, 17245, A.TRAINER, 6299, A.TRAINER, 26564, A.TRAINER, 26952, A.TRAINER, 3557, A.TRAINER, 26904, A.TRAINER, 29924)

	-- Iridescent Hammer -- 6518
	AddRecipe(6518, 140, 5541, R_UNCOMMON, GAME_ORIG, 140, 170, 185, 200)
	self:addTradeFlags(RecipeDB, 6518, F.ALLIANCE, F.HORDE, F.WORLD_DROP, F.IBOE, F.RBOE, F.DPS, F.ONE_HAND, F.MACE)
	self:addTradeAcquire(RecipeDB, 6518, A.WORLD_DROP, 2)

	-- Iron Shield Spike -- 7221
	AddRecipe(7221, 150, 6042, R_UNCOMMON, GAME_ORIG, 150, 180, 195, 210)
	self:addTradeFlags(RecipeDB, 7221, F.ALLIANCE, F.HORDE, F.WORLD_DROP, F.IBOE, F.RBOE, F.TANK, F.SHIELD)
	self:addTradeAcquire(RecipeDB, 7221, A.WORLD_DROP, 2)

	-- Iron Counterweight -- 7222
	AddRecipe(7222, 165, 6043, R_UNCOMMON, GAME_ORIG, 165, 190, 202, 215)
	self:addTradeFlags(RecipeDB, 7222, F.ALLIANCE, F.HORDE, F.WORLD_DROP, F.IBOE, F.RBOE, F.AXE)
	self:addTradeAcquire(RecipeDB, 7222, A.WORLD_DROP, 2)

	-- Golden Scale Bracers -- 7223
	AddRecipe(7223, 185, 6040, R_COMMON, GAME_ORIG, 185, 210, 222, 235)
	self:addTradeFlags(RecipeDB, 7223, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.DPS, F.TANK, F.MAIL)
	self:addTradeAcquire(RecipeDB, 7223, A.TRAINER, 2836, A.TRAINER, 3355, A.TRAINER, 4258, A.TRAINER, 16583, A.TRAINER, 16669, A.TRAINER, 16823, A.TRAINER, 19341, A.TRAINER, 28694, A.TRAINER, 27034, A.TRAINER, 5511, A.TRAINER, 514, A.TRAINER, 1241, A.TRAINER, 16724, A.TRAINER, 33591, A.TRAINER, 2998, A.TRAINER, 3478, A.TRAINER, 3136, A.TRAINER, 4596, A.TRAINER, 3174, A.TRAINER, 26988, A.TRAINER, 33609, A.TRAINER, 33631, A.TRAINER, 15400, A.TRAINER, 33675, A.TRAINER, 26981, A.TRAINER, 17245, A.TRAINER, 6299, A.TRAINER, 26564, A.TRAINER, 26952, A.TRAINER, 3557, A.TRAINER, 26904, A.TRAINER, 29924)

	-- Steel Weapon Chain -- 7224
	AddRecipe(7224, 190, 6041, R_UNCOMMON, GAME_ORIG, 190, 215, 227, 240)
	self:addTradeFlags(RecipeDB, 7224, F.ALLIANCE, F.HORDE, F.INSTANCE, F.MOB_DROP, F.IBOE, F.RBOE)
	self:addTradeAcquire(RecipeDB, 7224, A.WORLD_DROP, 2)

	-- Heavy Copper Maul -- 7408
	AddRecipe(7408, 65, 6214, R_COMMON, GAME_ORIG, 65, 105, 125, 145)
	self:addTradeFlags(RecipeDB, 7408, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.DPS, F.TWO_HAND, F.MACE)
	self:addTradeAcquire(RecipeDB, 7408, A.TRAINER, 514, A.TRAINER, 1241, A.TRAINER, 2836, A.TRAINER, 2998, A.TRAINER, 3136, A.TRAINER, 3174, A.TRAINER, 3355, A.TRAINER, 3478, A.TRAINER, 3557, A.TRAINER, 4258, A.TRAINER, 4596, A.TRAINER, 5511, A.TRAINER, 6299, A.TRAINER, 15400, A.TRAINER, 16583, A.TRAINER, 16669, A.TRAINER, 16724, A.TRAINER, 16823, A.TRAINER, 17245, A.TRAINER, 19341, A.TRAINER, 28694, A.TRAINER, 27034, A.TRAINER, 33591, A.TRAINER, 26988, A.TRAINER, 33609, A.TRAINER, 33631, A.TRAINER, 33675, A.TRAINER, 26981, A.TRAINER, 26564, A.TRAINER, 26952, A.TRAINER, 26904, A.TRAINER, 29924)

	-- Rough Bronze Boots -- 7817
	AddRecipe(7817, 95, 6350, R_COMMON, GAME_ORIG, 95, 125, 140, 155)
	self:addTradeFlags(RecipeDB, 7817, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.DPS, F.MAIL)
	self:addTradeAcquire(RecipeDB, 7817, A.TRAINER, 2836, A.TRAINER, 2998, A.TRAINER, 3136, A.TRAINER, 3355, A.TRAINER, 3478, A.TRAINER, 4258, A.TRAINER, 4596, A.TRAINER, 5511, A.TRAINER, 16583, A.TRAINER, 16669, A.TRAINER, 16724, A.TRAINER, 16823, A.TRAINER, 19341, A.TRAINER, 28694, A.TRAINER, 27034, A.TRAINER, 514, A.TRAINER, 1241, A.TRAINER, 33591, A.TRAINER, 3174, A.TRAINER, 26988, A.TRAINER, 33609, A.TRAINER, 33631, A.TRAINER, 15400, A.TRAINER, 33675, A.TRAINER, 26981, A.TRAINER, 17245, A.TRAINER, 6299, A.TRAINER, 26564, A.TRAINER, 26952, A.TRAINER, 3557, A.TRAINER, 26904, A.TRAINER, 29924)

	-- Silver Rod -- 7818
	AddRecipe(7818, 100, 6338, R_COMMON, GAME_ORIG, 100, 105, 107, 110)
	self:addTradeFlags(RecipeDB, 7818, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP)
	self:addTradeAcquire(RecipeDB, 7818, A.TRAINER, 2836, A.TRAINER, 2998, A.TRAINER, 3136, A.TRAINER, 3355, A.TRAINER, 3478, A.TRAINER, 4258, A.TRAINER, 4596, A.TRAINER, 5511, A.TRAINER, 16583, A.TRAINER, 16669, A.TRAINER, 16724, A.TRAINER, 16823, A.TRAINER, 28694, A.TRAINER, 27034, A.TRAINER, 514, A.TRAINER, 1241, A.TRAINER, 33591, A.TRAINER, 3174, A.TRAINER, 26988, A.TRAINER, 33609, A.TRAINER, 33631, A.TRAINER, 15400, A.TRAINER, 33675, A.TRAINER, 26981, A.TRAINER, 17245, A.TRAINER, 6299, A.TRAINER, 26564, A.TRAINER, 26952, A.TRAINER, 3557, A.TRAINER, 26904, A.TRAINER, 29924)

	-- Ironforge Breastplate -- 8367
	AddRecipe(8367, 100, 6731, R_UNCOMMON, GAME_ORIG, 100, 140, 160, 180)
	self:addTradeFlags(RecipeDB, 8367, F.ALLIANCE, F.QUEST, F.IBOE, F.RBOE, F.DPS, F.MAIL)
	self:addTradeAcquire(RecipeDB, 8367, A.QUEST, 1618)

	-- Iron Buckle -- 8768
	AddRecipe(8768, 150, 7071, R_COMMON, GAME_ORIG, 150, 150, 152, 155)
	self:addTradeFlags(RecipeDB, 8768, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP)
	self:addTradeAcquire(RecipeDB, 8768, A.TRAINER, 2836, A.TRAINER, 2998, A.TRAINER, 3136, A.TRAINER, 3355, A.TRAINER, 3478, A.TRAINER, 4258, A.TRAINER, 4596, A.TRAINER, 5511, A.TRAINER, 16583, A.TRAINER, 16669, A.TRAINER, 16724, A.TRAINER, 16823, A.TRAINER, 19341, A.TRAINER, 28694, A.TRAINER, 27034, A.TRAINER, 514, A.TRAINER, 1241, A.TRAINER, 33591, A.TRAINER, 3174, A.TRAINER, 26988, A.TRAINER, 33609, A.TRAINER, 33631, A.TRAINER, 15400, A.TRAINER, 33675, A.TRAINER, 26981, A.TRAINER, 17245, A.TRAINER, 6299, A.TRAINER, 26564, A.TRAINER, 26952, A.TRAINER, 3557, A.TRAINER, 26904, A.TRAINER, 29924)

	-- Copper Dagger -- 8880
	AddRecipe(8880, 30, 7166, R_COMMON, GAME_ORIG, 30, 70, 90, 110)
	self:addTradeFlags(RecipeDB, 8880, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.ONE_HAND, F.DAGGER)
	self:addTradeAcquire(RecipeDB, 8880, A.TRAINER, 514, A.TRAINER, 1241, A.TRAINER, 2836, A.TRAINER, 2998, A.TRAINER, 3136, A.TRAINER, 3174, A.TRAINER, 3355, A.TRAINER, 3478, A.TRAINER, 3557, A.TRAINER, 4258, A.TRAINER, 4596, A.TRAINER, 5511, A.TRAINER, 6299, A.TRAINER, 15400, A.TRAINER, 16583, A.TRAINER, 16669, A.TRAINER, 16724, A.TRAINER, 16823, A.TRAINER, 17245, A.TRAINER, 19341, A.TRAINER, 28694, A.TRAINER, 27034, A.TRAINER, 33591, A.TRAINER, 26988, A.TRAINER, 33609, A.TRAINER, 33631, A.TRAINER, 33675, A.TRAINER, 26981, A.TRAINER, 26564, A.TRAINER, 26952, A.TRAINER, 26904, A.TRAINER, 29924)

	-- Barbaric Iron Shoulders -- 9811
	AddRecipe(9811, 160, 7913, R_UNCOMMON, GAME_ORIG, 160, 185, 197, 210)
	self:addTradeFlags(RecipeDB, 9811, F.HORDE, F.QUEST, F.IBOE, F.RBOE, F.DPS, F.MAIL)
	self:addTradeAcquire(RecipeDB, 9811, A.QUEST, 2752)

	-- Barbaric Iron Breastplate -- 9813
	AddRecipe(9813, 160, 7914, R_UNCOMMON, GAME_ORIG, 160, 185, 197, 210)
	self:addTradeFlags(RecipeDB, 9813, F.HORDE, F.QUEST, F.IBOE, F.RBOE, F.DPS, F.MAIL)
	self:addTradeAcquire(RecipeDB, 9813, A.QUEST, 2751)

	-- Barbaric Iron Helm -- 9814
	AddRecipe(9814, 175, 7915, R_UNCOMMON, GAME_ORIG, 175, 200, 212, 225)
	self:addTradeFlags(RecipeDB, 9814, F.HORDE, F.QUEST, F.IBOE, F.RBOE, F.DPS, F.MAIL)
	self:addTradeAcquire(RecipeDB, 9814, A.QUEST, 2754)

	-- Barbaric Iron Boots -- 9818
	AddRecipe(9818, 180, 7916, R_UNCOMMON, GAME_ORIG, 180, 205, 217, 230)
	self:addTradeFlags(RecipeDB, 9818, F.HORDE, F.QUEST, F.IBOE, F.RBOE, F.DPS, F.MAIL)
	self:addTradeAcquire(RecipeDB, 9818, A.QUEST, 2753)

	-- Barbaric Iron Gloves -- 9820
	AddRecipe(9820, 185, 7917, R_UNCOMMON, GAME_ORIG, 185, 210, 222, 235)
	self:addTradeFlags(RecipeDB, 9820, F.HORDE, F.QUEST, F.IBOE, F.RBOE, F.DPS, F.MAIL)
	self:addTradeAcquire(RecipeDB, 9820, A.QUEST, 2755)

	-- Steel Breastplate -- 9916
	AddRecipe(9916, 200, 7963, R_COMMON, GAME_ORIG, 200, 225, 237, 250)
	self:addTradeFlags(RecipeDB, 9916, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.DPS, F.MAIL)
	self:addTradeAcquire(RecipeDB, 9916, A.TRAINER, 2836, A.TRAINER, 3355, A.TRAINER, 4258, A.TRAINER, 16583, A.TRAINER, 16669, A.TRAINER, 16823, A.TRAINER, 19341, A.TRAINER, 28694, A.TRAINER, 27034, A.TRAINER, 5511, A.TRAINER, 514, A.TRAINER, 1241, A.TRAINER, 16724, A.TRAINER, 33591, A.TRAINER, 2998, A.TRAINER, 3478, A.TRAINER, 3136, A.TRAINER, 4596, A.TRAINER, 3174, A.TRAINER, 26988, A.TRAINER, 33609, A.TRAINER, 33631, A.TRAINER, 15400, A.TRAINER, 33675, A.TRAINER, 26981, A.TRAINER, 17245, A.TRAINER, 6299, A.TRAINER, 26564, A.TRAINER, 26952, A.TRAINER, 3557, A.TRAINER, 26904, A.TRAINER, 29924)

	-- Solid Sharpening Stone -- 9918
	AddRecipe(9918, 200, 7964, R_COMMON, GAME_ORIG, 200, 200, 205, 210)
	self:addTradeFlags(RecipeDB, 9918, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.DPS)
	self:addTradeAcquire(RecipeDB, 9918, A.TRAINER, 2836, A.TRAINER, 3355, A.TRAINER, 4258, A.TRAINER, 16583, A.TRAINER, 16669, A.TRAINER, 16823, A.TRAINER, 19341, A.TRAINER, 28694, A.TRAINER, 27034, A.TRAINER, 5511, A.TRAINER, 514, A.TRAINER, 1241, A.TRAINER, 16724, A.TRAINER, 33591, A.TRAINER, 2998, A.TRAINER, 3478, A.TRAINER, 3136, A.TRAINER, 4596, A.TRAINER, 3174, A.TRAINER, 26988, A.TRAINER, 33609, A.TRAINER, 33631, A.TRAINER, 33675, A.TRAINER, 26981, A.TRAINER, 17245, A.TRAINER, 6299, A.TRAINER, 26564, A.TRAINER, 26952, A.TRAINER, 3557, A.TRAINER, 26904, A.TRAINER, 29924)

	-- Solid Grinding Stone -- 9920
	AddRecipe(9920, 200, 7966, R_COMMON, GAME_ORIG, 200, 200, 205, 210)
	self:addTradeFlags(RecipeDB, 9920, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP)
	self:addTradeAcquire(RecipeDB, 9920, A.TRAINER, 2836, A.TRAINER, 3355, A.TRAINER, 4258, A.TRAINER, 16583, A.TRAINER, 16669, A.TRAINER, 16823, A.TRAINER, 28694, A.TRAINER, 27034, A.TRAINER, 5511, A.TRAINER, 514, A.TRAINER, 1241, A.TRAINER, 16724, A.TRAINER, 33591, A.TRAINER, 2998, A.TRAINER, 3478, A.TRAINER, 3136, A.TRAINER, 4596, A.TRAINER, 3174, A.TRAINER, 26988, A.TRAINER, 33609, A.TRAINER, 33631, A.TRAINER, 33675, A.TRAINER, 26981, A.TRAINER, 17245, A.TRAINER, 6299, A.TRAINER, 26564, A.TRAINER, 26952, A.TRAINER, 3557, A.TRAINER, 26904, A.TRAINER, 29924)

	-- Solid Weightstone -- 9921
	AddRecipe(9921, 200, 7965, R_COMMON, GAME_ORIG, 200, 200, 205, 210)
	self:addTradeFlags(RecipeDB, 9921, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP)
	self:addTradeAcquire(RecipeDB, 9921, A.TRAINER, 2836, A.TRAINER, 3355, A.TRAINER, 4258, A.TRAINER, 16583, A.TRAINER, 16669, A.TRAINER, 16823, A.TRAINER, 19341, A.TRAINER, 28694, A.TRAINER, 27034, A.TRAINER, 5511, A.TRAINER, 514, A.TRAINER, 1241, A.TRAINER, 16724, A.TRAINER, 33591, A.TRAINER, 2998, A.TRAINER, 3478, A.TRAINER, 3136, A.TRAINER, 4596, A.TRAINER, 3174, A.TRAINER, 26988, A.TRAINER, 33609, A.TRAINER, 33631, A.TRAINER, 33675, A.TRAINER, 26981, A.TRAINER, 17245, A.TRAINER, 6299, A.TRAINER, 26564, A.TRAINER, 26952, A.TRAINER, 3557, A.TRAINER, 26904, A.TRAINER, 29924)

	-- Heavy Mithril Shoulder -- 9926
	AddRecipe(9926, 205, 7918, R_COMMON, GAME_ORIG, 205, 225, 235, 245)
	self:addTradeFlags(RecipeDB, 9926, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.PLATE)
	self:addTradeAcquire(RecipeDB, 9926, A.TRAINER, 2836, A.TRAINER, 3355, A.TRAINER, 4258, A.TRAINER, 16583, A.TRAINER, 16669, A.TRAINER, 16823, A.TRAINER, 19341, A.TRAINER, 28694, A.TRAINER, 27034, A.TRAINER, 5511, A.TRAINER, 514, A.TRAINER, 1241, A.TRAINER, 16724, A.TRAINER, 33591, A.TRAINER, 2998, A.TRAINER, 3478, A.TRAINER, 3136, A.TRAINER, 4596, A.TRAINER, 3174, A.TRAINER, 26988, A.TRAINER, 33609, A.TRAINER, 33631, A.TRAINER, 33675, A.TRAINER, 26981, A.TRAINER, 17245, A.TRAINER, 6299, A.TRAINER, 26564, A.TRAINER, 26952, A.TRAINER, 3557, A.TRAINER, 26904, A.TRAINER, 29924)

	-- Heavy Mithril Gauntlet -- 9928
	AddRecipe(9928, 205, 7919, R_COMMON, GAME_ORIG, 205, 225, 235, 245)
	self:addTradeFlags(RecipeDB, 9928, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.PLATE)
	self:addTradeAcquire(RecipeDB, 9928, A.TRAINER, 2836, A.TRAINER, 3355, A.TRAINER, 4258, A.TRAINER, 16583, A.TRAINER, 16669, A.TRAINER, 16823, A.TRAINER, 19341, A.TRAINER, 28694, A.TRAINER, 27034, A.TRAINER, 5511, A.TRAINER, 514, A.TRAINER, 1241, A.TRAINER, 16724, A.TRAINER, 33591, A.TRAINER, 2998, A.TRAINER, 3478, A.TRAINER, 3136, A.TRAINER, 4596, A.TRAINER, 3174, A.TRAINER, 26988, A.TRAINER, 33609, A.TRAINER, 33631, A.TRAINER, 33675, A.TRAINER, 26981, A.TRAINER, 17245, A.TRAINER, 6299, A.TRAINER, 26564, A.TRAINER, 26952, A.TRAINER, 3557, A.TRAINER, 26904, A.TRAINER, 29924)

	-- Mithril Scale Pants -- 9931
	AddRecipe(9931, 210, 7920, R_COMMON, GAME_ORIG, 210, 230, 240, 250)
	self:addTradeFlags(RecipeDB, 9931, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.DPS, F.MAIL)
	self:addTradeAcquire(RecipeDB, 9931, A.TRAINER, 2836, A.TRAINER, 3355, A.TRAINER, 4258, A.TRAINER, 16583, A.TRAINER, 16669, A.TRAINER, 16823, A.TRAINER, 19341, A.TRAINER, 28694, A.TRAINER, 27034, A.TRAINER, 5511, A.TRAINER, 514, A.TRAINER, 1241, A.TRAINER, 16724, A.TRAINER, 33591, A.TRAINER, 2998, A.TRAINER, 3478, A.TRAINER, 3136, A.TRAINER, 4596, A.TRAINER, 3174, A.TRAINER, 26988, A.TRAINER, 33609, A.TRAINER, 33631, A.TRAINER, 33675, A.TRAINER, 26981, A.TRAINER, 17245, A.TRAINER, 6299, A.TRAINER, 26564, A.TRAINER, 26952, A.TRAINER, 3557, A.TRAINER, 26904, A.TRAINER, 29924)

	-- Heavy Mithril Pants -- 9933
	AddRecipe(9933, 210, 7921, R_UNCOMMON, GAME_ORIG, 210, 230, 240, 250)
	self:addTradeFlags(RecipeDB, 9933, F.ALLIANCE, F.HORDE, F.WORLD_DROP, F.IBOE, F.RBOE, F.PLATE)
	self:addTradeAcquire(RecipeDB, 9933, A.WORLD_DROP, 2)

	-- Steel Plate Helm -- 9935
	AddRecipe(9935, 215, 7922, R_COMMON, GAME_ORIG, 215, 235, 245, 255)
	self:addTradeFlags(RecipeDB, 9935, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.DPS, F.PLATE)
	self:addTradeAcquire(RecipeDB, 9935, A.TRAINER, 2836, A.TRAINER, 3355, A.TRAINER, 4258, A.TRAINER, 16583, A.TRAINER, 16669, A.TRAINER, 16823, A.TRAINER, 19341, A.TRAINER, 28694, A.TRAINER, 27034, A.TRAINER, 5511, A.TRAINER, 514, A.TRAINER, 1241, A.TRAINER, 16724, A.TRAINER, 33591, A.TRAINER, 2998, A.TRAINER, 3478, A.TRAINER, 3136, A.TRAINER, 4596, A.TRAINER, 3174, A.TRAINER, 26988, A.TRAINER, 33609, A.TRAINER, 33631, A.TRAINER, 33675, A.TRAINER, 26981, A.TRAINER, 17245, A.TRAINER, 6299, A.TRAINER, 26564, A.TRAINER, 26952, A.TRAINER, 3557, A.TRAINER, 26904, A.TRAINER, 29924)

	-- Mithril Scale Bracers -- 9937
	AddRecipe(9937, 215, 7924, R_COMMON, GAME_ORIG, 215, 235, 245, 255)
	self:addTradeFlags(RecipeDB, 9937, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOE, F.DPS, F.MAIL)
	self:addTradeAcquire(RecipeDB, 9937, A.VENDOR, 8161, A.VENDOR, 8176)

	-- Mithril Shield Spike -- 9939
	AddRecipe(9939, 215, 7967, R_RARE, GAME_ORIG, 215, 235, 245, 255)
	self:addTradeFlags(RecipeDB, 9939, F.ALLIANCE, F.HORDE, F.WORLD_DROP, F.IBOE, F.RBOE, F.TANK, F.SHIELD)
	self:addTradeAcquire(RecipeDB, 9939, A.WORLD_DROP, 3)

	-- Ornate Mithril Pants -- 9945
	AddRecipe(9945, 220, 7926, R_UNCOMMON, GAME_ORIG, 220, 240, 250, 260)
	self:addTradeFlags(RecipeDB, 9945, F.ALLIANCE, F.HORDE, F.QUEST, F.IBOE, F.RBOP, F.TANK, F.PLATE)
	self:addTradeAcquire(RecipeDB, 9945, A.QUEST, 2761)

	-- Ornate Mithril Gloves -- 9950
	AddRecipe(9950, 220, 7927, R_UNCOMMON, GAME_ORIG, 220, 240, 250, 260)
	self:addTradeFlags(RecipeDB, 9950, F.ALLIANCE, F.HORDE, F.QUEST, F.IBOE, F.RBOP, F.PLATE)
	self:addTradeAcquire(RecipeDB, 9950, A.QUEST, 2762)

	-- Ornate Mithril Shoulder -- 9952
	AddRecipe(9952, 225, 7928, R_UNCOMMON, GAME_ORIG, 225, 245, 255, 265)
	self:addTradeFlags(RecipeDB, 9952, F.ALLIANCE, F.HORDE, F.QUEST, F.IBOE, F.RBOP, F.TANK, F.PLATE)
	self:addTradeAcquire(RecipeDB, 9952, A.QUEST, 2763)

	-- Truesilver Gauntlets -- 9954
	AddRecipe(9954, 225, 7938, R_COMMON, GAME_ORIG, 225, 245, 255, 265)
	self:addTradeFlags(RecipeDB, 9954, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.DPS, F.PLATE)
	self:addTradeAcquire(RecipeDB, 9954, A.TRAINER, 5164, A.TRAINER, 7230, A.TRAINER, 11177, A.TRAINER, 20125, A.TRAINER, 29506)

	-- Orcish War Leggings -- 9957
	AddRecipe(9957, 250, 7929, R_UNCOMMON, GAME_ORIG, 250, 250, 260, 270)
	self:addTradeFlags(RecipeDB, 9957, F.HORDE, F.QUEST, F.IBOE, F.RBOP, F.DPS, F.MAIL)
	self:addTradeAcquire(RecipeDB, 9957, A.QUEST, 2756)

	-- Heavy Mithril Breastplate -- 9959
	AddRecipe(9959, 230, 7930, R_COMMON, GAME_ORIG, 230, 250, 260, 270)
	self:addTradeFlags(RecipeDB, 9959, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.PLATE)
	self:addTradeAcquire(RecipeDB, 9959, A.TRAINER, 2836, A.TRAINER, 16583, A.TRAINER, 16823, A.TRAINER, 19341, A.TRAINER, 28694, A.TRAINER, 27034, A.TRAINER, 4258, A.TRAINER, 5511, A.TRAINER, 514, A.TRAINER, 1241, A.TRAINER, 16724, A.TRAINER, 3355, A.TRAINER, 33591, A.TRAINER, 2998, A.TRAINER, 3478, A.TRAINER, 3136, A.TRAINER, 4596, A.TRAINER, 3174, A.TRAINER, 26988, A.TRAINER, 33609, A.TRAINER, 33631, A.TRAINER, 15400, A.TRAINER, 33675, A.TRAINER, 26981, A.TRAINER, 17245, A.TRAINER, 6299, A.TRAINER, 26564, A.TRAINER, 26952, A.TRAINER, 3557, A.TRAINER, 26904, A.TRAINER, 29924)

	-- Mithril Coif -- 9961
	AddRecipe(9961, 230, 7931, R_COMMON, GAME_ORIG, 230, 250, 260, 270)
	self:addTradeFlags(RecipeDB, 9961, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.DPS, F.MAIL)
	self:addTradeAcquire(RecipeDB, 9961, A.TRAINER, 2836, A.TRAINER, 16583, A.TRAINER, 16823, A.TRAINER, 19341, A.TRAINER, 28694, A.TRAINER, 27034, A.TRAINER, 4258, A.TRAINER, 5511, A.TRAINER, 514, A.TRAINER, 1241, A.TRAINER, 16724, A.TRAINER, 3355, A.TRAINER, 33591, A.TRAINER, 2998, A.TRAINER, 3478, A.TRAINER, 3136, A.TRAINER, 4596, A.TRAINER, 3174, A.TRAINER, 26988, A.TRAINER, 33609, A.TRAINER, 33631, A.TRAINER, 15400, A.TRAINER, 33675, A.TRAINER, 26981, A.TRAINER, 17245, A.TRAINER, 6299, A.TRAINER, 26564, A.TRAINER, 26952, A.TRAINER, 3557, A.TRAINER, 26904, A.TRAINER, 29924)

	-- Mithril Spurs -- 9964
	AddRecipe(9964, 235, 7969, R_UNCOMMON, GAME_ORIG, 235, 255, 265, 275)
	self:addTradeFlags(RecipeDB, 9964, F.ALLIANCE, F.HORDE, F.WORLD_DROP, F.IBOE, F.RBOE)
	self:addTradeAcquire(RecipeDB, 9964, A.WORLD_DROP, 2)

	-- Mithril Scale Shoulders -- 9966
	AddRecipe(9966, 235, 7932, R_RARE, GAME_ORIG, 235, 255, 265, 275)
	self:addTradeFlags(RecipeDB, 9966, F.ALLIANCE, F.HORDE, F.INSTANCE, F.RAID, F.MOB_DROP, F.IBOE, F.RBOE, F.DPS, F.MAIL)
	self:addTradeAcquire(RecipeDB, 9966, A.WORLD_DROP, 3, A.CUSTOM, 33)

	-- Heavy Mithril Boots -- 9968
	AddRecipe(9968, 235, 7933, R_COMMON, GAME_ORIG, 235, 255, 265, 275)
	self:addTradeFlags(RecipeDB, 9968, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.DPS, F.PLATE)
	self:addTradeAcquire(RecipeDB, 9968, A.TRAINER, 514, A.TRAINER, 1241, A.TRAINER, 2836, A.TRAINER, 2998, A.TRAINER, 3136, A.TRAINER, 3174, A.TRAINER, 3355, A.TRAINER, 3478, A.TRAINER, 3557, A.TRAINER, 4258, A.TRAINER, 4596, A.TRAINER, 5511, A.TRAINER, 6299, A.TRAINER, 15400, A.TRAINER, 16583, A.TRAINER, 16724, A.TRAINER, 16823, A.TRAINER, 17245, A.TRAINER, 19341, A.TRAINER, 28694, A.TRAINER, 27034, A.TRAINER, 33591, A.TRAINER, 26988, A.TRAINER, 33609, A.TRAINER, 33631, A.TRAINER, 33675, A.TRAINER, 26981, A.TRAINER, 26564, A.TRAINER, 26952, A.TRAINER, 26904, A.TRAINER, 29924)

	-- Heavy Mithril Helm -- 9970
	AddRecipe(9970, 245, 7934, R_UNCOMMON, GAME_ORIG, 245, 255, 265, 275)
	self:addTradeFlags(RecipeDB, 9970, F.ALLIANCE, F.HORDE, F.WORLD_DROP, F.IBOE, F.RBOE, F.DPS, F.PLATE)
	self:addTradeAcquire(RecipeDB, 9970, A.WORLD_DROP, 2)

	-- Ornate Mithril Breastplate -- 9972
	AddRecipe(9972, 260, 7935, R_UNCOMMON, GAME_ORIG, 260, 260, 270, 280)
	self:addTradeFlags(RecipeDB, 9972, F.ALLIANCE, F.HORDE, F.QUEST, F.IBOE, F.RBOP, F.TANK, F.PLATE)
	self:addTradeAcquire(RecipeDB, 9972, A.QUEST, 2773)

	-- Truesilver Breastplate -- 9974
	AddRecipe(9974, 245, 7939, R_COMMON, GAME_ORIG, 245, 265, 275, 285)
	self:addTradeFlags(RecipeDB, 9974, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.PLATE)
	self:addTradeAcquire(RecipeDB, 9974, A.TRAINER, 5164, A.TRAINER, 7230, A.TRAINER, 11177, A.TRAINER, 20125, A.TRAINER, 29506)

	-- Ornate Mithril Boots -- 9979
	AddRecipe(9979, 265, 7936, R_UNCOMMON, GAME_ORIG, 265, 265, 275, 285)
	self:addTradeFlags(RecipeDB, 9979, F.ALLIANCE, F.HORDE, F.QUEST, F.IBOE, F.RBOP, F.TANK, F.PLATE)
	self:addTradeAcquire(RecipeDB, 9979, A.QUEST, 2772)

	-- Ornate Mithril Helm -- 9980
	AddRecipe(9980, 265, 7937, R_UNCOMMON, GAME_ORIG, 265, 265, 275, 285)
	self:addTradeFlags(RecipeDB, 9980, F.ALLIANCE, F.HORDE, F.QUEST, F.IBOE, F.RBOP, F.DPS, F.PLATE)
	self:addTradeAcquire(RecipeDB, 9980, A.QUEST, 2771)

	-- Copper Claymore -- 9983
	AddRecipe(9983, 30, 7955, R_COMMON, GAME_ORIG, 30, 70, 90, 110)
	self:addTradeFlags(RecipeDB, 9983, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.TWO_HAND, F.SWORD)
	self:addTradeAcquire(RecipeDB, 9983, A.TRAINER, 514, A.TRAINER, 1241, A.TRAINER, 2836, A.TRAINER, 2998, A.TRAINER, 3136, A.TRAINER, 3174, A.TRAINER, 3355, A.TRAINER, 3478, A.TRAINER, 3557, A.TRAINER, 4258, A.TRAINER, 4596, A.TRAINER, 5511, A.TRAINER, 6299, A.TRAINER, 15400, A.TRAINER, 16583, A.TRAINER, 16669, A.TRAINER, 16724, A.TRAINER, 16823, A.TRAINER, 17245, A.TRAINER, 19341, A.TRAINER, 28694, A.TRAINER, 27034, A.TRAINER, 33591, A.TRAINER, 26988, A.TRAINER, 33609, A.TRAINER, 33631, A.TRAINER, 33675, A.TRAINER, 26981, A.TRAINER, 26564, A.TRAINER, 26952, A.TRAINER, 26904, A.TRAINER, 29924)

	-- Bronze Warhammer -- 9985
	AddRecipe(9985, 125, 7956, R_COMMON, GAME_ORIG, 125, 155, 170, 185)
	self:addTradeFlags(RecipeDB, 9985, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.DPS, F.TWO_HAND, F.MACE)
	self:addTradeAcquire(RecipeDB, 9985, A.TRAINER, 2836, A.TRAINER, 2998, A.TRAINER, 3136, A.TRAINER, 3355, A.TRAINER, 3478, A.TRAINER, 4258, A.TRAINER, 4596, A.TRAINER, 5511, A.TRAINER, 16583, A.TRAINER, 16669, A.TRAINER, 16724, A.TRAINER, 16823, A.TRAINER, 19341, A.TRAINER, 28694, A.TRAINER, 27034, A.TRAINER, 514, A.TRAINER, 1241, A.TRAINER, 33591, A.TRAINER, 3174, A.TRAINER, 26988, A.TRAINER, 33609, A.TRAINER, 33631, A.TRAINER, 15400, A.TRAINER, 33675, A.TRAINER, 26981, A.TRAINER, 17245, A.TRAINER, 6299, A.TRAINER, 26564, A.TRAINER, 26952, A.TRAINER, 3557, A.TRAINER, 26904, A.TRAINER, 29924)

	-- Bronze Greatsword -- 9986
	AddRecipe(9986, 130, 7957, R_COMMON, GAME_ORIG, 130, 160, 175, 190)
	self:addTradeFlags(RecipeDB, 9986, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.DPS, F.TWO_HAND, F.SWORD)
	self:addTradeAcquire(RecipeDB, 9986, A.TRAINER, 2836, A.TRAINER, 2998, A.TRAINER, 3136, A.TRAINER, 3355, A.TRAINER, 3478, A.TRAINER, 4258, A.TRAINER, 4596, A.TRAINER, 5511, A.TRAINER, 16583, A.TRAINER, 16669, A.TRAINER, 16724, A.TRAINER, 16823, A.TRAINER, 19341, A.TRAINER, 28694, A.TRAINER, 27034, A.TRAINER, 514, A.TRAINER, 1241, A.TRAINER, 33591, A.TRAINER, 3174, A.TRAINER, 26988, A.TRAINER, 33609, A.TRAINER, 33631, A.TRAINER, 15400, A.TRAINER, 33675, A.TRAINER, 26981, A.TRAINER, 17245, A.TRAINER, 6299, A.TRAINER, 26564, A.TRAINER, 26952, A.TRAINER, 3557, A.TRAINER, 26904, A.TRAINER, 29924)

	-- Bronze Battle Axe -- 9987
	AddRecipe(9987, 135, 7958, R_COMMON, GAME_ORIG, 135, 165, 180, 195)
	self:addTradeFlags(RecipeDB, 9987, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.DPS, F.TWO_HAND, F.AXE)
	self:addTradeAcquire(RecipeDB, 9987, A.TRAINER, 2836, A.TRAINER, 2998, A.TRAINER, 3136, A.TRAINER, 3355, A.TRAINER, 3478, A.TRAINER, 4258, A.TRAINER, 4596, A.TRAINER, 5511, A.TRAINER, 16583, A.TRAINER, 16669, A.TRAINER, 16724, A.TRAINER, 16823, A.TRAINER, 19341, A.TRAINER, 28694, A.TRAINER, 27034, A.TRAINER, 514, A.TRAINER, 1241, A.TRAINER, 33591, A.TRAINER, 3174, A.TRAINER, 26988, A.TRAINER, 33609, A.TRAINER, 33631, A.TRAINER, 15400, A.TRAINER, 33675, A.TRAINER, 26981, A.TRAINER, 17245, A.TRAINER, 6299, A.TRAINER, 26564, A.TRAINER, 26952, A.TRAINER, 3557, A.TRAINER, 26904, A.TRAINER, 29924)

	-- Heavy Mithril Axe -- 9993
	AddRecipe(9993, 210, 7941, R_COMMON, GAME_ORIG, 210, 235, 247, 260)
	self:addTradeFlags(RecipeDB, 9993, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.DPS, F.ONE_HAND, F.AXE)
	self:addTradeAcquire(RecipeDB, 9993, A.TRAINER, 2836, A.TRAINER, 3355, A.TRAINER, 4258, A.TRAINER, 16583, A.TRAINER, 16669, A.TRAINER, 16823, A.TRAINER, 19341, A.TRAINER, 28694, A.TRAINER, 27034, A.TRAINER, 5511, A.TRAINER, 514, A.TRAINER, 1241, A.TRAINER, 16724, A.TRAINER, 33591, A.TRAINER, 2998, A.TRAINER, 3478, A.TRAINER, 3136, A.TRAINER, 4596, A.TRAINER, 3174, A.TRAINER, 26988, A.TRAINER, 33609, A.TRAINER, 33631, A.TRAINER, 15400, A.TRAINER, 33675, A.TRAINER, 26981, A.TRAINER, 17245, A.TRAINER, 6299, A.TRAINER, 26564, A.TRAINER, 26952, A.TRAINER, 3557, A.TRAINER, 26904, A.TRAINER, 29924)

	-- Blue Glittering Axe -- 9995
	AddRecipe(9995, 220, 7942, R_UNCOMMON, GAME_ORIG, 220, 245, 257, 270)
	self:addTradeFlags(RecipeDB, 9995, F.ALLIANCE, F.HORDE, F.WORLD_DROP, F.IBOE, F.RBOE, F.DPS, F.ONE_HAND, F.AXE)
	self:addTradeAcquire(RecipeDB, 9995, A.WORLD_DROP, 2)

	-- Wicked Mithril Blade -- 9997
	AddRecipe(9997, 225, 7943, R_UNCOMMON, GAME_ORIG, 225, 250, 262, 275)
	self:addTradeFlags(RecipeDB, 9997, F.ALLIANCE, F.HORDE, F.WORLD_DROP, F.IBOE, F.RBOP, F.DPS, F.ONE_HAND, F.SWORD)
	self:addTradeAcquire(RecipeDB, 9997, A.WORLD_DROP, 2)

	-- Big Black Mace -- 10001
	AddRecipe(10001, 230, 7945, R_COMMON, GAME_ORIG, 230, 255, 267, 280)
	self:addTradeFlags(RecipeDB, 10001, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.DPS, F.ONE_HAND, F.MACE)
	self:addTradeAcquire(RecipeDB, 10001, A.TRAINER, 2836, A.TRAINER, 16583, A.TRAINER, 16823, A.TRAINER, 19341, A.TRAINER, 28694, A.TRAINER, 27034, A.TRAINER, 4258, A.TRAINER, 5511, A.TRAINER, 514, A.TRAINER, 1241, A.TRAINER, 16724, A.TRAINER, 3355, A.TRAINER, 33591, A.TRAINER, 2998, A.TRAINER, 3478, A.TRAINER, 3136, A.TRAINER, 4596, A.TRAINER, 3174, A.TRAINER, 26988, A.TRAINER, 33609, A.TRAINER, 33631, A.TRAINER, 15400, A.TRAINER, 33675, A.TRAINER, 26981, A.TRAINER, 17245, A.TRAINER, 6299, A.TRAINER, 26564, A.TRAINER, 26952, A.TRAINER, 3557, A.TRAINER, 26904, A.TRAINER, 29924)

	-- The Shatterer -- 10003
	AddRecipe(10003, 235, 7954, R_COMMON, GAME_ORIG, 235, 260, 272, 285)
	self:addTradeFlags(RecipeDB, 10003, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.ONE_HAND, F.MACE)
	self:addTradeAcquire(RecipeDB, 10003, A.TRAINER, 7232, A.TRAINER, 11146, A.TRAINER, 11178, A.TRAINER, 20124, A.TRAINER, 29505)

	-- Dazzling Mithril Rapier -- 10005
	AddRecipe(10005, 240, 7944, R_UNCOMMON, GAME_ORIG, 240, 265, 277, 290)
	self:addTradeFlags(RecipeDB, 10005, F.ALLIANCE, F.HORDE, F.WORLD_DROP, F.IBOE, F.RBOE, F.DPS, F.ONE_HAND, F.SWORD)
	self:addTradeAcquire(RecipeDB, 10005, A.WORLD_DROP, 2)

	-- Phantom Blade -- 10007
	AddRecipe(10007, 245, 7961, R_COMMON, GAME_ORIG, 245, 270, 282, 295)
	self:addTradeFlags(RecipeDB, 10007, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.ONE_HAND, F.SWORD)
	self:addTradeAcquire(RecipeDB, 10007, A.TRAINER, 7232, A.TRAINER, 11146, A.TRAINER, 11178, A.TRAINER, 20124, A.TRAINER, 29505)

	-- Runed Mithril Hammer -- 10009
	AddRecipe(10009, 245, 7946, R_RARE, GAME_ORIG, 245, 270, 282, 295)
	self:addTradeFlags(RecipeDB, 10009, F.ALLIANCE, F.HORDE, F.INSTANCE, F.RAID, F.MOB_DROP, F.IBOE, F.RBOE, F.DPS, F.ONE_HAND, F.MACE)
	self:addTradeAcquire(RecipeDB, 10009, A.WORLD_DROP, 3, A.CUSTOM, 33)

	-- Blight -- 10011
	AddRecipe(10011, 250, 7959, R_COMMON, GAME_ORIG, 250, 275, 287, 300)
	self:addTradeFlags(RecipeDB, 10011, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.TWO_HAND, F.POLEARM)
	self:addTradeAcquire(RecipeDB, 10011, A.TRAINER, 7231, A.TRAINER, 7232, A.TRAINER, 11146, A.TRAINER, 11178, A.TRAINER, 20124, A.TRAINER, 29505)

	-- Ebon Shiv -- 10013
	AddRecipe(10013, 255, 7947, R_COMMON, GAME_ORIG, 255, 280, 292, 305)
	self:addTradeFlags(RecipeDB, 10013, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOP, F.DPS, F.ONE_HAND, F.DAGGER)
	self:addTradeAcquire(RecipeDB, 10013, A.VENDOR, 11278)

	-- Truesilver Champion -- 10015
	AddRecipe(10015, 260, 7960, R_COMMON, GAME_ORIG, 260, 285, 297, 310)
	self:addTradeFlags(RecipeDB, 10015, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.TWO_HAND, F.SWORD)
	self:addTradeAcquire(RecipeDB, 10015, A.TRAINER, 7231, A.TRAINER, 7232, A.TRAINER, 11146, A.TRAINER, 11178, A.TRAINER, 20124, A.TRAINER, 29505)

	-- Inlaid Mithril Cylinder -- 11454
	AddRecipe(11454, 200, 9060, R_COMMON, GAME_ORIG, 200, 225, 237, 250)
	self:addTradeFlags(RecipeDB, 11454, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOE)
	self:addTradeAcquire(RecipeDB, 11454, A.CUSTOM, 9)

	-- Golden Scale Gauntlets -- 11643
	AddRecipe(11643, 205, 9366, R_UNCOMMON, GAME_ORIG, 205, 225, 235, 245)
	self:addTradeFlags(RecipeDB, 11643, F.ALLIANCE, F.QUEST, F.IBOE, F.RBOE, F.DPS, F.MAIL)
	self:addTradeAcquire(RecipeDB, 11643, A.QUEST, 2758)

	-- Silvered Bronze Leggings -- 12259
	AddRecipe(12259, 155, 10423, R_UNCOMMON, GAME_ORIG, 155, 180, 192, 205)
	self:addTradeFlags(RecipeDB, 12259, F.ALLIANCE, F.HORDE, F.WORLD_DROP, F.IBOE, F.RBOE, F.DPS, F.MAIL)
	self:addTradeAcquire(RecipeDB, 12259, A.WORLD_DROP, 2)

	-- Rough Copper Vest -- 12260
	AddRecipe(12260, 1, 10421, R_COMMON, GAME_ORIG, 1, 15, 35, 55)
	self:addTradeFlags(RecipeDB, 12260, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.MAIL)
	self:addTradeAcquire(RecipeDB, 12260, A.CUSTOM, 8)

	-- Golden Rod -- 14379
	AddRecipe(14379, 150, 11128, R_COMMON, GAME_ORIG, 150, 155, 157, 160)
	self:addTradeFlags(RecipeDB, 14379, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP)
	self:addTradeAcquire(RecipeDB, 14379, A.TRAINER, 2836, A.TRAINER, 2998, A.TRAINER, 3136, A.TRAINER, 3355, A.TRAINER, 3478, A.TRAINER, 4258, A.TRAINER, 4596, A.TRAINER, 5511, A.TRAINER, 16583, A.TRAINER, 16669, A.TRAINER, 16724, A.TRAINER, 16823, A.TRAINER, 19341, A.TRAINER, 28694, A.TRAINER, 27034, A.TRAINER, 514, A.TRAINER, 1241, A.TRAINER, 33591, A.TRAINER, 3174, A.TRAINER, 26988, A.TRAINER, 33609, A.TRAINER, 33631, A.TRAINER, 15400, A.TRAINER, 33675, A.TRAINER, 26981, A.TRAINER, 17245, A.TRAINER, 6299, A.TRAINER, 26564, A.TRAINER, 26952, A.TRAINER, 3557, A.TRAINER, 26904, A.TRAINER, 29924)

	-- Truesilver Rod -- 14380
	AddRecipe(14380, 200, 11144, R_COMMON, GAME_ORIG, 200, 205, 207, 210)
	self:addTradeFlags(RecipeDB, 14380, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP)
	self:addTradeAcquire(RecipeDB, 14380, A.TRAINER, 2836, A.TRAINER, 3355, A.TRAINER, 4258, A.TRAINER, 16583, A.TRAINER, 16669, A.TRAINER, 16823, A.TRAINER, 19341, A.TRAINER, 28694, A.TRAINER, 27034, A.TRAINER, 5511, A.TRAINER, 514, A.TRAINER, 1241, A.TRAINER, 16724, A.TRAINER, 33591, A.TRAINER, 2998, A.TRAINER, 3478, A.TRAINER, 3136, A.TRAINER, 4596, A.TRAINER, 3174, A.TRAINER, 26988, A.TRAINER, 33609, A.TRAINER, 33631, A.TRAINER, 15400, A.TRAINER, 33675, A.TRAINER, 26981, A.TRAINER, 17245, A.TRAINER, 6299, A.TRAINER, 26564, A.TRAINER, 26952, A.TRAINER, 3557, A.TRAINER, 26904, A.TRAINER, 29924)

	-- Dark Iron Pulverizer -- 15292
	AddRecipe(15292, 265, 11608, R_RARE, GAME_ORIG, 265, 285, 295, 305)
	self:addTradeFlags(RecipeDB, 15292, F.ALLIANCE, F.HORDE, F.INSTANCE, F.MOB_DROP, F.IBOE, F.RBOE, F.TWO_HAND, F.MACE)
	self:addTradeAcquire(RecipeDB, 15292, A.MOB, 9028)

	-- Dark Iron Mail -- 15293
	AddRecipe(15293, 270, 11606, R_UNCOMMON, GAME_ORIG, 270, 290, 300, 310)
	self:addTradeFlags(RecipeDB, 15293, F.ALLIANCE, F.HORDE, F.INSTANCE, F.IBOE, F.RBOP, F.MAIL)
	self:addTradeAcquire(RecipeDB, 15293, A.CUSTOM, 25)

	-- Dark Iron Sunderer -- 15294
	AddRecipe(15294, 275, 11607, R_RARE, GAME_ORIG, 275, 295, 305, 315)
	self:addTradeFlags(RecipeDB, 15294, F.ALLIANCE, F.HORDE, F.INSTANCE, F.IBOE, F.RBOE, F.TWO_HAND, F.AXE)
	self:addTradeAcquire(RecipeDB, 15294, A.MOB, 9554, A.MOB, 10043)

	-- Dark Iron Shoulders -- 15295
	AddRecipe(15295, 280, 11605, R_UNCOMMON, GAME_ORIG, 280, 300, 310, 320)
	self:addTradeFlags(RecipeDB, 15295, F.ALLIANCE, F.HORDE, F.INSTANCE, F.IBOE, F.RBOP, F.PLATE)
	self:addTradeAcquire(RecipeDB, 15295, A.CUSTOM, 25)

	-- Dark Iron Plate -- 15296
	AddRecipe(15296, 285, 11604, R_RARE, GAME_ORIG, 285, 305, 315, 325)
	self:addTradeFlags(RecipeDB, 15296, F.ALLIANCE, F.HORDE, F.INSTANCE, F.IBOP, F.RBOP, F.PLATE)
	self:addTradeAcquire(RecipeDB, 15296, A.MOB, 9543)

	-- Glinting Steel Dagger -- 15972
	AddRecipe(15972, 180, 12259, R_COMMON, GAME_ORIG, 180, 205, 217, 230)
	self:addTradeFlags(RecipeDB, 15972, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.DPS, F.ONE_HAND, F.DAGGER)
	self:addTradeAcquire(RecipeDB, 15972, A.TRAINER, 2836, A.TRAINER, 3355, A.TRAINER, 4258, A.TRAINER, 16583, A.TRAINER, 16669, A.TRAINER, 16823, A.TRAINER, 19341, A.TRAINER, 28694, A.TRAINER, 27034, A.TRAINER, 5511, A.TRAINER, 514, A.TRAINER, 1241, A.TRAINER, 16724, A.TRAINER, 33591, A.TRAINER, 2998, A.TRAINER, 3478, A.TRAINER, 3136, A.TRAINER, 4596, A.TRAINER, 3174, A.TRAINER, 26988, A.TRAINER, 33609, A.TRAINER, 33631, A.TRAINER, 15400, A.TRAINER, 33675, A.TRAINER, 26981, A.TRAINER, 17245, A.TRAINER, 6299, A.TRAINER, 26564, A.TRAINER, 26952, A.TRAINER, 3557, A.TRAINER, 26904, A.TRAINER, 29924)

	-- Searing Golden Blade -- 15973
	AddRecipe(15973, 190, 12260, R_UNCOMMON, GAME_ORIG, 190, 215, 227, 240)
	self:addTradeFlags(RecipeDB, 15973, F.ALLIANCE, F.HORDE, F.WORLD_DROP, F.IBOE, F.RBOE, F.HEALER, F.CASTER, F.ONE_HAND, F.DAGGER)
	self:addTradeAcquire(RecipeDB, 15973, A.WORLD_DROP, 2)

	-- Dense Grinding Stone -- 16639
	AddRecipe(16639, 250, 12644, R_COMMON, GAME_ORIG, 250, 255, 257, 260)
	self:addTradeFlags(RecipeDB, 16639, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP)
	self:addTradeAcquire(RecipeDB, 16639, A.TRAINER, 2836, A.TRAINER, 16583, A.TRAINER, 16823, A.TRAINER, 19341, A.TRAINER, 28694, A.TRAINER, 27034, A.TRAINER, 4258, A.TRAINER, 5511, A.TRAINER, 514, A.TRAINER, 1241, A.TRAINER, 16724, A.TRAINER, 3355, A.TRAINER, 33591, A.TRAINER, 2998, A.TRAINER, 3478, A.TRAINER, 3136, A.TRAINER, 4596, A.TRAINER, 3174, A.TRAINER, 26988, A.TRAINER, 33609, A.TRAINER, 33631, A.TRAINER, 15400, A.TRAINER, 33675, A.TRAINER, 26981, A.TRAINER, 17245, A.TRAINER, 6299, A.TRAINER, 26564, A.TRAINER, 26952, A.TRAINER, 3557, A.TRAINER, 26904, A.TRAINER, 29924)

	-- Dense Weightstone -- 16640
	AddRecipe(16640, 250, 12643, R_COMMON, GAME_ORIG, 250, 255, 257, 260)
	self:addTradeFlags(RecipeDB, 16640, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP)
	self:addTradeAcquire(RecipeDB, 16640, A.TRAINER, 2836, A.TRAINER, 16583, A.TRAINER, 16823, A.TRAINER, 19341, A.TRAINER, 28694, A.TRAINER, 27034, A.TRAINER, 4258, A.TRAINER, 5511, A.TRAINER, 514, A.TRAINER, 1241, A.TRAINER, 16724, A.TRAINER, 3355, A.TRAINER, 33591, A.TRAINER, 2998, A.TRAINER, 3478, A.TRAINER, 3136, A.TRAINER, 4596, A.TRAINER, 3174, A.TRAINER, 26988, A.TRAINER, 33609, A.TRAINER, 33631, A.TRAINER, 15400, A.TRAINER, 33675, A.TRAINER, 26981, A.TRAINER, 17245, A.TRAINER, 6299, A.TRAINER, 26952, A.TRAINER, 3557, A.TRAINER, 26904, A.TRAINER, 29924)

	-- Dense Sharpening Stone -- 16641
	AddRecipe(16641, 250, 12404, R_COMMON, GAME_ORIG, 250, 255, 257, 260)
	self:addTradeFlags(RecipeDB, 16641, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.DPS)
	self:addTradeAcquire(RecipeDB, 16641, A.TRAINER, 2836, A.TRAINER, 16583, A.TRAINER, 16823, A.TRAINER, 19341, A.TRAINER, 28694, A.TRAINER, 27034, A.TRAINER, 4258, A.TRAINER, 5511, A.TRAINER, 514, A.TRAINER, 1241, A.TRAINER, 16724, A.TRAINER, 3355, A.TRAINER, 33591, A.TRAINER, 2998, A.TRAINER, 3478, A.TRAINER, 3136, A.TRAINER, 4596, A.TRAINER, 3174, A.TRAINER, 26988, A.TRAINER, 33609, A.TRAINER, 33631, A.TRAINER, 15400, A.TRAINER, 33675, A.TRAINER, 26981, A.TRAINER, 17245, A.TRAINER, 6299, A.TRAINER, 26952, A.TRAINER, 3557, A.TRAINER, 26904, A.TRAINER, 29924)

	-- Thorium Armor -- 16642
	AddRecipe(16642, 250, 12405, R_UNCOMMON, GAME_ORIG, 250, 270, 280, 290)
	self:addTradeFlags(RecipeDB, 16642, F.ALLIANCE, F.HORDE, F.TRAINER, F.WORLD_DROP, F.IBOE, F.RBOE, F.DPS, F.PLATE)
	self:addTradeAcquire(RecipeDB, 16642, A.WORLD_DROP, 2, A.TRAINER, 4258, A.TRAINER, 5511, A.TRAINER, 514, A.TRAINER, 1241, A.TRAINER, 16724, A.TRAINER, 3355, A.TRAINER, 2836, A.TRAINER, 2998, A.TRAINER, 3478, A.TRAINER, 3136, A.TRAINER, 4596, A.TRAINER, 3174, A.TRAINER, 33609, A.TRAINER, 33631, A.TRAINER, 16823, A.TRAINER, 15400, A.TRAINER, 33675, A.TRAINER, 17245, A.TRAINER, 6299, A.TRAINER, 3557)

	-- Thorium Belt -- 16643
	AddRecipe(16643, 250, 12406, R_UNCOMMON, GAME_ORIG, 250, 270, 280, 290)
	self:addTradeFlags(RecipeDB, 16643, F.ALLIANCE, F.HORDE, F.TRAINER, F.WORLD_DROP, F.IBOE, F.RBOE, F.DPS, F.PLATE)
	self:addTradeAcquire(RecipeDB, 16643, A.WORLD_DROP, 2, A.TRAINER, 4258, A.TRAINER, 5511, A.TRAINER, 514, A.TRAINER, 1241, A.TRAINER, 16724, A.TRAINER, 3355, A.TRAINER, 2836, A.TRAINER, 2998, A.TRAINER, 3478, A.TRAINER, 3136, A.TRAINER, 4596, A.TRAINER, 3174, A.TRAINER, 33609, A.TRAINER, 33631, A.TRAINER, 16823, A.TRAINER, 15400, A.TRAINER, 33675, A.TRAINER, 17245, A.TRAINER, 6299, A.TRAINER, 3557)

	-- Thorium Bracers -- 16644
	AddRecipe(16644, 255, 12408, R_UNCOMMON, GAME_ORIG, 255, 275, 285, 295)
	self:addTradeFlags(RecipeDB, 16644, F.ALLIANCE, F.HORDE, F.TRAINER, F.WORLD_DROP, F.IBOE, F.RBOE, F.DPS, F.PLATE)
	self:addTradeAcquire(RecipeDB, 16644, A.WORLD_DROP, 2, A.TRAINER, 4258, A.TRAINER, 5511, A.TRAINER, 514, A.TRAINER, 1241, A.TRAINER, 16724, A.TRAINER, 3355, A.TRAINER, 2836, A.TRAINER, 2998, A.TRAINER, 3478, A.TRAINER, 3136, A.TRAINER, 4596, A.TRAINER, 3174, A.TRAINER, 33609, A.TRAINER, 33631, A.TRAINER, 16823, A.TRAINER, 15400, A.TRAINER, 33675, A.TRAINER, 17245, A.TRAINER, 6299, A.TRAINER, 3557)

	-- Radiant Belt -- 16645
	AddRecipe(16645, 260, 12416, R_UNCOMMON, GAME_ORIG, 260, 280, 290, 300)
	self:addTradeFlags(RecipeDB, 16645, F.ALLIANCE, F.HORDE, F.RAID, F.MOB_DROP, F.IBOE, F.RBOE, F.MAIL)
	self:addTradeAcquire(RecipeDB, 16645, A.WORLD_DROP, 2, A.CUSTOM, 33)

	-- Imperial Plate Shoulders -- 16646
	AddRecipe(16646, 265, 12428, R_UNCOMMON, GAME_ORIG, 265, 285, 295, 305)
	self:addTradeFlags(RecipeDB, 16646, F.ALLIANCE, F.HORDE, F.QUEST, F.IBOE, F.RBOP, F.DPS, F.PLATE)
	self:addTradeAcquire(RecipeDB, 16646, A.QUEST, 7659)

	-- Imperial Plate Belt -- 16647
	AddRecipe(16647, 265, 12424, R_UNCOMMON, GAME_ORIG, 265, 285, 295, 305)
	self:addTradeFlags(RecipeDB, 16647, F.ALLIANCE, F.HORDE, F.QUEST, F.IBOE, F.RBOP, F.DPS, F.PLATE)
	self:addTradeAcquire(RecipeDB, 16647, A.QUEST, 7653)

	-- Radiant Breastplate -- 16648
	AddRecipe(16648, 270, 12415, R_UNCOMMON, GAME_ORIG, 270, 290, 300, 310)
	self:addTradeFlags(RecipeDB, 16648, F.ALLIANCE, F.HORDE, F.WORLD_DROP, F.IBOE, F.RBOE, F.MAIL)
	self:addTradeAcquire(RecipeDB, 16648, A.WORLD_DROP, 2)

	-- Imperial Plate Bracers -- 16649
	AddRecipe(16649, 270, 12425, R_UNCOMMON, GAME_ORIG, 270, 290, 300, 310)
	self:addTradeFlags(RecipeDB, 16649, F.ALLIANCE, F.HORDE, F.QUEST, F.IBOE, F.RBOP, F.DPS, F.PLATE)
	self:addTradeAcquire(RecipeDB, 16649, A.QUEST, 7655)

	-- Wildthorn Mail -- 16650
	AddRecipe(16650, 270, 12624, R_UNCOMMON, GAME_ORIG, 270, 290, 300, 310)
	self:addTradeFlags(RecipeDB, 16650, F.ALLIANCE, F.HORDE, F.WORLD_DROP, F.IBOE, F.RBOE, F.HEALER, F.CASTER, F.MAIL)
	self:addTradeAcquire(RecipeDB, 16650, A.WORLD_DROP, 2)

	-- Thorium Shield Spike -- 16651
	AddRecipe(16651, 275, 12645, R_UNCOMMON, GAME_ORIG, 275, 295, 305, 315)
	self:addTradeFlags(RecipeDB, 16651, F.ALLIANCE, F.HORDE, F.RAID, F.MOB_DROP, F.IBOE, F.RBOE, F.TANK)
	self:addTradeAcquire(RecipeDB, 16651, A.WORLD_DROP, 2, A.CUSTOM, 33)

	-- Thorium Boots -- 16652
	AddRecipe(16652, 280, 12409, R_UNCOMMON, GAME_ORIG, 280, 300, 310, 320)
	self:addTradeFlags(RecipeDB, 16652, F.ALLIANCE, F.HORDE, F.TRAINER, F.WORLD_DROP, F.IBOE, F.RBOE, F.DPS, F.PLATE)
	self:addTradeAcquire(RecipeDB, 16652, A.WORLD_DROP, 2, A.TRAINER, 4258, A.TRAINER, 5511, A.TRAINER, 514, A.TRAINER, 1241, A.TRAINER, 16724, A.TRAINER, 3355, A.TRAINER, 2836, A.TRAINER, 2998, A.TRAINER, 3478, A.TRAINER, 3136, A.TRAINER, 4596, A.TRAINER, 3174, A.TRAINER, 33609, A.TRAINER, 33631, A.TRAINER, 16823, A.TRAINER, 15400, A.TRAINER, 33675, A.TRAINER, 17245, A.TRAINER, 6299, A.TRAINER, 3557)

	-- Thorium Helm -- 16653
	AddRecipe(16653, 280, 12410, R_UNCOMMON, GAME_ORIG, 280, 300, 310, 320)
	self:addTradeFlags(RecipeDB, 16653, F.ALLIANCE, F.HORDE, F.TRAINER, F.WORLD_DROP, F.IBOE, F.RBOE, F.DPS, F.PLATE)
	self:addTradeAcquire(RecipeDB, 16653, A.WORLD_DROP, 2, A.TRAINER, 4258, A.TRAINER, 5511, A.TRAINER, 514, A.TRAINER, 1241, A.TRAINER, 16724, A.TRAINER, 3355, A.TRAINER, 2836, A.TRAINER, 2998, A.TRAINER, 3478, A.TRAINER, 3136, A.TRAINER, 4596, A.TRAINER, 3174, A.TRAINER, 33609, A.TRAINER, 33631, A.TRAINER, 16823, A.TRAINER, 15400, A.TRAINER, 33675, A.TRAINER, 17245, A.TRAINER, 6299, A.TRAINER, 3557)

	-- Radiant Gloves -- 16654
	AddRecipe(16654, 285, 12418, R_UNCOMMON, GAME_ORIG, 285, 305, 315, 325)
	self:addTradeFlags(RecipeDB, 16654, F.ALLIANCE, F.HORDE, F.WORLD_DROP, F.IBOE, F.RBOE, F.DPS, F.MAIL)
	self:addTradeAcquire(RecipeDB, 16654, A.WORLD_DROP, 2)

	-- Fiery Plate Gauntlets -- 16655
	AddRecipe(16655, 290, 12631, R_RARE, GAME_ORIG, 290, 310, 320, 330)
	self:addTradeFlags(RecipeDB, 16655, F.ALLIANCE, F.HORDE, F.QUEST, F.IBOE, F.RBOP, F.PLATE)
	self:addTradeAcquire(RecipeDB, 16655, A.QUEST, 5124)

	-- Radiant Boots -- 16656
	AddRecipe(16656, 290, 12419, R_UNCOMMON, GAME_ORIG, 290, 310, 320, 330)
	self:addTradeFlags(RecipeDB, 16656, F.ALLIANCE, F.HORDE, F.WORLD_DROP, F.IBOE, F.RBOE, F.DPS, F.MAIL)
	self:addTradeAcquire(RecipeDB, 16656, A.WORLD_DROP, 2)

	-- Imperial Plate Boots -- 16657
	AddRecipe(16657, 295, 12426, R_UNCOMMON, GAME_ORIG, 295, 315, 325, 335)
	self:addTradeFlags(RecipeDB, 16657, F.ALLIANCE, F.HORDE, F.QUEST, F.IBOE, F.RBOP, F.DPS, F.PLATE)
	self:addTradeAcquire(RecipeDB, 16657, A.QUEST, 7654)

	-- Imperial Plate Helm -- 16658
	AddRecipe(16658, 295, 12427, R_UNCOMMON, GAME_ORIG, 295, 315, 325, 335)
	self:addTradeFlags(RecipeDB, 16658, F.ALLIANCE, F.HORDE, F.QUEST, F.IBOE, F.RBOP, F.DPS, F.PLATE)
	self:addTradeAcquire(RecipeDB, 16658, A.QUEST, 7657)

	-- Radiant Circlet -- 16659
	AddRecipe(16659, 295, 12417, R_UNCOMMON, GAME_ORIG, 295, 315, 325, 335)
	self:addTradeFlags(RecipeDB, 16659, F.ALLIANCE, F.HORDE, F.RAID, F.MOB_DROP, F.IBOE, F.RBOE, F.DPS, F.MAIL)
	self:addTradeAcquire(RecipeDB, 16659, A.WORLD_DROP, 2)

	-- Dawnbringer Shoulders -- 16660
	AddRecipe(16660, 290, 12625, R_RARE, GAME_ORIG, 290, 310, 320, 330)
	self:addTradeFlags(RecipeDB, 16660, F.ALLIANCE, F.HORDE, F.RAID, F.MOB_DROP, F.IBOE, F.RBOE, F.HEALER, F.CASTER, F.PLATE)
	self:addTradeAcquire(RecipeDB, 16660, A.WORLD_DROP, 2)

	-- Storm Gauntlets -- 16661
	AddRecipe(16661, 295, 12632, R_RARE, GAME_ORIG, 295, 315, 325, 335)
	self:addTradeFlags(RecipeDB, 16661, F.ALLIANCE, F.HORDE, F.VENDOR, F.INSTANCE, F.RAID, F.MOB_DROP, F.IBOE, F.RBOE, F.HEALER, F.CASTER, F.MAIL)
	self:addTradeAcquire(RecipeDB, 16661, A.WORLD_DROP, 2, A.VENDOR, 11278)

	-- Thorium Leggings -- 16662
	AddRecipe(16662, 300, 12414, R_UNCOMMON, GAME_ORIG, 300, 320, 330, 340)
	self:addTradeFlags(RecipeDB, 16662, F.ALLIANCE, F.HORDE, F.TRAINER, F.WORLD_DROP, F.IBOE, F.RBOE, F.DPS, F.PLATE)
	self:addTradeAcquire(RecipeDB, 16662, A.WORLD_DROP, 2, A.TRAINER, 4258, A.TRAINER, 5511, A.TRAINER, 514, A.TRAINER, 1241, A.TRAINER, 16724, A.TRAINER, 3355, A.TRAINER, 2836, A.TRAINER, 2998, A.TRAINER, 3478, A.TRAINER, 3136, A.TRAINER, 4596, A.TRAINER, 33609, A.TRAINER, 33631, A.TRAINER, 3174, A.TRAINER, 16823, A.TRAINER, 15400, A.TRAINER, 33675, A.TRAINER, 17245, A.TRAINER, 6299, A.TRAINER, 3557)

	-- Imperial Plate Chest -- 16663
	AddRecipe(16663, 300, 12422, R_UNCOMMON, GAME_ORIG, 300, 320, 330, 340)
	self:addTradeFlags(RecipeDB, 16663, F.ALLIANCE, F.HORDE, F.QUEST, F.IBOE, F.RBOP, F.DPS, F.PLATE)
	self:addTradeAcquire(RecipeDB, 16663, A.QUEST, 7656)

	-- Runic Plate Shoulders -- 16664
	AddRecipe(16664, 300, 12610, R_UNCOMMON, GAME_ORIG, 300, 320, 330, 340)
	self:addTradeFlags(RecipeDB, 16664, F.ALLIANCE, F.HORDE, F.MOB_DROP, F.IBOE, F.RBOP, F.PLATE)
	self:addTradeAcquire(RecipeDB, 16664, A.MOB, 4366)

	-- Runic Plate Boots -- 16665
	AddRecipe(16665, 300, 12611, R_UNCOMMON, GAME_ORIG, 300, 320, 330, 340)
	self:addTradeFlags(RecipeDB, 16665, F.ALLIANCE, F.HORDE, F.MOB_DROP, F.IBOE, F.RBOP, F.PLATE)
	self:addTradeAcquire(RecipeDB, 16665, A.MOB, 1836)

	-- Demon Forged Breastplate -- 16667
	AddRecipe(16667, 285, 12628, R_RARE, GAME_ORIG, 285, 305, 315, 325)
	self:addTradeFlags(RecipeDB, 16667, F.ALLIANCE, F.HORDE, F.QUEST, F.IBOE, F.RBOP, F.PLATE)
	self:addTradeAcquire(RecipeDB, 16667, A.QUEST, 5127)

	-- Whitesoul Helm -- 16724
	AddRecipe(16724, 300, 12633, R_RARE, GAME_ORIG, 300, 320, 330, 340)
	self:addTradeFlags(RecipeDB, 16724, F.ALLIANCE, F.HORDE, F.INSTANCE, F.RAID, F.MOB_DROP, F.IBOE, F.RBOE, F.HEALER, F.CASTER, F.PLATE)
	self:addTradeAcquire(RecipeDB, 16724, A.WORLD_DROP, 2)

	-- Radiant Leggings -- 16725
	AddRecipe(16725, 300, 12420, R_UNCOMMON, GAME_ORIG, 300, 320, 330, 340)
	self:addTradeFlags(RecipeDB, 16725, F.ALLIANCE, F.HORDE, F.WORLD_DROP, F.IBOE, F.RBOE, F.DPS, F.MAIL)
	self:addTradeAcquire(RecipeDB, 16725, A.WORLD_DROP, 2)

	-- Runic Plate Helm -- 16726
	AddRecipe(16726, 300, 12612, R_UNCOMMON, GAME_ORIG, 300, 320, 330, 340)
	self:addTradeFlags(RecipeDB, 16726, F.ALLIANCE, F.HORDE, F.MOB_DROP, F.IBOE, F.RBOP, F.PLATE)
	self:addTradeAcquire(RecipeDB, 16726, A.MOB, 4364)

	-- Helm of the Great Chief -- 16728
	AddRecipe(16728, 300, 12636, R_RARE, GAME_ORIG, 300, 320, 330, 340)
	self:addTradeFlags(RecipeDB, 16728, F.ALLIANCE, F.HORDE, F.INSTANCE, F.RAID, F.MOB_DROP, F.IBOE, F.RBOE, F.HEALER, F.CASTER, F.MAIL)
	self:addTradeAcquire(RecipeDB, 16728, A.WORLD_DROP, 2)

	-- Lionheart Helm -- 16729
	AddRecipe(16729, 300, 12640, R_EPIC, GAME_ORIG, 300, 320, 330, 340)
	self:addTradeFlags(RecipeDB, 16729, F.ALLIANCE, F.HORDE, F.RAID, F.MOB_DROP, F.IBOE, F.RBOE, F.DPS, F.PLATE)
	self:addTradeAcquire(RecipeDB, 16729, A.WORLD_DROP, 2)

	-- Imperial Plate Leggings -- 16730
	AddRecipe(16730, 300, 12429, R_UNCOMMON, GAME_ORIG, 300, 320, 330, 340)
	self:addTradeFlags(RecipeDB, 16730, F.ALLIANCE, F.HORDE, F.QUEST, F.IBOE, F.RBOP, F.DPS, F.PLATE)
	self:addTradeAcquire(RecipeDB, 16730, A.QUEST, 7658)

	-- Runic Breastplate -- 16731
	AddRecipe(16731, 300, 12613, R_UNCOMMON, GAME_ORIG, 300, 320, 330, 340)
	self:addTradeFlags(RecipeDB, 16731, F.ALLIANCE, F.HORDE, F.MOB_DROP, F.IBOE, F.RBOP, F.PLATE)
	self:addTradeAcquire(RecipeDB, 16731, A.MOB, 4368, A.MOB, 16072)

	-- Runic Plate Leggings -- 16732
	AddRecipe(16732, 300, 12614, R_UNCOMMON, GAME_ORIG, 300, 320, 330, 340)
	self:addTradeFlags(RecipeDB, 16732, F.ALLIANCE, F.HORDE, F.MOB_DROP, F.IBOE, F.RBOP, F.PLATE)
	self:addTradeAcquire(RecipeDB, 16732, A.MOB, 1885)

	-- Stronghold Gauntlets -- 16741
	AddRecipe(16741, 300, 12639, R_EPIC, GAME_ORIG, 300, 320, 330, 340)
	self:addTradeFlags(RecipeDB, 16741, F.ALLIANCE, F.HORDE, F.RAID, F.MOB_DROP, F.IBOE, F.RBOE, F.TANK, F.PLATE)
	self:addTradeAcquire(RecipeDB, 16741, A.WORLD_DROP, 2)

	-- Enchanted Thorium Helm -- 16742
	AddRecipe(16742, 300, 12620, R_RARE, GAME_ORIG, 300, 320, 330, 340)
	self:addTradeFlags(RecipeDB, 16742, F.ALLIANCE, F.HORDE, F.QUEST, F.IBOE, F.RBOP, F.TANK, F.PLATE)
	self:addTradeAcquire(RecipeDB, 16742, A.QUEST, 7651)

	-- Enchanted Thorium Leggings -- 16744
	AddRecipe(16744, 300, 12619, R_RARE, GAME_ORIG, 300, 320, 330, 340)
	self:addTradeFlags(RecipeDB, 16744, F.ALLIANCE, F.HORDE, F.QUEST, F.IBOE, F.RBOP, F.TANK, F.PLATE)
	self:addTradeAcquire(RecipeDB, 16744, A.QUEST, 7650)

	-- Enchanted Thorium Breastplate -- 16745
	AddRecipe(16745, 300, 12618, R_RARE, GAME_ORIG, 300, 320, 330, 340)
	self:addTradeFlags(RecipeDB, 16745, F.ALLIANCE, F.HORDE, F.QUEST, F.IBOE, F.RBOP, F.TANK, F.PLATE)
	self:addTradeAcquire(RecipeDB, 16745, A.QUEST, 7649)

	-- Invulnerable Mail -- 16746
	AddRecipe(16746, 300, 12641, R_EPIC, GAME_ORIG, 300, 320, 330, 340)
	self:addTradeFlags(RecipeDB, 16746, F.ALLIANCE, F.HORDE, F.INSTANCE, F.RAID, F.MOB_DROP, F.IBOE, F.RBOE, F.TANK, F.MAIL)
	self:addTradeAcquire(RecipeDB, 16746, A.WORLD_DROP, 2)

	-- Ornate Thorium Handaxe -- 16969
	AddRecipe(16969, 275, 12773, R_UNCOMMON, GAME_ORIG, 275, 300, 312, 325)
	self:addTradeFlags(RecipeDB, 16969, F.ALLIANCE, F.HORDE, F.TRAINER, F.VENDOR, F.IBOP, F.RBOP, F.DPS, F.ONE_HAND, F.AXE)
	self:addTradeAcquire(RecipeDB, 16969, A.VENDOR, 11278, A.TRAINER, 4258, A.TRAINER, 5511, A.TRAINER, 514, A.TRAINER, 1241, A.TRAINER, 16724, A.TRAINER, 3355, A.TRAINER, 2836, A.TRAINER, 2998, A.TRAINER, 3478, A.TRAINER, 3136, A.TRAINER, 4596, A.TRAINER, 3174, A.TRAINER, 33609, A.TRAINER, 33631, A.TRAINER, 16823, A.TRAINER, 15400, A.TRAINER, 33675, A.TRAINER, 17245, A.TRAINER, 6299, A.TRAINER, 3557)

	-- Dawn's Edge -- 16970
	AddRecipe(16970, 275, 12774, R_RARE, GAME_ORIG, 275, 300, 312, 325)
	self:addTradeFlags(RecipeDB, 16970, F.ALLIANCE, F.HORDE, F.QUEST, F.IBOE, F.RBOE, F.ONE_HAND, F.AXE)
	self:addTradeAcquire(RecipeDB, 16970, A.QUEST, 5306)

	-- Huge Thorium Battleaxe -- 16971
	AddRecipe(16971, 280, 12775, R_COMMON, GAME_ORIG, 280, 305, 317, 330)
	self:addTradeFlags(RecipeDB, 16971, F.ALLIANCE, F.HORDE, F.TRAINER, F.VENDOR, F.IBOE, F.RBOP, F.DPS, F.TWO_HAND, F.AXE)
	self:addTradeAcquire(RecipeDB, 16971, A.VENDOR, 11278, A.TRAINER, 4258, A.TRAINER, 5511, A.TRAINER, 514, A.TRAINER, 1241, A.TRAINER, 16724, A.TRAINER, 3355, A.TRAINER, 2836, A.TRAINER, 2998, A.TRAINER, 3478, A.TRAINER, 3136, A.TRAINER, 4596, A.TRAINER, 3174, A.TRAINER, 33609, A.TRAINER, 33631, A.TRAINER, 16823, A.TRAINER, 15400, A.TRAINER, 33675, A.TRAINER, 17245, A.TRAINER, 6299, A.TRAINER, 3557)

	-- Enchanted Battlehammer -- 16973
	AddRecipe(16973, 280, 12776, R_UNCOMMON, GAME_ORIG, 280, 305, 317, 330)
	self:addTradeFlags(RecipeDB, 16973, F.ALLIANCE, F.HORDE, F.QUEST, F.IBOE, F.RBOE, F.TANK, F.TWO_HAND, F.MACE)
	self:addTradeAcquire(RecipeDB, 16973, A.QUEST, 5305)

	-- Blazing Rapier -- 16978
	AddRecipe(16978, 280, 12777, R_UNCOMMON, GAME_ORIG, 280, 305, 317, 330)
	self:addTradeFlags(RecipeDB, 16978, F.ALLIANCE, F.HORDE, F.QUEST, F.IBOE, F.RBOE, F.ONE_HAND, F.SWORD)
	self:addTradeAcquire(RecipeDB, 16978, A.QUEST, 5307)

	-- Serenity -- 16983
	AddRecipe(16983, 285, 12781, R_UNCOMMON, GAME_ORIG, 285, 310, 322, 335)
	self:addTradeFlags(RecipeDB, 16983, F.ALLIANCE, F.HORDE, F.INSTANCE, F.IBOE, F.RBOE, F.ONE_HAND, F.MACE)
	self:addTradeAcquire(RecipeDB, 16983, A.CUSTOM, 31)

	-- Volcanic Hammer -- 16984
	AddRecipe(16984, 290, 12792, R_UNCOMMON, GAME_ORIG, 290, 315, 327, 340)
	self:addTradeFlags(RecipeDB, 16984, F.ALLIANCE, F.HORDE, F.MOB_DROP, F.IBOE, F.RBOE, F.ONE_HAND, F.MACE)
	self:addTradeAcquire(RecipeDB, 16984, A.MOB, 10119)

	-- Corruption -- 16985
	AddRecipe(16985, 290, 12782, R_COMMON, GAME_ORIG, 290, 315, 327, 340)
	self:addTradeFlags(RecipeDB, 16985, F.ALLIANCE, F.HORDE, F.INSTANCE, F.IBOP, F.RBOP, F.HEALER, F.CASTER, F.TWO_HAND, F.SWORD)
	self:addTradeAcquire(RecipeDB, 16985, A.CUSTOM, 31)

	-- Hammer of the Titans -- 16988
	AddRecipe(16988, 300, 12796, R_RARE, GAME_ORIG, 300, 320, 330, 340)
	self:addTradeFlags(RecipeDB, 16988, F.ALLIANCE, F.HORDE, F.INSTANCE, F.IBOE, F.RBOE, F.DPS, F.TWO_HAND, F.MACE)
	self:addTradeAcquire(RecipeDB, 16988, A.MOB, 10438)

	-- Arcanite Champion -- 16990
	AddRecipe(16990, 300, 12790, R_RARE, GAME_ORIG, 300, 320, 330, 340)
	self:addTradeFlags(RecipeDB, 16990, F.ALLIANCE, F.HORDE, F.INSTANCE, F.IBOE, F.RBOE, F.DPS, F.TWO_HAND, F.SWORD)
	self:addTradeAcquire(RecipeDB, 16990, A.MOB, 10899)

	-- Annihilator -- 16991
	AddRecipe(16991, 300, 12798, R_RARE, GAME_ORIG, 300, 320, 330, 340)
	self:addTradeFlags(RecipeDB, 16991, F.ALLIANCE, F.HORDE, F.INSTANCE, F.IBOE, F.RBOE, F.ONE_HAND, F.AXE)
	self:addTradeAcquire(RecipeDB, 16991, A.MOB, 9736)

	-- Frostguard -- 16992
	AddRecipe(16992, 300, 12797, R_RARE, GAME_ORIG, 300, 320, 330, 340)
	self:addTradeFlags(RecipeDB, 16992, F.ALLIANCE, F.HORDE, F.MOB_DROP, F.IBOE, F.RBOE, F.ONE_HAND, F.SWORD)
	self:addTradeAcquire(RecipeDB, 16992, A.MOB, 1844)

	-- Masterwork Stormhammer -- 16993
	AddRecipe(16993, 300, 12794, R_RARE, GAME_ORIG, 300, 320, 330, 340)
	self:addTradeFlags(RecipeDB, 16993, F.ALLIANCE, F.HORDE, F.INSTANCE, F.IBOE, F.RBOE, F.ONE_HAND, F.MACE)
	self:addTradeAcquire(RecipeDB, 16993, A.MOB, 10899)

	-- Arcanite Reaper -- 16994
	AddRecipe(16994, 300, 12784, R_RARE, GAME_ORIG, 300, 320, 330, 340)
	self:addTradeFlags(RecipeDB, 16994, F.ALLIANCE, F.HORDE, F.INSTANCE, F.IBOE, F.RBOE, F.DPS, F.TWO_HAND, F.AXE)
	self:addTradeAcquire(RecipeDB, 16994, A.MOB, 9596)

	-- Heartseeker -- 16995
	AddRecipe(16995, 300, 12783, R_RARE, GAME_ORIG, 300, 320, 330, 340)
	self:addTradeFlags(RecipeDB, 16995, F.ALLIANCE, F.HORDE, F.INSTANCE, F.IBOE, F.RBOE, F.DPS, F.ONE_HAND, F.DAGGER)
	self:addTradeAcquire(RecipeDB, 16995, A.MOB, 10997)

	-- Silver Skeleton Key -- 19666
	AddRecipe(19666, 100, 15869, R_COMMON, GAME_ORIG, 100, 100, 110, 120)
	self:addTradeFlags(RecipeDB, 19666, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP)
	self:addTradeAcquire(RecipeDB, 19666, A.TRAINER, 2836, A.TRAINER, 2998, A.TRAINER, 3136, A.TRAINER, 3355, A.TRAINER, 3478, A.TRAINER, 4258, A.TRAINER, 4596, A.TRAINER, 5511, A.TRAINER, 16583, A.TRAINER, 16669, A.TRAINER, 16724, A.TRAINER, 16823, A.TRAINER, 19341, A.TRAINER, 28694, A.TRAINER, 27034, A.TRAINER, 514, A.TRAINER, 1241, A.TRAINER, 33591, A.TRAINER, 3174, A.TRAINER, 26988, A.TRAINER, 33609, A.TRAINER, 33631, A.TRAINER, 15400, A.TRAINER, 33675, A.TRAINER, 26981, A.TRAINER, 17245, A.TRAINER, 6299, A.TRAINER, 26564, A.TRAINER, 26952, A.TRAINER, 3557, A.TRAINER, 26904, A.TRAINER, 29924)

	-- Golden Skeleton Key -- 19667
	AddRecipe(19667, 150, 15870, R_COMMON, GAME_ORIG, 150, 150, 160, 170)
	self:addTradeFlags(RecipeDB, 19667, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP)
	self:addTradeAcquire(RecipeDB, 19667, A.TRAINER, 2836, A.TRAINER, 2998, A.TRAINER, 3136, A.TRAINER, 3355, A.TRAINER, 3478, A.TRAINER, 4258, A.TRAINER, 4596, A.TRAINER, 5511, A.TRAINER, 16583, A.TRAINER, 16669, A.TRAINER, 16724, A.TRAINER, 16823, A.TRAINER, 19341, A.TRAINER, 28694, A.TRAINER, 27034, A.TRAINER, 514, A.TRAINER, 1241, A.TRAINER, 33591, A.TRAINER, 3174, A.TRAINER, 26988, A.TRAINER, 33609, A.TRAINER, 33631, A.TRAINER, 15400, A.TRAINER, 33675, A.TRAINER, 26981, A.TRAINER, 17245, A.TRAINER, 6299, A.TRAINER, 26564, A.TRAINER, 26952, A.TRAINER, 3557, A.TRAINER, 26904, A.TRAINER, 29924)

	-- Truesilver Skeleton Key -- 19668
	AddRecipe(19668, 200, 15871, R_COMMON, GAME_ORIG, 200, 200, 210, 220)
	self:addTradeFlags(RecipeDB, 19668, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP)
	self:addTradeAcquire(RecipeDB, 19668, A.TRAINER, 2836, A.TRAINER, 3355, A.TRAINER, 4258, A.TRAINER, 16583, A.TRAINER, 16669, A.TRAINER, 16823, A.TRAINER, 19341, A.TRAINER, 28694, A.TRAINER, 27034, A.TRAINER, 5511, A.TRAINER, 514, A.TRAINER, 1241, A.TRAINER, 16724, A.TRAINER, 33591, A.TRAINER, 2998, A.TRAINER, 3478, A.TRAINER, 3136, A.TRAINER, 4596, A.TRAINER, 3174, A.TRAINER, 26988, A.TRAINER, 33609, A.TRAINER, 33631, A.TRAINER, 15400, A.TRAINER, 33675, A.TRAINER, 26981, A.TRAINER, 17245, A.TRAINER, 6299, A.TRAINER, 26564, A.TRAINER, 26952, A.TRAINER, 3557, A.TRAINER, 26904, A.TRAINER, 29924)

	-- Arcanite Skeleton Key -- 19669
	AddRecipe(19669, 275, 15872, R_COMMON, GAME_ORIG, 275, 275, 280, 285)
	self:addTradeFlags(RecipeDB, 19669, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP)
	self:addTradeAcquire(RecipeDB, 19669, A.TRAINER, 2836, A.TRAINER, 16583, A.TRAINER, 16823, A.TRAINER, 19341, A.TRAINER, 28694, A.TRAINER, 27034, A.TRAINER, 4258, A.TRAINER, 5511, A.TRAINER, 514, A.TRAINER, 1241, A.TRAINER, 16724, A.TRAINER, 3355, A.TRAINER, 33591, A.TRAINER, 2998, A.TRAINER, 3478, A.TRAINER, 3136, A.TRAINER, 4596, A.TRAINER, 3174, A.TRAINER, 26988, A.TRAINER, 33609, A.TRAINER, 33631, A.TRAINER, 15400, A.TRAINER, 33675, A.TRAINER, 26981, A.TRAINER, 17245, A.TRAINER, 6299, A.TRAINER, 26564, A.TRAINER, 26952, A.TRAINER, 3557, A.TRAINER, 26904, A.TRAINER, 29924)

	-- Arcanite Rod -- 20201
	AddRecipe(20201, 275, 16206, R_COMMON, GAME_ORIG, 275, 275, 280, 285)
	self:addTradeFlags(RecipeDB, 20201, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP)
	self:addTradeAcquire(RecipeDB, 20201, A.TRAINER, 2836, A.TRAINER, 16583, A.TRAINER, 16823, A.TRAINER, 19341, A.TRAINER, 28694, A.TRAINER, 27034, A.TRAINER, 4258, A.TRAINER, 5511, A.TRAINER, 514, A.TRAINER, 1241, A.TRAINER, 16724, A.TRAINER, 3355, A.TRAINER, 33591, A.TRAINER, 2998, A.TRAINER, 3478, A.TRAINER, 3136, A.TRAINER, 4596, A.TRAINER, 3174, A.TRAINER, 26988, A.TRAINER, 33609, A.TRAINER, 33631, A.TRAINER, 15400, A.TRAINER, 33675, A.TRAINER, 26981, A.TRAINER, 17245, A.TRAINER, 6299, A.TRAINER, 26564, A.TRAINER, 26952, A.TRAINER, 3557, A.TRAINER, 26904, A.TRAINER, 29924)

	-- Fiery Chain Girdle -- 20872
	AddRecipe(20872, 295, 16989, R_RARE, GAME_ORIG, 295, 315, 325, 335)
	self:addTradeFlags(RecipeDB, 20872, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOP, F.HEALER, F.CASTER, F.MAIL, F.THORIUM_BROTHERHOOD)
	self:addTradeAcquire(RecipeDB, 20872, A.REPUTATION, FAC.THORIUM_BROTHERHOOD, REP.HONORED, 12944)

	-- Fiery Chain Shoulders -- 20873
	AddRecipe(20873, 300, 16988, R_RARE, GAME_ORIG, 300, 320, 330, 340)
	self:addTradeFlags(RecipeDB, 20873, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOP, F.MAIL, F.THORIUM_BROTHERHOOD)
	self:addTradeAcquire(RecipeDB, 20873, A.REPUTATION, FAC.THORIUM_BROTHERHOOD, REP.REVERED, 12944)

	-- Dark Iron Bracers -- 20874
	AddRecipe(20874, 295, 17014, R_RARE, GAME_ORIG, 295, 315, 325, 335)
	self:addTradeFlags(RecipeDB, 20874, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOP, F.PLATE, F.THORIUM_BROTHERHOOD)
	self:addTradeAcquire(RecipeDB, 20874, A.REPUTATION, FAC.THORIUM_BROTHERHOOD, REP.FRIENDLY, 12944)

	-- Dark Iron Leggings -- 20876
	AddRecipe(20876, 300, 17013, R_RARE, GAME_ORIG, 300, 320, 330, 340)
	self:addTradeFlags(RecipeDB, 20876, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOP, F.PLATE, F.THORIUM_BROTHERHOOD)
	self:addTradeAcquire(RecipeDB, 20876, A.REPUTATION, FAC.THORIUM_BROTHERHOOD, REP.REVERED, 12944)

	-- Dark Iron Reaver -- 20890
	AddRecipe(20890, 300, 17015, R_RARE, GAME_ORIG, 300, 320, 330, 340)
	self:addTradeFlags(RecipeDB, 20890, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOP, F.ONE_HAND, F.SWORD, F.THORIUM_BROTHERHOOD)
	self:addTradeAcquire(RecipeDB, 20890, A.REPUTATION, FAC.THORIUM_BROTHERHOOD, REP.HONORED, 12944)

	-- Dark Iron Destroyer -- 20897
	AddRecipe(20897, 300, 17016, R_RARE, GAME_ORIG, 300, 320, 330, 340)
	self:addTradeFlags(RecipeDB, 20897, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOP, F.DPS, F.ONE_HAND, F.AXE, F.THORIUM_BROTHERHOOD)
	self:addTradeAcquire(RecipeDB, 20897, A.REPUTATION, FAC.THORIUM_BROTHERHOOD, REP.HONORED, 12944)

	-- Sulfuron Hammer -- 21161
	AddRecipe(21161, 300, 17193, R_EPIC, GAME_ORIG, 300, 325, 337, 350)
	self:addTradeFlags(RecipeDB, 21161, F.ALLIANCE, F.HORDE, F.QUEST, F.IBOE, F.RBOE, F.TWO_HAND, F.MACE)
	self:addTradeAcquire(RecipeDB, 21161, A.QUEST, 7604)

	-- Edge of Winter -- 21913
	AddRecipe(21913, 190, 17704, R_UNCOMMON, GAME_ORIG, 190, 215, 227, 240)
	self:addTradeFlags(RecipeDB, 21913, F.ALLIANCE, F.HORDE, F.SEASONAL, F.MOB_DROP, F.IBOE, F.RBOE, F.ONE_HAND, F.AXE)
	self:addTradeAcquire(RecipeDB, 21913, A.SEASONAL, 1)

	-- Elemental Sharpening Stone -- 22757
	AddRecipe(22757, 300, 18262, R_RARE, GAME_ORIG, 300, 300, 310, 320)
	self:addTradeFlags(RecipeDB, 22757, F.ALLIANCE, F.HORDE, F.RAID, F.IBOE, F.RBOP)
	self:addTradeAcquire(RecipeDB, 22757, A.CUSTOM, 26)

	-- Heavy Timbermaw Belt -- 23628
	AddRecipe(23628, 290, 19043, R_COMMON, GAME_ORIG, 290, 310, 320, 330)
	self:addTradeFlags(RecipeDB, 23628, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOP, F.DPS, F.MAIL, F.TIMBERMAW_HOLD)
	self:addTradeAcquire(RecipeDB, 23628, A.REPUTATION, FAC.TIMBERMAW_HOLD, REP.HONORED, 11557)

	-- Heavy Timbermaw Boots -- 23629
	AddRecipe(23629, 300, 19048, R_COMMON, GAME_ORIG, 300, 320, 330, 340)
	self:addTradeFlags(RecipeDB, 23629, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOP, F.DPS, F.MAIL, F.TIMBERMAW_HOLD)
	self:addTradeAcquire(RecipeDB, 23629, A.REPUTATION, FAC.TIMBERMAW_HOLD, REP.REVERED, 11557)

	-- Girdle of the Dawn -- 23632
	AddRecipe(23632, 290, 19051, R_COMMON, GAME_ORIG, 290, 310, 320, 330)
	self:addTradeFlags(RecipeDB, 23632, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOP, F.DPS, F.PLATE, F.ARGENTDAWN)
	self:addTradeAcquire(RecipeDB, 23632, A.REPUTATION, FAC.ARGENTDAWN, REP.HONORED, 10856, A.REPUTATION, FAC.ARGENTDAWN, REP.HONORED, 10857, A.REPUTATION, FAC.ARGENTDAWN, REP.HONORED, 11536)

	-- Gloves of the Dawn -- 23633
	AddRecipe(23633, 300, 19057, R_COMMON, GAME_ORIG, 300, 320, 330, 340)
	self:addTradeFlags(RecipeDB, 23633, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOP, F.DPS, F.PLATE, F.ARGENTDAWN)
	self:addTradeAcquire(RecipeDB, 23633, A.REPUTATION, FAC.ARGENTDAWN, REP.REVERED, 10856, A.REPUTATION, FAC.ARGENTDAWN, REP.REVERED, 10857, A.REPUTATION, FAC.ARGENTDAWN, REP.REVERED, 11536)

	-- Dark Iron Helm -- 23636
	AddRecipe(23636, 300, 19148, R_COMMON, GAME_ORIG, 300, 320, 330, 340)
	self:addTradeFlags(RecipeDB, 23636, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOP, F.PLATE, F.THORIUM_BROTHERHOOD)
	self:addTradeAcquire(RecipeDB, 23636, A.REPUTATION, FAC.THORIUM_BROTHERHOOD, REP.HONORED, 12944)

	-- Dark Iron Gauntlets -- 23637
	AddRecipe(23637, 300, 19164, R_COMMON, GAME_ORIG, 300, 320, 330, 340)
	self:addTradeFlags(RecipeDB, 23637, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOP, F.DPS, F.PLATE, F.THORIUM_BROTHERHOOD)
	self:addTradeAcquire(RecipeDB, 23637, A.REPUTATION, FAC.THORIUM_BROTHERHOOD, REP.REVERED, 12944)

	-- Black Amnesty -- 23638
	AddRecipe(23638, 300, 19166, R_COMMON, GAME_ORIG, 300, 320, 330, 340)
	self:addTradeFlags(RecipeDB, 23638, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOP, F.ONE_HAND, F.DAGGER, F.THORIUM_BROTHERHOOD)
	self:addTradeAcquire(RecipeDB, 23638, A.REPUTATION, FAC.THORIUM_BROTHERHOOD, REP.REVERED, 12944)

	-- Blackfury -- 23639
	AddRecipe(23639, 300, 19167, R_COMMON, GAME_ORIG, 300, 320, 330, 340)
	self:addTradeFlags(RecipeDB, 23639, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOP, F.DPS, F.TWO_HAND, F.POLEARM, F.THORIUM_BROTHERHOOD)
	self:addTradeAcquire(RecipeDB, 23639, A.REPUTATION, FAC.THORIUM_BROTHERHOOD, REP.REVERED, 12944)

	-- Ebon Hand -- 23650
	AddRecipe(23650, 300, 19170, R_COMMON, GAME_ORIG, 300, 320, 330, 340)
	self:addTradeFlags(RecipeDB, 23650, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOP, F.ONE_HAND, F.MACE, F.THORIUM_BROTHERHOOD)
	self:addTradeAcquire(RecipeDB, 23650, A.REPUTATION, FAC.THORIUM_BROTHERHOOD, REP.HONORED, 12944)

	-- Blackguard -- 23652
	AddRecipe(23652, 300, 19168, R_COMMON, GAME_ORIG, 300, 320, 330, 340)
	self:addTradeFlags(RecipeDB, 23652, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOP, F.TANK, F.ONE_HAND, F.SWORD, F.THORIUM_BROTHERHOOD)
	self:addTradeAcquire(RecipeDB, 23652, A.REPUTATION, FAC.THORIUM_BROTHERHOOD, REP.HONORED, 12944)

	-- Nightfall -- 23653
	AddRecipe(23653, 300, 19169, R_COMMON, GAME_ORIG, 300, 320, 330, 340)
	self:addTradeFlags(RecipeDB, 23653, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOP, F.TWO_HAND, F.AXE, F.THORIUM_BROTHERHOOD)
	self:addTradeAcquire(RecipeDB, 23653, A.REPUTATION, FAC.THORIUM_BROTHERHOOD, REP.EXALTED, 12944)

	-- Bloodsoul Breastplate -- 24136
	AddRecipe(24136, 300, 19690, R_COMMON, GAME_ORIG, 300, 320, 330, 340)
	self:addTradeFlags(RecipeDB, 24136, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOP, F.DPS, F.HEALER, F.CASTER, F.MAIL, F.ZANDALAR)
	self:addTradeAcquire(RecipeDB, 24136, A.REPUTATION, FAC.ZANDALAR, REP.REVERED, 14921)

	-- Bloodsoul Shoulders -- 24137
	AddRecipe(24137, 300, 19691, R_COMMON, GAME_ORIG, 300, 320, 330, 340)
	self:addTradeFlags(RecipeDB, 24137, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOP, F.DPS, F.MAIL, F.ZANDALAR)
	self:addTradeAcquire(RecipeDB, 24137, A.REPUTATION, FAC.ZANDALAR, REP.HONORED, 14921)

	-- Bloodsoul Gauntlets -- 24138
	AddRecipe(24138, 300, 19692, R_COMMON, GAME_ORIG, 300, 320, 330, 340)
	self:addTradeFlags(RecipeDB, 24138, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOP, F.DPS, F.MAIL, F.ZANDALAR)
	self:addTradeAcquire(RecipeDB, 24138, A.REPUTATION, FAC.ZANDALAR, REP.FRIENDLY, 14921)

	-- Darksoul Breastplate -- 24139
	AddRecipe(24139, 300, 19693, R_COMMON, GAME_ORIG, 300, 320, 330, 340)
	self:addTradeFlags(RecipeDB, 24139, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOP, F.TANK, F.PLATE, F.ZANDALAR)
	self:addTradeAcquire(RecipeDB, 24139, A.REPUTATION, FAC.ZANDALAR, REP.REVERED, 14921)

	-- Darksoul Leggings -- 24140
	AddRecipe(24140, 300, 19694, R_COMMON, GAME_ORIG, 300, 320, 330, 340)
	self:addTradeFlags(RecipeDB, 24140, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOP, F.TANK, F.PLATE, F.ZANDALAR)
	self:addTradeAcquire(RecipeDB, 24140, A.REPUTATION, FAC.ZANDALAR, REP.HONORED, 14921)

	-- Darksoul Shoulders -- 24141
	AddRecipe(24141, 300, 19695, R_COMMON, GAME_ORIG, 300, 320, 330, 340)
	self:addTradeFlags(RecipeDB, 24141, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOP, F.TANK, F.PLATE, F.ZANDALAR)
	self:addTradeAcquire(RecipeDB, 24141, A.REPUTATION, FAC.ZANDALAR, REP.FRIENDLY, 14921)

	-- Dark Iron Boots -- 24399
	AddRecipe(24399, 300, 20039, R_COMMON, GAME_ORIG, 300, 320, 330, 340)
	self:addTradeFlags(RecipeDB, 24399, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOP, F.PLATE, F.THORIUM_BROTHERHOOD)
	self:addTradeAcquire(RecipeDB, 24399, A.REPUTATION, FAC.THORIUM_BROTHERHOOD, REP.EXALTED, 12944)

	-- Darkrune Gauntlets -- 24912
	AddRecipe(24912, 300, 20549, R_RARE, GAME_ORIG, 300, 320, 330, 340)
	self:addTradeFlags(RecipeDB, 24912, F.ALLIANCE, F.HORDE, F.QUEST, F.IBOE, F.RBOE, F.TANK, F.PLATE)
	self:addTradeAcquire(RecipeDB, 24912, A.QUEST, 8323)

	-- Darkrune Helm -- 24913
	AddRecipe(24913, 300, 20551, R_RARE, GAME_ORIG, 300, 320, 330, 340)
	self:addTradeFlags(RecipeDB, 24913, F.ALLIANCE, F.HORDE, F.QUEST, F.IBOE, F.RBOE, F.PLATE)
	self:addTradeAcquire(RecipeDB, 24913, A.QUEST, 8323)

	-- Darkrune Breastplate -- 24914
	AddRecipe(24914, 300, 20550, R_RARE, GAME_ORIG, 300, 320, 330, 340)
	self:addTradeFlags(RecipeDB, 24914, F.ALLIANCE, F.HORDE, F.QUEST, F.IBOE, F.RBOE, F.TANK, F.PLATE)
	self:addTradeAcquire(RecipeDB, 24914, A.QUEST, 8323)

	-- Heavy Obsidian Belt -- 27585
	AddRecipe(27585, 300, 22197, R_COMMON, GAME_ORIG, 300, 320, 330, 340)
	self:addTradeFlags(RecipeDB, 27585, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOP, F.DPS, F.PLATE, F.CENARION_CIRCLE)
	self:addTradeAcquire(RecipeDB, 27585, A.REPUTATION, FAC.CENARION_CIRCLE, REP.FRIENDLY, 15176)

	-- Jagged Obsidian Shield -- 27586
	AddRecipe(27586, 300, 22198, R_COMMON, GAME_ORIG, 300, 320, 330, 340)
	self:addTradeFlags(RecipeDB, 27586, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOP, F.TANK, F.SHIELD, F.ONE_HAND, F.CENARION_CIRCLE)
	self:addTradeAcquire(RecipeDB, 27586, A.REPUTATION, FAC.CENARION_CIRCLE, REP.REVERED, 15471)

	-- Thick Obsidian Breastplate -- 27587
	AddRecipe(27587, 300, 22196, R_RARE, GAME_ORIG, 300, 320, 330, 340)
	self:addTradeFlags(RecipeDB, 27587, F.ALLIANCE, F.HORDE, F.RAID, F.MOB_DROP, F.IBOE, F.RBOE, F.DPS, F.PLATE)
	self:addTradeAcquire(RecipeDB, 27587, A.MOB, 15263)

	-- Light Obsidian Belt -- 27588
	AddRecipe(27588, 300, 22195, R_COMMON, GAME_ORIG, 300, 320, 330, 340)
	self:addTradeFlags(RecipeDB, 27588, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOP, F.DPS, F.MAIL, F.CENARION_CIRCLE)
	self:addTradeAcquire(RecipeDB, 27588, A.REPUTATION, FAC.CENARION_CIRCLE, REP.HONORED, 15176)

	-- Black Grasp of the Destroyer -- 27589
	AddRecipe(27589, 300, 22194, R_RARE, GAME_ORIG, 300, 320, 330, 340)
	self:addTradeFlags(RecipeDB, 27589, F.ALLIANCE, F.HORDE, F.RAID, F.IBOE, F.RBOE, F.DPS, F.MAIL)
	self:addTradeAcquire(RecipeDB, 27589, A.MOB, 15340)

	-- Obsidian Mail Tunic -- 27590
	AddRecipe(27590, 300, 22191, R_COMMON, GAME_ORIG, 300, 320, 330, 340)
	self:addTradeFlags(RecipeDB, 27590, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOP, F.DPS, F.MAIL, F.CENARION_CIRCLE)
	self:addTradeAcquire(RecipeDB, 27590, A.REPUTATION, FAC.CENARION_CIRCLE, REP.EXALTED, 15471)

	-- Titanic Leggings -- 27829
	AddRecipe(27829, 300, 22385, R_EPIC, GAME_ORIG, 300, 320, 330, 340)
	self:addTradeFlags(RecipeDB, 27829, F.ALLIANCE, F.HORDE, F.RAID, F.MOB_DROP, F.IBOE, F.RBOE, F.DPS, F.PLATE)
	self:addTradeAcquire(RecipeDB, 27829, A.WORLD_DROP, 2)

	-- Persuader -- 27830
	AddRecipe(27830, 300, 22384, R_EPIC, GAME_ORIG, 300, 320, 330, 340)
	self:addTradeFlags(RecipeDB, 27830, F.ALLIANCE, F.HORDE, F.RAID, F.MOB_DROP, F.IBOE, F.RBOE, F.ONE_HAND, F.MACE)
	self:addTradeAcquire(RecipeDB, 27830, A.WORLD_DROP, 2)

	-- Sageblade -- 27832
	AddRecipe(27832, 300, 22383, R_EPIC, GAME_ORIG, 300, 320, 330, 340)
	self:addTradeFlags(RecipeDB, 27832, F.ALLIANCE, F.HORDE, F.RAID, F.MOB_DROP, F.IBOE, F.RBOE, F.CASTER, F.ONE_HAND, F.SWORD)
	self:addTradeAcquire(RecipeDB, 27832, A.WORLD_DROP, 2)

	-- Icebane Breastplate -- 28242
	AddRecipe(28242, 300, 22669, R_EPIC, GAME_ORIG, 300, 320, 330, 340)
	self:addTradeFlags(RecipeDB, 28242, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.TANK, F.PLATE)
	self:addTradeAcquire(RecipeDB, 28242, A.REPUTATION, FAC.ARGENTDAWN, REP.EXALTED, 16365, A.CUSTOM, 41)

	-- Icebane Gauntlets -- 28243
	AddRecipe(28243, 300, 22670, R_EPIC, GAME_ORIG, 300, 320, 330, 340)
	self:addTradeFlags(RecipeDB, 28243, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.TANK, F.PLATE)
	self:addTradeAcquire(RecipeDB, 28243, A.REPUTATION, FAC.ARGENTDAWN, REP.REVERED, 16365, A.CUSTOM, 41)

	-- Icebane Bracers -- 28244
	AddRecipe(28244, 300, 22671, R_EPIC, GAME_ORIG, 300, 320, 330, 340)
	self:addTradeFlags(RecipeDB, 28244, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.TANK, F.PLATE)
	self:addTradeAcquire(RecipeDB, 28244, A.REPUTATION, FAC.ARGENTDAWN, REP.REVERED, 16365, A.CUSTOM, 41)

	-- Ironvine Breastplate -- 28461
	AddRecipe(28461, 300, 22762, R_COMMON, GAME_ORIG, 300, 320, 330, 340)
	self:addTradeFlags(RecipeDB, 28461, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOP, F.TANK, F.PLATE, F.CENARION_CIRCLE)
	self:addTradeAcquire(RecipeDB, 28461, A.REPUTATION, FAC.CENARION_CIRCLE, REP.REVERED, 15176)

	-- Ironvine Gloves -- 28462
	AddRecipe(28462, 300, 22763, R_COMMON, GAME_ORIG, 300, 320, 330, 340)
	self:addTradeFlags(RecipeDB, 28462, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOP, F.TANK, F.PLATE, F.CENARION_CIRCLE)
	self:addTradeAcquire(RecipeDB, 28462, A.REPUTATION, FAC.CENARION_CIRCLE, REP.HONORED, 15176)

	-- Ironvine Belt -- 28463
	AddRecipe(28463, 300, 22764, R_COMMON, GAME_ORIG, 300, 320, 330, 340)
	self:addTradeFlags(RecipeDB, 28463, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOP, F.TANK, F.PLATE, F.CENARION_CIRCLE)
	self:addTradeAcquire(RecipeDB, 28463, A.REPUTATION, FAC.CENARION_CIRCLE, REP.FRIENDLY, 15176)

	-- Fel Iron Plate Gloves -- 29545
	AddRecipe(29545, 300, 23482, R_COMMON, GAME_TBC, 300, 310, 320, 330)
	self:addTradeFlags(RecipeDB, 29545, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.DPS, F.PLATE)
	self:addTradeAcquire(RecipeDB, 29545, A.TRAINER, 16583, A.TRAINER, 16823, A.TRAINER, 19341, A.TRAINER, 28694, A.TRAINER, 27034, A.TRAINER, 33591, A.TRAINER, 26988, A.TRAINER, 33609, A.TRAINER, 33631, A.TRAINER, 33675, A.TRAINER, 26981, A.TRAINER, 26564, A.TRAINER, 26952, A.TRAINER, 26904, A.TRAINER, 29924)

	-- Fel Iron Plate Belt -- 29547
	AddRecipe(29547, 305, 23484, R_COMMON, GAME_TBC, 305, 315, 325, 335)
	self:addTradeFlags(RecipeDB, 29547, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.DPS, F.PLATE)
	self:addTradeAcquire(RecipeDB, 29547, A.TRAINER, 16583, A.TRAINER, 16823, A.TRAINER, 19341, A.TRAINER, 28694, A.TRAINER, 27034, A.TRAINER, 33591, A.TRAINER, 26988, A.TRAINER, 33609, A.TRAINER, 33631, A.TRAINER, 33675, A.TRAINER, 26981, A.TRAINER, 26564, A.TRAINER, 26952, A.TRAINER, 26904, A.TRAINER, 29924)

	-- Fel Iron Plate Boots -- 29548
	AddRecipe(29548, 315, 23487, R_COMMON, GAME_TBC, 315, 325, 335, 345)
	self:addTradeFlags(RecipeDB, 29548, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.DPS, F.PLATE)
	self:addTradeAcquire(RecipeDB, 29548, A.TRAINER, 16583, A.TRAINER, 16823, A.TRAINER, 19341, A.TRAINER, 28694, A.TRAINER, 27034, A.TRAINER, 33591, A.TRAINER, 26988, A.TRAINER, 33609, A.TRAINER, 33631, A.TRAINER, 33675, A.TRAINER, 26981, A.TRAINER, 26564, A.TRAINER, 26952, A.TRAINER, 26904, A.TRAINER, 29924)

	-- Fel Iron Plate Pants -- 29549
	AddRecipe(29549, 315, 23488, R_COMMON, GAME_TBC, 315, 325, 335, 345)
	self:addTradeFlags(RecipeDB, 29549, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.DPS, F.PLATE)
	self:addTradeAcquire(RecipeDB, 29549, A.TRAINER, 16583, A.TRAINER, 16823, A.TRAINER, 19341, A.TRAINER, 28694, A.TRAINER, 27034, A.TRAINER, 33591, A.TRAINER, 26988, A.TRAINER, 33609, A.TRAINER, 33631, A.TRAINER, 33675, A.TRAINER, 26981, A.TRAINER, 26564, A.TRAINER, 26952, A.TRAINER, 26904, A.TRAINER, 29924)

	-- Fel Iron Breastplate -- 29550
	AddRecipe(29550, 325, 23489, R_COMMON, GAME_TBC, 325, 335, 345, 355)
	self:addTradeFlags(RecipeDB, 29550, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.DPS, F.PLATE)
	self:addTradeAcquire(RecipeDB, 29550, A.TRAINER, 16583, A.TRAINER, 16823, A.TRAINER, 19341, A.TRAINER, 28694, A.TRAINER, 27034, A.TRAINER, 33591, A.TRAINER, 26988, A.TRAINER, 33609, A.TRAINER, 33631, A.TRAINER, 33675, A.TRAINER, 26981, A.TRAINER, 26564, A.TRAINER, 26952, A.TRAINER, 26904, A.TRAINER, 29924)

	-- Fel Iron Chain Coif -- 29551
	AddRecipe(29551, 300, 23493, R_COMMON, GAME_TBC, 300, 320, 330, 340)
	self:addTradeFlags(RecipeDB, 29551, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.DPS, F.MAIL)
	self:addTradeAcquire(RecipeDB, 29551, A.TRAINER, 16583, A.TRAINER, 16823, A.TRAINER, 19341, A.TRAINER, 28694, A.TRAINER, 27034, A.TRAINER, 33591, A.TRAINER, 26988, A.TRAINER, 33609, A.TRAINER, 33631, A.TRAINER, 33675, A.TRAINER, 26981, A.TRAINER, 26564, A.TRAINER, 26952, A.TRAINER, 26904, A.TRAINER, 29924)

	-- Fel Iron Chain Gloves -- 29552
	AddRecipe(29552, 310, 23491, R_COMMON, GAME_TBC, 310, 320, 330, 340)
	self:addTradeFlags(RecipeDB, 29552, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.DPS, F.MAIL)
	self:addTradeAcquire(RecipeDB, 29552, A.TRAINER, 16583, A.TRAINER, 16823, A.TRAINER, 19341, A.TRAINER, 28694, A.TRAINER, 27034, A.TRAINER, 33591, A.TRAINER, 26988, A.TRAINER, 33609, A.TRAINER, 33631, A.TRAINER, 33675, A.TRAINER, 26981, A.TRAINER, 26564, A.TRAINER, 26952, A.TRAINER, 26904, A.TRAINER, 29924)

	-- Fel Iron Chain Bracers -- 29553
	AddRecipe(29553, 315, 23494, R_COMMON, GAME_TBC, 315, 325, 335, 345)
	self:addTradeFlags(RecipeDB, 29553, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.DPS, F.MAIL)
	self:addTradeAcquire(RecipeDB, 29553, A.TRAINER, 16583, A.TRAINER, 16823, A.TRAINER, 19341, A.TRAINER, 28694, A.TRAINER, 27034, A.TRAINER, 33591, A.TRAINER, 26988, A.TRAINER, 33609, A.TRAINER, 33631, A.TRAINER, 33675, A.TRAINER, 26981, A.TRAINER, 26564, A.TRAINER, 26952, A.TRAINER, 26904, A.TRAINER, 29924)

	-- Fel Iron Chain Tunic -- 29556
	AddRecipe(29556, 320, 23490, R_COMMON, GAME_TBC, 320, 330, 340, 350)
	self:addTradeFlags(RecipeDB, 29556, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.DPS, F.MAIL)
	self:addTradeAcquire(RecipeDB, 29556, A.TRAINER, 16583, A.TRAINER, 16823, A.TRAINER, 19341, A.TRAINER, 28694, A.TRAINER, 27034, A.TRAINER, 33591, A.TRAINER, 26988, A.TRAINER, 33609, A.TRAINER, 33631, A.TRAINER, 33675, A.TRAINER, 26981, A.TRAINER, 26564, A.TRAINER, 26952, A.TRAINER, 26904, A.TRAINER, 29924)

	-- Fel Iron Hatchet -- 29557
	AddRecipe(29557, 310, 23497, R_COMMON, GAME_TBC, 310, 320, 330, 340)
	self:addTradeFlags(RecipeDB, 29557, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.DPS, F.ONE_HAND, F.AXE)
	self:addTradeAcquire(RecipeDB, 29557, A.TRAINER, 16583, A.TRAINER, 16823, A.TRAINER, 19341, A.TRAINER, 28694, A.TRAINER, 27034, A.TRAINER, 33591, A.TRAINER, 26988, A.TRAINER, 33609, A.TRAINER, 33631, A.TRAINER, 33675, A.TRAINER, 26981, A.TRAINER, 26564, A.TRAINER, 26952, A.TRAINER, 26904, A.TRAINER, 29924)

	-- Fel Iron Hammer -- 29558
	AddRecipe(29558, 315, 23498, R_COMMON, GAME_TBC, 315, 325, 335, 345)
	self:addTradeFlags(RecipeDB, 29558, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.ONE_HAND, F.MACE)
	self:addTradeAcquire(RecipeDB, 29558, A.TRAINER, 16583, A.TRAINER, 16823, A.TRAINER, 19341, A.TRAINER, 28694, A.TRAINER, 27034, A.TRAINER, 33591, A.TRAINER, 26988, A.TRAINER, 33609, A.TRAINER, 33631, A.TRAINER, 33675, A.TRAINER, 26981, A.TRAINER, 26564, A.TRAINER, 26952, A.TRAINER, 26904, A.TRAINER, 29924)

	-- Fel Iron Greatsword -- 29565
	AddRecipe(29565, 320, 23499, R_COMMON, GAME_TBC, 320, 330, 340, 350)
	self:addTradeFlags(RecipeDB, 29565, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.DPS, F.TWO_HAND, F.SWORD)
	self:addTradeAcquire(RecipeDB, 29565, A.TRAINER, 16583, A.TRAINER, 16823, A.TRAINER, 19341, A.TRAINER, 28694, A.TRAINER, 27034, A.TRAINER, 33591, A.TRAINER, 26988, A.TRAINER, 33609, A.TRAINER, 33631, A.TRAINER, 33675, A.TRAINER, 26981, A.TRAINER, 26564, A.TRAINER, 26952, A.TRAINER, 26904, A.TRAINER, 29924)

	-- Adamantite Maul -- 29566
	AddRecipe(29566, 325, 23502, R_COMMON, GAME_TBC, 325, 335, 345, 355)
	self:addTradeFlags(RecipeDB, 29566, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOE, F.DPS, F.TWO_HAND, F.MACE)
	self:addTradeAcquire(RecipeDB, 29566, A.VENDOR, 16670, A.VENDOR, 16713, A.VENDOR, 19662)

	-- Adamantite Cleaver -- 29568
	AddRecipe(29568, 330, 23503, R_COMMON, GAME_TBC, 330, 340, 350, 360)
	self:addTradeFlags(RecipeDB, 29568, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOE, F.DPS, F.TWO_HAND, F.AXE)
	self:addTradeAcquire(RecipeDB, 29568, A.VENDOR, 16670, A.VENDOR, 16713, A.VENDOR, 19662)

	-- Adamantite Dagger -- 29569
	AddRecipe(29569, 330, 23504, R_COMMON, GAME_TBC, 330, 340, 350, 360)
	self:addTradeFlags(RecipeDB, 29569, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOE, F.ONE_HAND, F.DAGGER)
	self:addTradeAcquire(RecipeDB, 29569, A.VENDOR, 16670, A.VENDOR, 16713, A.VENDOR, 19662)

	-- Adamantite Rapier -- 29571
	AddRecipe(29571, 335, 23505, R_COMMON, GAME_TBC, 335, 345, 355, 365)
	self:addTradeFlags(RecipeDB, 29571, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOE, F.TANK, F.ONE_HAND, F.SWORD)
	self:addTradeAcquire(RecipeDB, 29571, A.VENDOR, 16670, A.VENDOR, 16713, A.VENDOR, 19662)

	-- Adamantite Plate Bracers -- 29603
	AddRecipe(29603, 335, 23506, R_COMMON, GAME_TBC, 335, 345, 355, 365)
	self:addTradeFlags(RecipeDB, 29603, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOE, F.DPS, F.PLATE)
	self:addTradeAcquire(RecipeDB, 29603, A.VENDOR, 19342, A.VENDOR, 19694)

	-- Adamantite Plate Gloves -- 29605
	AddRecipe(29605, 335, 23508, R_COMMON, GAME_TBC, 335, 345, 355, 365)
	self:addTradeFlags(RecipeDB, 29605, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOE, F.DPS, F.PLATE)
	self:addTradeAcquire(RecipeDB, 29605, A.VENDOR, 19342, A.VENDOR, 19694)

	-- Adamantite Breastplate -- 29606
	AddRecipe(29606, 340, 23507, R_COMMON, GAME_TBC, 340, 350, 360, 370)
	self:addTradeFlags(RecipeDB, 29606, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOE, F.DPS, F.PLATE)
	self:addTradeAcquire(RecipeDB, 29606, A.VENDOR, 19342, A.VENDOR, 19694)

	-- Enchanted Adamantite Belt -- 29608
	AddRecipe(29608, 355, 23510, R_COMMON, GAME_TBC, 355, 365, 375, 385)
	self:addTradeFlags(RecipeDB, 29608, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOP, F.TANK, F.PLATE, F.SCRYER)
	self:addTradeAcquire(RecipeDB, 29608, A.REPUTATION, FAC.SCRYER, REP.FRIENDLY, 19331)

	-- Enchanted Adamantite Breastplate -- 29610
	AddRecipe(29610, 360, 23509, R_COMMON, GAME_TBC, 360, 370, 380, 390)
	self:addTradeFlags(RecipeDB, 29610, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOP, F.TANK, F.PLATE, F.SCRYER)
	self:addTradeAcquire(RecipeDB, 29610, A.REPUTATION, FAC.SCRYER, REP.REVERED, 19331)

	-- Enchanted Adamantite Boots -- 29611
	AddRecipe(29611, 355, 23511, R_COMMON, GAME_TBC, 355, 365, 375, 385)
	self:addTradeFlags(RecipeDB, 29611, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOP, F.TANK, F.PLATE, F.SCRYER)
	self:addTradeAcquire(RecipeDB, 29611, A.REPUTATION, FAC.SCRYER, REP.HONORED, 19331)

	-- Enchanted Adamantite Leggings -- 29613
	AddRecipe(29613, 365, 23512, R_COMMON, GAME_TBC, 365, 375, 385, 395)
	self:addTradeFlags(RecipeDB, 29613, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOP, F.TANK, F.PLATE, F.SCRYER)
	self:addTradeAcquire(RecipeDB, 29613, A.REPUTATION, FAC.SCRYER, REP.EXALTED, 19331)

	-- Flamebane Bracers -- 29614
	AddRecipe(29614, 350, 23515, R_COMMON, GAME_TBC, 350, 360, 370, 380)
	self:addTradeFlags(RecipeDB, 29614, F.ALLIANCE, F.VENDOR, F.IBOE, F.RBOP, F.TANK, F.PLATE, F.ALDOR)
	self:addTradeAcquire(RecipeDB, 29614, A.REPUTATION, FAC.ALDOR, REP.FRIENDLY, 19321)

	-- Flamebane Helm -- 29615
	AddRecipe(29615, 355, 23516, R_COMMON, GAME_TBC, 355, 365, 375, 385)
	self:addTradeFlags(RecipeDB, 29615, F.ALLIANCE, F.VENDOR, F.IBOE, F.RBOP, F.TANK, F.PLATE, F.ALDOR)
	self:addTradeAcquire(RecipeDB, 29615, A.REPUTATION, FAC.ALDOR, REP.EXALTED, 19321)

	-- Flamebane Gloves -- 29616
	AddRecipe(29616, 360, 23514, R_COMMON, GAME_TBC, 360, 370, 380, 390)
	self:addTradeFlags(RecipeDB, 29616, F.ALLIANCE, F.VENDOR, F.IBOE, F.RBOP, F.TANK, F.PLATE, F.ALDOR)
	self:addTradeAcquire(RecipeDB, 29616, A.REPUTATION, FAC.ALDOR, REP.HONORED, 19321)

	-- Flamebane Breastplate -- 29617
	AddRecipe(29617, 365, 23513, R_COMMON, GAME_TBC, 365, 375, 385, 395)
	self:addTradeFlags(RecipeDB, 29617, F.ALLIANCE, F.VENDOR, F.IBOE, F.RBOP, F.TANK, F.PLATE, F.ALDOR)
	self:addTradeAcquire(RecipeDB, 29617, A.REPUTATION, FAC.ALDOR, REP.REVERED, 19321)

	-- Felsteel Gloves -- 29619
	AddRecipe(29619, 360, 23517, R_RARE, GAME_TBC, 360, 370, 380, 390)
	self:addTradeFlags(RecipeDB, 29619, F.ALLIANCE, F.HORDE, F.INSTANCE, F.MOB_DROP, F.IBOE, F.RBOP, F.TANK, F.PLATE)
	self:addTradeAcquire(RecipeDB, 29619, A.MOB, 18497)

	-- Felsteel Leggings -- 29620
	AddRecipe(29620, 360, 23518, R_RARE, GAME_TBC, 360, 370, 380, 390)
	self:addTradeFlags(RecipeDB, 29620, F.ALLIANCE, F.HORDE, F.INSTANCE, F.IBOE, F.RBOP, F.TANK, F.PLATE)
	self:addTradeAcquire(RecipeDB, 29620, A.MOB, 20900)

	-- Felsteel Helm -- 29621
	AddRecipe(29621, 365, 23519, R_RARE, GAME_TBC, 365, 375, 385, 395)
	self:addTradeFlags(RecipeDB, 29621, F.ALLIANCE, F.HORDE, F.INSTANCE, F.IBOE, F.RBOP, F.TANK, F.PLATE)
	self:addTradeAcquire(RecipeDB, 29621, A.MOB, 18830)

	-- Gauntlets of the Iron Tower -- 29622
	AddRecipe(29622, 365, 23532, R_EPIC, GAME_TBC, 365, 375, 385, 395)
	self:addTradeFlags(RecipeDB, 29622, F.ALLIANCE, F.HORDE, F.RAID, F.IBOE, F.RBOE, F.TANK, F.PLATE)
	self:addTradeAcquire(RecipeDB, 29622, A.WORLD_DROP, 4)

	-- Khorium Belt -- 29628
	AddRecipe(29628, 360, 23524, R_RARE, GAME_TBC, 360, 370, 380, 390)
	self:addTradeFlags(RecipeDB, 29628, F.ALLIANCE, F.HORDE, F.MOB_DROP, F.IBOE, F.RBOP, F.HEALER, F.CASTER, F.PLATE)
	self:addTradeAcquire(RecipeDB, 29628, A.MOB, 18203)

	-- Khorium Pants -- 29629
	AddRecipe(29629, 360, 23523, R_RARE, GAME_TBC, 360, 370, 380, 390)
	self:addTradeFlags(RecipeDB, 29629, F.ALLIANCE, F.HORDE, F.MOB_DROP, F.IBOE, F.RBOP, F.HEALER, F.CASTER, F.PLATE)
	self:addTradeAcquire(RecipeDB, 29629, A.MOB, 20878)

	-- Khorium Boots -- 29630
	AddRecipe(29630, 365, 23525, R_RARE, GAME_TBC, 365, 375, 385, 395)
	self:addTradeFlags(RecipeDB, 29630, F.ALLIANCE, F.HORDE, F.MOB_DROP, F.IBOE, F.RBOP, F.HEALER, F.CASTER, F.PLATE)
	self:addTradeAcquire(RecipeDB, 29630, A.MOB, 18873)

	-- Ragesteel Gloves -- 29642
	AddRecipe(29642, 365, 23520, R_RARE, GAME_TBC, 365, 375, 385, 395)
	self:addTradeFlags(RecipeDB, 29642, F.ALLIANCE, F.HORDE, F.MOB_DROP, F.IBOE, F.RBOP, F.DPS, F.PLATE)
	self:addTradeAcquire(RecipeDB, 29642, A.MOB, 17136)

	-- Ragesteel Helm -- 29643
	AddRecipe(29643, 365, 23521, R_RARE, GAME_TBC, 365, 375, 385, 395)
	self:addTradeFlags(RecipeDB, 29643, F.ALLIANCE, F.HORDE, F.MOB_DROP, F.IBOE, F.RBOP, F.DPS, F.PLATE)
	self:addTradeAcquire(RecipeDB, 29643, A.MOB, 16952)

	-- Ragesteel Breastplate -- 29645
	AddRecipe(29645, 370, 23522, R_RARE, GAME_TBC, 370, 380, 390, 400)
	self:addTradeFlags(RecipeDB, 29645, F.ALLIANCE, F.HORDE, F.MOB_DROP, F.IBOE, F.RBOP, F.DPS, F.PLATE)
	self:addTradeAcquire(RecipeDB, 29645, A.MOB, 21454, A.MOB, 23305, A.MOB, 23324)

	-- Swiftsteel Gloves -- 29648
	AddRecipe(29648, 370, 23526, R_RARE, GAME_TBC, 370, 380, 390, 400)
	self:addTradeFlags(RecipeDB, 29648, F.ALLIANCE, F.HORDE, F.INSTANCE, F.IBOE, F.RBOP, F.DPS, F.MAIL)
	self:addTradeAcquire(RecipeDB, 29648, A.MOB, 18314)

	-- Earthpeace Breastplate -- 29649
	AddRecipe(29649, 370, 23527, R_RARE, GAME_TBC, 370, 380, 390, 400)
	self:addTradeFlags(RecipeDB, 29649, F.ALLIANCE, F.HORDE, F.INSTANCE, F.IBOE, F.RBOP, F.HEALER, F.CASTER, F.MAIL)
	self:addTradeAcquire(RecipeDB, 29649, A.MOB, 17975)

	-- Fel Sharpening Stone -- 29654
	AddRecipe(29654, 300, 23528, R_COMMON, GAME_TBC, 300, 300, 305, 310)
	self:addTradeFlags(RecipeDB, 29654, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.DPS)
	self:addTradeAcquire(RecipeDB, 29654, A.TRAINER, 16583, A.TRAINER, 16823, A.TRAINER, 19341, A.TRAINER, 28694, A.TRAINER, 27034, A.TRAINER, 33591, A.TRAINER, 26988, A.TRAINER, 33609, A.TRAINER, 33631, A.TRAINER, 33675, A.TRAINER, 26981, A.TRAINER, 26564, A.TRAINER, 26952, A.TRAINER, 26904, A.TRAINER, 29924)

	-- Adamantite Sharpening Stone -- 29656
	AddRecipe(29656, 350, 23529, R_COMMON, GAME_TBC, 350, 350, 355, 360)
	self:addTradeFlags(RecipeDB, 29656, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOP, F.DPS, F.CENARION_EXPEDITION)
	self:addTradeAcquire(RecipeDB, 29656, A.REPUTATION, FAC.CENARION_EXPEDITION, REP.HONORED, 17904)

	-- Felsteel Shield Spike -- 29657
	AddRecipe(29657, 360, 23530, R_COMMON, GAME_TBC, 360, 370, 380, 390)
	self:addTradeFlags(RecipeDB, 29657, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOP, F.TANK, F.HELLFIRE)
	self:addTradeAcquire(RecipeDB, 29657, A.REPUTATION, FAC.HONOR_HOLD, REP.EXALTED, 17657, A.REPUTATION, FAC.THRALLMAR, REP.EXALTED, 17585)

	-- Felfury Gauntlets -- 29658
	AddRecipe(29658, 365, 23531, R_EPIC, GAME_TBC, 365, 375, 385, 395)
	self:addTradeFlags(RecipeDB, 29658, F.ALLIANCE, F.HORDE, F.RAID, F.MOB_DROP, F.IBOE, F.RBOE, F.DPS, F.MAIL)
	self:addTradeAcquire(RecipeDB, 29658, A.WORLD_DROP, 2)

	-- Steelgrip Gauntlets -- 29662
	AddRecipe(29662, 365, 23533, R_EPIC, GAME_TBC, 365, 375, 385, 395)
	self:addTradeFlags(RecipeDB, 29662, F.ALLIANCE, F.HORDE, F.RAID, F.MOB_DROP, F.IBOE, F.RBOE, F.DPS, F.PLATE)
	self:addTradeAcquire(RecipeDB, 29662, A.WORLD_DROP, 4)

	-- Storm Helm -- 29663
	AddRecipe(29663, 365, 23534, R_EPIC, GAME_TBC, 365, 375, 385, 395)
	self:addTradeFlags(RecipeDB, 29663, F.ALLIANCE, F.HORDE, F.INSTANCE, F.RAID, F.MOB_DROP, F.IBOE, F.RBOE, F.DPS, F.MAIL)
	self:addTradeAcquire(RecipeDB, 29663, A.WORLD_DROP, 4)

	-- Helm of the Stalwart Defender -- 29664
	AddRecipe(29664, 365, 23535, R_EPIC, GAME_TBC, 365, 375, 385, 395)
	self:addTradeFlags(RecipeDB, 29664, F.ALLIANCE, F.HORDE, F.INSTANCE, F.RAID, F.IBOE, F.RBOE, F.TANK, F.PLATE)
	self:addTradeAcquire(RecipeDB, 29664, A.WORLD_DROP, 4)

	-- Oathkeeper's Helm -- 29668
	AddRecipe(29668, 365, 23536, R_EPIC, GAME_TBC, 365, 375, 385, 395)
	self:addTradeFlags(RecipeDB, 29668, F.ALLIANCE, F.HORDE, F.INSTANCE, F.RAID, F.MOB_DROP, F.IBOE, F.RBOE, F.TANK, F.PLATE)
	self:addTradeAcquire(RecipeDB, 29668, A.WORLD_DROP, 4)

	-- Black Felsteel Bracers -- 29669
	AddRecipe(29669, 365, 23537, R_EPIC, GAME_TBC, 365, 375, 385, 395)
	self:addTradeFlags(RecipeDB, 29669, F.ALLIANCE, F.HORDE, F.RAID, F.MOB_DROP, F.IBOE, F.RBOE, F.DPS, F.PLATE)
	self:addTradeAcquire(RecipeDB, 29669, A.WORLD_DROP, 4)

	-- Bracers of the Green Fortress -- 29671
	AddRecipe(29671, 365, 23538, R_EPIC, GAME_TBC, 365, 375, 385, 395)
	self:addTradeFlags(RecipeDB, 29671, F.ALLIANCE, F.HORDE, F.RAID, F.MOB_DROP, F.IBOE, F.RBOE, F.TANK, F.PLATE)
	self:addTradeAcquire(RecipeDB, 29671, A.WORLD_DROP, 4)

	-- Blessed Bracers -- 29672
	AddRecipe(29672, 365, 23539, R_EPIC, GAME_TBC, 365, 375, 385, 395)
	self:addTradeFlags(RecipeDB, 29672, F.ALLIANCE, F.HORDE, F.WORLD_DROP, F.IBOE, F.RBOE, F.HEALER, F.CASTER, F.PLATE)
	self:addTradeAcquire(RecipeDB, 29672, A.WORLD_DROP, 4)

	-- Felsteel Longblade -- 29692
	AddRecipe(29692, 365, 23540, R_EPIC, GAME_TBC, 365, 375, 385, 395)
	self:addTradeFlags(RecipeDB, 29692, F.ALLIANCE, F.HORDE, F.RAID, F.MOB_DROP, F.IBOE, F.RBOE, F.DPS, F.ONE_HAND, F.SWORD)
	self:addTradeAcquire(RecipeDB, 29692, A.WORLD_DROP, 2)

	-- Khorium Champion -- 29693
	AddRecipe(29693, 365, 23541, R_EPIC, GAME_TBC, 365, 375, 385, 395)
	self:addTradeFlags(RecipeDB, 29693, F.ALLIANCE, F.HORDE, F.RAID, F.MOB_DROP, F.IBOE, F.RBOE, F.DPS, F.TWO_HAND, F.SWORD)
	self:addTradeAcquire(RecipeDB, 29693, A.WORLD_DROP, 4)

	-- Fel Edged Battleaxe -- 29694
	AddRecipe(29694, 365, 23542, R_EPIC, GAME_TBC, 365, 375, 385, 395)
	self:addTradeFlags(RecipeDB, 29694, F.ALLIANCE, F.HORDE, F.RAID, F.MOB_DROP, F.IBOE, F.RBOE, F.ONE_HAND, F.AXE)
	self:addTradeAcquire(RecipeDB, 29694, A.WORLD_DROP, 4)

	-- Felsteel Reaper -- 29695
	AddRecipe(29695, 365, 23543, R_EPIC, GAME_TBC, 365, 375, 385, 395)
	self:addTradeFlags(RecipeDB, 29695, F.ALLIANCE, F.HORDE, F.INSTANCE, F.RAID, F.MOB_DROP, F.IBOE, F.RBOE, F.DPS, F.TWO_HAND, F.AXE)
	self:addTradeAcquire(RecipeDB, 29695, A.WORLD_DROP, 4)

	-- Runic Hammer -- 29696
	AddRecipe(29696, 365, 23544, R_EPIC, GAME_TBC, 365, 375, 385, 395)
	self:addTradeFlags(RecipeDB, 29696, F.ALLIANCE, F.HORDE, F.INSTANCE, F.RAID, F.MOB_DROP, F.IBOE, F.RBOE, F.DPS, F.ONE_HAND, F.MACE)
	self:addTradeAcquire(RecipeDB, 29696, A.WORLD_DROP, 2)

	-- Fel Hardened Maul -- 29697
	AddRecipe(29697, 365, 23546, R_EPIC, GAME_TBC, 365, 375, 385, 395)
	self:addTradeFlags(RecipeDB, 29697, F.ALLIANCE, F.HORDE, F.RAID, F.MOB_DROP, F.IBOE, F.RBOE, F.DPS, F.TWO_HAND, F.MACE)
	self:addTradeAcquire(RecipeDB, 29697, A.WORLD_DROP, 4)

	-- Eternium Runed Blade -- 29698
	AddRecipe(29698, 365, 23554, R_EPIC, GAME_TBC, 365, 375, 385, 395)
	self:addTradeFlags(RecipeDB, 29698, F.ALLIANCE, F.HORDE, F.INSTANCE, F.RAID, F.MOB_DROP, F.IBOE, F.RBOE, F.HEALER, F.CASTER, F.ONE_HAND, F.DAGGER)
	self:addTradeAcquire(RecipeDB, 29698, A.WORLD_DROP, 4)

	-- Dirge -- 29699
	AddRecipe(29699, 365, 23555, R_EPIC, GAME_TBC, 365, 375, 385, 395)
	self:addTradeFlags(RecipeDB, 29699, F.ALLIANCE, F.HORDE, F.INSTANCE, F.RAID, F.MOB_DROP, F.IBOE, F.RBOE, F.DPS, F.ONE_HAND, F.DAGGER)
	self:addTradeAcquire(RecipeDB, 29699, A.WORLD_DROP, 2)

	-- Hand of Eternity -- 29700
	AddRecipe(29700, 365, 23556, R_EPIC, GAME_TBC, 365, 375, 385, 395)
	self:addTradeFlags(RecipeDB, 29700, F.ALLIANCE, F.HORDE, F.RAID, F.MOB_DROP, F.IBOE, F.RBOE, F.HEALER, F.CASTER, F.ONE_HAND, F.MACE)
	self:addTradeAcquire(RecipeDB, 29700, A.WORLD_DROP, 2)

	-- Lesser Ward of Shielding -- 29728
	AddRecipe(29728, 340, 23575, R_COMMON, GAME_TBC, 340, 340, 345, 350)
	self:addTradeFlags(RecipeDB, 29728, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOE)
	self:addTradeAcquire(RecipeDB, 29728, A.VENDOR, 16583, A.VENDOR, 19373)

	-- Greater Ward of Shielding -- 29729
	AddRecipe(29729, 375, 23576, R_RARE, GAME_TBC, 375, 375, 375, 375)
	self:addTradeFlags(RecipeDB, 29729, F.ALLIANCE, F.HORDE, F.MOB_DROP, F.IBOE, F.RBOP)
	self:addTradeAcquire(RecipeDB, 29729, A.MOB, 18853)

	-- Lesser Rune of Warding -- 32284
	AddRecipe(32284, 325, 23559, R_COMMON, GAME_TBC, 325, 325, 330, 335)
	self:addTradeFlags(RecipeDB, 32284, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP)
	self:addTradeAcquire(RecipeDB, 32284, A.TRAINER, 16583, A.TRAINER, 16823, A.TRAINER, 19341, A.TRAINER, 28694, A.TRAINER, 27034, A.TRAINER, 33591, A.TRAINER, 26988, A.TRAINER, 33609, A.TRAINER, 33631, A.TRAINER, 26981, A.TRAINER, 26564, A.TRAINER, 26952, A.TRAINER, 26904, A.TRAINER, 29924)

	-- Greater Rune of Warding -- 32285
	AddRecipe(32285, 350, 25521, R_COMMON, GAME_TBC, 350, 350, 355, 360)
	self:addTradeFlags(RecipeDB, 32285, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOP, F.CENARION_EXPEDITION)
	self:addTradeAcquire(RecipeDB, 32285, A.REPUTATION, FAC.CENARION_EXPEDITION, REP.HONORED, 17904)

	-- Fel Iron Rod -- 32655
	AddRecipe(32655, 300, 25843, R_COMMON, GAME_TBC, 300, 300, 305, 310)
	self:addTradeFlags(RecipeDB, 32655, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP)
	self:addTradeAcquire(RecipeDB, 32655, A.TRAINER, 16583, A.TRAINER, 16823, A.TRAINER, 19341, A.TRAINER, 28694, A.TRAINER, 27034, A.TRAINER, 33591, A.TRAINER, 26988, A.TRAINER, 33609, A.TRAINER, 33631, A.TRAINER, 33675, A.TRAINER, 26981, A.TRAINER, 26564, A.TRAINER, 26952, A.TRAINER, 26904, A.TRAINER, 29924)

	-- Adamantite Rod -- 32656
	AddRecipe(32656, 350, 25844, R_COMMON, GAME_TBC, 350, 350, 355, 360)
	self:addTradeFlags(RecipeDB, 32656, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOE)
	self:addTradeAcquire(RecipeDB, 32656, A.VENDOR, 19662)

	-- Eternium Rod -- 32657
	AddRecipe(32657, 360, 25845, R_COMMON, GAME_TBC, 360, 365, 370, 375)
	self:addTradeFlags(RecipeDB, 32657, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOE)
	self:addTradeAcquire(RecipeDB, 32657, A.VENDOR, 16583, A.VENDOR, 19373)

	-- Nether Chain Shirt -- 34529
	AddRecipe(34529, 350, 23563, R_COMMON, GAME_TBC, 350, 360, 370, 380, 9788)
	self:addTradeFlags(RecipeDB, 34529, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOP, F.RBOP, F.DPS, F.HEALER, F.CASTER, F.MAIL)
	self:addTradeAcquire(RecipeDB, 34529, A.TRAINER, 5164, A.TRAINER, 7230, A.TRAINER, 11177, A.TRAINER, 20125, A.TRAINER, 29506)

	-- Twisting Nether Chain Shirt -- 34530
	AddRecipe(34530, 375, 23564, R_COMMON, GAME_TBC, 375, 385, 395, 405, 9788)
	self:addTradeFlags(RecipeDB, 34530, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOP, F.RBOP, F.DPS, F.MAIL)
	self:addTradeAcquire(RecipeDB, 34530, A.TRAINER, 5164, A.TRAINER, 7230, A.TRAINER, 11177, A.TRAINER, 20125, A.TRAINER, 29506)

	-- Breastplate of Kings -- 34533
	AddRecipe(34533, 350, 28483, R_COMMON, GAME_TBC, 350, 360, 370, 380, 9788)
	self:addTradeFlags(RecipeDB, 34533, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOP, F.RBOP, F.DPS, F.PLATE)
	self:addTradeAcquire(RecipeDB, 34533, A.TRAINER, 5164, A.TRAINER, 7230, A.TRAINER, 11177, A.TRAINER, 20125, A.TRAINER, 29506)

	-- Bulwark of Kings -- 34534
	AddRecipe(34534, 375, 28484, R_COMMON, GAME_TBC, 375, 385, 395, 405, 9788)
	self:addTradeFlags(RecipeDB, 34534, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOP, F.RBOP, F.DPS, F.PLATE)
	self:addTradeAcquire(RecipeDB, 34534, A.TRAINER, 5164, A.TRAINER, 7230, A.TRAINER, 11177, A.TRAINER, 20125, A.TRAINER, 29506)

	-- Fireguard -- 34535
	AddRecipe(34535, 350, 28425, R_COMMON, GAME_TBC, 350, 360, 370, 380, 17039)
	self:addTradeFlags(RecipeDB, 34535, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOP, F.RBOP, F.DPS, F.ONE_HAND, F.SWORD)
	self:addTradeAcquire(RecipeDB, 34535, A.TRAINER, 7231, A.TRAINER, 7232, A.TRAINER, 11146, A.TRAINER, 11178, A.TRAINER, 20124, A.TRAINER, 29505)

	-- Blazeguard -- 34537
	AddRecipe(34537, 375, 28426, R_COMMON, GAME_TBC, 375, 385, 395, 405, 17039)
	self:addTradeFlags(RecipeDB, 34537, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOP, F.RBOP, F.DPS, F.ONE_HAND, F.SWORD)
	self:addTradeAcquire(RecipeDB, 34537, A.TRAINER, 7231, A.TRAINER, 7232, A.TRAINER, 11146, A.TRAINER, 11178, A.TRAINER, 20124, A.TRAINER, 29505)

	-- Lionheart Blade -- 34538
	AddRecipe(34538, 350, 28428, R_COMMON, GAME_TBC, 350, 360, 370, 380, 17039)
	self:addTradeFlags(RecipeDB, 34538, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOP, F.RBOP, F.DPS, F.TWO_HAND, F.SWORD)
	self:addTradeAcquire(RecipeDB, 34538, A.TRAINER, 7231, A.TRAINER, 7232, A.TRAINER, 11146, A.TRAINER, 11178, A.TRAINER, 20124, A.TRAINER, 29505)

	-- Lionheart Champion -- 34540
	AddRecipe(34540, 375, 28429, R_COMMON, GAME_TBC, 375, 385, 395, 405, 17039)
	self:addTradeFlags(RecipeDB, 34540, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOP, F.RBOP, F.DPS, F.TWO_HAND, F.SWORD)
	self:addTradeAcquire(RecipeDB, 34540, A.TRAINER, 7231, A.TRAINER, 7232, A.TRAINER, 11146, A.TRAINER, 11178, A.TRAINER, 20124, A.TRAINER, 29505)

	-- The Planar Edge -- 34541
	AddRecipe(34541, 350, 28431, R_COMMON, GAME_TBC, 350, 360, 370, 380, 17041)
	self:addTradeFlags(RecipeDB, 34541, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOP, F.RBOP, F.DPS, F.ONE_HAND, F.AXE)
	self:addTradeAcquire(RecipeDB, 34541, A.TRAINER, 7231, A.TRAINER, 7232, A.TRAINER, 11146, A.TRAINER, 11178, A.TRAINER, 20124, A.TRAINER, 29505)

	-- Black Planar Edge -- 34542
	AddRecipe(34542, 375, 28432, R_COMMON, GAME_TBC, 375, 385, 395, 405, 17041)
	self:addTradeFlags(RecipeDB, 34542, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOP, F.RBOP, F.DPS, F.ONE_HAND, F.AXE)
	self:addTradeAcquire(RecipeDB, 34542, A.TRAINER, 7231, A.TRAINER, 7232, A.TRAINER, 11146, A.TRAINER, 11178, A.TRAINER, 20124, A.TRAINER, 29505)

	-- Lunar Crescent -- 34543
	AddRecipe(34543, 350, 28434, R_COMMON, GAME_TBC, 350, 360, 370, 380, 17041)
	self:addTradeFlags(RecipeDB, 34543, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOP, F.RBOP, F.DPS, F.TWO_HAND, F.AXE)
	self:addTradeAcquire(RecipeDB, 34543, A.TRAINER, 7231, A.TRAINER, 7232, A.TRAINER, 11146, A.TRAINER, 11178, A.TRAINER, 20124, A.TRAINER, 29505)

	-- Mooncleaver -- 34544
	AddRecipe(34544, 375, 28435, R_COMMON, GAME_TBC, 375, 385, 395, 405, 17041)
	self:addTradeFlags(RecipeDB, 34544, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOP, F.RBOP, F.DPS, F.TWO_HAND, F.AXE)
	self:addTradeAcquire(RecipeDB, 34544, A.TRAINER, 7231, A.TRAINER, 7232, A.TRAINER, 11146, A.TRAINER, 11178, A.TRAINER, 20124, A.TRAINER, 29505)

	-- Drakefist Hammer -- 34545
	AddRecipe(34545, 350, 28437, R_COMMON, GAME_TBC, 350, 360, 370, 380, 17040)
	self:addTradeFlags(RecipeDB, 34545, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOP, F.RBOP, F.ONE_HAND, F.MACE)
	self:addTradeAcquire(RecipeDB, 34545, A.TRAINER, 7231, A.TRAINER, 7232, A.TRAINER, 11146, A.TRAINER, 11178, A.TRAINER, 20124, A.TRAINER, 29505)

	-- Dragonmaw -- 34546
	AddRecipe(34546, 375, 28438, R_COMMON, GAME_TBC, 375, 385, 395, 405, 17040)
	self:addTradeFlags(RecipeDB, 34546, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOP, F.RBOP, F.ONE_HAND, F.MACE)
	self:addTradeAcquire(RecipeDB, 34546, A.TRAINER, 7231, A.TRAINER, 7232, A.TRAINER, 11146, A.TRAINER, 11178, A.TRAINER, 20124, A.TRAINER, 29505)

	-- Thunder -- 34547
	AddRecipe(34547, 350, 28440, R_COMMON, GAME_TBC, 350, 360, 370, 380, 17040)
	self:addTradeFlags(RecipeDB, 34547, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOP, F.RBOP, F.DPS, F.TWO_HAND, F.MACE)
	self:addTradeAcquire(RecipeDB, 34547, A.TRAINER, 7231, A.TRAINER, 7232, A.TRAINER, 11146, A.TRAINER, 11178, A.TRAINER, 20124, A.TRAINER, 29505)

	-- Deep Thunder -- 34548
	AddRecipe(34548, 375, 28441, R_COMMON, GAME_TBC, 375, 385, 395, 405, 17040)
	self:addTradeFlags(RecipeDB, 34548, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOP, F.RBOP, F.DPS, F.TWO_HAND, F.MACE)
	self:addTradeAcquire(RecipeDB, 34548, A.TRAINER, 7231, A.TRAINER, 7232, A.TRAINER, 11146, A.TRAINER, 11178, A.TRAINER, 20124, A.TRAINER, 29505)

	-- Fel Weightstone -- 34607
	AddRecipe(34607, 300, 28420, R_COMMON, GAME_TBC, 300, 300, 305, 310)
	self:addTradeFlags(RecipeDB, 34607, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.DPS)
	self:addTradeAcquire(RecipeDB, 34607, A.TRAINER, 16583, A.TRAINER, 16823, A.TRAINER, 19341, A.TRAINER, 28694, A.TRAINER, 27034, A.TRAINER, 33591, A.TRAINER, 26988, A.TRAINER, 33609, A.TRAINER, 33631, A.TRAINER, 33675, A.TRAINER, 26981, A.TRAINER, 26564, A.TRAINER, 26952, A.TRAINER, 26904, A.TRAINER, 29924)

	-- Adamantite Weightstone -- 34608
	AddRecipe(34608, 350, 28421, R_COMMON, GAME_TBC, 350, 350, 355, 360)
	self:addTradeFlags(RecipeDB, 34608, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOP, F.DPS, F.CENARION_EXPEDITION)
	self:addTradeAcquire(RecipeDB, 34608, A.REPUTATION, FAC.CENARION_EXPEDITION, REP.HONORED, 17904)

	-- Thick Bronze Darts -- 34979
	AddRecipe(34979, 100, 29201, R_COMMON, GAME_TBC, 100, 130, 145, 160)
	self:addTradeFlags(RecipeDB, 34979, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.DPS, F.THROWN)
	self:addTradeAcquire(RecipeDB, 34979, A.TRAINER, 2836, A.TRAINER, 2998, A.TRAINER, 3136, A.TRAINER, 3355, A.TRAINER, 3478, A.TRAINER, 4258, A.TRAINER, 4596, A.TRAINER, 5511, A.TRAINER, 16583, A.TRAINER, 16669, A.TRAINER, 16724, A.TRAINER, 16823, A.TRAINER, 19341, A.TRAINER, 28694, A.TRAINER, 27034, A.TRAINER, 514, A.TRAINER, 1241, A.TRAINER, 33591, A.TRAINER, 3174, A.TRAINER, 26988, A.TRAINER, 33609, A.TRAINER, 33631, A.TRAINER, 15400, A.TRAINER, 33675, A.TRAINER, 26981, A.TRAINER, 17245, A.TRAINER, 6299, A.TRAINER, 26564, A.TRAINER, 26952, A.TRAINER, 3557, A.TRAINER, 26904, A.TRAINER, 29924)

	-- Whirling Steel Axes -- 34981
	AddRecipe(34981, 200, 29202, R_COMMON, GAME_TBC, 200, 220, 230, 240)
	self:addTradeFlags(RecipeDB, 34981, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.DPS, F.THROWN)
	self:addTradeAcquire(RecipeDB, 34981, A.TRAINER, 2836, A.TRAINER, 3355, A.TRAINER, 4258, A.TRAINER, 16583, A.TRAINER, 16669, A.TRAINER, 16823, A.TRAINER, 19341, A.TRAINER, 28694, A.TRAINER, 27034, A.TRAINER, 5511, A.TRAINER, 514, A.TRAINER, 1241, A.TRAINER, 16724, A.TRAINER, 33591, A.TRAINER, 2998, A.TRAINER, 3478, A.TRAINER, 3136, A.TRAINER, 4596, A.TRAINER, 3174, A.TRAINER, 26988, A.TRAINER, 33609, A.TRAINER, 33631, A.TRAINER, 15400, A.TRAINER, 33675, A.TRAINER, 26981, A.TRAINER, 17245, A.TRAINER, 6299, A.TRAINER, 26564, A.TRAINER, 26952, A.TRAINER, 3557, A.TRAINER, 26904, A.TRAINER, 29924)

	-- Enchanted Thorium Blades -- 34982
	AddRecipe(34982, 300, 29203, R_COMMON, GAME_TBC, 300, 320, 330, 340)
	self:addTradeFlags(RecipeDB, 34982, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.DPS, F.THROWN)
	self:addTradeAcquire(RecipeDB, 34982, A.TRAINER, 2836, A.TRAINER, 16583, A.TRAINER, 16823, A.TRAINER, 19341, A.TRAINER, 28694, A.TRAINER, 27034, A.TRAINER, 4258, A.TRAINER, 5511, A.TRAINER, 514, A.TRAINER, 1241, A.TRAINER, 16724, A.TRAINER, 3355, A.TRAINER, 33591, A.TRAINER, 2998, A.TRAINER, 3478, A.TRAINER, 3136, A.TRAINER, 4596, A.TRAINER, 3174, A.TRAINER, 26988, A.TRAINER, 33609, A.TRAINER, 33631, A.TRAINER, 15400, A.TRAINER, 33675, A.TRAINER, 26981, A.TRAINER, 17245, A.TRAINER, 6299, A.TRAINER, 26564, A.TRAINER, 26952, A.TRAINER, 3557, A.TRAINER, 26904, A.TRAINER, 29924)

	-- Felsteel Whisper Knives -- 34983
	AddRecipe(34983, 350, 29204, R_COMMON, GAME_TBC, 350, 360, 370, 380)
	self:addTradeFlags(RecipeDB, 34983, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.DPS, F.THROWN)
	self:addTradeAcquire(RecipeDB, 34983, A.TRAINER, 16583, A.TRAINER, 16823, A.TRAINER, 19341, A.TRAINER, 28694, A.TRAINER, 27034, A.TRAINER, 33591, A.TRAINER, 26988, A.TRAINER, 33609, A.TRAINER, 33631, A.TRAINER, 33675, A.TRAINER, 26981, A.TRAINER, 26564, A.TRAINER, 26952, A.TRAINER, 26904, A.TRAINER, 29924)

	-- Earthforged Leggings -- 36122
	AddRecipe(36122, 260, 30069, R_COMMON, GAME_TBC, 260, 280, 290, 300, 9788)
	self:addTradeFlags(RecipeDB, 36122, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOP, F.RBOP, F.DPS, F.PLATE)
	self:addTradeAcquire(RecipeDB, 36122, A.TRAINER, 5164, A.TRAINER, 7230, A.TRAINER, 11177, A.TRAINER, 20125, A.TRAINER, 29506)

	-- Windforged Leggings -- 36124
	AddRecipe(36124, 260, 30070, R_COMMON, GAME_TBC, 260, 280, 290, 300, 9788)
	self:addTradeFlags(RecipeDB, 36124, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOP, F.RBOP, F.DPS, F.MAIL)
	self:addTradeAcquire(RecipeDB, 36124, A.TRAINER, 5164, A.TRAINER, 7230, A.TRAINER, 11177, A.TRAINER, 20125, A.TRAINER, 29506)

	-- Light Earthforged Blade -- 36125
	AddRecipe(36125, 260, 30071, R_COMMON, GAME_TBC, 260, 280, 290, 300, 9787)
	self:addTradeFlags(RecipeDB, 36125, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOP, F.RBOP, F.ONE_HAND, F.SWORD)
	self:addTradeAcquire(RecipeDB, 36125, A.TRAINER, 7231, A.TRAINER, 7232, A.TRAINER, 11146, A.TRAINER, 11178, A.TRAINER, 20124, A.TRAINER, 29505)

	-- Light Skyforged Axe -- 36126
	AddRecipe(36126, 260, 30072, R_COMMON, GAME_TBC, 260, 280, 290, 300, 9787)
	self:addTradeFlags(RecipeDB, 36126, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOP, F.RBOP, F.ONE_HAND, F.AXE)
	self:addTradeAcquire(RecipeDB, 36126, A.TRAINER, 7231, A.TRAINER, 7232, A.TRAINER, 11146, A.TRAINER, 11178, A.TRAINER, 20124, A.TRAINER, 29505)

	-- Light Emberforged Hammer -- 36128
	AddRecipe(36128, 260, 30073, R_COMMON, GAME_TBC, 260, 280, 290, 300, 9787)
	self:addTradeFlags(RecipeDB, 36128, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOP, F.RBOP, F.DPS, F.ONE_HAND, F.MACE)
	self:addTradeAcquire(RecipeDB, 36128, A.TRAINER, 7231, A.TRAINER, 7232, A.TRAINER, 11146, A.TRAINER, 11178, A.TRAINER, 20124, A.TRAINER, 29505)

	-- Heavy Earthforged Breastplate -- 36129
	AddRecipe(36129, 330, 30074, R_COMMON, GAME_TBC, 330, 340, 350, 360, 9788)
	self:addTradeFlags(RecipeDB, 36129, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOP, F.RBOP, F.TANK, F.PLATE)
	self:addTradeAcquire(RecipeDB, 36129, A.TRAINER, 5164, A.TRAINER, 7230, A.TRAINER, 11177, A.TRAINER, 20125, A.TRAINER, 29506)

	-- Stormforged Hauberk -- 36130
	AddRecipe(36130, 330, 30076, R_COMMON, GAME_TBC, 330, 340, 350, 360, 9788)
	self:addTradeFlags(RecipeDB, 36130, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOP, F.RBOP, F.DPS, F.MAIL)
	self:addTradeAcquire(RecipeDB, 36130, A.TRAINER, 5164, A.TRAINER, 7230, A.TRAINER, 11177, A.TRAINER, 20125, A.TRAINER, 29506)

	-- Windforged Rapier -- 36131
	AddRecipe(36131, 330, 30077, R_COMMON, GAME_TBC, 330, 340, 350, 360, 17039)
	self:addTradeFlags(RecipeDB, 36131, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOP, F.RBOP, F.ONE_HAND, F.SWORD)
	self:addTradeAcquire(RecipeDB, 36131, A.TRAINER, 7231, A.TRAINER, 7232, A.TRAINER, 11146, A.TRAINER, 11178, A.TRAINER, 20124, A.TRAINER, 29505)

	-- Stoneforged Claymore -- 36133
	AddRecipe(36133, 330, 30086, R_COMMON, GAME_TBC, 330, 340, 350, 360, 17039)
	self:addTradeFlags(RecipeDB, 36133, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOP, F.RBOP, F.DPS, F.TWO_HAND, F.SWORD)
	self:addTradeAcquire(RecipeDB, 36133, A.TRAINER, 7231, A.TRAINER, 7232, A.TRAINER, 11146, A.TRAINER, 11178, A.TRAINER, 20124, A.TRAINER, 29505)

	-- Stormforged Axe -- 36134
	AddRecipe(36134, 330, 30087, R_COMMON, GAME_TBC, 330, 340, 350, 360, 17041)
	self:addTradeFlags(RecipeDB, 36134, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOP, F.RBOP, F.DPS, F.ONE_HAND, F.AXE)
	self:addTradeAcquire(RecipeDB, 36134, A.TRAINER, 7231, A.TRAINER, 7232, A.TRAINER, 11146, A.TRAINER, 11178, A.TRAINER, 20124, A.TRAINER, 29505)

	-- Skyforged Great Axe -- 36135
	AddRecipe(36135, 330, 30088, R_COMMON, GAME_TBC, 330, 340, 350, 360, 17041)
	self:addTradeFlags(RecipeDB, 36135, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOP, F.RBOP, F.DPS, F.TWO_HAND, F.AXE)
	self:addTradeAcquire(RecipeDB, 36135, A.TRAINER, 7231, A.TRAINER, 7232, A.TRAINER, 11146, A.TRAINER, 11178, A.TRAINER, 20124, A.TRAINER, 29505)

	-- Lavaforged Warhammer -- 36136
	AddRecipe(36136, 330, 30089, R_COMMON, GAME_TBC, 330, 340, 350, 360, 17040)
	self:addTradeFlags(RecipeDB, 36136, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOP, F.RBOP, F.DPS, F.ONE_HAND, F.MACE)
	self:addTradeAcquire(RecipeDB, 36136, A.TRAINER, 7231, A.TRAINER, 7232, A.TRAINER, 11146, A.TRAINER, 11178, A.TRAINER, 20124, A.TRAINER, 29505)

	-- Great Earthforged Hammer -- 36137
	AddRecipe(36137, 330, 30093, R_COMMON, GAME_TBC, 330, 340, 350, 360, 17040)
	self:addTradeFlags(RecipeDB, 36137, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOP, F.RBOP, F.DPS, F.TWO_HAND, F.MACE)
	self:addTradeAcquire(RecipeDB, 36137, A.TRAINER, 7231, A.TRAINER, 7232, A.TRAINER, 11146, A.TRAINER, 11178, A.TRAINER, 20124, A.TRAINER, 29505)

	-- Embrace of the Twisting Nether -- 36256
	AddRecipe(36256, 375, 23565, R_COMMON, GAME_TBC, 375, 385, 395, 405, 9788)
	self:addTradeFlags(RecipeDB, 36256, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOP, F.RBOP, F.DPS, F.MAIL)
	self:addTradeAcquire(RecipeDB, 36256, A.TRAINER, 5164, A.TRAINER, 7230, A.TRAINER, 11177, A.TRAINER, 20125, A.TRAINER, 29506)

	-- Bulwark of the Ancient Kings -- 36257
	AddRecipe(36257, 375, 28485, R_COMMON, GAME_TBC, 375, 385, 395, 405, 9788)
	self:addTradeFlags(RecipeDB, 36257, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOP, F.RBOP, F.DPS, F.PLATE)
	self:addTradeAcquire(RecipeDB, 36257, A.TRAINER, 5164, A.TRAINER, 7230, A.TRAINER, 11177, A.TRAINER, 20125, A.TRAINER, 29506)

	-- Blazefury -- 36258
	AddRecipe(36258, 375, 28427, R_COMMON, GAME_TBC, 375, 385, 395, 405, 17039)
	self:addTradeFlags(RecipeDB, 36258, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOP, F.RBOP, F.DPS, F.ONE_HAND, F.SWORD)
	self:addTradeAcquire(RecipeDB, 36258, A.TRAINER, 7231, A.TRAINER, 7232, A.TRAINER, 11146, A.TRAINER, 11178, A.TRAINER, 20124, A.TRAINER, 29505)

	-- Lionheart Executioner -- 36259
	AddRecipe(36259, 375, 28430, R_COMMON, GAME_TBC, 375, 385, 395, 405, 17039)
	self:addTradeFlags(RecipeDB, 36259, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOP, F.RBOP, F.DPS, F.TWO_HAND, F.SWORD)
	self:addTradeAcquire(RecipeDB, 36259, A.TRAINER, 7231, A.TRAINER, 7232, A.TRAINER, 11146, A.TRAINER, 11178, A.TRAINER, 20124, A.TRAINER, 29505)

	-- Wicked Edge of the Planes -- 36260
	AddRecipe(36260, 375, 28433, R_COMMON, GAME_TBC, 375, 385, 395, 405, 17041)
	self:addTradeFlags(RecipeDB, 36260, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOP, F.RBOP, F.DPS, F.ONE_HAND, F.AXE)
	self:addTradeAcquire(RecipeDB, 36260, A.TRAINER, 7231, A.TRAINER, 7232, A.TRAINER, 11146, A.TRAINER, 11178, A.TRAINER, 20124, A.TRAINER, 29505)

	-- Bloodmoon -- 36261
	AddRecipe(36261, 375, 28436, R_COMMON, GAME_TBC, 375, 385, 395, 405, 17041)
	self:addTradeFlags(RecipeDB, 36261, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOP, F.RBOP, F.DPS, F.TWO_HAND, F.AXE)
	self:addTradeAcquire(RecipeDB, 36261, A.TRAINER, 7231, A.TRAINER, 7232, A.TRAINER, 11146, A.TRAINER, 11178, A.TRAINER, 20124, A.TRAINER, 29505)

	-- Dragonstrike -- 36262
	AddRecipe(36262, 375, 28439, R_COMMON, GAME_TBC, 375, 385, 395, 405, 17040)
	self:addTradeFlags(RecipeDB, 36262, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOP, F.RBOP, F.ONE_HAND, F.MACE)
	self:addTradeAcquire(RecipeDB, 36262, A.TRAINER, 7231, A.TRAINER, 7232, A.TRAINER, 11146, A.TRAINER, 11178, A.TRAINER, 20124, A.TRAINER, 29505)

	-- Stormherald -- 36263
	AddRecipe(36263, 375, 28442, R_COMMON, GAME_TBC, 375, 385, 395, 405, 17040)
	self:addTradeFlags(RecipeDB, 36263, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOP, F.RBOP, F.DPS, F.TWO_HAND, F.MACE)
	self:addTradeAcquire(RecipeDB, 36263, A.TRAINER, 7231, A.TRAINER, 7232, A.TRAINER, 11146, A.TRAINER, 11178, A.TRAINER, 20124, A.TRAINER, 29505)

	-- Belt of the Guardian -- 36389
	AddRecipe(36389, 375, 30034, R_EPIC, GAME_TBC, 375, 385, 395, 405)
	self:addTradeFlags(RecipeDB, 36389, F.ALLIANCE, F.HORDE, F.RAID, F.IBOE, F.RBOP, F.TANK, F.PLATE)
	self:addTradeAcquire(RecipeDB, 36389, A.CUSTOM, 37, A.CUSTOM, 43)

	-- Red Belt of Battle -- 36390
	AddRecipe(36390, 375, 30032, R_EPIC, GAME_TBC, 375, 385, 395, 405)
	self:addTradeFlags(RecipeDB, 36390, F.ALLIANCE, F.HORDE, F.RAID, F.IBOE, F.RBOP, F.DPS, F.PLATE)
	self:addTradeAcquire(RecipeDB, 36390, A.CUSTOM, 37, A.CUSTOM, 43)

	-- Boots of the Protector -- 36391
	AddRecipe(36391, 375, 30033, R_EPIC, GAME_TBC, 375, 385, 395, 405)
	self:addTradeFlags(RecipeDB, 36391, F.ALLIANCE, F.HORDE, F.RAID, F.IBOP, F.RBOP, F.TANK, F.PLATE)
	self:addTradeAcquire(RecipeDB, 36391, A.CUSTOM, 37, A.CUSTOM, 43)

	-- Red Havoc Boots -- 36392
	AddRecipe(36392, 375, 30031, R_EPIC, GAME_TBC, 375, 385, 395, 405)
	self:addTradeFlags(RecipeDB, 36392, F.ALLIANCE, F.HORDE, F.RAID, F.IBOP, F.RBOP, F.TANK, F.PLATE)
	self:addTradeAcquire(RecipeDB, 36392, A.CUSTOM, 37, A.CUSTOM, 43)

	-- Wildguard Breastplate -- 38473
	AddRecipe(38473, 375, 31364, R_EPIC, GAME_TBC, 375, 385, 395, 405)
	self:addTradeFlags(RecipeDB, 38473, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOP, F.TANK, F.PLATE, F.CENARION_EXPEDITION)
	self:addTradeAcquire(RecipeDB, 38473, A.REPUTATION, FAC.CENARION_EXPEDITION, REP.EXALTED, 17904)

	-- Wildguard Leggings -- 38475
	AddRecipe(38475, 375, 31367, R_EPIC, GAME_TBC, 375, 385, 395, 405)
	self:addTradeFlags(RecipeDB, 38475, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOP, F.PLATE, F.CENARION_EXPEDITION)
	self:addTradeAcquire(RecipeDB, 38475, A.REPUTATION, FAC.CENARION_EXPEDITION, REP.REVERED, 17904)

	-- Wildguard Helm -- 38476
	AddRecipe(38476, 375, 31368, R_EPIC, GAME_TBC, 375, 385, 395, 405)
	self:addTradeFlags(RecipeDB, 38476, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOP, F.TANK, F.PLATE, F.CENARION_EXPEDITION)
	self:addTradeAcquire(RecipeDB, 38476, A.REPUTATION, FAC.CENARION_EXPEDITION, REP.REVERED, 17904)

	-- Iceguard Breastplate -- 38477
	AddRecipe(38477, 375, 31369, R_EPIC, GAME_TBC, 375, 385, 395, 405)
	self:addTradeFlags(RecipeDB, 38477, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOP, F.TANK, F.PLATE, F.VIOLETEYE)
	self:addTradeAcquire(RecipeDB, 38477, A.REPUTATION, FAC.VIOLETEYE, REP.HONORED, 16388)

	-- Iceguard Leggings -- 38478
	AddRecipe(38478, 375, 31370, R_EPIC, GAME_TBC, 375, 385, 395, 405)
	self:addTradeFlags(RecipeDB, 38478, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOP, F.PLATE, F.VIOLETEYE)
	self:addTradeAcquire(RecipeDB, 38478, A.REPUTATION, FAC.VIOLETEYE, REP.REVERED, 16388)

	-- Iceguard Helm -- 38479
	AddRecipe(38479, 375, 31371, R_EPIC, GAME_TBC, 375, 385, 395, 405)
	self:addTradeFlags(RecipeDB, 38479, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOP, F.TANK, F.PLATE, F.VIOLETEYE)
	self:addTradeAcquire(RecipeDB, 38479, A.REPUTATION, FAC.VIOLETEYE, REP.HONORED, 16388)

	-- Shadesteel Sabots -- 40033
	AddRecipe(40033, 375, 32402, R_COMMON, GAME_TBC, 375, 385, 395, 405)
	self:addTradeFlags(RecipeDB, 40033, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOP, F.PLATE, F.ASHTONGUE)
	self:addTradeAcquire(RecipeDB, 40033, A.REPUTATION, FAC.ASHTONGUE, REP.HONORED, 23159)

	-- Shadesteel Bracers -- 40034
	AddRecipe(40034, 375, 32403, R_COMMON, GAME_TBC, 375, 385, 395, 405)
	self:addTradeFlags(RecipeDB, 40034, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOP, F.PLATE, F.ASHTONGUE)
	self:addTradeAcquire(RecipeDB, 40034, A.REPUTATION, FAC.ASHTONGUE, REP.FRIENDLY, 23159)

	-- Shadesteel Greaves -- 40035
	AddRecipe(40035, 375, 32404, R_COMMON, GAME_TBC, 375, 385, 395, 405)
	self:addTradeFlags(RecipeDB, 40035, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOP, F.PLATE, F.ASHTONGUE)
	self:addTradeAcquire(RecipeDB, 40035, A.REPUTATION, FAC.ASHTONGUE, REP.HONORED, 23159)

	-- Shadesteel Girdle -- 40036
	AddRecipe(40036, 375, 32401, R_COMMON, GAME_TBC, 375, 385, 395, 405)
	self:addTradeFlags(RecipeDB, 40036, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOP, F.PLATE, F.ASHTONGUE)
	self:addTradeAcquire(RecipeDB, 40036, A.REPUTATION, FAC.ASHTONGUE, REP.FRIENDLY, 23159)

	-- Swiftsteel Bracers -- 41132
	AddRecipe(41132, 375, 32568, R_EPIC, GAME_TBC, 375, 385, 395, 405)
	self:addTradeFlags(RecipeDB, 41132, F.ALLIANCE, F.HORDE, F.RAID, F.IBOE, F.RBOE, F.DPS, F.PLATE)
	self:addTradeAcquire(RecipeDB, 41132, A.CUSTOM, 27, A.CUSTOM, 34)

	-- Swiftsteel Shoulders -- 41133
	AddRecipe(41133, 375, 32570, R_EPIC, GAME_TBC, 375, 385, 395, 405)
	self:addTradeFlags(RecipeDB, 41133, F.ALLIANCE, F.HORDE, F.WORLD_DROP, F.IBOP, F.RBOP, F.DPS, F.PLATE)
	self:addTradeAcquire(RecipeDB, 41133, A.WORLD_DROP, 4)

	-- Dawnsteel Bracers -- 41134
	AddRecipe(41134, 375, 32571, R_EPIC, GAME_TBC, 375, 385, 395, 405)
	self:addTradeFlags(RecipeDB, 41134, F.ALLIANCE, F.HORDE, F.WORLD_DROP, F.IBOE, F.RBOE, F.HEALER, F.CASTER, F.PLATE)
	self:addTradeAcquire(RecipeDB, 41134, A.WORLD_DROP, 4)

	-- Dawnsteel Shoulders -- 41135
	AddRecipe(41135, 375, 32573, R_EPIC, GAME_TBC, 375, 385, 395, 405)
	self:addTradeFlags(RecipeDB, 41135, F.ALLIANCE, F.HORDE, F.RAID, F.IBOP, F.RBOP, F.HEALER, F.CASTER, F.PLATE)
	self:addTradeAcquire(RecipeDB, 41135, A.CUSTOM, 27, A.CUSTOM, 34)

	-- Ragesteel Shoulders -- 42662
	AddRecipe(42662, 365, 33173, R_RARE, GAME_TBC, 365, 375, 385, 395)
	self:addTradeFlags(RecipeDB, 42662, F.ALLIANCE, F.HORDE, F.MOB_DROP, F.IBOE, F.RBOP, F.DPS, F.PLATE)
	self:addTradeAcquire(RecipeDB, 42662, A.MOB, 21050, A.MOB, 21059, A.MOB, 21060, A.MOB, 21061)

	-- Adamantite Weapon Chain -- 42688
	AddRecipe(42688, 335, 33185, R_UNCOMMON, GAME_TBC, 335, 345, 350, 355)
	self:addTradeFlags(RecipeDB, 42688, F.ALLIANCE, F.HORDE, F.MOB_DROP, F.IBOE, F.RBOP, F.TANK)
	self:addTradeAcquire(RecipeDB, 42688, A.MOB, 24664)

	-- Heavy Copper Longsword -- 43549
	AddRecipe(43549, 35, 33791, R_UNCOMMON, GAME_TBC, 35, 75, 95, 115)
	self:addTradeFlags(RecipeDB, 43549, F.ALLIANCE, F.QUEST, F.IBOE, F.RBOE, F.DPS, F.ONE_HAND, F.SWORD)
	self:addTradeAcquire(RecipeDB, 43549, A.QUEST, 1578)

	-- Hammer of Righteous Might -- 43846
	AddRecipe(43846, 365, 32854, R_EPIC, GAME_TBC, 365, 375, 385, 395)
	self:addTradeFlags(RecipeDB, 43846, F.ALLIANCE, F.HORDE, F.WORLD_DROP, F.IBOE, F.RBOE, F.HEALER, F.CASTER, F.TWO_HAND, F.MACE)
	self:addTradeAcquire(RecipeDB, 43846, A.WORLD_DROP, 4)

	-- Sunblessed Gauntlets -- 46140
	AddRecipe(46140, 365, 34380, R_EPIC, GAME_TBC, 365, 375, 392, 410)
	self:addTradeFlags(RecipeDB, 46140, F.ALLIANCE, F.HORDE, F.RAID, F.IBOE, F.RBOP, F.HEALER, F.CASTER, F.PLATE)
	self:addTradeAcquire(RecipeDB, 46140, A.CUSTOM, 24)

	-- Hard Khorium Battlefists -- 46141
	AddRecipe(46141, 365, 34378, R_EPIC, GAME_TBC, 365, 375, 392, 410)
	self:addTradeFlags(RecipeDB, 46141, F.ALLIANCE, F.HORDE, F.RAID, F.IBOE, F.RBOP, F.DPS, F.PLATE)
	self:addTradeAcquire(RecipeDB, 46141, A.CUSTOM, 24)

	-- Sunblessed Breastplate -- 46142
	AddRecipe(46142, 365, 34379, R_EPIC, GAME_TBC, 365, 375, 392, 410)
	self:addTradeFlags(RecipeDB, 46142, F.ALLIANCE, F.HORDE, F.RAID, F.IBOP, F.RBOE, F.HEALER, F.CASTER, F.PLATE)
	self:addTradeAcquire(RecipeDB, 46142, A.CUSTOM, 24)

	-- Hard Khorium Battleplate -- 46144
	AddRecipe(46144, 365, 34377, R_EPIC, GAME_TBC, 365, 375, 392, 410)
	self:addTradeFlags(RecipeDB, 46144, F.ALLIANCE, F.HORDE, F.RAID, F.IBOP, F.RBOP, F.DPS, F.PLATE)
	self:addTradeAcquire(RecipeDB, 46144, A.CUSTOM, 24)

	-- Cobalt Legplates -- 52567
	AddRecipe(52567, 370, 39086, R_UNCOMMON, GAME_WOTLK, 370, 375, 380, 3985)
	self:addTradeFlags(RecipeDB, 52567, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.TANK, F.PLATE)
	self:addTradeAcquire(RecipeDB, 52567, A.TRAINER, 26564, A.TRAINER, 26904, A.TRAINER, 26952, A.TRAINER, 26981, A.TRAINER, 26988, A.TRAINER, 27034, A.TRAINER, 28694, A.TRAINER, 29924, A.TRAINER, 33591)

	-- Cobalt Belt -- 52568
	AddRecipe(52568, 350, 39087, R_UNCOMMON, GAME_WOTLK, 350, 360, 370, 380)
	self:addTradeFlags(RecipeDB, 52568, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.TANK, F.PLATE)
	self:addTradeAcquire(RecipeDB, 52568, A.TRAINER, 26564, A.TRAINER, 26904, A.TRAINER, 26952, A.TRAINER, 26981, A.TRAINER, 26988, A.TRAINER, 27034, A.TRAINER, 28694, A.TRAINER, 29924, A.TRAINER, 33591)

	-- Cobalt Boots -- 52569
	AddRecipe(52569, 350, 39088, R_UNCOMMON, GAME_WOTLK, 350, 360, 370, 380)
	self:addTradeFlags(RecipeDB, 52569, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.TANK, F.PLATE)
	self:addTradeAcquire(RecipeDB, 52569, A.TRAINER, 26564, A.TRAINER, 26904, A.TRAINER, 26952, A.TRAINER, 26981, A.TRAINER, 26988, A.TRAINER, 27034, A.TRAINER, 28694, A.TRAINER, 29924, A.TRAINER, 33591)

	-- Cobalt Chestpiece -- 52570
	AddRecipe(52570, 375, 39085, R_UNCOMMON, GAME_WOTLK, 375, 380, 385, 390)
	self:addTradeFlags(RecipeDB, 52570, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.TANK, F.PLATE)
	self:addTradeAcquire(RecipeDB, 52570, A.TRAINER, 26564, A.TRAINER, 26904, A.TRAINER, 26952, A.TRAINER, 26981, A.TRAINER, 26988, A.TRAINER, 27034, A.TRAINER, 28694, A.TRAINER, 29924, A.TRAINER, 33591)

	-- Cobalt Helm -- 52571
	AddRecipe(52571, 370, 39084, R_UNCOMMON, GAME_WOTLK, 370, 375, 380, 385)
	self:addTradeFlags(RecipeDB, 52571, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.TANK, F.PLATE)
	self:addTradeAcquire(RecipeDB, 52571, A.TRAINER, 26564, A.TRAINER, 26904, A.TRAINER, 26952, A.TRAINER, 26981, A.TRAINER, 26988, A.TRAINER, 27034, A.TRAINER, 28694, A.TRAINER, 29924, A.TRAINER, 33591)

	-- Cobalt Shoulders -- 52572
	AddRecipe(52572, 360, 39083, R_UNCOMMON, GAME_WOTLK, 360, 370, 375, 380)
	self:addTradeFlags(RecipeDB, 52572, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.TANK, F.PLATE)
	self:addTradeAcquire(RecipeDB, 52572, A.TRAINER, 26564, A.TRAINER, 26904, A.TRAINER, 26952, A.TRAINER, 26981, A.TRAINER, 26988, A.TRAINER, 27034, A.TRAINER, 28694, A.TRAINER, 29924, A.TRAINER, 33591)

	-- Cobalt Triangle Shield -- 54550
	AddRecipe(54550, 360, 40668, R_UNCOMMON, GAME_WOTLK, 360, 370, 375, 380)
	self:addTradeFlags(RecipeDB, 54550, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.TANK, F.SHIELD, F.ONE_HAND)
	self:addTradeAcquire(RecipeDB, 54550, A.TRAINER, 26564, A.TRAINER, 26904, A.TRAINER, 26952, A.TRAINER, 26981, A.TRAINER, 26988, A.TRAINER, 27034, A.TRAINER, 28694, A.TRAINER, 29924, A.TRAINER, 33591)

	-- Tempered Saronite Belt -- 54551
	AddRecipe(54551, 395, 40669, R_RARE, GAME_WOTLK, 395, 400, 405, 410)
	self:addTradeFlags(RecipeDB, 54551, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.TANK, F.PLATE)
	self:addTradeAcquire(RecipeDB, 54551, A.TRAINER, 26564, A.TRAINER, 26904, A.TRAINER, 26952, A.TRAINER, 26981, A.TRAINER, 26988, A.TRAINER, 27034, A.TRAINER, 28694, A.TRAINER, 29924, A.TRAINER, 33591)

	-- Tempered Saronite Boots -- 54552
	AddRecipe(54552, 400, 40671, R_RARE, GAME_WOTLK, 400, 405, 410, 415)
	self:addTradeFlags(RecipeDB, 54552, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.TANK, F.PLATE)
	self:addTradeAcquire(RecipeDB, 54552, A.TRAINER, 26564, A.TRAINER, 26904, A.TRAINER, 26952, A.TRAINER, 26981, A.TRAINER, 26988, A.TRAINER, 27034, A.TRAINER, 28694, A.TRAINER, 29924, A.TRAINER, 33591)

	-- Tempered Saronite Breastplate -- 54553
	AddRecipe(54553, 400, 40672, R_RARE, GAME_WOTLK, 400, 405, 410, 415)
	self:addTradeFlags(RecipeDB, 54553, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.TANK, F.PLATE)
	self:addTradeAcquire(RecipeDB, 54553, A.TRAINER, 26564, A.TRAINER, 26904, A.TRAINER, 26952, A.TRAINER, 26981, A.TRAINER, 26988, A.TRAINER, 27034, A.TRAINER, 28694, A.TRAINER, 29924, A.TRAINER, 33591)

	-- Tempered Saronite Legplates -- 54554
	AddRecipe(54554, 395, 40674, R_RARE, GAME_WOTLK, 395, 400, 405, 410)
	self:addTradeFlags(RecipeDB, 54554, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.TANK, F.PLATE)
	self:addTradeAcquire(RecipeDB, 54554, A.TRAINER, 26564, A.TRAINER, 26904, A.TRAINER, 26952, A.TRAINER, 26981, A.TRAINER, 26988, A.TRAINER, 27034, A.TRAINER, 28694, A.TRAINER, 29924, A.TRAINER, 33591)

	-- Tempered Saronite Helm -- 54555
	AddRecipe(54555, 405, 40673, R_RARE, GAME_WOTLK, 405, 410, 415, 420)
	self:addTradeFlags(RecipeDB, 54555, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.TANK, F.PLATE)
	self:addTradeAcquire(RecipeDB, 54555, A.TRAINER, 26564, A.TRAINER, 26904, A.TRAINER, 26952, A.TRAINER, 26981, A.TRAINER, 26988, A.TRAINER, 27034, A.TRAINER, 28694, A.TRAINER, 29924, A.TRAINER, 33591)

	-- Tempered Saronite Shoulders -- 54556
	AddRecipe(54556, 405, 40675, R_RARE, GAME_WOTLK, 405, 410, 415, 420)
	self:addTradeFlags(RecipeDB, 54556, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.TANK, F.PLATE)
	self:addTradeAcquire(RecipeDB, 54556, A.TRAINER, 26564, A.TRAINER, 26904, A.TRAINER, 26952, A.TRAINER, 26981, A.TRAINER, 26988, A.TRAINER, 27034, A.TRAINER, 28694, A.TRAINER, 29924, A.TRAINER, 33591)

	-- Saronite Defender -- 54557
	AddRecipe(54557, 390, 40670, R_RARE, GAME_WOTLK, 390, 395, 400, 405)
	self:addTradeFlags(RecipeDB, 54557, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.TANK, F.SHIELD, F.ONE_HAND)
	self:addTradeAcquire(RecipeDB, 54557, A.TRAINER, 26564, A.TRAINER, 26904, A.TRAINER, 26952, A.TRAINER, 26981, A.TRAINER, 26988, A.TRAINER, 27034, A.TRAINER, 28694, A.TRAINER, 29924, A.TRAINER, 33591)

	-- Spiked Cobalt Helm -- 54917
	AddRecipe(54917, 375, 40942, R_UNCOMMON, GAME_WOTLK, 375, 380, 385, 390)
	self:addTradeFlags(RecipeDB, 54917, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.DPS, F.PLATE)
	self:addTradeAcquire(RecipeDB, 54917, A.TRAINER, 26564, A.TRAINER, 26904, A.TRAINER, 26952, A.TRAINER, 26981, A.TRAINER, 26988, A.TRAINER, 27034, A.TRAINER, 28694, A.TRAINER, 29924, A.TRAINER, 33591)

	-- Spiked Cobalt Boots -- 54918
	AddRecipe(54918, 380, 40949, R_UNCOMMON, GAME_WOTLK, 380, 385, 390, 395)
	self:addTradeFlags(RecipeDB, 54918, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.DPS, F.PLATE)
	self:addTradeAcquire(RecipeDB, 54918, A.TRAINER, 26564, A.TRAINER, 26904, A.TRAINER, 26952, A.TRAINER, 26981, A.TRAINER, 26988, A.TRAINER, 27034, A.TRAINER, 28694, A.TRAINER, 29924, A.TRAINER, 33591)

	-- Spiked Cobalt Shoulders -- 54941
	AddRecipe(54941, 385, 40950, R_UNCOMMON, GAME_WOTLK, 385, 390, 395, 400)
	self:addTradeFlags(RecipeDB, 54941, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.DPS, F.PLATE)
	self:addTradeAcquire(RecipeDB, 54941, A.TRAINER, 26564, A.TRAINER, 26904, A.TRAINER, 26952, A.TRAINER, 26981, A.TRAINER, 26988, A.TRAINER, 27034, A.TRAINER, 28694, A.TRAINER, 29924, A.TRAINER, 33591)

	-- Spiked Cobalt Chestpiece -- 54944
	AddRecipe(54944, 385, 40951, R_UNCOMMON, GAME_WOTLK, 385, 390, 395, 400)
	self:addTradeFlags(RecipeDB, 54944, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.DPS, F.PLATE)
	self:addTradeAcquire(RecipeDB, 54944, A.TRAINER, 26564, A.TRAINER, 26904, A.TRAINER, 26952, A.TRAINER, 26981, A.TRAINER, 26988, A.TRAINER, 27034, A.TRAINER, 28694, A.TRAINER, 29924, A.TRAINER, 33591)

	-- Spiked Cobalt Gauntlets -- 54945
	AddRecipe(54945, 390, 40952, R_UNCOMMON, GAME_WOTLK, 390, 395, 400, 405)
	self:addTradeFlags(RecipeDB, 54945, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.DPS, F.PLATE)
	self:addTradeAcquire(RecipeDB, 54945, A.TRAINER, 26564, A.TRAINER, 26904, A.TRAINER, 26952, A.TRAINER, 26981, A.TRAINER, 26988, A.TRAINER, 27034, A.TRAINER, 28694, A.TRAINER, 29924, A.TRAINER, 33591)

	-- Spiked Cobalt Belt -- 54946
	AddRecipe(54946, 395, 40953, R_UNCOMMON, GAME_WOTLK, 395, 400, 405, 410)
	self:addTradeFlags(RecipeDB, 54946, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.DPS, F.PLATE)
	self:addTradeAcquire(RecipeDB, 54946, A.TRAINER, 26564, A.TRAINER, 26904, A.TRAINER, 26952, A.TRAINER, 26981, A.TRAINER, 26988, A.TRAINER, 27034, A.TRAINER, 28694, A.TRAINER, 29924, A.TRAINER, 33591)

	-- Spiked Cobalt Legplates -- 54947
	AddRecipe(54947, 395, 40943, R_UNCOMMON, GAME_WOTLK, 395, 400, 405, 410)
	self:addTradeFlags(RecipeDB, 54947, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.DPS, F.PLATE)
	self:addTradeAcquire(RecipeDB, 54947, A.TRAINER, 26564, A.TRAINER, 26904, A.TRAINER, 26952, A.TRAINER, 26981, A.TRAINER, 26988, A.TRAINER, 27034, A.TRAINER, 28694, A.TRAINER, 29924, A.TRAINER, 33591)

	-- Spiked Cobalt Bracers -- 54948
	AddRecipe(54948, 400, 40954, R_UNCOMMON, GAME_WOTLK, 400, 405, 410, 415)
	self:addTradeFlags(RecipeDB, 54948, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.DPS, F.PLATE)
	self:addTradeAcquire(RecipeDB, 54948, A.TRAINER, 26564, A.TRAINER, 26904, A.TRAINER, 26952, A.TRAINER, 26981, A.TRAINER, 26988, A.TRAINER, 27034, A.TRAINER, 28694, A.TRAINER, 29924, A.TRAINER, 33591)

	-- Horned Cobalt Helm -- 54949
	AddRecipe(54949, 400, 40955, R_UNCOMMON, GAME_WOTLK, 400, 405, 410, 415)
	self:addTradeFlags(RecipeDB, 54949, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.DPS, F.PLATE)
	self:addTradeAcquire(RecipeDB, 54949, A.TRAINER, 26564, A.TRAINER, 26904, A.TRAINER, 26952, A.TRAINER, 26981, A.TRAINER, 26988, A.TRAINER, 27034, A.TRAINER, 28694, A.TRAINER, 29924, A.TRAINER, 33591)

	-- Reinforced Cobalt Shoulders -- 54978
	AddRecipe(54978, 375, 40956, R_UNCOMMON, GAME_WOTLK, 375, 395, 400, 405)
	self:addTradeFlags(RecipeDB, 54978, F.ALLIANCE, F.HORDE, F.MOB_DROP, F.IBOE, F.RBOP, F.DPS, F.PLATE)
	self:addTradeAcquire(RecipeDB, 54978, A.MOB, 27333)

	-- Reinforced Cobalt Helm -- 54979
	AddRecipe(54979, 375, 40957, R_UNCOMMON, GAME_WOTLK, 375, 405, 410, 415)
	self:addTradeFlags(RecipeDB, 54979, F.ALLIANCE, F.HORDE, F.MOB_DROP, F.IBOE, F.RBOP, F.DPS, F.PLATE)
	self:addTradeAcquire(RecipeDB, 54979, A.MOB, 26270)

	-- Reinforced Cobalt Legplates -- 54980
	AddRecipe(54980, 375, 40958, R_UNCOMMON, GAME_WOTLK, 375, 410, 415, 420)
	self:addTradeFlags(RecipeDB, 54980, F.ALLIANCE, F.HORDE, F.MOB_DROP, F.IBOE, F.RBOP, F.DPS, F.PLATE)
	self:addTradeAcquire(RecipeDB, 54980, A.MOB, 29235)

	-- Reinforced Cobalt Chestpiece -- 54981
	AddRecipe(54981, 375, 40959, R_UNCOMMON, GAME_WOTLK, 375, 415, 420, 425)
	self:addTradeFlags(RecipeDB, 54981, F.ALLIANCE, F.HORDE, F.MOB_DROP, F.IBOE, F.RBOP, F.DPS, F.PLATE)
	self:addTradeAcquire(RecipeDB, 54981, A.MOB, 28123)

	-- Saronite Protector -- 55013
	AddRecipe(55013, 390, 41117, R_RARE, GAME_WOTLK, 390, 395, 400, 405)
	self:addTradeFlags(RecipeDB, 55013, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.HEALER, F.CASTER, F.SHIELD, F.ONE_HAND)
	self:addTradeAcquire(RecipeDB, 55013, A.TRAINER, 26564, A.TRAINER, 26904, A.TRAINER, 26952, A.TRAINER, 26981, A.TRAINER, 26988, A.TRAINER, 27034, A.TRAINER, 28694, A.TRAINER, 29924, A.TRAINER, 33591)

	-- Saronite Bulwark -- 55014
	AddRecipe(55014, 410, 41113, R_RARE, GAME_WOTLK, 410, 415, 420, 425)
	self:addTradeFlags(RecipeDB, 55014, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.TANK, F.SHIELD, F.ONE_HAND)
	self:addTradeAcquire(RecipeDB, 55014, A.TRAINER, 26564, A.TRAINER, 26904, A.TRAINER, 26952, A.TRAINER, 26981, A.TRAINER, 26988, A.TRAINER, 27034, A.TRAINER, 28694, A.TRAINER, 29924, A.TRAINER, 33591)

	-- Tempered Saronite Gauntlets -- 55015
	AddRecipe(55015, 415, 41114, R_RARE, GAME_WOTLK, 415, 420, 425, 430)
	self:addTradeFlags(RecipeDB, 55015, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.TANK, F.PLATE)
	self:addTradeAcquire(RecipeDB, 55015, A.TRAINER, 26564, A.TRAINER, 26904, A.TRAINER, 26952, A.TRAINER, 26981, A.TRAINER, 26988, A.TRAINER, 27034, A.TRAINER, 28694, A.TRAINER, 29924, A.TRAINER, 33591)

	-- Tempered Saronite Bracers -- 55017
	AddRecipe(55017, 410, 41116, R_RARE, GAME_WOTLK, 410, 415, 420, 425)
	self:addTradeFlags(RecipeDB, 55017, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.TANK, F.PLATE)
	self:addTradeAcquire(RecipeDB, 55017, A.TRAINER, 26564, A.TRAINER, 26904, A.TRAINER, 26952, A.TRAINER, 26981, A.TRAINER, 26988, A.TRAINER, 27034, A.TRAINER, 28694, A.TRAINER, 29924, A.TRAINER, 33591)

	-- Brilliant Saronite Legplates -- 55055
	AddRecipe(55055, 395, 41126, R_RARE, GAME_WOTLK, 395, 400, 405, 410)
	self:addTradeFlags(RecipeDB, 55055, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.HEALER, F.CASTER, F.PLATE)
	self:addTradeAcquire(RecipeDB, 55055, A.TRAINER, 26564, A.TRAINER, 26904, A.TRAINER, 26952, A.TRAINER, 26981, A.TRAINER, 26988, A.TRAINER, 27034, A.TRAINER, 28694, A.TRAINER, 29924, A.TRAINER, 33591)

	-- Brilliant Saronite Gauntlets -- 55056
	AddRecipe(55056, 400, 41127, R_RARE, GAME_WOTLK, 400, 405, 410, 415)
	self:addTradeFlags(RecipeDB, 55056, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.HEALER, F.CASTER, F.PLATE)
	self:addTradeAcquire(RecipeDB, 55056, A.TRAINER, 26564, A.TRAINER, 26904, A.TRAINER, 26952, A.TRAINER, 26981, A.TRAINER, 26988, A.TRAINER, 27034, A.TRAINER, 28694, A.TRAINER, 29924, A.TRAINER, 33591)

	-- Brilliant Saronite Boots -- 55057
	AddRecipe(55057, 405, 41128, R_RARE, GAME_WOTLK, 405, 410, 415, 420)
	self:addTradeFlags(RecipeDB, 55057, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.HEALER, F.CASTER, F.PLATE)
	self:addTradeAcquire(RecipeDB, 55057, A.TRAINER, 26564, A.TRAINER, 26904, A.TRAINER, 26952, A.TRAINER, 26981, A.TRAINER, 26988, A.TRAINER, 27034, A.TRAINER, 28694, A.TRAINER, 29924, A.TRAINER, 33591)

	-- Brilliant Saronite Breastplate -- 55058
	AddRecipe(55058, 415, 41129, R_RARE, GAME_WOTLK, 415, 420, 425, 430)
	self:addTradeFlags(RecipeDB, 55058, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.HEALER, F.CASTER, F.PLATE)
	self:addTradeAcquire(RecipeDB, 55058, A.TRAINER, 26564, A.TRAINER, 26904, A.TRAINER, 26952, A.TRAINER, 26981, A.TRAINER, 26988, A.TRAINER, 27034, A.TRAINER, 28694, A.TRAINER, 29924, A.TRAINER, 33591)

	-- Honed Cobalt Cleaver -- 55174
	AddRecipe(55174, 390, 41181, R_RARE, GAME_WOTLK, 390, 395, 400, 405)
	self:addTradeFlags(RecipeDB, 55174, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.DPS, F.TWO_HAND, F.AXE)
	self:addTradeAcquire(RecipeDB, 55174, A.TRAINER, 26564, A.TRAINER, 26904, A.TRAINER, 26952, A.TRAINER, 26981, A.TRAINER, 26988, A.TRAINER, 27034, A.TRAINER, 28694, A.TRAINER, 29924, A.TRAINER, 33591)

	-- Savage Cobalt Slicer -- 55177
	AddRecipe(55177, 395, 41182, R_RARE, GAME_WOTLK, 395, 400, 405, 410)
	self:addTradeFlags(RecipeDB, 55177, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.DPS, F.ONE_HAND, F.SWORD)
	self:addTradeAcquire(RecipeDB, 55177, A.TRAINER, 26564, A.TRAINER, 26904, A.TRAINER, 26952, A.TRAINER, 26981, A.TRAINER, 26988, A.TRAINER, 27034, A.TRAINER, 28694, A.TRAINER, 29924, A.TRAINER, 33591)

	-- Saronite Ambusher -- 55179
	AddRecipe(55179, 400, 41183, R_RARE, GAME_WOTLK, 400, 405, 410, 415)
	self:addTradeFlags(RecipeDB, 55179, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.DPS, F.ONE_HAND, F.DAGGER)
	self:addTradeAcquire(RecipeDB, 55179, A.TRAINER, 26564, A.TRAINER, 26904, A.TRAINER, 26952, A.TRAINER, 26981, A.TRAINER, 26988, A.TRAINER, 27034, A.TRAINER, 28694, A.TRAINER, 29924, A.TRAINER, 33591)

	-- Saronite Shiv -- 55181
	AddRecipe(55181, 405, 41184, R_RARE, GAME_WOTLK, 405, 410, 415, 420)
	self:addTradeFlags(RecipeDB, 55181, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.DPS, F.TANK, F.ONE_HAND, F.DAGGER)
	self:addTradeAcquire(RecipeDB, 55181, A.TRAINER, 26564, A.TRAINER, 26904, A.TRAINER, 26952, A.TRAINER, 26981, A.TRAINER, 26988, A.TRAINER, 27034, A.TRAINER, 28694, A.TRAINER, 29924, A.TRAINER, 33591)

	-- Furious Saronite Beatstick -- 55182
	AddRecipe(55182, 410, 41185, R_RARE, GAME_WOTLK, 410, 415, 420, 425)
	self:addTradeFlags(RecipeDB, 55182, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.DPS, F.ONE_HAND, F.MACE)
	self:addTradeAcquire(RecipeDB, 55182, A.TRAINER, 26564, A.TRAINER, 26904, A.TRAINER, 26952, A.TRAINER, 26981, A.TRAINER, 26988, A.TRAINER, 27034, A.TRAINER, 28694, A.TRAINER, 29924, A.TRAINER, 33591)

	-- Corroded Saronite Edge -- 55183
	AddRecipe(55183, 415, 41186, R_RARE, GAME_WOTLK, 415, 420, 425, 430, 9787)
	self:addTradeFlags(RecipeDB, 55183, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOP, F.RBOP, F.DPS, F.ONE_HAND, F.SWORD)
	self:addTradeAcquire(RecipeDB, 55183, A.TRAINER, 11146, A.TRAINER, 29505, A.TRAINER, 11178)

	-- Corroded Saronite Woundbringer -- 55184
	AddRecipe(55184, 415, 41187, R_RARE, GAME_WOTLK, 415, 420, 425, 430, 9787)
	self:addTradeFlags(RecipeDB, 55184, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOP, F.RBOP, F.DPS, F.ONE_HAND, F.SWORD)
	self:addTradeAcquire(RecipeDB, 55184, A.TRAINER, 11146, A.TRAINER, 29505, A.TRAINER, 11178)

	-- Saronite Mindcrusher -- 55185
	AddRecipe(55185, 415, 41188, R_RARE, GAME_WOTLK, 415, 420, 425, 430, 9787)
	self:addTradeFlags(RecipeDB, 55185, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOP, F.RBOP, F.DPS, F.TWO_HAND, F.MACE)
	self:addTradeAcquire(RecipeDB, 55185, A.TRAINER, 11146, A.TRAINER, 29505, A.TRAINER, 11178)

	-- Chestplate of Conquest -- 55186
	AddRecipe(55186, 415, 41189, R_RARE, GAME_WOTLK, 415, 420, 425, 430, 9788)
	self:addTradeFlags(RecipeDB, 55186, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOP, F.RBOP, F.DPS, F.PLATE)
	self:addTradeAcquire(RecipeDB, 55186, A.TRAINER, 29506, A.TRAINER, 5164, A.TRAINER, 11177)

	-- Legplates of Conquest -- 55187
	AddRecipe(55187, 415, 41190, R_RARE, GAME_WOTLK, 415, 420, 425, 430, 9788)
	self:addTradeFlags(RecipeDB, 55187, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOP, F.RBOP, F.DPS, F.PLATE)
	self:addTradeAcquire(RecipeDB, 55187, A.TRAINER, 29506, A.TRAINER, 5164, A.TRAINER, 11177)

	-- Sturdy Cobalt Quickblade -- 55200
	AddRecipe(55200, 380, 41239, R_UNCOMMON, GAME_WOTLK, 380, 385, 390, 395)
	self:addTradeFlags(RecipeDB, 55200, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.DPS, F.ONE_HAND, F.SWORD)
	self:addTradeAcquire(RecipeDB, 55200, A.TRAINER, 26564, A.TRAINER, 26904, A.TRAINER, 26952, A.TRAINER, 26981, A.TRAINER, 26988, A.TRAINER, 27034, A.TRAINER, 28694, A.TRAINER, 29924, A.TRAINER, 33591)

	-- Cobalt Tenderizer -- 55201
	AddRecipe(55201, 380, 41240, R_UNCOMMON, GAME_WOTLK, 380, 385, 390, 395)
	self:addTradeFlags(RecipeDB, 55201, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.DPS, F.ONE_HAND, F.MACE)
	self:addTradeAcquire(RecipeDB, 55201, A.TRAINER, 26564, A.TRAINER, 26904, A.TRAINER, 26952, A.TRAINER, 26981, A.TRAINER, 26988, A.TRAINER, 27034, A.TRAINER, 28694, A.TRAINER, 29924, A.TRAINER, 33591)

	-- Sure-fire Shuriken -- 55202
	AddRecipe(55202, 385, 41241, R_UNCOMMON, GAME_WOTLK, 385, 390, 395, 400)
	self:addTradeFlags(RecipeDB, 55202, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.THROWN)
	self:addTradeAcquire(RecipeDB, 55202, A.TRAINER, 26564, A.TRAINER, 26904, A.TRAINER, 26952, A.TRAINER, 26981, A.TRAINER, 26988, A.TRAINER, 27034, A.TRAINER, 28694, A.TRAINER, 29924, A.TRAINER, 33591)

	-- Forged Cobalt Claymore -- 55203
	AddRecipe(55203, 385, 41242, R_UNCOMMON, GAME_WOTLK, 385, 390, 395, 400)
	self:addTradeFlags(RecipeDB, 55203, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.DPS, F.TWO_HAND, F.SWORD)
	self:addTradeAcquire(RecipeDB, 55203, A.TRAINER, 26564, A.TRAINER, 26904, A.TRAINER, 26952, A.TRAINER, 26981, A.TRAINER, 26988, A.TRAINER, 27034, A.TRAINER, 28694, A.TRAINER, 29924, A.TRAINER, 33591)

	-- Notched Cobalt War Axe -- 55204
	AddRecipe(55204, 390, 41243, R_UNCOMMON, GAME_WOTLK, 390, 395, 400, 405)
	self:addTradeFlags(RecipeDB, 55204, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.DPS, F.ONE_HAND, F.AXE)
	self:addTradeAcquire(RecipeDB, 55204, A.TRAINER, 26564, A.TRAINER, 26904, A.TRAINER, 26952, A.TRAINER, 26981, A.TRAINER, 26988, A.TRAINER, 27034, A.TRAINER, 28694, A.TRAINER, 29924, A.TRAINER, 33591)

	-- Deadly Saronite Dirk -- 55206
	AddRecipe(55206, 405, 41245, R_RARE, GAME_WOTLK, 405, 415, 420, 425)
	self:addTradeFlags(RecipeDB, 55206, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.DPS, F.TANK, F.THROWN)
	self:addTradeAcquire(RecipeDB, 55206, A.TRAINER, 26564, A.TRAINER, 26904, A.TRAINER, 26952, A.TRAINER, 26981, A.TRAINER, 26988, A.TRAINER, 27034, A.TRAINER, 28694, A.TRAINER, 29924, A.TRAINER, 33591)

	-- Vengeance Bindings -- 55298
	AddRecipe(55298, 420, 41355, R_RARE, GAME_WOTLK, 420, 425, 430, 435)
	self:addTradeFlags(RecipeDB, 55298, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.DPS, F.PLATE)
	self:addTradeAcquire(RecipeDB, 55298, A.TRAINER, 26564, A.TRAINER, 26904, A.TRAINER, 26952, A.TRAINER, 26981, A.TRAINER, 26988, A.TRAINER, 27034, A.TRAINER, 28694, A.TRAINER, 29924, A.TRAINER, 33591)

	-- Righteous Gauntlets -- 55300
	AddRecipe(55300, 420, 41356, R_RARE, GAME_WOTLK, 420, 430, 440, 450)
	self:addTradeFlags(RecipeDB, 55300, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.HEALER, F.CASTER, F.PLATE)
	self:addTradeAcquire(RecipeDB, 55300, A.TRAINER, 26564, A.TRAINER, 26904, A.TRAINER, 26952, A.TRAINER, 26981, A.TRAINER, 26988, A.TRAINER, 27034, A.TRAINER, 28694, A.TRAINER, 29924, A.TRAINER, 33591)

	-- Daunting Handguards -- 55301
	AddRecipe(55301, 420, 41357, R_RARE, GAME_WOTLK, 420, 430, 440, 450)
	self:addTradeFlags(RecipeDB, 55301, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.TANK, F.PLATE)
	self:addTradeAcquire(RecipeDB, 55301, A.TRAINER, 26564, A.TRAINER, 26904, A.TRAINER, 26952, A.TRAINER, 26981, A.TRAINER, 26988, A.TRAINER, 27034, A.TRAINER, 28694, A.TRAINER, 29924, A.TRAINER, 33591)

	-- Helm of Command -- 55302
	AddRecipe(55302, 425, 41344, R_RARE, GAME_WOTLK, 425, 435, 445, 455)
	self:addTradeFlags(RecipeDB, 55302, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.DPS, F.PLATE)
	self:addTradeAcquire(RecipeDB, 55302, A.TRAINER, 26564, A.TRAINER, 26904, A.TRAINER, 26952, A.TRAINER, 26981, A.TRAINER, 26988, A.TRAINER, 27034, A.TRAINER, 28694, A.TRAINER, 29924, A.TRAINER, 33591)

	-- Daunting Legplates -- 55303
	AddRecipe(55303, 425, 41345, R_RARE, GAME_WOTLK, 425, 435, 445, 455)
	self:addTradeFlags(RecipeDB, 55303, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.TANK, F.PLATE)
	self:addTradeAcquire(RecipeDB, 55303, A.TRAINER, 26564, A.TRAINER, 26904, A.TRAINER, 26952, A.TRAINER, 26981, A.TRAINER, 26988, A.TRAINER, 27034, A.TRAINER, 28694, A.TRAINER, 29924, A.TRAINER, 33591)

	-- Righteous Greaves -- 55304
	AddRecipe(55304, 425, 41346, R_RARE, GAME_WOTLK, 425, 435, 445, 455)
	self:addTradeFlags(RecipeDB, 55304, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.HEALER, F.CASTER, F.PLATE)
	self:addTradeAcquire(RecipeDB, 55304, A.TRAINER, 26564, A.TRAINER, 26904, A.TRAINER, 26952, A.TRAINER, 26981, A.TRAINER, 26988, A.TRAINER, 27034, A.TRAINER, 28694, A.TRAINER, 29924, A.TRAINER, 33591)

	-- Savage Saronite Bracers -- 55305
	AddRecipe(55305, 420, 41354, R_RARE, GAME_WOTLK, 420, 425, 430, 435)
	self:addTradeFlags(RecipeDB, 55305, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.DPS, F.PLATE)
	self:addTradeAcquire(RecipeDB, 55305, A.TRAINER, 26564, A.TRAINER, 26904, A.TRAINER, 26952, A.TRAINER, 26981, A.TRAINER, 26988, A.TRAINER, 27034, A.TRAINER, 28694, A.TRAINER, 29924, A.TRAINER, 33591)

	-- Savage Saronite Pauldrons -- 55306
	AddRecipe(55306, 420, 41351, R_RARE, GAME_WOTLK, 420, 430, 440, 450)
	self:addTradeFlags(RecipeDB, 55306, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.DPS, F.PLATE)
	self:addTradeAcquire(RecipeDB, 55306, A.TRAINER, 26564, A.TRAINER, 26904, A.TRAINER, 26952, A.TRAINER, 26981, A.TRAINER, 26988, A.TRAINER, 27034, A.TRAINER, 28694, A.TRAINER, 29924, A.TRAINER, 33591)

	-- Savage Saronite Waistguard -- 55307
	AddRecipe(55307, 420, 41352, R_RARE, GAME_WOTLK, 420, 430, 440, 450)
	self:addTradeFlags(RecipeDB, 55307, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.DPS, F.PLATE)
	self:addTradeAcquire(RecipeDB, 55307, A.TRAINER, 26564, A.TRAINER, 26904, A.TRAINER, 26952, A.TRAINER, 26981, A.TRAINER, 26988, A.TRAINER, 27034, A.TRAINER, 28694, A.TRAINER, 29924, A.TRAINER, 33591)

	-- Savage Saronite Walkers -- 55308
	AddRecipe(55308, 420, 41348, R_RARE, GAME_WOTLK, 420, 430, 440, 450)
	self:addTradeFlags(RecipeDB, 55308, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.DPS, F.PLATE)
	self:addTradeAcquire(RecipeDB, 55308, A.TRAINER, 26564, A.TRAINER, 26904, A.TRAINER, 26952, A.TRAINER, 26981, A.TRAINER, 26988, A.TRAINER, 27034, A.TRAINER, 28694, A.TRAINER, 29924, A.TRAINER, 33591)

	-- Savage Saronite Gauntlets -- 55309
	AddRecipe(55309, 420, 41349, R_RARE, GAME_WOTLK, 420, 430, 440, 450)
	self:addTradeFlags(RecipeDB, 55309, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.DPS, F.PLATE)
	self:addTradeAcquire(RecipeDB, 55309, A.TRAINER, 26564, A.TRAINER, 26904, A.TRAINER, 26952, A.TRAINER, 26981, A.TRAINER, 26988, A.TRAINER, 27034, A.TRAINER, 28694, A.TRAINER, 29924, A.TRAINER, 33591)

	-- Savage Saronite Legplates -- 55310
	AddRecipe(55310, 425, 41347, R_RARE, GAME_WOTLK, 425, 435, 445, 455)
	self:addTradeFlags(RecipeDB, 55310, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.DPS, F.PLATE)
	self:addTradeAcquire(RecipeDB, 55310, A.TRAINER, 26564, A.TRAINER, 26904, A.TRAINER, 26952, A.TRAINER, 26981, A.TRAINER, 26988, A.TRAINER, 27034, A.TRAINER, 28694, A.TRAINER, 29924, A.TRAINER, 33591)

	-- Savage Saronite Hauberk -- 55311
	AddRecipe(55311, 425, 41353, R_RARE, GAME_WOTLK, 425, 435, 445, 455)
	self:addTradeFlags(RecipeDB, 55311, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.DPS, F.PLATE)
	self:addTradeAcquire(RecipeDB, 55311, A.TRAINER, 26564, A.TRAINER, 26904, A.TRAINER, 26952, A.TRAINER, 26981, A.TRAINER, 26988, A.TRAINER, 27034, A.TRAINER, 28694, A.TRAINER, 29924, A.TRAINER, 33591)

	-- Savage Saronite Skullshield -- 55312
	AddRecipe(55312, 425, 41350, R_RARE, GAME_WOTLK, 425, 435, 445, 455)
	self:addTradeFlags(RecipeDB, 55312, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.DPS, F.PLATE)
	self:addTradeAcquire(RecipeDB, 55312, A.TRAINER, 26564, A.TRAINER, 26904, A.TRAINER, 26952, A.TRAINER, 26981, A.TRAINER, 26988, A.TRAINER, 27034, A.TRAINER, 28694, A.TRAINER, 29924, A.TRAINER, 33591)

	-- Titansteel Destroyer -- 55369
	AddRecipe(55369, 440, 41257, R_EPIC, GAME_WOTLK, 440, 450, 460, 470)
	self:addTradeFlags(RecipeDB, 55369, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.DPS, F.TWO_HAND, F.MACE)
	self:addTradeAcquire(RecipeDB, 55369, A.TRAINER, 26564, A.TRAINER, 26904, A.TRAINER, 26952, A.TRAINER, 26981, A.TRAINER, 26988, A.TRAINER, 27034, A.TRAINER, 28694, A.TRAINER, 29924, A.TRAINER, 33591)

	-- Titansteel Bonecrusher -- 55370
	AddRecipe(55370, 440, 41383, R_EPIC, GAME_WOTLK, 440, 450, 460, 470)
	self:addTradeFlags(RecipeDB, 55370, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.DPS, F.TANK, F.ONE_HAND, F.MACE)
	self:addTradeAcquire(RecipeDB, 55370, A.TRAINER, 26564, A.TRAINER, 26904, A.TRAINER, 26952, A.TRAINER, 26981, A.TRAINER, 26988, A.TRAINER, 27034, A.TRAINER, 28694, A.TRAINER, 29924, A.TRAINER, 33591)

	-- Titansteel Guardian -- 55371
	AddRecipe(55371, 440, 41384, R_EPIC, GAME_WOTLK, 440, 450, 460, 470)
	self:addTradeFlags(RecipeDB, 55371, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.HEALER, F.CASTER, F.ONE_HAND, F.MACE)
	self:addTradeAcquire(RecipeDB, 55371, A.TRAINER, 26564, A.TRAINER, 26904, A.TRAINER, 26952, A.TRAINER, 26981, A.TRAINER, 26988, A.TRAINER, 27034, A.TRAINER, 28694, A.TRAINER, 29924, A.TRAINER, 33591)

	-- Spiked Titansteel Helm -- 55372
	AddRecipe(55372, 440, 41386, R_EPIC, GAME_WOTLK, 440, 450, 460, 470)
	self:addTradeFlags(RecipeDB, 55372, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.DPS, F.PLATE)
	self:addTradeAcquire(RecipeDB, 55372, A.TRAINER, 26564, A.TRAINER, 26904, A.TRAINER, 26952, A.TRAINER, 26981, A.TRAINER, 26988, A.TRAINER, 27034, A.TRAINER, 28694, A.TRAINER, 29924, A.TRAINER, 33591)

	-- Tempered Titansteel Helm -- 55373
	AddRecipe(55373, 440, 41387, R_EPIC, GAME_WOTLK, 440, 450, 460, 470)
	self:addTradeFlags(RecipeDB, 55373, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.TANK, F.PLATE)
	self:addTradeAcquire(RecipeDB, 55373, A.TRAINER, 26564, A.TRAINER, 26904, A.TRAINER, 26952, A.TRAINER, 26981, A.TRAINER, 26988, A.TRAINER, 27034, A.TRAINER, 28694, A.TRAINER, 29924, A.TRAINER, 33591)

	-- Brilliant Titansteel Helm -- 55374
	AddRecipe(55374, 440, 41388, R_EPIC, GAME_WOTLK, 440, 450, 460, 470)
	self:addTradeFlags(RecipeDB, 55374, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.HEALER, F.CASTER, F.PLATE)
	self:addTradeAcquire(RecipeDB, 55374, A.TRAINER, 26564, A.TRAINER, 26904, A.TRAINER, 26952, A.TRAINER, 26981, A.TRAINER, 26988, A.TRAINER, 27034, A.TRAINER, 28694, A.TRAINER, 29924, A.TRAINER, 33591)

	-- Spiked Titansteel Treads -- 55375
	AddRecipe(55375, 440, 41391, R_EPIC, GAME_WOTLK, 440, 450, 460, 470)
	self:addTradeFlags(RecipeDB, 55375, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.DPS, F.PLATE)
	self:addTradeAcquire(RecipeDB, 55375, A.TRAINER, 26564, A.TRAINER, 26904, A.TRAINER, 26952, A.TRAINER, 26981, A.TRAINER, 26988, A.TRAINER, 27034, A.TRAINER, 28694, A.TRAINER, 29924, A.TRAINER, 33591)

	-- Tempered Titansteel Treads -- 55376
	AddRecipe(55376, 440, 41392, R_EPIC, GAME_WOTLK, 440, 450, 460, 470)
	self:addTradeFlags(RecipeDB, 55376, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.TANK, F.PLATE)
	self:addTradeAcquire(RecipeDB, 55376, A.TRAINER, 26564, A.TRAINER, 26904, A.TRAINER, 26952, A.TRAINER, 26981, A.TRAINER, 26988, A.TRAINER, 27034, A.TRAINER, 28694, A.TRAINER, 29924, A.TRAINER, 33591)

	-- Brilliant Titansteel Treads -- 55377
	AddRecipe(55377, 440, 41394, R_EPIC, GAME_WOTLK, 440, 450, 460, 470)
	self:addTradeFlags(RecipeDB, 55377, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.HEALER, F.CASTER, F.PLATE)
	self:addTradeAcquire(RecipeDB, 55377, A.TRAINER, 26564, A.TRAINER, 26904, A.TRAINER, 26952, A.TRAINER, 26981, A.TRAINER, 26988, A.TRAINER, 27034, A.TRAINER, 28694, A.TRAINER, 29924, A.TRAINER, 33591)

	-- Socket Bracer -- 55628
	AddRecipe(55628, 400, nil, R_COMMON, GAME_WOTLK, 400, 400, 400, 400)
	self:addTradeFlags(RecipeDB, 55628, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP)
	self:addTradeAcquire(RecipeDB, 55628, A.TRAINER, 26564, A.TRAINER, 26904, A.TRAINER, 26952, A.TRAINER, 26981, A.TRAINER, 26988, A.TRAINER, 27034, A.TRAINER, 28694, A.TRAINER, 29924, A.TRAINER, 33591)

	-- Socket Gloves -- 55641
	AddRecipe(55641, 400, nil, R_COMMON, GAME_WOTLK, 400, 400, 400, 400)
	self:addTradeFlags(RecipeDB, 55641, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP)
	self:addTradeAcquire(RecipeDB, 55641, A.TRAINER, 26564, A.TRAINER, 26904, A.TRAINER, 26952, A.TRAINER, 26981, A.TRAINER, 26988, A.TRAINER, 27034, A.TRAINER, 28694, A.TRAINER, 29924, A.TRAINER, 33591)

	-- Eternal Belt Buckle -- 55656
	AddRecipe(55656, 415, 41611, R_RARE, GAME_WOTLK, 415, 420, 425, 430)
	self:addTradeFlags(RecipeDB, 55656, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP)
	self:addTradeAcquire(RecipeDB, 55656, A.TRAINER, 26564, A.TRAINER, 26904, A.TRAINER, 26952, A.TRAINER, 26981, A.TRAINER, 26988, A.TRAINER, 27034, A.TRAINER, 28694, A.TRAINER, 29924, A.TRAINER, 33591)

	-- Titanium Rod -- 55732
	AddRecipe(55732, 420, 41745, R_COMMON, GAME_WOTLK, 420, 425, 430, 435)
	self:addTradeFlags(RecipeDB, 55732, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP)
	self:addTradeAcquire(RecipeDB, 55732, A.TRAINER, 26564, A.TRAINER, 26904, A.TRAINER, 26952, A.TRAINER, 26981, A.TRAINER, 26988, A.TRAINER, 27034, A.TRAINER, 28694, A.TRAINER, 29924, A.TRAINER, 33591)

	-- Cobalt Bracers -- 55834
	AddRecipe(55834, 360, 41974, R_UNCOMMON, GAME_WOTLK, 360, 370, 375, 380)
	self:addTradeFlags(RecipeDB, 55834, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.TANK, F.PLATE)
	self:addTradeAcquire(RecipeDB, 55834, A.TRAINER, 26564, A.TRAINER, 26904, A.TRAINER, 26952, A.TRAINER, 26981, A.TRAINER, 26988, A.TRAINER, 27034, A.TRAINER, 28694, A.TRAINER, 29924, A.TRAINER, 33591)

	-- Cobalt Gauntlets -- 55835
	AddRecipe(55835, 370, 41975, R_UNCOMMON, GAME_WOTLK, 370, 380, 385, 390)
	self:addTradeFlags(RecipeDB, 55835, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.TANK, F.PLATE)
	self:addTradeAcquire(RecipeDB, 55835, A.TRAINER, 26564, A.TRAINER, 26904, A.TRAINER, 26952, A.TRAINER, 26981, A.TRAINER, 26988, A.TRAINER, 27034, A.TRAINER, 28694, A.TRAINER, 29924, A.TRAINER, 33591)

	-- Titanium Weapon Chain -- 55839
	AddRecipe(55839, 420, 41976, R_UNCOMMON, GAME_WOTLK, 420, 425, 430, 435)
	self:addTradeFlags(RecipeDB, 55839, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP)
	self:addTradeAcquire(RecipeDB, 55839, A.TRAINER, 26564, A.TRAINER, 26904, A.TRAINER, 26952, A.TRAINER, 26981, A.TRAINER, 26988, A.TRAINER, 27034, A.TRAINER, 28694, A.TRAINER, 29924, A.TRAINER, 33591)

	-- Titansteel Shanker -- 56234
	AddRecipe(56234, 440, 42435, R_EPIC, GAME_WOTLK, 440, 450, 460, 470)
	self:addTradeFlags(RecipeDB, 56234, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.DPS, F.ONE_HAND, F.DAGGER)
	self:addTradeAcquire(RecipeDB, 56234, A.TRAINER, 26564, A.TRAINER, 26904, A.TRAINER, 26952, A.TRAINER, 26981, A.TRAINER, 26988, A.TRAINER, 27034, A.TRAINER, 28694, A.TRAINER, 29924, A.TRAINER, 33591)

	-- Cudgel of Saronite Justice -- 56280
	AddRecipe(56280, 410, 42443, R_RARE, GAME_WOTLK, 410, 415, 420, 425)
	self:addTradeFlags(RecipeDB, 56280, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.HEALER, F.CASTER, F.ONE_HAND, F.MACE)
	self:addTradeAcquire(RecipeDB, 56280, A.TRAINER, 26564, A.TRAINER, 26904, A.TRAINER, 26952, A.TRAINER, 26981, A.TRAINER, 26988, A.TRAINER, 27034, A.TRAINER, 28694, A.TRAINER, 29924, A.TRAINER, 33591)

	-- Titanium Shield Spike -- 56357
	AddRecipe(56357, 420, 42500, R_COMMON, GAME_WOTLK, 420, 425, 430, 435)
	self:addTradeFlags(RecipeDB, 56357, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.TANK, F.SHIELD)
	self:addTradeAcquire(RecipeDB, 56357, A.TRAINER, 26564, A.TRAINER, 26904, A.TRAINER, 26952, A.TRAINER, 26981, A.TRAINER, 26988, A.TRAINER, 27034, A.TRAINER, 28694, A.TRAINER, 29924, A.TRAINER, 33591)

	-- Titansteel Shield Wall -- 56400
	AddRecipe(56400, 440, 42508, R_EPIC, GAME_WOTLK, 440, 450, 460, 470)
	self:addTradeFlags(RecipeDB, 56400, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.TANK, F.SHIELD, F.ONE_HAND)
	self:addTradeAcquire(RecipeDB, 56400, A.TRAINER, 26564, A.TRAINER, 26904, A.TRAINER, 26952, A.TRAINER, 26981, A.TRAINER, 26988, A.TRAINER, 27034, A.TRAINER, 28694, A.TRAINER, 29924, A.TRAINER, 33591)

	-- Ornate Saronite Bracers -- 56549
	AddRecipe(56549, 420, 42723, R_COMMON, GAME_WOTLK, 420, 425, 430, 435)
	self:addTradeFlags(RecipeDB, 56549, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.HEALER, F.CASTER, F.PLATE)
	self:addTradeAcquire(RecipeDB, 56549, A.TRAINER, 26564, A.TRAINER, 26904, A.TRAINER, 26952, A.TRAINER, 26981, A.TRAINER, 26988, A.TRAINER, 27034, A.TRAINER, 28694, A.TRAINER, 29924, A.TRAINER, 33591)

	-- Ornate Saronite Pauldrons -- 56550
	AddRecipe(56550, 420, 42727, R_COMMON, GAME_WOTLK, 420, 430, 440, 450)
	self:addTradeFlags(RecipeDB, 56550, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.HEALER, F.CASTER, F.PLATE)
	self:addTradeAcquire(RecipeDB, 56550, A.TRAINER, 26564, A.TRAINER, 26904, A.TRAINER, 26952, A.TRAINER, 26981, A.TRAINER, 26988, A.TRAINER, 27034, A.TRAINER, 28694, A.TRAINER, 29924, A.TRAINER, 33591)

	-- Ornate Saronite Waistguard -- 56551
	AddRecipe(56551, 420, 42729, R_COMMON, GAME_WOTLK, 420, 430, 440, 450)
	self:addTradeFlags(RecipeDB, 56551, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.HEALER, F.CASTER, F.PLATE)
	self:addTradeAcquire(RecipeDB, 56551, A.TRAINER, 26564, A.TRAINER, 26904, A.TRAINER, 26952, A.TRAINER, 26981, A.TRAINER, 26988, A.TRAINER, 27034, A.TRAINER, 28694, A.TRAINER, 29924, A.TRAINER, 33591)

	-- Ornate Saronite Walkers -- 56552
	AddRecipe(56552, 420, 42730, R_RARE, GAME_WOTLK, 420, 430, 440, 450)
	self:addTradeFlags(RecipeDB, 56552, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.HEALER, F.CASTER, F.PLATE)
	self:addTradeAcquire(RecipeDB, 56552, A.TRAINER, 26564, A.TRAINER, 26904, A.TRAINER, 26952, A.TRAINER, 26981, A.TRAINER, 26988, A.TRAINER, 27034, A.TRAINER, 28694, A.TRAINER, 29924, A.TRAINER, 33591)

	-- Ornate Saronite Gauntlets -- 56553
	AddRecipe(56553, 420, 42724, R_COMMON, GAME_WOTLK, 420, 430, 440, 450)
	self:addTradeFlags(RecipeDB, 56553, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.HEALER, F.CASTER, F.PLATE)
	self:addTradeAcquire(RecipeDB, 56553, A.TRAINER, 26564, A.TRAINER, 26904, A.TRAINER, 26952, A.TRAINER, 26981, A.TRAINER, 26988, A.TRAINER, 27034, A.TRAINER, 28694, A.TRAINER, 29924, A.TRAINER, 33591)

	-- Ornate Saronite Legplates -- 56554
	AddRecipe(56554, 425, 42726, R_COMMON, GAME_WOTLK, 425, 435, 445, 455)
	self:addTradeFlags(RecipeDB, 56554, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.HEALER, F.CASTER, F.PLATE)
	self:addTradeAcquire(RecipeDB, 56554, A.TRAINER, 26564, A.TRAINER, 26904, A.TRAINER, 26952, A.TRAINER, 26981, A.TRAINER, 26988, A.TRAINER, 27034, A.TRAINER, 28694, A.TRAINER, 29924, A.TRAINER, 33591)

	-- Ornate Saronite Hauberk -- 56555
	AddRecipe(56555, 425, 42725, R_COMMON, GAME_WOTLK, 425, 435, 445, 455)
	self:addTradeFlags(RecipeDB, 56555, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.HEALER, F.CASTER, F.PLATE)
	self:addTradeAcquire(RecipeDB, 56555, A.TRAINER, 26564, A.TRAINER, 26904, A.TRAINER, 26952, A.TRAINER, 26981, A.TRAINER, 26988, A.TRAINER, 27034, A.TRAINER, 28694, A.TRAINER, 29924, A.TRAINER, 33591)

	-- Ornate Saronite Skullshield -- 56556
	AddRecipe(56556, 425, 42728, R_RARE, GAME_WOTLK, 425, 435, 445, 455)
	self:addTradeFlags(RecipeDB, 56556, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.HEALER, F.CASTER, F.PLATE)
	self:addTradeAcquire(RecipeDB, 56556, A.TRAINER, 26564, A.TRAINER, 26904, A.TRAINER, 26952, A.TRAINER, 26981, A.TRAINER, 26988, A.TRAINER, 27034, A.TRAINER, 28694, A.TRAINER, 29924, A.TRAINER, 33591)

	-- Cobalt Skeleton Key -- 59405
	AddRecipe(59405, 350, 43854, R_COMMON, GAME_WOTLK, 350, 360, 365, 370)
	self:addTradeFlags(RecipeDB, 59405, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP)
	self:addTradeAcquire(RecipeDB, 59405, A.TRAINER, 26564, A.TRAINER, 26904, A.TRAINER, 26952, A.TRAINER, 26981, A.TRAINER, 26988, A.TRAINER, 27034, A.TRAINER, 28694, A.TRAINER, 29924, A.TRAINER, 33591)

	-- Titanium Skeleton Key -- 59406
	AddRecipe(59406, 430, 43853, R_COMMON, GAME_WOTLK, 430, 435, 440, 445)
	self:addTradeFlags(RecipeDB, 59406, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP)
	self:addTradeAcquire(RecipeDB, 59406, A.TRAINER, 26564, A.TRAINER, 26904, A.TRAINER, 26952, A.TRAINER, 26981, A.TRAINER, 26988, A.TRAINER, 27034, A.TRAINER, 28694, A.TRAINER, 29924, A.TRAINER, 33591)

	-- Brilliant Saronite Belt -- 59436
	AddRecipe(59436, 395, 43860, R_COMMON, GAME_WOTLK, 395, 400, 405, 410)
	self:addTradeFlags(RecipeDB, 59436, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.HEALER, F.CASTER, F.PLATE)
	self:addTradeAcquire(RecipeDB, 59436, A.TRAINER, 26564, A.TRAINER, 26904, A.TRAINER, 26952, A.TRAINER, 26981, A.TRAINER, 26988, A.TRAINER, 27034, A.TRAINER, 28694, A.TRAINER, 29924, A.TRAINER, 33591)

	-- Brilliant Saronite Bracers -- 59438
	AddRecipe(59438, 400, 43864, R_COMMON, GAME_WOTLK, 400, 405, 410, 415)
	self:addTradeFlags(RecipeDB, 59438, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.HEALER, F.CASTER, F.PLATE)
	self:addTradeAcquire(RecipeDB, 59438, A.TRAINER, 26564, A.TRAINER, 26904, A.TRAINER, 26952, A.TRAINER, 26981, A.TRAINER, 26988, A.TRAINER, 27034, A.TRAINER, 28694, A.TRAINER, 29924, A.TRAINER, 33591)

	-- Brilliant Saronite Pauldrons -- 59440
	AddRecipe(59440, 405, 43865, R_COMMON, GAME_WOTLK, 405, 410, 415, 420)
	self:addTradeFlags(RecipeDB, 59440, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.HEALER, F.CASTER, F.PLATE)
	self:addTradeAcquire(RecipeDB, 59440, A.TRAINER, 26564, A.TRAINER, 26904, A.TRAINER, 26952, A.TRAINER, 26981, A.TRAINER, 26988, A.TRAINER, 27034, A.TRAINER, 28694, A.TRAINER, 29924, A.TRAINER, 33591)

	-- Brilliant Saronite Helm -- 59441
	AddRecipe(59441, 415, 43870, R_COMMON, GAME_WOTLK, 415, 420, 425, 430)
	self:addTradeFlags(RecipeDB, 59441, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.HEALER, F.CASTER, F.PLATE)
	self:addTradeAcquire(RecipeDB, 59441, A.TRAINER, 26564, A.TRAINER, 26904, A.TRAINER, 26952, A.TRAINER, 26981, A.TRAINER, 26988, A.TRAINER, 27034, A.TRAINER, 28694, A.TRAINER, 29924, A.TRAINER, 33591)

	-- Saronite Spellblade -- 59442
	AddRecipe(59442, 410, 43871, R_COMMON, GAME_WOTLK, 410, 415, 420, 425)
	self:addTradeFlags(RecipeDB, 59442, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.HEALER, F.CASTER, F.ONE_HAND, F.SWORD)
	self:addTradeAcquire(RecipeDB, 59442, A.TRAINER, 26564, A.TRAINER, 26904, A.TRAINER, 26952, A.TRAINER, 26981, A.TRAINER, 26988, A.TRAINER, 27034, A.TRAINER, 28694, A.TRAINER, 29924, A.TRAINER, 33591)

	-- Icebane Chestguard -- 61008
	AddRecipe(61008, 425, 43586, R_COMMON, GAME_WOTLK, 425, 435, 445, 455)
	self:addTradeFlags(RecipeDB, 61008, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.PLATE)
	self:addTradeAcquire(RecipeDB, 61008, A.TRAINER, 26564, A.TRAINER, 26904, A.TRAINER, 26952, A.TRAINER, 26981, A.TRAINER, 26988, A.TRAINER, 27034, A.TRAINER, 28694, A.TRAINER, 29924, A.TRAINER, 33591)

	-- Icebane Girdle -- 61009
	AddRecipe(61009, 420, 43587, R_COMMON, GAME_WOTLK, 420, 430, 440, 450)
	self:addTradeFlags(RecipeDB, 61009, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.PLATE)
	self:addTradeAcquire(RecipeDB, 61009, A.TRAINER, 26564, A.TRAINER, 26904, A.TRAINER, 26952, A.TRAINER, 26981, A.TRAINER, 26988, A.TRAINER, 27034, A.TRAINER, 28694, A.TRAINER, 29924, A.TRAINER, 33591)

	-- Icebane Treads -- 61010
	AddRecipe(61010, 420, 43588, R_COMMON, GAME_WOTLK, 420, 430, 440, 450)
	self:addTradeFlags(RecipeDB, 61010, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.PLATE)
	self:addTradeAcquire(RecipeDB, 61010, A.TRAINER, 26564, A.TRAINER, 26904, A.TRAINER, 26952, A.TRAINER, 26981, A.TRAINER, 26988, A.TRAINER, 27034, A.TRAINER, 28694, A.TRAINER, 29924, A.TRAINER, 33591)

	-- Titanium Plating -- 62202
	AddRecipe(62202, 450, 44936, R_RARE, GAME_WOTLK, 450, 455, 460, 465)
	self:addTradeFlags(RecipeDB, 62202, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOP, F.TANK, F.SHIELD)
	self:addTradeAcquire(RecipeDB, 62202, A.REPUTATION, FAC.HORDE_EXPEDITION, REP.EXALTED, 32565, A.REPUTATION, FAC.HORDE_EXPEDITION, REP.EXALTED, 32774, A.REPUTATION, 1037, REP.EXALTED, 32564, A.REPUTATION, 1037, REP.EXALTED, 32773)

	-- Titansteel Spellblade -- 63182
	AddRecipe(63182, 440, 45085, R_EPIC, GAME_WOTLK, 440, 450, 460, 470)
	self:addTradeFlags(RecipeDB, 63182, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.HEALER, F.CASTER, F.ONE_HAND, F.DAGGER)
	self:addTradeAcquire(RecipeDB, 63182, A.TRAINER, 26564, A.TRAINER, 26904, A.TRAINER, 26952, A.TRAINER, 26981, A.TRAINER, 26988, A.TRAINER, 27034, A.TRAINER, 28694, A.TRAINER, 29924, A.TRAINER, 33591)

	-- Belt of the Titans -- 63187
	AddRecipe(63187, 450, 45088, R_EPIC, GAME_WOTLK, 450, 455, 465, 475)
	self:addTradeFlags(RecipeDB, 63187, F.ALLIANCE, F.HORDE, F.RAID, F.MOB_DROP, F.IBOE, F.RBOE, F.DPS, F.PLATE)
	self:addTradeAcquire(RecipeDB, 63187, A.CUSTOM, 39)

	-- Battlelord's Plate Boots -- 63188
	AddRecipe(63188, 450, 45089, R_EPIC, GAME_WOTLK, 450, 455, 465, 475)
	self:addTradeFlags(RecipeDB, 63188, F.ALLIANCE, F.HORDE, F.RAID, F.MOB_DROP, F.IBOE, F.RBOE, F.DPS, F.PLATE)
	self:addTradeAcquire(RecipeDB, 63188, A.CUSTOM, 39)

	-- Plate Girdle of Righteousness -- 63189
	AddRecipe(63189, 450, 45090, R_EPIC, GAME_WOTLK, 450, 455, 465, 475)
	self:addTradeFlags(RecipeDB, 63189, F.ALLIANCE, F.HORDE, F.RAID, F.MOB_DROP, F.IBOE, F.RBOE, F.HEALER, F.CASTER, F.PLATE)
	self:addTradeAcquire(RecipeDB, 63189, A.CUSTOM, 39)

	-- Treads of Destiny -- 63190
	AddRecipe(63190, 450, 45091, R_EPIC, GAME_WOTLK, 450, 455, 465, 475)
	self:addTradeFlags(RecipeDB, 63190, F.ALLIANCE, F.HORDE, F.RAID, F.MOB_DROP, F.IBOE, F.RBOE, F.HEALER, F.CASTER, F.PLATE)
	self:addTradeAcquire(RecipeDB, 63190, A.CUSTOM, 39)

	-- Indestructible Plate Girdle -- 63191
	AddRecipe(63191, 450, 45092, R_EPIC, GAME_WOTLK, 450, 455, 465, 475)
	self:addTradeFlags(RecipeDB, 63191, F.ALLIANCE, F.HORDE, F.RAID, F.MOB_DROP, F.IBOE, F.RBOE, F.TANK, F.PLATE)
	self:addTradeAcquire(RecipeDB, 63191, A.CUSTOM, 39)

	-- Spiked Deathdealers -- 63192
	AddRecipe(63192, 450, 45093, R_EPIC, GAME_WOTLK, 450, 455, 465, 475)
	self:addTradeFlags(RecipeDB, 63192, F.ALLIANCE, F.HORDE, F.RAID, F.MOB_DROP, F.IBOE, F.RBOE, F.TANK, F.PLATE)
	self:addTradeAcquire(RecipeDB, 63192, A.CUSTOM, 39)

	-- Puresteel Legplates -- 70562
	AddRecipe(70562, 450, 49902, R_EPIC, GAME_WOTLK, 450, 475, 487, 500)
	self:addTradeFlags(RecipeDB, 70562, F.ALLIANCE, F.HORDE, F.VENDOR, F.ASHEN_VERDICT)
	self:addTradeAcquire(RecipeDB, 70562, A.REPUTATION, FAC.ASHEN_VERDICT, REP.REVERED, 37687)

	-- Protectors of Life -- 70563
	AddRecipe(70563, 450, 49905, R_EPIC, GAME_WOTLK, 450, 475, 487, 500)
	self:addTradeFlags(RecipeDB, 70563, F.ALLIANCE, F.HORDE, F.VENDOR, F.ASHEN_VERDICT)
	self:addTradeAcquire(RecipeDB, 70563, A.REPUTATION, FAC.ASHEN_VERDICT, REP.HONORED, 37687)

	-- Legplates of Painful Death -- 70565
	AddRecipe(70565, 450, 49903, R_EPIC, GAME_WOTLK, 450, 475, 487, 500)
	self:addTradeFlags(RecipeDB, 70565, F.ALLIANCE, F.HORDE, F.VENDOR, F.ASHEN_VERDICT)
	self:addTradeAcquire(RecipeDB, 70565, A.REPUTATION, FAC.ASHEN_VERDICT, REP.REVERED, 37687)

	-- Hellfrozen Bonegrinders -- 70566
	AddRecipe(70566, 450, 49906, R_EPIC, GAME_WOTLK, 450, 475, 487, 500)
	self:addTradeFlags(RecipeDB, 70566, F.ALLIANCE, F.HORDE, F.VENDOR, F.ASHEN_VERDICT)
	self:addTradeAcquire(RecipeDB, 70566, A.REPUTATION, FAC.ASHEN_VERDICT, REP.HONORED, 37687)

	-- Pillars of Might -- 70567
	AddRecipe(70567, 450, 49904, R_EPIC, GAME_WOTLK, 450, 475, 487, 500)
	self:addTradeFlags(RecipeDB, 70567, F.ALLIANCE, F.HORDE, F.VENDOR, F.ASHEN_VERDICT)
	self:addTradeAcquire(RecipeDB, 70567, A.REPUTATION, FAC.ASHEN_VERDICT, REP.REVERED, 37687)

	-- Boots of Kingly Upheaval -- 70568
	AddRecipe(70568, 450, 49907, R_EPIC, GAME_WOTLK, 450, 475, 487, 500)
	self:addTradeFlags(RecipeDB, 70568, F.ALLIANCE, F.HORDE, F.VENDOR, F.ASHEN_VERDICT)
	self:addTradeAcquire(RecipeDB, 70568, A.REPUTATION, FAC.ASHEN_VERDICT, REP.HONORED, 37687)

	-- Some recipes are only availible to specific factions.
	-- We only add the faction specific recipes if the user is part of that faction
	local BFAC = LibStub("LibBabble-Faction-3.0"):GetLookupTable()
	local _,faction = UnitFactionGroup("player")

	if faction == BFAC["Alliance"] then

		-- Breastplate of the White Knight (Ally) -- 67091
		AddRecipe(67091, 450, 47591, R_EPIC, GAME_WOTLK, 450, 455, 465, 475)
		self:addTradeFlags(RecipeDB, 67091, F.ALLIANCE, F.RAID, F.MOB_DROP, F.IBOE, F.RBOE, F.TANK, F.PLATE)
		self:addTradeAcquire(RecipeDB, 67091, A.CUSTOM, 42)

		-- Saronite Swordbreakers (Ally) -- 67092
		AddRecipe(67092, 450, 47570, R_EPIC, GAME_WOTLK, 450, 455, 465, 475)
		self:addTradeFlags(RecipeDB, 67092, F.ALLIANCE, F.RAID, F.MOB_DROP, F.IBOE, F.RBOE, F.TANK, F.PLATE)
		self:addTradeAcquire(RecipeDB, 67092, A.CUSTOM, 42)

		-- Titanium Razorplate (Ally) -- 67093
		AddRecipe(67093, 450, 47589, R_EPIC, GAME_WOTLK, 450, 455, 465, 475)
		self:addTradeFlags(RecipeDB, 67093, F.ALLIANCE, F.RAID, F.MOB_DROP, F.IBOE, F.RBOE, F.DPS, F.PLATE)
		self:addTradeAcquire(RecipeDB, 67093, A.CUSTOM, 42)

		-- Titanium Spikeguards (Ally) -- 67094
		AddRecipe(67094, 450, 47572, R_EPIC, GAME_WOTLK, 450, 455, 465, 475)
		self:addTradeFlags(RecipeDB, 67094, F.ALLIANCE, F.RAID, F.MOB_DROP, F.IBOE, F.RBOE, F.DPS, F.PLATE)
		self:addTradeAcquire(RecipeDB, 67094, A.CUSTOM, 42)

		-- Sunforged Breastplate (Ally) -- 67095
		AddRecipe(67095, 450, 47593, R_EPIC, GAME_WOTLK, 450, 460, 467, 475)
		self:addTradeFlags(RecipeDB, 67095, F.ALLIANCE, F.RAID, F.MOB_DROP, F.IBOE, F.RBOE, F.HEALER, F.PLATE)
		self:addTradeAcquire(RecipeDB, 67095, A.CUSTOM, 42)

		-- Sunforged Bracers (Ally) -- 67096
		AddRecipe(67096, 450, 47574, R_EPIC, GAME_WOTLK, 450, 455, 465, 475)
		self:addTradeFlags(RecipeDB, 67096, F.ALLIANCE, F.RAID, F.MOB_DROP, F.IBOE, F.RBOE, F.HEALER, F.PLATE)
		self:addTradeAcquire(RecipeDB, 67096, A.CUSTOM, 42)	

	elseif faction == BFAC["Horde"] then

		-- Breastplate of the White Knight -- 67130
		AddRecipe(67130, 450, 47592, R_EPIC, GAME_WOTLK, 450, 455, 465, 475)
		self:addTradeFlags(RecipeDB, 67130, F.HORDE, F.RAID, F.MOB_DROP, F.IBOE, F.RBOE, F.TANK, F.PLATE)
		self:addTradeAcquire(RecipeDB, 67130, A.CUSTOM, 42)

		-- Saronite Swordbreakers -- 67131
		AddRecipe(67131, 450, 47571, R_EPIC, GAME_WOTLK, 450, 455, 465, 475)
		self:addTradeFlags(RecipeDB, 67131, F.HORDE, F.RAID, F.MOB_DROP, F.IBOE, F.RBOE, F.TANK, F.PLATE)
		self:addTradeAcquire(RecipeDB, 67131, A.CUSTOM, 42)

		-- Titanium Razorplate -- 67132
		AddRecipe(67132, 450, 47590, R_EPIC, GAME_WOTLK, 450, 455, 465, 475)
		self:addTradeFlags(RecipeDB, 67132, F.HORDE, F.RAID, F.MOB_DROP, F.IBOE, F.RBOE, F.DPS, F.PLATE)
		self:addTradeAcquire(RecipeDB, 67132, A.CUSTOM, 42)

		-- Titanium Spikeguards -- 67133
		AddRecipe(67133, 450, 47573, R_EPIC, GAME_WOTLK, 450, 455, 465, 475)
		self:addTradeFlags(RecipeDB, 67133, F.HORDE, F.RAID, F.MOB_DROP, F.IBOE, F.RBOE, F.DPS, F.PLATE)
		self:addTradeAcquire(RecipeDB, 67133, A.CUSTOM, 42)

		-- Sunforged Breastplate -- 67134
		AddRecipe(67134, 450, 47594, R_EPIC, GAME_WOTLK, 450, 460, 467, 475)
		self:addTradeFlags(RecipeDB, 67134, F.HORDE, F.RAID, F.MOB_DROP, F.IBOE, F.RBOE, F.HEALER, F.CASTER, F.PLATE)
		self:addTradeAcquire(RecipeDB, 67134, A.CUSTOM, 42)

		-- Sunforged Bracers -- 67135
		AddRecipe(67135, 450, 47575, R_EPIC, GAME_WOTLK, 450, 455, 465, 475)
		self:addTradeFlags(RecipeDB, 67135, F.HORDE, F.RAID, F.MOB_DROP, F.IBOE, F.RBOE, F.HEALER, F.CASTER, F.PLATE)
		self:addTradeAcquire(RecipeDB, 67135, A.CUSTOM, 42)

	end

	return num_recipes

end
