--[[
************************************************************************
Leatherworking.lua
Leatherworking data for all of Ackis Recipe List
************************************************************************
File date: 2010-02-06T07:24:17Z 
File revision: 2852 
Project revision: 2853
Project version: r2853
************************************************************************
Please see http://www.wowace.com/addons/arl/ for more information.
************************************************************************
This source code is released under All Rights Reserved.
************************************************************************
]]--

-------------------------------------------------------------------------------
-- AddOn namespace.
-------------------------------------------------------------------------------
local MODNAME	= "Ackis Recipe List"
local addon	= LibStub("AceAddon-3.0"):GetAddon(MODNAME)
local L		= LibStub("AceLocale-3.0"):GetLocale(MODNAME)

local private	= select(2, ...)

-------------------------------------------------------------------------------
-- Item "rarity"
-------------------------------------------------------------------------------
local R_COMMON, R_UNCOMMON, R_RARE, R_EPIC, R_LEGENDARY, R_ARTIFACT = 1, 2, 3, 4, 5, 6

-------------------------------------------------------------------------------
-- Origin
-------------------------------------------------------------------------------
local GAME_ORIG, GAME_TBC, GAME_WOTLK = 0, 1, 2

-------------------------------------------------------------------------------
-- Filter flags. Acquire types, and Reputation levels.
-------------------------------------------------------------------------------
local F		= private.filter_flags
local A		= private.acquire_types
local REP	= private.rep_levels
local FAC	= private.faction_ids

local FRIENDLY	= 1
local HONORED	= 2
local REVERED	= 3
local EXALTED	= 4

local initialized = false
local num_recipes = 0

function addon:InitLeatherworking(RecipeDB)
	if initialized then
		return num_recipes
	end
	initialized = true

	--------------------------------------------------------------------------------------------------------------------
	-- Counter and wrapper function
	--------------------------------------------------------------------------------------------------------------------
	local function AddRecipe(SpellID, Skill, ItemID, Rarity, Game, Orange, Yellow, Green, Gray, Speciality)
		num_recipes = num_recipes + 1
		self:addTradeSkill(RecipeDB, SpellID, Skill, ItemID, Rarity, 2108, Speciality, Game, Orange, Yellow, Green, Gray)
	end

	-- Handstitched Leather Boots -- 2149
	AddRecipe(2149, 1, 2302, R_COMMON, GAME_ORIG, 1, 40, 55, 70)
	self:addTradeFlags(RecipeDB, 2149, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.LEATHER)
	self:addTradeAcquire(RecipeDB, 2149, A.CUSTOM, 8)

	-- Light Armor Kit -- 2152
	AddRecipe(2152, 1, 2304, R_COMMON, GAME_ORIG, 1, 30, 45, 60)
	self:addTradeFlags(RecipeDB, 2152, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP)
	self:addTradeAcquire(RecipeDB, 2152, A.CUSTOM, 8)

	-- Handstitched Leather Pants -- 2153
	AddRecipe(2153, 15, 2303, R_COMMON, GAME_ORIG, 15, 45, 60, 75)
	self:addTradeFlags(RecipeDB, 2153, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.LEATHER)
	self:addTradeAcquire(RecipeDB, 2153, A.TRAINER, 1632, A.TRAINER, 3007, A.TRAINER, 3069, A.TRAINER, 3365, A.TRAINER, 3549, A.TRAINER, 3605, A.TRAINER, 3703, A.TRAINER, 4212, A.TRAINER, 4588, A.TRAINER, 5127, A.TRAINER, 5564, A.TRAINER, 5784, A.TRAINER, 11097, A.TRAINER, 11098, A.TRAINER, 16278, A.TRAINER, 16688, A.TRAINER, 16728, A.TRAINER, 17442, A.TRAINER, 18754, A.TRAINER, 18771, A.TRAINER, 19187, A.TRAINER, 21087, A.TRAINER, 1385, A.TRAINER, 3967, A.TRAINER, 33612, A.TRAINER, 33635, A.TRAINER, 33681, A.TRAINER, 8153)

	-- Fine Leather Boots -- 2158
	AddRecipe(2158, 90, 2307, R_UNCOMMON, GAME_ORIG, 90, 120, 135, 150)
	self:addTradeFlags(RecipeDB, 2158, F.ALLIANCE, F.HORDE, F.WORLD_DROP, F.IBOE, F.RBOE, F.DPS, F.LEATHER)
	self:addTradeAcquire(RecipeDB, 2158, A.WORLD_DROP, 2)

	-- Fine Leather Cloak -- 2159
	AddRecipe(2159, 85, 2308, R_COMMON, GAME_ORIG, 85, 105, 120, 135)
	self:addTradeFlags(RecipeDB, 2159, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.CLOAK)
	self:addTradeAcquire(RecipeDB, 2159, A.TRAINER, 1385, A.TRAINER, 3007, A.TRAINER, 3365, A.TRAINER, 3703, A.TRAINER, 3967, A.TRAINER, 4212, A.TRAINER, 4588, A.TRAINER, 5127, A.TRAINER, 5564, A.TRAINER, 11097, A.TRAINER, 11098, A.TRAINER, 16688, A.TRAINER, 16728, A.TRAINER, 18754, A.TRAINER, 18771, A.TRAINER, 19187, A.TRAINER, 21087, A.TRAINER, 1632, A.TRAINER, 5784, A.TRAINER, 3549, A.TRAINER, 33612, A.TRAINER, 33635, A.TRAINER, 33681, A.TRAINER, 8153, A.TRAINER, 17442, A.TRAINER, 16278, A.TRAINER, 3605)

	-- Embossed Leather Vest -- 2160
	AddRecipe(2160, 40, 2300, R_COMMON, GAME_ORIG, 40, 70, 85, 100)
	self:addTradeFlags(RecipeDB, 2160, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.LEATHER)
	self:addTradeAcquire(RecipeDB, 2160, A.TRAINER, 1632, A.TRAINER, 3007, A.TRAINER, 3069, A.TRAINER, 3365, A.TRAINER, 3549, A.TRAINER, 3605, A.TRAINER, 3703, A.TRAINER, 4212, A.TRAINER, 4588, A.TRAINER, 5127, A.TRAINER, 5564, A.TRAINER, 5784, A.TRAINER, 11097, A.TRAINER, 11098, A.TRAINER, 16278, A.TRAINER, 16688, A.TRAINER, 16728, A.TRAINER, 17442, A.TRAINER, 18754, A.TRAINER, 18771, A.TRAINER, 19187, A.TRAINER, 21087, A.TRAINER, 1385, A.TRAINER, 3967, A.TRAINER, 33612, A.TRAINER, 33635, A.TRAINER, 33681, A.TRAINER, 8153)

	-- Embossed Leather Boots -- 2161
	AddRecipe(2161, 55, 2309, R_COMMON, GAME_ORIG, 55, 85, 100, 115)
	self:addTradeFlags(RecipeDB, 2161, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.DPS, F.LEATHER)
	self:addTradeAcquire(RecipeDB, 2161, A.TRAINER, 1632, A.TRAINER, 3007, A.TRAINER, 3069, A.TRAINER, 3365, A.TRAINER, 3549, A.TRAINER, 3605, A.TRAINER, 3703, A.TRAINER, 3967, A.TRAINER, 4212, A.TRAINER, 4588, A.TRAINER, 5127, A.TRAINER, 5564, A.TRAINER, 5784, A.TRAINER, 11097, A.TRAINER, 11098, A.TRAINER, 16278, A.TRAINER, 16688, A.TRAINER, 16728, A.TRAINER, 17442, A.TRAINER, 18754, A.TRAINER, 18771, A.TRAINER, 19187, A.TRAINER, 21087, A.TRAINER, 1385, A.TRAINER, 33612, A.TRAINER, 33635, A.TRAINER, 33681, A.TRAINER, 8153)

	-- Embossed Leather Cloak -- 2162
	AddRecipe(2162, 60, 2310, R_COMMON, GAME_ORIG, 60, 90, 105, 120)
	self:addTradeFlags(RecipeDB, 2162, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.DPS, F.CLOAK)
	self:addTradeAcquire(RecipeDB, 2162, A.TRAINER, 1632, A.TRAINER, 3007, A.TRAINER, 3069, A.TRAINER, 3365, A.TRAINER, 3549, A.TRAINER, 3605, A.TRAINER, 3703, A.TRAINER, 3967, A.TRAINER, 4212, A.TRAINER, 4588, A.TRAINER, 5127, A.TRAINER, 5564, A.TRAINER, 5784, A.TRAINER, 11097, A.TRAINER, 11098, A.TRAINER, 16278, A.TRAINER, 16688, A.TRAINER, 16728, A.TRAINER, 17442, A.TRAINER, 18754, A.TRAINER, 18771, A.TRAINER, 19187, A.TRAINER, 21087, A.TRAINER, 1385, A.TRAINER, 33612, A.TRAINER, 33635, A.TRAINER, 33681, A.TRAINER, 8153)

	-- White Leather Jerkin -- 2163
	AddRecipe(2163, 60, 2311, R_UNCOMMON, GAME_ORIG, 60, 90, 105, 120)
	self:addTradeFlags(RecipeDB, 2163, F.ALLIANCE, F.HORDE, F.WORLD_DROP, F.IBOE, F.RBOE, F.DPS, F.LEATHER)
	self:addTradeAcquire(RecipeDB, 2163, A.WORLD_DROP, 2)

	-- Fine Leather Gloves -- 2164
	AddRecipe(2164, 75, 2312, R_UNCOMMON, GAME_ORIG, 75, 105, 120, 135)
	self:addTradeFlags(RecipeDB, 2164, F.ALLIANCE, F.HORDE, F.WORLD_DROP, F.IBOE, F.RBOE, F.HEALER, F.CASTER, F.LEATHER)
	self:addTradeAcquire(RecipeDB, 2164, A.WORLD_DROP, 2)

	-- Medium Armor Kit -- 2165
	AddRecipe(2165, 100, 2313, R_COMMON, GAME_ORIG, 100, 115, 122, 130)
	self:addTradeFlags(RecipeDB, 2165, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP)
	self:addTradeAcquire(RecipeDB, 2165, A.TRAINER, 3007, A.TRAINER, 3365, A.TRAINER, 3703, A.TRAINER, 3967, A.TRAINER, 4212, A.TRAINER, 4588, A.TRAINER, 5127, A.TRAINER, 5564, A.TRAINER, 11097, A.TRAINER, 11098, A.TRAINER, 16688, A.TRAINER, 16728, A.TRAINER, 18754, A.TRAINER, 18771, A.TRAINER, 19187, A.TRAINER, 21087, A.TRAINER, 1632, A.TRAINER, 5784, A.TRAINER, 1385, A.TRAINER, 3549, A.TRAINER, 33612, A.TRAINER, 33635, A.TRAINER, 33681, A.TRAINER, 8153, A.TRAINER, 17442, A.TRAINER, 16278, A.TRAINER, 3605)

	-- Toughened Leather Armor -- 2166
	AddRecipe(2166, 120, 2314, R_COMMON, GAME_ORIG, 120, 145, 157, 170)
	self:addTradeFlags(RecipeDB, 2166, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.LEATHER)
	self:addTradeAcquire(RecipeDB, 2166, A.TRAINER, 1385, A.TRAINER, 3007, A.TRAINER, 3365, A.TRAINER, 3703, A.TRAINER, 3967, A.TRAINER, 4212, A.TRAINER, 4588, A.TRAINER, 5127, A.TRAINER, 5564, A.TRAINER, 8153, A.TRAINER, 11097, A.TRAINER, 11098, A.TRAINER, 16688, A.TRAINER, 16728, A.TRAINER, 18754, A.TRAINER, 18771, A.TRAINER, 19187, A.TRAINER, 21087, A.TRAINER, 1632, A.TRAINER, 5784, A.TRAINER, 3549, A.TRAINER, 33612, A.TRAINER, 33635, A.TRAINER, 33681, A.TRAINER, 17442, A.TRAINER, 16278, A.TRAINER, 3605)

	-- Dark Leather Boots -- 2167
	AddRecipe(2167, 100, 2315, R_COMMON, GAME_ORIG, 100, 125, 137, 150)
	self:addTradeFlags(RecipeDB, 2167, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.DPS, F.LEATHER)
	self:addTradeAcquire(RecipeDB, 2167, A.TRAINER, 1385, A.TRAINER, 3007, A.TRAINER, 3365, A.TRAINER, 3703, A.TRAINER, 3967, A.TRAINER, 4212, A.TRAINER, 4588, A.TRAINER, 5127, A.TRAINER, 5564, A.TRAINER, 11097, A.TRAINER, 11098, A.TRAINER, 16688, A.TRAINER, 16728, A.TRAINER, 18754, A.TRAINER, 18771, A.TRAINER, 19187, A.TRAINER, 21087, A.TRAINER, 1632, A.TRAINER, 5784, A.TRAINER, 3549, A.TRAINER, 33612, A.TRAINER, 33635, A.TRAINER, 33681, A.TRAINER, 8153, A.TRAINER, 17442, A.TRAINER, 16278, A.TRAINER, 3605)

	-- Dark Leather Cloak -- 2168
	AddRecipe(2168, 110, 2316, R_COMMON, GAME_ORIG, 110, 135, 147, 160)
	self:addTradeFlags(RecipeDB, 2168, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.DPS, F.CLOAK)
	self:addTradeAcquire(RecipeDB, 2168, A.TRAINER, 1385, A.TRAINER, 3007, A.TRAINER, 3365, A.TRAINER, 3703, A.TRAINER, 3967, A.TRAINER, 4212, A.TRAINER, 4588, A.TRAINER, 5127, A.TRAINER, 5564, A.TRAINER, 11097, A.TRAINER, 11098, A.TRAINER, 16688, A.TRAINER, 16728, A.TRAINER, 18754, A.TRAINER, 18771, A.TRAINER, 19187, A.TRAINER, 21087, A.TRAINER, 1632, A.TRAINER, 5784, A.TRAINER, 3549, A.TRAINER, 33612, A.TRAINER, 33635, A.TRAINER, 33681, A.TRAINER, 8153, A.TRAINER, 17442, A.TRAINER, 16278, A.TRAINER, 3605)

	-- Dark Leather Tunic -- 2169
	AddRecipe(2169, 100, 2317, R_UNCOMMON, GAME_ORIG, 100, 125, 137, 150)
	self:addTradeFlags(RecipeDB, 2169, F.ALLIANCE, F.HORDE, F.WORLD_DROP, F.IBOE, F.RBOE, F.DPS, F.LEATHER)
	self:addTradeAcquire(RecipeDB, 2169, A.WORLD_DROP, 2)

	-- Light Leather -- 2881
	AddRecipe(2881, 1, 2318, R_COMMON, GAME_ORIG, 1, 20, 30, 40)
	self:addTradeFlags(RecipeDB, 2881, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.LEATHER)
	self:addTradeAcquire(RecipeDB, 2881, A.CUSTOM, 8)

	-- Handstitched Leather Belt -- 3753
	AddRecipe(3753, 25, 4237, R_COMMON, GAME_ORIG, 25, 55, 70, 85)
	self:addTradeFlags(RecipeDB, 3753, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.LEATHER)
	self:addTradeAcquire(RecipeDB, 3753, A.TRAINER, 1385, A.TRAINER, 1632, A.TRAINER, 3007, A.TRAINER, 3069, A.TRAINER, 3365, A.TRAINER, 3549, A.TRAINER, 3605, A.TRAINER, 3703, A.TRAINER, 4212, A.TRAINER, 4588, A.TRAINER, 5127, A.TRAINER, 5564, A.TRAINER, 5784, A.TRAINER, 11097, A.TRAINER, 11098, A.TRAINER, 16278, A.TRAINER, 16688, A.TRAINER, 16728, A.TRAINER, 17442, A.TRAINER, 18754, A.TRAINER, 18771, A.TRAINER, 19187, A.TRAINER, 21087, A.TRAINER, 3967, A.TRAINER, 33612, A.TRAINER, 33635, A.TRAINER, 33681, A.TRAINER, 8153)

	-- Embossed Leather Gloves -- 3756
	AddRecipe(3756, 55, 4239, R_COMMON, GAME_ORIG, 55, 85, 100, 115)
	self:addTradeFlags(RecipeDB, 3756, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.DPS, F.LEATHER)
	self:addTradeAcquire(RecipeDB, 3756, A.TRAINER, 1632, A.TRAINER, 3007, A.TRAINER, 3069, A.TRAINER, 3365, A.TRAINER, 3549, A.TRAINER, 3605, A.TRAINER, 3703, A.TRAINER, 3967, A.TRAINER, 4212, A.TRAINER, 4588, A.TRAINER, 5127, A.TRAINER, 5564, A.TRAINER, 5784, A.TRAINER, 11097, A.TRAINER, 11098, A.TRAINER, 16278, A.TRAINER, 16688, A.TRAINER, 16728, A.TRAINER, 17442, A.TRAINER, 18754, A.TRAINER, 18771, A.TRAINER, 19187, A.TRAINER, 21087, A.TRAINER, 1385, A.TRAINER, 33635, A.TRAINER, 33612, A.TRAINER, 33681, A.TRAINER, 8153)

	-- Embossed Leather Pants -- 3759
	AddRecipe(3759, 75, 4242, R_COMMON, GAME_ORIG, 75, 105, 120, 135)
	self:addTradeFlags(RecipeDB, 3759, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.DPS, F.LEATHER)
	self:addTradeAcquire(RecipeDB, 3759, A.TRAINER, 1385, A.TRAINER, 1632, A.TRAINER, 3007, A.TRAINER, 3069, A.TRAINER, 3365, A.TRAINER, 3549, A.TRAINER, 3605, A.TRAINER, 3703, A.TRAINER, 3967, A.TRAINER, 4212, A.TRAINER, 4588, A.TRAINER, 5127, A.TRAINER, 5564, A.TRAINER, 5784, A.TRAINER, 11097, A.TRAINER, 11098, A.TRAINER, 16278, A.TRAINER, 16688, A.TRAINER, 16728, A.TRAINER, 17442, A.TRAINER, 18754, A.TRAINER, 18771, A.TRAINER, 19187, A.TRAINER, 21087, A.TRAINER, 33635, A.TRAINER, 33612, A.TRAINER, 33681, A.TRAINER, 8153)

	-- Hillman's Cloak -- 3760
	AddRecipe(3760, 150, 3719, R_COMMON, GAME_ORIG, 150, 170, 180, 190)
	self:addTradeFlags(RecipeDB, 3760, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.HEALER, F.CASTER, F.CLOAK)
	self:addTradeAcquire(RecipeDB, 3760, A.TRAINER, 1385, A.TRAINER, 3007, A.TRAINER, 3365, A.TRAINER, 3703, A.TRAINER, 3967, A.TRAINER, 4212, A.TRAINER, 4588, A.TRAINER, 5127, A.TRAINER, 5564, A.TRAINER, 8153, A.TRAINER, 11097, A.TRAINER, 11098, A.TRAINER, 16688, A.TRAINER, 16728, A.TRAINER, 18754, A.TRAINER, 18771, A.TRAINER, 19187, A.TRAINER, 21087, A.TRAINER, 1632, A.TRAINER, 5784, A.TRAINER, 3549, A.TRAINER, 33612, A.TRAINER, 33635, A.TRAINER, 33681, A.TRAINER, 17442, A.TRAINER, 16278, A.TRAINER, 3605)

	-- Fine Leather Tunic -- 3761
	AddRecipe(3761, 85, 4243, R_COMMON, GAME_ORIG, 85, 115, 130, 145)
	self:addTradeFlags(RecipeDB, 3761, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.DPS, F.LEATHER)
	self:addTradeAcquire(RecipeDB, 3761, A.TRAINER, 3007, A.TRAINER, 3365, A.TRAINER, 3703, A.TRAINER, 3967, A.TRAINER, 4212, A.TRAINER, 4588, A.TRAINER, 5127, A.TRAINER, 5564, A.TRAINER, 11097, A.TRAINER, 11098, A.TRAINER, 16688, A.TRAINER, 16728, A.TRAINER, 18754, A.TRAINER, 18771, A.TRAINER, 19187, A.TRAINER, 21087, A.TRAINER, 1632, A.TRAINER, 5784, A.TRAINER, 1385, A.TRAINER, 3549, A.TRAINER, 33635, A.TRAINER, 33612, A.TRAINER, 33681, A.TRAINER, 8153, A.TRAINER, 17442, A.TRAINER, 16278, A.TRAINER, 3605)

	-- Hillman's Leather Vest -- 3762
	AddRecipe(3762, 100, 4244, R_UNCOMMON, GAME_ORIG, 100, 125, 137, 150)
	self:addTradeFlags(RecipeDB, 3762, F.ALLIANCE, F.HORDE, F.WORLD_DROP, F.IBOE, F.RBOE, F.HEALER, F.CASTER, F.LEATHER)
	self:addTradeAcquire(RecipeDB, 3762, A.WORLD_DROP, 2)

	-- Fine Leather Belt -- 3763
	AddRecipe(3763, 80, 4246, R_COMMON, GAME_ORIG, 80, 110, 125, 140)
	self:addTradeFlags(RecipeDB, 3763, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.LEATHER)
	self:addTradeAcquire(RecipeDB, 3763, A.TRAINER, 3007, A.TRAINER, 3365, A.TRAINER, 3703, A.TRAINER, 3967, A.TRAINER, 4212, A.TRAINER, 4588, A.TRAINER, 5127, A.TRAINER, 5564, A.TRAINER, 11097, A.TRAINER, 11098, A.TRAINER, 16688, A.TRAINER, 16728, A.TRAINER, 18754, A.TRAINER, 18771, A.TRAINER, 19187, A.TRAINER, 21087, A.TRAINER, 1632, A.TRAINER, 5784, A.TRAINER, 1385, A.TRAINER, 3549, A.TRAINER, 33635, A.TRAINER, 33612, A.TRAINER, 33681, A.TRAINER, 8153, A.TRAINER, 17442, A.TRAINER, 16278, A.TRAINER, 3605)

	-- Hillman's Leather Gloves -- 3764
	AddRecipe(3764, 145, 4247, R_COMMON, GAME_ORIG, 145, 170, 182, 195)
	self:addTradeFlags(RecipeDB, 3764, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.HEALER, F.CASTER, F.LEATHER)
	self:addTradeAcquire(RecipeDB, 3764, A.TRAINER, 1385, A.TRAINER, 3007, A.TRAINER, 3365, A.TRAINER, 3703, A.TRAINER, 3967, A.TRAINER, 4212, A.TRAINER, 4588, A.TRAINER, 5127, A.TRAINER, 5564, A.TRAINER, 8153, A.TRAINER, 11097, A.TRAINER, 11098, A.TRAINER, 16688, A.TRAINER, 16728, A.TRAINER, 18754, A.TRAINER, 18771, A.TRAINER, 19187, A.TRAINER, 21087, A.TRAINER, 1632, A.TRAINER, 5784, A.TRAINER, 3549, A.TRAINER, 33612, A.TRAINER, 33635, A.TRAINER, 33681, A.TRAINER, 17442, A.TRAINER, 16278, A.TRAINER, 3605)

	-- Dark Leather Gloves -- 3765
	AddRecipe(3765, 120, 4248, R_UNCOMMON, GAME_ORIG, 120, 155, 167, 180)
	self:addTradeFlags(RecipeDB, 3765, F.ALLIANCE, F.HORDE, F.WORLD_DROP, F.IBOE, F.RBOE, F.LEATHER)
	self:addTradeAcquire(RecipeDB, 3765, A.WORLD_DROP, 2)

	-- Dark Leather Belt -- 3766
	AddRecipe(3766, 125, 4249, R_COMMON, GAME_ORIG, 125, 150, 162, 175)
	self:addTradeFlags(RecipeDB, 3766, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.DPS, F.LEATHER)
	self:addTradeAcquire(RecipeDB, 3766, A.TRAINER, 1385, A.TRAINER, 3007, A.TRAINER, 3365, A.TRAINER, 3703, A.TRAINER, 3967, A.TRAINER, 4212, A.TRAINER, 4588, A.TRAINER, 5127, A.TRAINER, 5564, A.TRAINER, 8153, A.TRAINER, 11097, A.TRAINER, 11098, A.TRAINER, 16688, A.TRAINER, 16728, A.TRAINER, 18754, A.TRAINER, 18771, A.TRAINER, 19187, A.TRAINER, 21087, A.TRAINER, 1632, A.TRAINER, 5784, A.TRAINER, 3549, A.TRAINER, 33612, A.TRAINER, 33635, A.TRAINER, 33681, A.TRAINER, 16278, A.TRAINER, 3605)

	-- Hillman's Belt -- 3767
	AddRecipe(3767, 120, 4250, R_UNCOMMON, GAME_ORIG, 120, 145, 157, 170)
	self:addTradeFlags(RecipeDB, 3767, F.ALLIANCE, F.HORDE, F.WORLD_DROP, F.IBOE, F.RBOE, F.HEALER, F.CASTER, F.LEATHER)
	self:addTradeAcquire(RecipeDB, 3767, A.WORLD_DROP, 2)

	-- Hillman's Shoulders -- 3768
	AddRecipe(3768, 130, 4251, R_COMMON, GAME_ORIG, 130, 155, 167, 180)
	self:addTradeFlags(RecipeDB, 3768, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.DPS, F.LEATHER)
	self:addTradeAcquire(RecipeDB, 3768, A.TRAINER, 1385, A.TRAINER, 3007, A.TRAINER, 3365, A.TRAINER, 3703, A.TRAINER, 3967, A.TRAINER, 4212, A.TRAINER, 4588, A.TRAINER, 5127, A.TRAINER, 5564, A.TRAINER, 8153, A.TRAINER, 11097, A.TRAINER, 11098, A.TRAINER, 16688, A.TRAINER, 16728, A.TRAINER, 18754, A.TRAINER, 18771, A.TRAINER, 19187, A.TRAINER, 21087, A.TRAINER, 1632, A.TRAINER, 5784, A.TRAINER, 3549, A.TRAINER, 33612, A.TRAINER, 33635, A.TRAINER, 17442, A.TRAINER, 16278, A.TRAINER, 3605)

	-- Dark Leather Shoulders -- 3769
	AddRecipe(3769, 140, 4252, R_UNCOMMON, GAME_ORIG, 140, 165, 177, 190)
	self:addTradeFlags(RecipeDB, 3769, F.ALLIANCE, F.HORDE, F.WORLD_DROP, F.IBOE, F.RBOE, F.DPS, F.LEATHER)
	self:addTradeAcquire(RecipeDB, 3769, A.WORLD_DROP, 2)

	-- Toughened Leather Gloves -- 3770
	AddRecipe(3770, 135, 4253, R_COMMON, GAME_ORIG, 135, 160, 172, 185)
	self:addTradeFlags(RecipeDB, 3770, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.DPS, F.LEATHER)
	self:addTradeAcquire(RecipeDB, 3770, A.TRAINER, 1385, A.TRAINER, 3007, A.TRAINER, 3365, A.TRAINER, 3703, A.TRAINER, 3967, A.TRAINER, 4212, A.TRAINER, 4588, A.TRAINER, 5127, A.TRAINER, 5564, A.TRAINER, 8153, A.TRAINER, 11097, A.TRAINER, 11098, A.TRAINER, 16688, A.TRAINER, 16728, A.TRAINER, 18754, A.TRAINER, 18771, A.TRAINER, 19187, A.TRAINER, 21087, A.TRAINER, 1632, A.TRAINER, 5784, A.TRAINER, 3549, A.TRAINER, 33612, A.TRAINER, 33635, A.TRAINER, 33681, A.TRAINER, 17442, A.TRAINER, 16278, A.TRAINER, 3605)

	-- Barbaric Gloves -- 3771
	AddRecipe(3771, 150, 4254, R_UNCOMMON, GAME_ORIG, 150, 170, 180, 190)
	self:addTradeFlags(RecipeDB, 3771, F.ALLIANCE, F.HORDE, F.WORLD_DROP, F.IBOE, F.RBOE, F.DPS, F.LEATHER)
	self:addTradeAcquire(RecipeDB, 3771, A.WORLD_DROP, 2)

	-- Green Leather Armor -- 3772
	AddRecipe(3772, 155, 4255, R_COMMON, GAME_ORIG, 155, 175, 185, 195)
	self:addTradeFlags(RecipeDB, 3772, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOE, F.TANK, F.LEATHER)
	self:addTradeAcquire(RecipeDB, 3772, A.VENDOR, 2679, A.VENDOR, 2698)

	-- Guardian Armor -- 3773
	AddRecipe(3773, 175, 4256, R_UNCOMMON, GAME_ORIG, 175, 195, 205, 215)
	self:addTradeFlags(RecipeDB, 3773, F.ALLIANCE, F.HORDE, F.WORLD_DROP, F.IBOE, F.RBOE, F.HEALER, F.CASTER, F.LEATHER)
	self:addTradeAcquire(RecipeDB, 3773, A.WORLD_DROP, 2)

	-- Green Leather Belt -- 3774
	AddRecipe(3774, 160, 4257, R_COMMON, GAME_ORIG, 160, 180, 190, 200)
	self:addTradeFlags(RecipeDB, 3774, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.TANK, F.LEATHER)
	self:addTradeAcquire(RecipeDB, 3774, A.TRAINER, 3007, A.TRAINER, 4212, A.TRAINER, 11097, A.TRAINER, 11098, A.TRAINER, 18754, A.TRAINER, 18771, A.TRAINER, 19187, A.TRAINER, 21087, A.TRAINER, 1632, A.TRAINER, 5784, A.TRAINER, 16728, A.TRAINER, 3703, A.TRAINER, 1385, A.TRAINER, 3549, A.TRAINER, 3365, A.TRAINER, 3967, A.TRAINER, 33612, A.TRAINER, 33635, A.TRAINER, 16688, A.TRAINER, 33681, A.TRAINER, 8153, A.TRAINER, 17442, A.TRAINER, 16278, A.TRAINER, 3605, A.TRAINER, 5564, A.TRAINER, 5127, A.TRAINER, 4588)

	-- Guardian Belt -- 3775
	AddRecipe(3775, 170, 4258, R_RARE, GAME_ORIG, 170, 190, 200, 210)
	self:addTradeFlags(RecipeDB, 3775, F.ALLIANCE, F.HORDE, F.INSTANCE, F.MOB_DROP, F.IBOE, F.RBOE, F.HEALER, F.CASTER, F.LEATHER)
	self:addTradeAcquire(RecipeDB, 3775, A.WORLD_DROP, 3)

	-- Green Leather Bracers -- 3776
	AddRecipe(3776, 180, 4259, R_COMMON, GAME_ORIG, 180, 200, 210, 220)
	self:addTradeFlags(RecipeDB, 3776, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.TANK, F.LEATHER)
	self:addTradeAcquire(RecipeDB, 3776, A.TRAINER, 3007, A.TRAINER, 4212, A.TRAINER, 11097, A.TRAINER, 11098, A.TRAINER, 18754, A.TRAINER, 18771, A.TRAINER, 19187, A.TRAINER, 21087, A.TRAINER, 1632, A.TRAINER, 5784, A.TRAINER, 16728, A.TRAINER, 3703, A.TRAINER, 1385, A.TRAINER, 3549, A.TRAINER, 3365, A.TRAINER, 3967, A.TRAINER, 33612, A.TRAINER, 33635, A.TRAINER, 16688, A.TRAINER, 33681, A.TRAINER, 8153, A.TRAINER, 17442, A.TRAINER, 16278, A.TRAINER, 3605, A.TRAINER, 5564, A.TRAINER, 5127, A.TRAINER, 4588)

	-- Guardian Leather Bracers -- 3777
	AddRecipe(3777, 195, 4260, R_UNCOMMON, GAME_ORIG, 195, 215, 225, 235)
	self:addTradeFlags(RecipeDB, 3777, F.ALLIANCE, F.HORDE, F.WORLD_DROP, F.IBOE, F.RBOE, F.HEALER, F.CASTER, F.LEATHER)
	self:addTradeAcquire(RecipeDB, 3777, A.WORLD_DROP, 2)

	-- Gem-studded Leather Belt -- 3778
	AddRecipe(3778, 185, 4262, R_COMMON, GAME_ORIG, 185, 205, 215, 225)
	self:addTradeFlags(RecipeDB, 3778, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOE, F.LEATHER)
	self:addTradeAcquire(RecipeDB, 3778, A.VENDOR, 2699)

	-- Barbaric Belt -- 3779
	AddRecipe(3779, 200, 4264, R_RARE, GAME_ORIG, 200, 220, 230, 240)
	self:addTradeFlags(RecipeDB, 3779, F.ALLIANCE, F.HORDE, F.INSTANCE, F.MOB_DROP, F.IBOE, F.RBOE, F.DPS, F.LEATHER)
	self:addTradeAcquire(RecipeDB, 3779, A.WORLD_DROP, 2)

	-- Heavy Armor Kit -- 3780
	AddRecipe(3780, 150, 4265, R_COMMON, GAME_ORIG, 150, 170, 180, 190)
	self:addTradeFlags(RecipeDB, 3780, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP)
	self:addTradeAcquire(RecipeDB, 3780, A.TRAINER, 1385, A.TRAINER, 3007, A.TRAINER, 3365, A.TRAINER, 3703, A.TRAINER, 3967, A.TRAINER, 4212, A.TRAINER, 4588, A.TRAINER, 5127, A.TRAINER, 5564, A.TRAINER, 8153, A.TRAINER, 11097, A.TRAINER, 11098, A.TRAINER, 16688, A.TRAINER, 16728, A.TRAINER, 18754, A.TRAINER, 18771, A.TRAINER, 19187, A.TRAINER, 21087, A.TRAINER, 1632, A.TRAINER, 5784, A.TRAINER, 3549, A.TRAINER, 33612, A.TRAINER, 33635, A.TRAINER, 33681, A.TRAINER, 17442, A.TRAINER, 16278, A.TRAINER, 3605)

	-- Cured Light Hide -- 3816
	AddRecipe(3816, 35, 4231, R_COMMON, GAME_ORIG, 35, 55, 65, 75)
	self:addTradeFlags(RecipeDB, 3816, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP)
	self:addTradeAcquire(RecipeDB, 3816, A.TRAINER, 1632, A.TRAINER, 3007, A.TRAINER, 3069, A.TRAINER, 3365, A.TRAINER, 3549, A.TRAINER, 3605, A.TRAINER, 3703, A.TRAINER, 4212, A.TRAINER, 4588, A.TRAINER, 5127, A.TRAINER, 5564, A.TRAINER, 5784, A.TRAINER, 11097, A.TRAINER, 11098, A.TRAINER, 16278, A.TRAINER, 16688, A.TRAINER, 16728, A.TRAINER, 17442, A.TRAINER, 18754, A.TRAINER, 18771, A.TRAINER, 19187, A.TRAINER, 21087, A.TRAINER, 1385, A.TRAINER, 3967, A.TRAINER, 33612, A.TRAINER, 33635, A.TRAINER, 33681, A.TRAINER, 8153)

	-- Cured Medium Hide -- 3817
	AddRecipe(3817, 100, 4233, R_COMMON, GAME_ORIG, 100, 115, 122, 130)
	self:addTradeFlags(RecipeDB, 3817, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP)
	self:addTradeAcquire(RecipeDB, 3817, A.TRAINER, 3007, A.TRAINER, 3365, A.TRAINER, 3703, A.TRAINER, 3967, A.TRAINER, 4212, A.TRAINER, 4588, A.TRAINER, 5127, A.TRAINER, 5564, A.TRAINER, 11097, A.TRAINER, 11098, A.TRAINER, 16688, A.TRAINER, 16728, A.TRAINER, 18754, A.TRAINER, 18771, A.TRAINER, 19187, A.TRAINER, 21087, A.TRAINER, 1632, A.TRAINER, 5784, A.TRAINER, 1385, A.TRAINER, 3549, A.TRAINER, 33612, A.TRAINER, 33635, A.TRAINER, 33681, A.TRAINER, 8153, A.TRAINER, 17442, A.TRAINER, 16278, A.TRAINER, 3605)

	-- Cured Heavy Hide -- 3818
	AddRecipe(3818, 150, 4236, R_COMMON, GAME_ORIG, 150, 160, 165, 170)
	self:addTradeFlags(RecipeDB, 3818, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP)
	self:addTradeAcquire(RecipeDB, 3818, A.TRAINER, 1385, A.TRAINER, 3007, A.TRAINER, 3365, A.TRAINER, 3703, A.TRAINER, 3967, A.TRAINER, 4212, A.TRAINER, 4588, A.TRAINER, 5127, A.TRAINER, 5564, A.TRAINER, 8153, A.TRAINER, 11097, A.TRAINER, 11098, A.TRAINER, 16688, A.TRAINER, 16728, A.TRAINER, 18754, A.TRAINER, 18771, A.TRAINER, 19187, A.TRAINER, 21087, A.TRAINER, 1632, A.TRAINER, 5784, A.TRAINER, 3549, A.TRAINER, 33612, A.TRAINER, 33635, A.TRAINER, 33681, A.TRAINER, 17442, A.TRAINER, 16278, A.TRAINER, 3605)

	-- Raptor Hide Harness -- 4096
	AddRecipe(4096, 165, 4455, R_UNCOMMON, GAME_WOTLK, 165, 185, 195, 205)
	self:addTradeFlags(RecipeDB, 4096, F.HORDE, F.VENDOR, F.IBOE, F.RBOP, F.DPS, F.LEATHER)
	self:addTradeAcquire(RecipeDB, 4096, A.VENDOR, 2819)

	-- Raptor Hide Belt -- 4097
	AddRecipe(4097, 165, 4456, R_UNCOMMON, GAME_ORIG, 165, 185, 195, 205)
	self:addTradeFlags(RecipeDB, 4097, F.ALLIANCE, F.VENDOR, F.IBOE, F.RBOE, F.DPS, F.LEATHER)
	self:addTradeAcquire(RecipeDB, 4097, A.VENDOR, 2816)

	-- Kodo Hide Bag -- 5244
	AddRecipe(5244, 40, 5081, R_UNCOMMON, GAME_ORIG, 40, 70, 85, 100)
	self:addTradeFlags(RecipeDB, 5244, F.HORDE, F.QUEST, F.IBOE, F.RBOE)
	self:addTradeAcquire(RecipeDB, 5244, A.QUEST, 769)

	-- Barbaric Harness -- 6661
	AddRecipe(6661, 190, 5739, R_COMMON, GAME_ORIG, 190, 210, 220, 230)
	self:addTradeFlags(RecipeDB, 6661, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.LEATHER)
	self:addTradeAcquire(RecipeDB, 6661, A.TRAINER, 3007, A.TRAINER, 4212, A.TRAINER, 11097, A.TRAINER, 11098, A.TRAINER, 18754, A.TRAINER, 18771, A.TRAINER, 19187, A.TRAINER, 21087, A.TRAINER, 1632, A.TRAINER, 5784, A.TRAINER, 16728, A.TRAINER, 3703, A.TRAINER, 1385, A.TRAINER, 3549, A.TRAINER, 3365, A.TRAINER, 3967, A.TRAINER, 33612, A.TRAINER, 33635, A.TRAINER, 16688, A.TRAINER, 33681, A.TRAINER, 8153, A.TRAINER, 17442, A.TRAINER, 16278, A.TRAINER, 3605, A.TRAINER, 5564, A.TRAINER, 5127, A.TRAINER, 4588)

	-- Murloc Scale Belt -- 6702
	AddRecipe(6702, 90, 5780, R_COMMON, GAME_ORIG, 90, 120, 135, 150)
	self:addTradeFlags(RecipeDB, 6702, F.ALLIANCE, F.HORDE, F.VENDOR, F.INSTANCE, F.MOB_DROP, F.IBOE, F.RBOE, F.DPS, F.LEATHER)
	self:addTradeAcquire(RecipeDB, 6702, A.MOB, 1732, A.MOB, 3385, A.VENDOR, 843, A.VENDOR, 3556, A.VENDOR, 4186)

	-- Murloc Scale Breastplate -- 6703
	AddRecipe(6703, 95, 5781, R_COMMON, GAME_ORIG, 95, 125, 140, 155)
	self:addTradeFlags(RecipeDB, 6703, F.ALLIANCE, F.HORDE, F.VENDOR, F.INSTANCE, F.MOB_DROP, F.IBOE, F.RBOE, F.DPS, F.LEATHER)
	self:addTradeAcquire(RecipeDB, 6703, A.MOB, 657, A.MOB, 3386, A.VENDOR, 843, A.VENDOR, 3556, A.VENDOR, 4186)

	-- Thick Murloc Armor -- 6704
	AddRecipe(6704, 170, 5782, R_UNCOMMON, GAME_ORIG, 170, 190, 200, 210)
	self:addTradeFlags(RecipeDB, 6704, F.ALLIANCE, F.HORDE, F.VENDOR, F.MOB_DROP, F.IBOE, F.RBOE, F.DPS, F.LEATHER)
	self:addTradeAcquire(RecipeDB, 6704, A.MOB, 938, A.MOB, 1160, A.VENDOR, 2381, A.VENDOR, 2393)

	-- Murloc Scale Bracers -- 6705
	AddRecipe(6705, 190, 5783, R_UNCOMMON, GAME_ORIG, 190, 210, 220, 230)
	self:addTradeFlags(RecipeDB, 6705, F.ALLIANCE, F.HORDE, F.MOB_DROP, F.IBOE, F.RBOE, F.DPS, F.LEATHER)
	self:addTradeAcquire(RecipeDB, 6705, A.MOB, 2636, A.MOB, 1561, A.VENDOR, 4897)

	-- Handstitched Leather Vest -- 7126
	AddRecipe(7126, 1, 5957, R_COMMON, GAME_ORIG, 1, 40, 55, 70)
	self:addTradeFlags(RecipeDB, 7126, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.LEATHER)
	self:addTradeAcquire(RecipeDB, 7126, A.CUSTOM, 8)

	-- Fine Leather Pants -- 7133
	AddRecipe(7133, 105, 5958, R_UNCOMMON, GAME_ORIG, 105, 130, 142, 155)
	self:addTradeFlags(RecipeDB, 7133, F.ALLIANCE, F.HORDE, F.WORLD_DROP, F.IBOE, F.RBOE, F.HEALER, F.CASTER, F.LEATHER)
	self:addTradeAcquire(RecipeDB, 7133, A.WORLD_DROP, 2)

	-- Dark Leather Pants -- 7135
	AddRecipe(7135, 115, 5961, R_COMMON, GAME_ORIG, 115, 140, 152, 165)
	self:addTradeFlags(RecipeDB, 7135, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.DPS, F.LEATHER)
	self:addTradeAcquire(RecipeDB, 7135, A.TRAINER, 1385, A.TRAINER, 3007, A.TRAINER, 3365, A.TRAINER, 3703, A.TRAINER, 3967, A.TRAINER, 4212, A.TRAINER, 4588, A.TRAINER, 5127, A.TRAINER, 5564, A.TRAINER, 11097, A.TRAINER, 11098, A.TRAINER, 16688, A.TRAINER, 16728, A.TRAINER, 18754, A.TRAINER, 18771, A.TRAINER, 19187, A.TRAINER, 21087, A.TRAINER, 1632, A.TRAINER, 5784, A.TRAINER, 3549, A.TRAINER, 33612, A.TRAINER, 33635, A.TRAINER, 33681, A.TRAINER, 8153, A.TRAINER, 17442, A.TRAINER, 16278, A.TRAINER, 3605)

	-- Guardian Pants -- 7147
	AddRecipe(7147, 160, 5962, R_COMMON, GAME_ORIG, 160, 180, 190, 200)
	self:addTradeFlags(RecipeDB, 7147, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.HEALER, F.CASTER, F.LEATHER)
	self:addTradeAcquire(RecipeDB, 7147, A.TRAINER, 3007, A.TRAINER, 4212, A.TRAINER, 11097, A.TRAINER, 11098, A.TRAINER, 18754, A.TRAINER, 18771, A.TRAINER, 19187, A.TRAINER, 21087, A.TRAINER, 1632, A.TRAINER, 5784, A.TRAINER, 16728, A.TRAINER, 3703, A.TRAINER, 1385, A.TRAINER, 3549, A.TRAINER, 3365, A.TRAINER, 3967, A.TRAINER, 33612, A.TRAINER, 33635, A.TRAINER, 16688, A.TRAINER, 33681, A.TRAINER, 8153, A.TRAINER, 17442, A.TRAINER, 16278, A.TRAINER, 3605, A.TRAINER, 5564, A.TRAINER, 5127, A.TRAINER, 4588)

	-- Barbaric Leggings -- 7149
	AddRecipe(7149, 170, 5963, R_COMMON, GAME_ORIG, 170, 190, 200, 210)
	self:addTradeFlags(RecipeDB, 7149, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOE, F.DPS, F.LEATHER)
	self:addTradeAcquire(RecipeDB, 7149, A.VENDOR, 2810, A.VENDOR, 2821, A.VENDOR, 3958, A.VENDOR, 4877)

	-- Barbaric Shoulders -- 7151
	AddRecipe(7151, 175, 5964, R_COMMON, GAME_ORIG, 175, 195, 205, 215)
	self:addTradeFlags(RecipeDB, 7151, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.DPS, F.LEATHER)
	self:addTradeAcquire(RecipeDB, 7151, A.TRAINER, 3007, A.TRAINER, 4212, A.TRAINER, 11097, A.TRAINER, 11098, A.TRAINER, 18754, A.TRAINER, 18771, A.TRAINER, 19187, A.TRAINER, 21087, A.TRAINER, 1632, A.TRAINER, 5784, A.TRAINER, 16728, A.TRAINER, 1385, A.TRAINER, 3549, A.TRAINER, 3365, A.TRAINER, 3967, A.TRAINER, 3703, A.TRAINER, 33612, A.TRAINER, 33635, A.TRAINER, 16688, A.TRAINER, 33681, A.TRAINER, 8153, A.TRAINER, 17442, A.TRAINER, 16278, A.TRAINER, 3605, A.TRAINER, 5564, A.TRAINER, 5127, A.TRAINER, 4588)

	-- Guardian Cloak -- 7153
	AddRecipe(7153, 185, 5965, R_UNCOMMON, GAME_ORIG, 185, 205, 215, 225)
	self:addTradeFlags(RecipeDB, 7153, F.ALLIANCE, F.HORDE, F.WORLD_DROP, F.IBOE, F.RBOE, F.HEALER, F.CASTER, F.CLOAK)
	self:addTradeAcquire(RecipeDB, 7153, A.WORLD_DROP, 2)

	-- Guardian Gloves -- 7156
	AddRecipe(7156, 190, 5966, R_COMMON, GAME_ORIG, 190, 210, 220, 230)
	self:addTradeFlags(RecipeDB, 7156, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.HEALER, F.CASTER, F.LEATHER)
	self:addTradeAcquire(RecipeDB, 7156, A.TRAINER, 3007, A.TRAINER, 4212, A.TRAINER, 11097, A.TRAINER, 11098, A.TRAINER, 18754, A.TRAINER, 18771, A.TRAINER, 19187, A.TRAINER, 21087, A.TRAINER, 1632, A.TRAINER, 5784, A.TRAINER, 16728, A.TRAINER, 1385, A.TRAINER, 3549, A.TRAINER, 3365, A.TRAINER, 3967, A.TRAINER, 3703, A.TRAINER, 33612, A.TRAINER, 33635, A.TRAINER, 16688, A.TRAINER, 33681, A.TRAINER, 8153, A.TRAINER, 17442, A.TRAINER, 16278, A.TRAINER, 3605, A.TRAINER, 5564, A.TRAINER, 5127, A.TRAINER, 4588)

	-- Deviate Scale Cloak -- 7953
	AddRecipe(7953, 90, 6466, R_COMMON, GAME_ORIG, 90, 120, 135, 150)
	self:addTradeFlags(RecipeDB, 7953, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOE, F.DPS, F.CLOAK)
	self:addTradeAcquire(RecipeDB, 7953, A.VENDOR, 5783)

	-- Deviate Scale Gloves -- 7954
	AddRecipe(7954, 105, 6467, R_COMMON, GAME_ORIG, 105, 130, 142, 155)
	self:addTradeFlags(RecipeDB, 7954, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOE, F.DPS, F.LEATHER)
	self:addTradeAcquire(RecipeDB, 7954, A.VENDOR, 5783)

	-- Deviate Scale Belt -- 7955
	AddRecipe(7955, 115, 6468, R_UNCOMMON, GAME_ORIG, 115, 140, 152, 165)
	self:addTradeFlags(RecipeDB, 7955, F.ALLIANCE, F.HORDE, F.QUEST, F.IBOE, F.RBOE, F.DPS, F.LEATHER)
	self:addTradeAcquire(RecipeDB, 7955, A.QUEST, 1487)

	-- Moonglow Vest -- 8322
	AddRecipe(8322, 90, 6709, R_UNCOMMON, GAME_ORIG, 90, 115, 130, 145)
	self:addTradeFlags(RecipeDB, 8322, F.ALLIANCE, F.QUEST, F.IBOE, F.RBOE, F.HEALER, F.CASTER, F.LEATHER)
	self:addTradeAcquire(RecipeDB, 8322, A.QUEST, 1582)

	-- Handstitched Leather Cloak -- 9058
	AddRecipe(9058, 1, 7276, R_COMMON, GAME_ORIG, 1, 40, 55, 70)
	self:addTradeFlags(RecipeDB, 9058, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.CLOAK)
	self:addTradeAcquire(RecipeDB, 9058, A.CUSTOM, 8)

	-- Handstitched Leather Bracers -- 9059
	AddRecipe(9059, 1, 7277, R_COMMON, GAME_ORIG, 1, 40, 55, 70)
	self:addTradeFlags(RecipeDB, 9059, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.LEATHER)
	self:addTradeAcquire(RecipeDB, 9059, A.CUSTOM, 8)

	-- Light Leather Quiver -- 9060
	AddRecipe(9060, 30, 7278, R_COMMON, GAME_ORIG, 30, 60, 75, 90)
	self:addTradeFlags(RecipeDB, 9060, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP)
	self:addTradeAcquire(RecipeDB, 9060, A.TRAINER, 1632, A.TRAINER, 3007, A.TRAINER, 3069, A.TRAINER, 3365, A.TRAINER, 3549, A.TRAINER, 3605, A.TRAINER, 3703, A.TRAINER, 4212, A.TRAINER, 4588, A.TRAINER, 5127, A.TRAINER, 5564, A.TRAINER, 5784, A.TRAINER, 11097, A.TRAINER, 11098, A.TRAINER, 16278, A.TRAINER, 16688, A.TRAINER, 16728, A.TRAINER, 17442, A.TRAINER, 18754, A.TRAINER, 18771, A.TRAINER, 19187, A.TRAINER, 21087, A.TRAINER, 1385, A.TRAINER, 3967, A.TRAINER, 33612, A.TRAINER, 33635, A.TRAINER, 33681, A.TRAINER, 8153)

	-- Small Leather Ammo Pouch -- 9062
	AddRecipe(9062, 30, 7279, R_COMMON, GAME_ORIG, 30, 60, 75, 90)
	self:addTradeFlags(RecipeDB, 9062, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.AMMO)
	self:addTradeAcquire(RecipeDB, 9062, A.TRAINER, 1385, A.TRAINER, 1632, A.TRAINER, 3007, A.TRAINER, 3069, A.TRAINER, 3365, A.TRAINER, 3549, A.TRAINER, 3605, A.TRAINER, 3703, A.TRAINER, 3967, A.TRAINER, 4212, A.TRAINER, 4588, A.TRAINER, 5127, A.TRAINER, 5564, A.TRAINER, 5784, A.TRAINER, 11097, A.TRAINER, 11098, A.TRAINER, 16278, A.TRAINER, 16688, A.TRAINER, 16728, A.TRAINER, 17442, A.TRAINER, 18754, A.TRAINER, 18771, A.TRAINER, 19187, A.TRAINER, 21087, A.TRAINER, 33635, A.TRAINER, 33612, A.TRAINER, 33681, A.TRAINER, 8153)

	-- Rugged Leather Pants -- 9064
	AddRecipe(9064, 35, 7280, R_UNCOMMON, GAME_ORIG, 35, 65, 80, 95)
	self:addTradeFlags(RecipeDB, 9064, F.ALLIANCE, F.HORDE, F.WORLD_DROP, F.IBOE, F.RBOE, F.LEATHER)
	self:addTradeAcquire(RecipeDB, 9064, A.WORLD_DROP, 2)

	-- Light Leather Bracers -- 9065
	AddRecipe(9065, 70, 7281, R_COMMON, GAME_ORIG, 70, 100, 115, 130)
	self:addTradeFlags(RecipeDB, 9065, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.LEATHER)
	self:addTradeAcquire(RecipeDB, 9065, A.TRAINER, 1385, A.TRAINER, 1632, A.TRAINER, 3007, A.TRAINER, 3069, A.TRAINER, 3365, A.TRAINER, 3549, A.TRAINER, 3605, A.TRAINER, 3703, A.TRAINER, 3967, A.TRAINER, 4212, A.TRAINER, 4588, A.TRAINER, 5127, A.TRAINER, 5564, A.TRAINER, 5784, A.TRAINER, 11097, A.TRAINER, 11098, A.TRAINER, 16278, A.TRAINER, 16688, A.TRAINER, 16728, A.TRAINER, 17442, A.TRAINER, 18754, A.TRAINER, 18771, A.TRAINER, 19187, A.TRAINER, 21087, A.TRAINER, 33635, A.TRAINER, 33612, A.TRAINER, 33681, A.TRAINER, 8153)

	-- Light Leather Pants -- 9068
	AddRecipe(9068, 95, 7282, R_COMMON, GAME_ORIG, 95, 125, 140, 155)
	self:addTradeFlags(RecipeDB, 9068, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.DPS, F.LEATHER)
	self:addTradeAcquire(RecipeDB, 9068, A.TRAINER, 1385, A.TRAINER, 3007, A.TRAINER, 3365, A.TRAINER, 3703, A.TRAINER, 3967, A.TRAINER, 4212, A.TRAINER, 4588, A.TRAINER, 5127, A.TRAINER, 5564, A.TRAINER, 11097, A.TRAINER, 11098, A.TRAINER, 16688, A.TRAINER, 16728, A.TRAINER, 18754, A.TRAINER, 18771, A.TRAINER, 19187, A.TRAINER, 21087, A.TRAINER, 1632, A.TRAINER, 5784, A.TRAINER, 3549, A.TRAINER, 33612, A.TRAINER, 33635, A.TRAINER, 33681, A.TRAINER, 8153, A.TRAINER, 17442, A.TRAINER, 16278, A.TRAINER, 3605)

	-- Black Whelp Cloak -- 9070
	AddRecipe(9070, 100, 7283, R_COMMON, GAME_ORIG, 100, 125, 137, 150)
	self:addTradeFlags(RecipeDB, 9070, F.ALLIANCE, F.VENDOR, F.IBOE, F.RBOE, F.CLOAK)
	self:addTradeAcquire(RecipeDB, 9070, A.VENDOR, 2697)

	-- Red Whelp Gloves -- 9072
	AddRecipe(9072, 120, 7284, R_COMMON, GAME_ORIG, 120, 145, 157, 170)
	self:addTradeFlags(RecipeDB, 9072, F.ALLIANCE, F.VENDOR, F.IBOE, F.RBOE, F.LEATHER)
	self:addTradeAcquire(RecipeDB, 9072, A.VENDOR, 2679)

	-- Nimble Leather Gloves -- 9074
	AddRecipe(9074, 120, 7285, R_COMMON, GAME_ORIG, 120, 145, 157, 170)
	self:addTradeFlags(RecipeDB, 9074, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.DPS, F.LEATHER)
	self:addTradeAcquire(RecipeDB, 9074, A.TRAINER, 1385, A.TRAINER, 3007, A.TRAINER, 3365, A.TRAINER, 3703, A.TRAINER, 3967, A.TRAINER, 4212, A.TRAINER, 4588, A.TRAINER, 5127, A.TRAINER, 5564, A.TRAINER, 8153, A.TRAINER, 11097, A.TRAINER, 11098, A.TRAINER, 16688, A.TRAINER, 16728, A.TRAINER, 18754, A.TRAINER, 18771, A.TRAINER, 19187, A.TRAINER, 21087, A.TRAINER, 1632, A.TRAINER, 5784, A.TRAINER, 3549, A.TRAINER, 33612, A.TRAINER, 33635, A.TRAINER, 33681, A.TRAINER, 17442, A.TRAINER, 16278, A.TRAINER, 3605)

	-- Fletcher's Gloves -- 9145
	AddRecipe(9145, 125, 7348, R_COMMON, GAME_ORIG, 125, 150, 162, 175)
	self:addTradeFlags(RecipeDB, 9145, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.DPS, F.LEATHER)
	self:addTradeAcquire(RecipeDB, 9145, A.TRAINER, 1385, A.TRAINER, 3007, A.TRAINER, 3365, A.TRAINER, 3703, A.TRAINER, 3967, A.TRAINER, 4212, A.TRAINER, 4588, A.TRAINER, 5127, A.TRAINER, 5564, A.TRAINER, 8153, A.TRAINER, 11097, A.TRAINER, 11098, A.TRAINER, 16688, A.TRAINER, 16728, A.TRAINER, 18754, A.TRAINER, 18771, A.TRAINER, 19187, A.TRAINER, 21087, A.TRAINER, 1632, A.TRAINER, 5784, A.TRAINER, 3549, A.TRAINER, 33612, A.TRAINER, 33635, A.TRAINER, 33681, A.TRAINER, 17442, A.TRAINER, 16278, A.TRAINER, 3605)

	-- Herbalist's Gloves -- 9146
	AddRecipe(9146, 135, 7349, R_UNCOMMON, GAME_ORIG, 135, 160, 172, 185)
	self:addTradeFlags(RecipeDB, 9146, F.ALLIANCE, F.VENDOR, F.IBOE, F.RBOP, F.LEATHER)
	self:addTradeAcquire(RecipeDB, 9146, A.VENDOR, 6731)

	-- Earthen Leather Shoulders -- 9147
	AddRecipe(9147, 135, 7352, R_COMMON, GAME_ORIG, 135, 160, 172, 185)
	self:addTradeFlags(RecipeDB, 9147, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOE, F.LEATHER)
	self:addTradeAcquire(RecipeDB, 9147, A.VENDOR, 3537)

	-- Pilferer's Gloves -- 9148
	AddRecipe(9148, 140, 7358, R_UNCOMMON, GAME_ORIG, 140, 165, 177, 190)
	self:addTradeFlags(RecipeDB, 9148, F.ALLIANCE, F.HORDE, F.WORLD_DROP, F.IBOE, F.RBOE, F.DPS, F.LEATHER)
	self:addTradeAcquire(RecipeDB, 9148, A.WORLD_DROP, 2)

	-- Heavy Earthen Gloves -- 9149
	AddRecipe(9149, 145, 7359, R_UNCOMMON, GAME_ORIG, 145, 170, 182, 195)
	self:addTradeFlags(RecipeDB, 9149, F.ALLIANCE, F.HORDE, F.WORLD_DROP, F.IBOE, F.RBOE, F.DPS, F.LEATHER)
	self:addTradeAcquire(RecipeDB, 9149, A.WORLD_DROP, 2)

	-- Heavy Quiver -- 9193
	AddRecipe(9193, 150, 7371, R_COMMON, GAME_ORIG, 150, 170, 180, 190)
	self:addTradeFlags(RecipeDB, 9193, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP)
	self:addTradeAcquire(RecipeDB, 9193, A.TRAINER, 1385, A.TRAINER, 3007, A.TRAINER, 3365, A.TRAINER, 3703, A.TRAINER, 3967, A.TRAINER, 4212, A.TRAINER, 4588, A.TRAINER, 5127, A.TRAINER, 5564, A.TRAINER, 8153, A.TRAINER, 11097, A.TRAINER, 11098, A.TRAINER, 16688, A.TRAINER, 16728, A.TRAINER, 18754, A.TRAINER, 18771, A.TRAINER, 19187, A.TRAINER, 21087, A.TRAINER, 1632, A.TRAINER, 5784, A.TRAINER, 3549, A.TRAINER, 33612, A.TRAINER, 33635, A.TRAINER, 33681, A.TRAINER, 17442, A.TRAINER, 16278, A.TRAINER, 3605)

	-- Heavy Leather Ammo Pouch -- 9194
	AddRecipe(9194, 150, 7372, R_COMMON, GAME_ORIG, 150, 170, 180, 190)
	self:addTradeFlags(RecipeDB, 9194, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.AMMO)
	self:addTradeAcquire(RecipeDB, 9194, A.TRAINER, 1385, A.TRAINER, 3007, A.TRAINER, 3365, A.TRAINER, 3703, A.TRAINER, 3967, A.TRAINER, 4212, A.TRAINER, 4588, A.TRAINER, 5127, A.TRAINER, 5564, A.TRAINER, 8153, A.TRAINER, 11097, A.TRAINER, 11098, A.TRAINER, 16688, A.TRAINER, 16728, A.TRAINER, 18754, A.TRAINER, 18771, A.TRAINER, 19187, A.TRAINER, 21087, A.TRAINER, 1632, A.TRAINER, 5784, A.TRAINER, 3549, A.TRAINER, 33612, A.TRAINER, 33635, A.TRAINER, 33681, A.TRAINER, 17442, A.TRAINER, 16278, A.TRAINER, 3605)

	-- Dusky Leather Leggings -- 9195
	AddRecipe(9195, 165, 7373, R_UNCOMMON, GAME_ORIG, 165, 185, 195, 205)
	self:addTradeFlags(RecipeDB, 9195, F.ALLIANCE, F.HORDE, F.WORLD_DROP, F.IBOE, F.RBOE, F.DPS, F.LEATHER)
	self:addTradeAcquire(RecipeDB, 9195, A.WORLD_DROP, 2)

	-- Dusky Leather Armor -- 9196
	AddRecipe(9196, 175, 7374, R_COMMON, GAME_ORIG, 175, 195, 205, 215)
	self:addTradeFlags(RecipeDB, 9196, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.DPS, F.LEATHER)
	self:addTradeAcquire(RecipeDB, 9196, A.TRAINER, 3007, A.TRAINER, 4212, A.TRAINER, 11097, A.TRAINER, 11098, A.TRAINER, 18754, A.TRAINER, 18771, A.TRAINER, 19187, A.TRAINER, 21087, A.TRAINER, 1632, A.TRAINER, 5784, A.TRAINER, 16728, A.TRAINER, 3703, A.TRAINER, 1385, A.TRAINER, 3549, A.TRAINER, 3365, A.TRAINER, 3967, A.TRAINER, 33612, A.TRAINER, 33635, A.TRAINER, 16688, A.TRAINER, 33681, A.TRAINER, 8153, A.TRAINER, 17442, A.TRAINER, 16278, A.TRAINER, 3605, A.TRAINER, 5564, A.TRAINER, 5127, A.TRAINER, 4588)

	-- Green Whelp Armor -- 9197
	AddRecipe(9197, 175, 7375, R_UNCOMMON, GAME_ORIG, 175, 195, 205, 215)
	self:addTradeFlags(RecipeDB, 9197, F.ALLIANCE, F.HORDE, F.WORLD_DROP, F.IBOE, F.RBOE, F.HEALER, F.CASTER, F.LEATHER)
	self:addTradeAcquire(RecipeDB, 9197, A.WORLD_DROP, 2)

	-- Frost Leather Cloak -- 9198
	AddRecipe(9198, 180, 7377, R_COMMON, GAME_ORIG, 180, 200, 210, 220)
	self:addTradeFlags(RecipeDB, 9198, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.HEALER, F.CASTER, F.CLOAK)
	self:addTradeAcquire(RecipeDB, 9198, A.TRAINER, 3007, A.TRAINER, 4212, A.TRAINER, 11097, A.TRAINER, 11098, A.TRAINER, 18754, A.TRAINER, 18771, A.TRAINER, 19187, A.TRAINER, 21087, A.TRAINER, 1632, A.TRAINER, 5784, A.TRAINER, 16728, A.TRAINER, 3703, A.TRAINER, 1385, A.TRAINER, 3549, A.TRAINER, 3365, A.TRAINER, 3967, A.TRAINER, 33612, A.TRAINER, 33635, A.TRAINER, 16688, A.TRAINER, 33681, A.TRAINER, 8153, A.TRAINER, 17442, A.TRAINER, 16278, A.TRAINER, 3605, A.TRAINER, 5564, A.TRAINER, 5127, A.TRAINER, 4588)

	-- Dusky Bracers -- 9201
	AddRecipe(9201, 185, 7378, R_COMMON, GAME_ORIG, 185, 205, 215, 225)
	self:addTradeFlags(RecipeDB, 9201, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.DPS, F.LEATHER)
	self:addTradeAcquire(RecipeDB, 9201, A.TRAINER, 3007, A.TRAINER, 4212, A.TRAINER, 11097, A.TRAINER, 11098, A.TRAINER, 18754, A.TRAINER, 18771, A.TRAINER, 19187, A.TRAINER, 21087, A.TRAINER, 1632, A.TRAINER, 5784, A.TRAINER, 16728, A.TRAINER, 3703, A.TRAINER, 1385, A.TRAINER, 3549, A.TRAINER, 3365, A.TRAINER, 3967, A.TRAINER, 33612, A.TRAINER, 33635, A.TRAINER, 16688, A.TRAINER, 33681, A.TRAINER, 8153, A.TRAINER, 17442, A.TRAINER, 16278, A.TRAINER, 3605, A.TRAINER, 5564, A.TRAINER, 5127, A.TRAINER, 4588)

	-- Green Whelp Bracers -- 9202
	AddRecipe(9202, 190, 7386, R_UNCOMMON, GAME_ORIG, 190, 210, 220, 230)
	self:addTradeFlags(RecipeDB, 9202, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOP, F.LEATHER)
	self:addTradeAcquire(RecipeDB, 9202, A.VENDOR, 7854, A.VENDOR, 4589, A.VENDOR, 7852, A.VENDOR, 4225)

	-- Dusky Belt -- 9206
	AddRecipe(9206, 195, 7387, R_COMMON, GAME_ORIG, 195, 215, 225, 235)
	self:addTradeFlags(RecipeDB, 9206, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.DPS, F.LEATHER)
	self:addTradeAcquire(RecipeDB, 9206, A.TRAINER, 3007, A.TRAINER, 4212, A.TRAINER, 11097, A.TRAINER, 11098, A.TRAINER, 18754, A.TRAINER, 18771, A.TRAINER, 19187, A.TRAINER, 21087, A.TRAINER, 1632, A.TRAINER, 5784, A.TRAINER, 16728, A.TRAINER, 3703, A.TRAINER, 1385, A.TRAINER, 3549, A.TRAINER, 3365, A.TRAINER, 3967, A.TRAINER, 33612, A.TRAINER, 33635, A.TRAINER, 16688, A.TRAINER, 33681, A.TRAINER, 8153, A.TRAINER, 17442, A.TRAINER, 16278, A.TRAINER, 3605, A.TRAINER, 5564, A.TRAINER, 5127, A.TRAINER, 4588)

	-- Dusky Boots -- 9207
	AddRecipe(9207, 200, 7390, R_RARE, GAME_ORIG, 200, 220, 230, 240)
	self:addTradeFlags(RecipeDB, 9207, F.ALLIANCE, F.HORDE, F.INSTANCE, F.MOB_DROP, F.IBOE, F.RBOE, F.DPS, F.LEATHER)
	self:addTradeAcquire(RecipeDB, 9207, A.WORLD_DROP, 2)

	-- Swift Boots -- 9208
	AddRecipe(9208, 200, 7391, R_UNCOMMON, GAME_ORIG, 200, 220, 230, 240)
	self:addTradeFlags(RecipeDB, 9208, F.ALLIANCE, F.HORDE, F.WORLD_DROP, F.IBOE, F.RBOE, F.LEATHER)
	self:addTradeAcquire(RecipeDB, 9208, A.WORLD_DROP, 2)

	-- Cured Thick Hide -- 10482
	AddRecipe(10482, 200, 8172, R_COMMON, GAME_ORIG, 200, 200, 200, 200)
	self:addTradeFlags(RecipeDB, 10482, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP)
	self:addTradeAcquire(RecipeDB, 10482, A.TRAINER, 3007, A.TRAINER, 4212, A.TRAINER, 11097, A.TRAINER, 11098, A.TRAINER, 18754, A.TRAINER, 18771, A.TRAINER, 19187, A.TRAINER, 21087, A.TRAINER, 1632, A.TRAINER, 5784, A.TRAINER, 16728, A.TRAINER, 3703, A.TRAINER, 1385, A.TRAINER, 3549, A.TRAINER, 3365, A.TRAINER, 3967, A.TRAINER, 33612, A.TRAINER, 33635, A.TRAINER, 16688, A.TRAINER, 33681, A.TRAINER, 8153, A.TRAINER, 17442, A.TRAINER, 16278, A.TRAINER, 3605, A.TRAINER, 5564, A.TRAINER, 5127, A.TRAINER, 4588)

	-- Thick Armor Kit -- 10487
	AddRecipe(10487, 200, 8173, R_COMMON, GAME_ORIG, 200, 220, 230, 240)
	self:addTradeFlags(RecipeDB, 10487, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP)
	self:addTradeAcquire(RecipeDB, 10487, A.TRAINER, 3007, A.TRAINER, 4212, A.TRAINER, 11097, A.TRAINER, 11098, A.TRAINER, 18754, A.TRAINER, 18771, A.TRAINER, 19187, A.TRAINER, 21087, A.TRAINER, 1632, A.TRAINER, 5784, A.TRAINER, 16728, A.TRAINER, 3703, A.TRAINER, 1385, A.TRAINER, 3549, A.TRAINER, 3365, A.TRAINER, 3967, A.TRAINER, 33612, A.TRAINER, 33635, A.TRAINER, 16688, A.TRAINER, 33681, A.TRAINER, 8153, A.TRAINER, 17442, A.TRAINER, 16278, A.TRAINER, 3605, A.TRAINER, 5564, A.TRAINER, 5127, A.TRAINER, 4588)

	-- Comfortable Leather Hat -- 10490
	AddRecipe(10490, 200, 8174, R_RARE, GAME_ORIG, 200, 220, 230, 240)
	self:addTradeFlags(RecipeDB, 10490, F.ALLIANCE, F.HORDE, F.INSTANCE, F.MOB_DROP, F.IBOE, F.RBOE, F.LEATHER)
	self:addTradeAcquire(RecipeDB, 10490, A.WORLD_DROP, 2)

	-- Nightscape Tunic -- 10499
	AddRecipe(10499, 205, 8175, R_COMMON, GAME_ORIG, 205, 225, 235, 245)
	self:addTradeFlags(RecipeDB, 10499, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.DPS, F.LEATHER)
	self:addTradeAcquire(RecipeDB, 10499, A.TRAINER, 3007, A.TRAINER, 4212, A.TRAINER, 11097, A.TRAINER, 11098, A.TRAINER, 18754, A.TRAINER, 18771, A.TRAINER, 19187, A.TRAINER, 21087, A.TRAINER, 1632, A.TRAINER, 5784, A.TRAINER, 16728, A.TRAINER, 3703, A.TRAINER, 1385, A.TRAINER, 3549, A.TRAINER, 3365, A.TRAINER, 3967, A.TRAINER, 33612, A.TRAINER, 33635, A.TRAINER, 16688, A.TRAINER, 33681, A.TRAINER, 8153, A.TRAINER, 17442, A.TRAINER, 16278, A.TRAINER, 3605, A.TRAINER, 5564, A.TRAINER, 5127, A.TRAINER, 4588)

	-- Nightscape Headband -- 10507
	AddRecipe(10507, 205, 8176, R_COMMON, GAME_ORIG, 205, 225, 235, 245)
	self:addTradeFlags(RecipeDB, 10507, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.DPS, F.LEATHER)
	self:addTradeAcquire(RecipeDB, 10507, A.TRAINER, 3007, A.TRAINER, 4212, A.TRAINER, 11097, A.TRAINER, 11098, A.TRAINER, 18754, A.TRAINER, 18771, A.TRAINER, 19187, A.TRAINER, 21087, A.TRAINER, 1632, A.TRAINER, 5784, A.TRAINER, 16728, A.TRAINER, 3703, A.TRAINER, 1385, A.TRAINER, 3549, A.TRAINER, 3365, A.TRAINER, 3967, A.TRAINER, 33612, A.TRAINER, 33635, A.TRAINER, 16688, A.TRAINER, 33681, A.TRAINER, 8153, A.TRAINER, 17442, A.TRAINER, 16278, A.TRAINER, 3605, A.TRAINER, 5564, A.TRAINER, 5127, A.TRAINER, 4588)

	-- Turtle Scale Gloves -- 10509
	AddRecipe(10509, 205, 8187, R_COMMON, GAME_ORIG, 205, 225, 235, 245)
	self:addTradeFlags(RecipeDB, 10509, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOE, F.HEALER, F.CASTER, F.MAIL)
	self:addTradeAcquire(RecipeDB, 10509, A.VENDOR, 7852, A.VENDOR, 7854)

	-- Turtle Scale Breastplate -- 10511
	AddRecipe(10511, 210, 8189, R_COMMON, GAME_ORIG, 210, 230, 240, 250)
	self:addTradeFlags(RecipeDB, 10511, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.HEALER, F.CASTER, F.MAIL)
	self:addTradeAcquire(RecipeDB, 10511, A.TRAINER, 3007, A.TRAINER, 4212, A.TRAINER, 11097, A.TRAINER, 11098, A.TRAINER, 18754, A.TRAINER, 18771, A.TRAINER, 19187, A.TRAINER, 21087, A.TRAINER, 1632, A.TRAINER, 5784, A.TRAINER, 16728, A.TRAINER, 3703, A.TRAINER, 1385, A.TRAINER, 3549, A.TRAINER, 3365, A.TRAINER, 3967, A.TRAINER, 33612, A.TRAINER, 33635, A.TRAINER, 16688, A.TRAINER, 33681, A.TRAINER, 8153, A.TRAINER, 17442, A.TRAINER, 16278, A.TRAINER, 3605, A.TRAINER, 5564, A.TRAINER, 5127, A.TRAINER, 4588)

	-- Nightscape Shoulders -- 10516
	AddRecipe(10516, 210, 8192, R_UNCOMMON, GAME_ORIG, 210, 230, 240, 250)
	self:addTradeFlags(RecipeDB, 10516, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOP, F.DPS, F.LEATHER)
	self:addTradeAcquire(RecipeDB, 10516, A.VENDOR, 7854, A.VENDOR, 8160)

	-- Turtle Scale Bracers -- 10518
	AddRecipe(10518, 210, 8198, R_COMMON, GAME_ORIG, 210, 230, 240, 250)
	self:addTradeFlags(RecipeDB, 10518, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.MAIL)
	self:addTradeAcquire(RecipeDB, 10518, A.TRAINER, 3007, A.TRAINER, 4212, A.TRAINER, 11097, A.TRAINER, 11098, A.TRAINER, 18754, A.TRAINER, 18771, A.TRAINER, 19187, A.TRAINER, 21087, A.TRAINER, 1632, A.TRAINER, 5784, A.TRAINER, 16728, A.TRAINER, 3703, A.TRAINER, 1385, A.TRAINER, 3549, A.TRAINER, 3365, A.TRAINER, 3967, A.TRAINER, 33612, A.TRAINER, 33635, A.TRAINER, 33681, A.TRAINER, 8153, A.TRAINER, 17442, A.TRAINER, 16278, A.TRAINER, 3605, A.TRAINER, 5564, A.TRAINER, 5127, A.TRAINER, 4588)

	-- Big Voodoo Robe -- 10520
	AddRecipe(10520, 215, 8200, R_UNCOMMON, GAME_ORIG, 215, 235, 245, 255)
	self:addTradeFlags(RecipeDB, 10520, F.ALLIANCE, F.HORDE, F.WORLD_DROP, F.IBOE, F.RBOE, F.HEALER, F.CASTER, F.LEATHER)
	self:addTradeAcquire(RecipeDB, 10520, A.WORLD_DROP, 2)

	-- Tough Scorpid Breastplate -- 10525
	AddRecipe(10525, 220, 8203, R_UNCOMMON, GAME_ORIG, 220, 240, 250, 260)
	self:addTradeFlags(RecipeDB, 10525, F.ALLIANCE, F.HORDE, F.MOB_DROP, F.IBOE, F.RBOE, F.DPS, F.MAIL)
	self:addTradeAcquire(RecipeDB, 10525, A.MOB, 5618)

	-- Wild Leather Shoulders -- 10529
	AddRecipe(10529, 220, 8210, R_UNCOMMON, GAME_ORIG, 220, 240, 250, 260)
	self:addTradeFlags(RecipeDB, 10529, F.ALLIANCE, F.HORDE, F.QUEST, F.IBOE, F.RBOP, F.LEATHER)
	self:addTradeAcquire(RecipeDB, 10529, A.QUEST, 2848, A.QUEST, 2855)

	-- Big Voodoo Mask -- 10531
	AddRecipe(10531, 220, 8201, R_UNCOMMON, GAME_ORIG, 220, 240, 250, 260)
	self:addTradeFlags(RecipeDB, 10531, F.ALLIANCE, F.HORDE, F.WORLD_DROP, F.IBOE, F.RBOE, F.HEALER, F.CASTER, F.LEATHER)
	self:addTradeAcquire(RecipeDB, 10531, A.WORLD_DROP, 2)

	-- Tough Scorpid Bracers -- 10533
	AddRecipe(10533, 220, 8205, R_UNCOMMON, GAME_ORIG, 220, 240, 250, 260)
	self:addTradeFlags(RecipeDB, 10533, F.ALLIANCE, F.HORDE, F.MOB_DROP, F.IBOE, F.RBOE, F.DPS, F.MAIL)
	self:addTradeAcquire(RecipeDB, 10533, A.MOB, 5617)

	-- Tough Scorpid Gloves -- 10542
	AddRecipe(10542, 225, 8204, R_UNCOMMON, GAME_ORIG, 225, 245, 255, 265)
	self:addTradeFlags(RecipeDB, 10542, F.ALLIANCE, F.HORDE, F.MOB_DROP, F.IBOE, F.RBOE, F.DPS, F.MAIL)
	self:addTradeAcquire(RecipeDB, 10542, A.MOB, 5616)

	-- Wild Leather Vest -- 10544
	AddRecipe(10544, 225, 8211, R_UNCOMMON, GAME_ORIG, 225, 245, 255, 265)
	self:addTradeFlags(RecipeDB, 10544, F.ALLIANCE, F.HORDE, F.QUEST, F.IBOE, F.RBOP, F.LEATHER)
	self:addTradeAcquire(RecipeDB, 10544, A.QUEST, 2849, A.QUEST, 2856)

	-- Wild Leather Helmet -- 10546
	AddRecipe(10546, 225, 8214, R_UNCOMMON, GAME_ORIG, 225, 245, 255, 265)
	self:addTradeFlags(RecipeDB, 10546, F.ALLIANCE, F.HORDE, F.QUEST, F.IBOE, F.RBOP, F.LEATHER)
	self:addTradeAcquire(RecipeDB, 10546, A.QUEST, 2850, A.QUEST, 2857)

	-- Nightscape Pants -- 10548
	AddRecipe(10548, 230, 8193, R_COMMON, GAME_ORIG, 230, 250, 260, 270)
	self:addTradeFlags(RecipeDB, 10548, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.DPS, F.LEATHER)
	self:addTradeAcquire(RecipeDB, 10548, A.TRAINER, 11097, A.TRAINER, 11098, A.TRAINER, 18754, A.TRAINER, 18771, A.TRAINER, 19187, A.TRAINER, 21087, A.TRAINER, 4212, A.TRAINER, 3007, A.TRAINER, 1632, A.TRAINER, 5784, A.TRAINER, 16728, A.TRAINER, 3703, A.TRAINER, 1385, A.TRAINER, 3549, A.TRAINER, 3365, A.TRAINER, 3967, A.TRAINER, 33612, A.TRAINER, 33635, A.TRAINER, 16688, A.TRAINER, 33681, A.TRAINER, 8153, A.TRAINER, 17442, A.TRAINER, 16278, A.TRAINER, 3605, A.TRAINER, 5564, A.TRAINER, 5127, A.TRAINER, 4588)

	-- Turtle Scale Helm -- 10552
	AddRecipe(10552, 230, 8191, R_COMMON, GAME_ORIG, 230, 250, 260, 270)
	self:addTradeFlags(RecipeDB, 10552, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.HEALER, F.CASTER, F.MAIL)
	self:addTradeAcquire(RecipeDB, 10552, A.TRAINER, 11097, A.TRAINER, 11098, A.TRAINER, 18754, A.TRAINER, 18771, A.TRAINER, 19187, A.TRAINER, 21087, A.TRAINER, 4212, A.TRAINER, 3007, A.TRAINER, 1632, A.TRAINER, 5784, A.TRAINER, 16728, A.TRAINER, 3703, A.TRAINER, 1385, A.TRAINER, 3549, A.TRAINER, 3365, A.TRAINER, 3967, A.TRAINER, 33612, A.TRAINER, 33635, A.TRAINER, 16688, A.TRAINER, 33681, A.TRAINER, 8153, A.TRAINER, 17442, A.TRAINER, 16278, A.TRAINER, 3605, A.TRAINER, 5564, A.TRAINER, 5127, A.TRAINER, 4588)

	-- Tough Scorpid Boots -- 10554
	AddRecipe(10554, 235, 8209, R_UNCOMMON, GAME_ORIG, 235, 255, 265, 275)
	self:addTradeFlags(RecipeDB, 10554, F.ALLIANCE, F.HORDE, F.MOB_DROP, F.IBOE, F.RBOE, F.DPS, F.MAIL)
	self:addTradeAcquire(RecipeDB, 10554, A.MOB, 5615)

	-- Turtle Scale Leggings -- 10556
	AddRecipe(10556, 235, 8185, R_COMMON, GAME_ORIG, 235, 255, 265, 275)
	self:addTradeFlags(RecipeDB, 10556, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.HEALER, F.CASTER, F.MAIL)
	self:addTradeAcquire(RecipeDB, 10556, A.TRAINER, 11097, A.TRAINER, 11098, A.TRAINER, 18754, A.TRAINER, 18771, A.TRAINER, 19187, A.TRAINER, 21087, A.TRAINER, 4212, A.TRAINER, 3007, A.TRAINER, 1632, A.TRAINER, 5784, A.TRAINER, 16728, A.TRAINER, 3703, A.TRAINER, 1385, A.TRAINER, 3549, A.TRAINER, 3365, A.TRAINER, 3967, A.TRAINER, 33612, A.TRAINER, 33635, A.TRAINER, 16688, A.TRAINER, 33681, A.TRAINER, 8153, A.TRAINER, 17442, A.TRAINER, 16278, A.TRAINER, 5564, A.TRAINER, 5127, A.TRAINER, 4588)

	-- Nightscape Boots -- 10558
	AddRecipe(10558, 235, 8197, R_COMMON, GAME_ORIG, 235, 255, 265, 275)
	self:addTradeFlags(RecipeDB, 10558, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.DPS, F.LEATHER)
	self:addTradeAcquire(RecipeDB, 10558, A.TRAINER, 11097, A.TRAINER, 11098, A.TRAINER, 18754, A.TRAINER, 18771, A.TRAINER, 19187, A.TRAINER, 21087, A.TRAINER, 4212, A.TRAINER, 3007, A.TRAINER, 1632, A.TRAINER, 5784, A.TRAINER, 16728, A.TRAINER, 3703, A.TRAINER, 1385, A.TRAINER, 3549, A.TRAINER, 3365, A.TRAINER, 3967, A.TRAINER, 33612, A.TRAINER, 33635, A.TRAINER, 16688, A.TRAINER, 33681, A.TRAINER, 8153, A.TRAINER, 17442, A.TRAINER, 16278, A.TRAINER, 3605, A.TRAINER, 5564, A.TRAINER, 5127, A.TRAINER, 4588)

	-- Big Voodoo Pants -- 10560
	AddRecipe(10560, 240, 8202, R_UNCOMMON, GAME_ORIG, 240, 260, 270, 280)
	self:addTradeFlags(RecipeDB, 10560, F.ALLIANCE, F.HORDE, F.WORLD_DROP, F.IBOE, F.RBOE, F.HEALER, F.CASTER, F.LEATHER)
	self:addTradeAcquire(RecipeDB, 10560, A.WORLD_DROP, 2)

	-- Big Voodoo Cloak -- 10562
	AddRecipe(10562, 240, 8216, R_UNCOMMON, GAME_ORIG, 240, 260, 270, 280)
	self:addTradeFlags(RecipeDB, 10562, F.ALLIANCE, F.HORDE, F.WORLD_DROP, F.IBOE, F.RBOE, F.HEALER, F.CASTER, F.CLOAK)
	self:addTradeAcquire(RecipeDB, 10562, A.WORLD_DROP, 2)

	-- Tough Scorpid Shoulders -- 10564
	AddRecipe(10564, 240, 8207, R_UNCOMMON, GAME_ORIG, 240, 260, 270, 280)
	self:addTradeFlags(RecipeDB, 10564, F.ALLIANCE, F.HORDE, F.MOB_DROP, F.IBOE, F.RBOE, F.DPS, F.MAIL)
	self:addTradeAcquire(RecipeDB, 10564, A.MOB, 5623, A.MOB, 7805, A.MOB, 7883)

	-- Wild Leather Boots -- 10566
	AddRecipe(10566, 245, 8213, R_UNCOMMON, GAME_ORIG, 245, 265, 275, 285)
	self:addTradeFlags(RecipeDB, 10566, F.ALLIANCE, F.HORDE, F.QUEST, F.IBOE, F.RBOP, F.LEATHER)
	self:addTradeAcquire(RecipeDB, 10566, A.QUEST, 2851, A.QUEST, 2858)

	-- Tough Scorpid Leggings -- 10568
	AddRecipe(10568, 245, 8206, R_UNCOMMON, GAME_ORIG, 245, 265, 275, 285)
	self:addTradeFlags(RecipeDB, 10568, F.ALLIANCE, F.HORDE, F.MOB_DROP, F.IBOE, F.RBOE, F.DPS, F.MAIL)
	self:addTradeAcquire(RecipeDB, 10568, A.MOB, 5615)

	-- Tough Scorpid Helm -- 10570
	AddRecipe(10570, 250, 8208, R_UNCOMMON, GAME_ORIG, 250, 270, 280, 290)
	self:addTradeFlags(RecipeDB, 10570, F.ALLIANCE, F.HORDE, F.MOB_DROP, F.IBOE, F.RBOE, F.DPS, F.MAIL)
	self:addTradeAcquire(RecipeDB, 10570, A.MOB, 5623, A.MOB, 7805, A.MOB, 7883)

	-- Wild Leather Leggings -- 10572
	AddRecipe(10572, 250, 8212, R_UNCOMMON, GAME_ORIG, 250, 270, 280, 290)
	self:addTradeFlags(RecipeDB, 10572, F.ALLIANCE, F.HORDE, F.QUEST, F.IBOE, F.RBOP, F.LEATHER)
	self:addTradeAcquire(RecipeDB, 10572, A.QUEST, 2852, A.QUEST, 2859)

	-- Wild Leather Cloak -- 10574
	AddRecipe(10574, 250, 8215, R_UNCOMMON, GAME_ORIG, 250, 270, 280, 290)
	self:addTradeFlags(RecipeDB, 10574, F.ALLIANCE, F.HORDE, F.QUEST, F.IBOE, F.RBOP, F.CLOAK)
	self:addTradeAcquire(RecipeDB, 10574, A.QUEST, 2853, A.QUEST, 2860)

	-- Dragonscale Gauntlets -- 10619
	AddRecipe(10619, 225, 8347, R_COMMON, GAME_ORIG, 225, 245, 255, 265)
	self:addTradeFlags(RecipeDB, 10619, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.MAIL)
	self:addTradeAcquire(RecipeDB, 10619, A.TRAINER, 7866, A.TRAINER, 7867, A.TRAINER, 29508)

	-- Wolfshead Helm -- 10621
	AddRecipe(10621, 225, 8345, R_COMMON, GAME_ORIG, 225, 245, 255, 265)
	self:addTradeFlags(RecipeDB, 10621, F.ALLIANCE, F.HORDE, F.TRAINER, F.DRUID, F.IBOE, F.RBOP, F.DPS, F.LEATHER)
	self:addTradeAcquire(RecipeDB, 10621, A.TRAINER, 7870, A.TRAINER, 7871, A.TRAINER, 29509)

	-- Gauntlets of the Sea -- 10630
	AddRecipe(10630, 230, 8346, R_COMMON, GAME_ORIG, 230, 250, 260, 270)
	self:addTradeFlags(RecipeDB, 10630, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.DPS, F.LEATHER)
	self:addTradeAcquire(RecipeDB, 10630, A.TRAINER, 7868, A.TRAINER, 7869, A.TRAINER, 29507)

	-- Helm of Fire -- 10632
	AddRecipe(10632, 250, 8348, R_COMMON, GAME_ORIG, 250, 270, 280, 290)
	self:addTradeFlags(RecipeDB, 10632, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.DPS, F.LEATHER)
	self:addTradeAcquire(RecipeDB, 10632, A.TRAINER, 7868, A.TRAINER, 7869, A.TRAINER, 29507)

	-- Feathered Breastplate -- 10647
	AddRecipe(10647, 250, 8349, R_COMMON, GAME_ORIG, 250, 270, 280, 290)
	self:addTradeFlags(RecipeDB, 10647, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.HEALER, F.CASTER, F.LEATHER)
	self:addTradeAcquire(RecipeDB, 10647, A.TRAINER, 7870, A.TRAINER, 7871, A.TRAINER, 29509)

	-- Dragonscale Breastplate -- 10650
	AddRecipe(10650, 255, 8367, R_COMMON, GAME_ORIG, 255, 275, 285, 295)
	self:addTradeFlags(RecipeDB, 10650, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.MAIL)
	self:addTradeAcquire(RecipeDB, 10650, A.TRAINER, 7866, A.TRAINER, 7867, A.TRAINER, 29508)

	-- Quickdraw Quiver -- 14930
	AddRecipe(14930, 225, 8217, R_COMMON, GAME_ORIG, 225, 245, 255, 265)
	self:addTradeFlags(RecipeDB, 14930, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.DPS)
	self:addTradeAcquire(RecipeDB, 14930, A.TRAINER, 3007, A.TRAINER, 4212, A.TRAINER, 11097, A.TRAINER, 11098, A.TRAINER, 18754, A.TRAINER, 18771, A.TRAINER, 19187, A.TRAINER, 21087, A.TRAINER, 1632, A.TRAINER, 5784, A.TRAINER, 16728, A.TRAINER, 3703, A.TRAINER, 1385, A.TRAINER, 3549, A.TRAINER, 3365, A.TRAINER, 3967, A.TRAINER, 33612, A.TRAINER, 33635, A.TRAINER, 16688, A.TRAINER, 33681, A.TRAINER, 8153, A.TRAINER, 17442, A.TRAINER, 16278, A.TRAINER, 3605, A.TRAINER, 5564, A.TRAINER, 5127, A.TRAINER, 4588)

	-- Thick Leather Ammo Pouch -- 14932
	AddRecipe(14932, 225, 8218, R_COMMON, GAME_ORIG, 225, 245, 255, 265)
	self:addTradeFlags(RecipeDB, 14932, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.AMMO)
	self:addTradeAcquire(RecipeDB, 14932, A.TRAINER, 3007, A.TRAINER, 4212, A.TRAINER, 11097, A.TRAINER, 11098, A.TRAINER, 18754, A.TRAINER, 18771, A.TRAINER, 19187, A.TRAINER, 21087, A.TRAINER, 1632, A.TRAINER, 5784, A.TRAINER, 16728, A.TRAINER, 3703, A.TRAINER, 1385, A.TRAINER, 3549, A.TRAINER, 3365, A.TRAINER, 3967, A.TRAINER, 33612, A.TRAINER, 33635, A.TRAINER, 16688, A.TRAINER, 33681, A.TRAINER, 8153, A.TRAINER, 17442, A.TRAINER, 16278, A.TRAINER, 3605, A.TRAINER, 5564, A.TRAINER, 5127, A.TRAINER, 4588)

	-- Cured Rugged Hide -- 19047
	AddRecipe(19047, 250, 15407, R_COMMON, GAME_ORIG, 250, 250, 255, 260)
	self:addTradeFlags(RecipeDB, 19047, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP)
	self:addTradeAcquire(RecipeDB, 19047, A.TRAINER, 11097, A.TRAINER, 11098, A.TRAINER, 18754, A.TRAINER, 18771, A.TRAINER, 19187, A.TRAINER, 21087, A.TRAINER, 4212, A.TRAINER, 3007, A.TRAINER, 1632, A.TRAINER, 5784, A.TRAINER, 16728, A.TRAINER, 3703, A.TRAINER, 1385, A.TRAINER, 3549, A.TRAINER, 3365, A.TRAINER, 3967, A.TRAINER, 33612, A.TRAINER, 33635, A.TRAINER, 16688, A.TRAINER, 33681, A.TRAINER, 8153, A.TRAINER, 17442, A.TRAINER, 16278, A.TRAINER, 3605, A.TRAINER, 5564, A.TRAINER, 5127, A.TRAINER, 4588)

	-- Heavy Scorpid Bracers -- 19048
	AddRecipe(19048, 255, 15077, R_COMMON, GAME_ORIG, 255, 275, 285, 295)
	self:addTradeFlags(RecipeDB, 19048, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOP, F.DPS, F.MAIL)
	self:addTradeAcquire(RecipeDB, 19048, A.VENDOR, 12956)

	-- Wicked Leather Gauntlets -- 19049
	AddRecipe(19049, 260, 15083, R_COMMON, GAME_ORIG, 260, 280, 290, 300)
	self:addTradeFlags(RecipeDB, 19049, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOE, F.DPS, F.LEATHER)
	self:addTradeAcquire(RecipeDB, 19049, A.VENDOR, 12942, A.VENDOR, 12943)

	-- Green Dragonscale Breastplate -- 19050
	AddRecipe(19050, 260, 15045, R_COMMON, GAME_ORIG, 260, 280, 290, 300)
	self:addTradeFlags(RecipeDB, 19050, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOE, F.HEALER, F.CASTER, F.MAIL)
	self:addTradeAcquire(RecipeDB, 19050, A.VENDOR, 11874)

	-- Heavy Scorpid Vest -- 19051
	AddRecipe(19051, 265, 15076, R_UNCOMMON, GAME_ORIG, 265, 285, 295, 305)
	self:addTradeFlags(RecipeDB, 19051, F.ALLIANCE, F.HORDE, F.MOB_DROP, F.IBOE, F.RBOE, F.DPS, F.MAIL)
	self:addTradeAcquire(RecipeDB, 19051, A.MOB, 5981, A.MOB, 6005)

	-- Wicked Leather Bracers -- 19052
	AddRecipe(19052, 265, 15084, R_UNCOMMON, GAME_ORIG, 265, 285, 295, 305)
	self:addTradeFlags(RecipeDB, 19052, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOE, F.DPS, F.LEATHER)
	self:addTradeAcquire(RecipeDB, 19052, A.TRAINER, 11097, A.TRAINER, 11098, A.TRAINER, 18754, A.TRAINER, 18771, A.TRAINER, 19187, A.TRAINER, 21087, A.TRAINER, 4212, A.TRAINER, 3007, A.TRAINER, 1632, A.TRAINER, 5784, A.TRAINER, 16728, A.TRAINER, 3703, A.TRAINER, 1385, A.TRAINER, 3549, A.TRAINER, 3365, A.TRAINER, 3967, A.TRAINER, 33612, A.TRAINER, 33635, A.TRAINER, 16688, A.TRAINER, 33681, A.TRAINER, 8153, A.TRAINER, 17442, A.TRAINER, 16278, A.TRAINER, 3605, A.TRAINER, 5564, A.TRAINER, 5127, A.TRAINER, 4588)

	-- Chimeric Gloves -- 19053
	AddRecipe(19053, 265, 15074, R_COMMON, GAME_ORIG, 265, 285, 295, 305)
	self:addTradeFlags(RecipeDB, 19053, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOP, F.LEATHER)
	self:addTradeAcquire(RecipeDB, 19053, A.VENDOR, 12957)

	-- Red Dragonscale Breastplate -- 19054
	AddRecipe(19054, 300, 15047, R_RARE, GAME_ORIG, 300, 320, 330, 340)
	self:addTradeFlags(RecipeDB, 19054, F.ALLIANCE, F.HORDE, F.INSTANCE, F.IBOE, F.RBOP, F.HEALER, F.CASTER, F.MAIL)
	self:addTradeAcquire(RecipeDB, 19054, A.MOB, 10363)

	-- Runic Leather Gauntlets -- 19055
	AddRecipe(19055, 270, 15091, R_UNCOMMON, GAME_ORIG, 270, 290, 300, 310)
	self:addTradeFlags(RecipeDB, 19055, F.ALLIANCE, F.HORDE, F.TRAINER, F.WORLD_DROP, F.IBOE, F.RBOE, F.HEALER, F.CASTER, F.LEATHER)
	self:addTradeAcquire(RecipeDB, 19055, A.WORLD_DROP, 2, A.TRAINER, 1385, A.TRAINER, 3007, A.TRAINER, 3365, A.TRAINER, 3703, A.TRAINER, 3967, A.TRAINER, 4212, A.TRAINER, 4588, A.TRAINER, 5127, A.TRAINER, 5564, A.TRAINER, 11097, A.TRAINER, 11098, A.TRAINER, 16688, A.TRAINER, 16728, A.TRAINER, 18754, A.TRAINER, 18771, A.TRAINER, 19187, A.TRAINER, 21087, A.TRAINER, 1632, A.TRAINER, 5784, A.TRAINER, 3549, A.TRAINER, 33612, A.TRAINER, 33635, A.TRAINER, 33681, A.TRAINER, 8153, A.TRAINER, 17442, A.TRAINER, 16278, A.TRAINER, 3605)

	-- Rugged Armor Kit -- 19058
	AddRecipe(19058, 250, 15564, R_COMMON, GAME_ORIG, 250, 255, 265, 275)
	self:addTradeFlags(RecipeDB, 19058, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP)
	self:addTradeAcquire(RecipeDB, 19058, A.TRAINER, 1385, A.TRAINER, 3007, A.TRAINER, 3365, A.TRAINER, 3703, A.TRAINER, 3967, A.TRAINER, 4212, A.TRAINER, 4588, A.TRAINER, 5127, A.TRAINER, 5564, A.TRAINER, 11097, A.TRAINER, 11098, A.TRAINER, 16688, A.TRAINER, 16728, A.TRAINER, 18754, A.TRAINER, 18771, A.TRAINER, 19187, A.TRAINER, 21087, A.TRAINER, 1632, A.TRAINER, 5784, A.TRAINER, 3549, A.TRAINER, 33612, A.TRAINER, 33635, A.TRAINER, 33681, A.TRAINER, 8153, A.TRAINER, 17442, A.TRAINER, 3605)

	-- Volcanic Leggings -- 19059
	AddRecipe(19059, 270, 15054, R_UNCOMMON, GAME_ORIG, 270, 290, 300, 310)
	self:addTradeFlags(RecipeDB, 19059, F.ALLIANCE, F.HORDE, F.MOB_DROP, F.IBOE, F.RBOE, F.LEATHER)
	self:addTradeAcquire(RecipeDB, 19059, A.MOB, 7035)

	-- Green Dragonscale Leggings -- 19060
	AddRecipe(19060, 270, 15046, R_RARE, GAME_ORIG, 270, 290, 300, 310)
	self:addTradeFlags(RecipeDB, 19060, F.ALLIANCE, F.HORDE, F.INSTANCE, F.IBOE, F.RBOE, F.HEALER, F.CASTER, F.MAIL)
	self:addTradeAcquire(RecipeDB, 19060, A.MOB, 5226)

	-- Living Shoulders -- 19061
	AddRecipe(19061, 270, 15061, R_COMMON, GAME_ORIG, 270, 290, 300, 310)
	self:addTradeFlags(RecipeDB, 19061, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOE, F.HEALER, F.CASTER, F.LEATHER)
	self:addTradeAcquire(RecipeDB, 19061, A.VENDOR, 7852, A.VENDOR, 7854)

	-- Ironfeather Shoulders -- 19062
	AddRecipe(19062, 270, 15067, R_COMMON, GAME_ORIG, 270, 290, 300, 310)
	self:addTradeFlags(RecipeDB, 19062, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOP, F.HEALER, F.CASTER, F.LEATHER)
	self:addTradeAcquire(RecipeDB, 19062, A.VENDOR, 12958)

	-- Chimeric Boots -- 19063
	AddRecipe(19063, 275, 15073, R_UNCOMMON, GAME_ORIG, 275, 295, 305, 315)
	self:addTradeFlags(RecipeDB, 19063, F.ALLIANCE, F.HORDE, F.WORLD_DROP, F.IBOE, F.RBOE, F.LEATHER)
	self:addTradeAcquire(RecipeDB, 19063, A.WORLD_DROP, 2)

	-- Heavy Scorpid Gauntlets -- 19064
	AddRecipe(19064, 275, 15078, R_UNCOMMON, GAME_ORIG, 275, 295, 305, 315)
	self:addTradeFlags(RecipeDB, 19064, F.ALLIANCE, F.HORDE, F.MOB_DROP, F.IBOE, F.RBOE, F.DPS, F.MAIL)
	self:addTradeAcquire(RecipeDB, 19064, A.MOB, 7025)

	-- Runic Leather Bracers -- 19065
	AddRecipe(19065, 275, 15092, R_UNCOMMON, GAME_ORIG, 275, 295, 305, 315)
	self:addTradeFlags(RecipeDB, 19065, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOE, F.LEATHER)
	self:addTradeAcquire(RecipeDB, 19065, A.TRAINER, 11097, A.TRAINER, 11098, A.TRAINER, 18754, A.TRAINER, 18771, A.TRAINER, 19187, A.TRAINER, 21087, A.TRAINER, 4212, A.TRAINER, 3007, A.TRAINER, 1632, A.TRAINER, 5784, A.TRAINER, 16728, A.TRAINER, 3703, A.TRAINER, 1385, A.TRAINER, 3549, A.TRAINER, 3365, A.TRAINER, 3967, A.TRAINER, 33612, A.TRAINER, 33635, A.TRAINER, 16688, A.TRAINER, 33681, A.TRAINER, 8153, A.TRAINER, 17442, A.TRAINER, 3605, A.TRAINER, 5564, A.TRAINER, 5127, A.TRAINER, 4588)

	-- Frostsaber Boots -- 19066
	AddRecipe(19066, 275, 15071, R_COMMON, GAME_ORIG, 275, 295, 305, 315)
	self:addTradeFlags(RecipeDB, 19066, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOP, F.LEATHER)
	self:addTradeAcquire(RecipeDB, 19066, A.VENDOR, 11189)

	-- Stormshroud Pants -- 19067
	AddRecipe(19067, 275, 15057, R_COMMON, GAME_ORIG, 275, 295, 305, 315)
	self:addTradeFlags(RecipeDB, 19067, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOE, F.DPS, F.TANK, F.LEATHER)
	self:addTradeAcquire(RecipeDB, 19067, A.VENDOR, 12942, A.VENDOR, 12943)

	-- Warbear Harness -- 19068
	AddRecipe(19068, 275, 15064, R_COMMON, GAME_ORIG, 275, 295, 305, 315)
	self:addTradeFlags(RecipeDB, 19068, F.ALLIANCE, F.HORDE, F.VENDOR, F.RAID, F.MOB_DROP, F.IBOE, F.RBOP, F.DPS, F.LEATHER, F.TIMBERMAW_HOLD)
	self:addTradeAcquire(RecipeDB, 19068, A.REPUTATION, FAC.TIMBERMAW_HOLD, REP.FRIENDLY, 11557)

	-- Heavy Scorpid Belt -- 19070
	AddRecipe(19070, 280, 15082, R_UNCOMMON, GAME_ORIG, 280, 300, 310, 320)
	self:addTradeFlags(RecipeDB, 19070, F.ALLIANCE, F.HORDE, F.WORLD_DROP, F.IBOE, F.RBOE, F.DPS, F.MAIL)
	self:addTradeAcquire(RecipeDB, 19070, A.WORLD_DROP, 2)

	-- Wicked Leather Headband -- 19071
	AddRecipe(19071, 280, 15086, R_UNCOMMON, GAME_ORIG, 280, 300, 310, 320)
	self:addTradeFlags(RecipeDB, 19071, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOE, F.DPS, F.LEATHER)
	self:addTradeAcquire(RecipeDB, 19071, A.TRAINER, 11097, A.TRAINER, 11098, A.TRAINER, 18754, A.TRAINER, 18771, A.TRAINER, 19187, A.TRAINER, 21087, A.TRAINER, 4212, A.TRAINER, 3007, A.TRAINER, 1632, A.TRAINER, 5784, A.TRAINER, 16728, A.TRAINER, 3703, A.TRAINER, 1385, A.TRAINER, 3549, A.TRAINER, 3365, A.TRAINER, 3967, A.TRAINER, 33612, A.TRAINER, 33635, A.TRAINER, 16688, A.TRAINER, 33681, A.TRAINER, 8153, A.TRAINER, 17442, A.TRAINER, 16278, A.TRAINER, 3605, A.TRAINER, 5564, A.TRAINER, 5127, A.TRAINER, 4588)

	-- Runic Leather Belt -- 19072
	AddRecipe(19072, 280, 15093, R_UNCOMMON, GAME_ORIG, 280, 300, 310, 320)
	self:addTradeFlags(RecipeDB, 19072, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOE, F.LEATHER)
	self:addTradeAcquire(RecipeDB, 19072, A.TRAINER, 11097, A.TRAINER, 11098, A.TRAINER, 18754, A.TRAINER, 18771, A.TRAINER, 19187, A.TRAINER, 21087, A.TRAINER, 4212, A.TRAINER, 1632, A.TRAINER, 5784, A.TRAINER, 16728, A.TRAINER, 3007, A.TRAINER, 3703, A.TRAINER, 1385, A.TRAINER, 3549, A.TRAINER, 3365, A.TRAINER, 3967, A.TRAINER, 33612, A.TRAINER, 33635, A.TRAINER, 16688, A.TRAINER, 33681, A.TRAINER, 8153, A.TRAINER, 17442, A.TRAINER, 16278, A.TRAINER, 3605, A.TRAINER, 5564, A.TRAINER, 5127, A.TRAINER, 4588)

	-- Chimeric Leggings -- 19073
	AddRecipe(19073, 280, 15072, R_UNCOMMON, GAME_ORIG, 280, 300, 310, 320)
	self:addTradeFlags(RecipeDB, 19073, F.ALLIANCE, F.HORDE, F.WORLD_DROP, F.IBOE, F.RBOE, F.LEATHER)
	self:addTradeAcquire(RecipeDB, 19073, A.WORLD_DROP, 2)

	-- Frostsaber Leggings -- 19074
	AddRecipe(19074, 285, 15069, R_UNCOMMON, GAME_ORIG, 285, 305, 315, 325)
	self:addTradeFlags(RecipeDB, 19074, F.ALLIANCE, F.HORDE, F.MOB_DROP, F.IBOE, F.RBOE, F.LEATHER)
	self:addTradeAcquire(RecipeDB, 19074, A.MOB, 7440)

	-- Heavy Scorpid Leggings -- 19075
	AddRecipe(19075, 285, 15079, R_UNCOMMON, GAME_ORIG, 285, 305, 315, 325)
	self:addTradeFlags(RecipeDB, 19075, F.ALLIANCE, F.HORDE, F.MOB_DROP, F.IBOE, F.RBOE, F.DPS, F.MAIL)
	self:addTradeAcquire(RecipeDB, 19075, A.MOB, 7027)

	-- Volcanic Breastplate -- 19076
	AddRecipe(19076, 285, 15053, R_UNCOMMON, GAME_ORIG, 285, 305, 315, 325)
	self:addTradeFlags(RecipeDB, 19076, F.ALLIANCE, F.HORDE, F.INSTANCE, F.IBOE, F.RBOE, F.LEATHER)
	self:addTradeAcquire(RecipeDB, 19076, A.MOB, 9259)

	-- Blue Dragonscale Breastplate -- 19077
	AddRecipe(19077, 285, 15048, R_COMMON, GAME_ORIG, 285, 305, 315, 325)
	self:addTradeFlags(RecipeDB, 19077, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOP, F.HEALER, F.CASTER, F.MAIL)
	self:addTradeAcquire(RecipeDB, 19077, A.VENDOR, 12957)

	-- Living Leggings -- 19078
	AddRecipe(19078, 285, 15060, R_RARE, GAME_ORIG, 285, 305, 315, 325)
	self:addTradeFlags(RecipeDB, 19078, F.ALLIANCE, F.HORDE, F.MOB_DROP, F.IBOE, F.RBOE, F.HEALER, F.CASTER, F.LEATHER)
	self:addTradeAcquire(RecipeDB, 19078, A.MOB, 7158)

	-- Stormshroud Armor -- 19079
	AddRecipe(19079, 285, 15056, R_RARE, GAME_ORIG, 285, 305, 315, 325)
	self:addTradeFlags(RecipeDB, 19079, F.ALLIANCE, F.HORDE, F.MOB_DROP, F.IBOE, F.RBOE, F.DPS, F.TANK, F.LEATHER)
	self:addTradeAcquire(RecipeDB, 19079, A.MOB, 6138)

	-- Warbear Woolies -- 19080
	AddRecipe(19080, 285, 15065, R_COMMON, GAME_ORIG, 285, 305, 315, 325)
	self:addTradeFlags(RecipeDB, 19080, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOP, F.DPS, F.LEATHER, F.TIMBERMAW_HOLD)
	self:addTradeAcquire(RecipeDB, 19080, A.REPUTATION, FAC.TIMBERMAW_HOLD, REP.FRIENDLY, 11557)

	-- Chimeric Vest -- 19081
	AddRecipe(19081, 290, 15075, R_UNCOMMON, GAME_ORIG, 290, 310, 320, 330)
	self:addTradeFlags(RecipeDB, 19081, F.ALLIANCE, F.HORDE, F.WORLD_DROP, F.IBOE, F.RBOE, F.LEATHER)
	self:addTradeAcquire(RecipeDB, 19081, A.WORLD_DROP, 2)

	-- Runic Leather Headband -- 19082
	AddRecipe(19082, 290, 15094, R_COMMON, GAME_ORIG, 290, 310, 320, 330)
	self:addTradeFlags(RecipeDB, 19082, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOE, F.LEATHER)
	self:addTradeAcquire(RecipeDB, 19082, A.TRAINER, 1385, A.TRAINER, 3007, A.TRAINER, 3365, A.TRAINER, 3703, A.TRAINER, 3967, A.TRAINER, 4212, A.TRAINER, 4588, A.TRAINER, 5127, A.TRAINER, 5564, A.TRAINER, 11097, A.TRAINER, 11098, A.TRAINER, 16688, A.TRAINER, 16728, A.TRAINER, 18754, A.TRAINER, 18771, A.TRAINER, 19187, A.TRAINER, 21087, A.TRAINER, 1632, A.TRAINER, 5784, A.TRAINER, 3549, A.TRAINER, 33612, A.TRAINER, 33635, A.TRAINER, 33681, A.TRAINER, 8153, A.TRAINER, 17442, A.TRAINER, 16278, A.TRAINER, 3605)

	-- Wicked Leather Pants -- 19083
	AddRecipe(19083, 290, 15087, R_UNCOMMON, GAME_ORIG, 290, 315, 325, 335)
	self:addTradeFlags(RecipeDB, 19083, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOE, F.DPS, F.LEATHER)
	self:addTradeAcquire(RecipeDB, 19083, A.TRAINER, 1385, A.TRAINER, 3007, A.TRAINER, 3365, A.TRAINER, 3703, A.TRAINER, 3967, A.TRAINER, 4212, A.TRAINER, 4588, A.TRAINER, 5127, A.TRAINER, 5564, A.TRAINER, 11097, A.TRAINER, 11098, A.TRAINER, 16688, A.TRAINER, 16728, A.TRAINER, 18754, A.TRAINER, 18771, A.TRAINER, 19187, A.TRAINER, 21087, A.TRAINER, 1632, A.TRAINER, 5784, A.TRAINER, 3549, A.TRAINER, 33612, A.TRAINER, 33635, A.TRAINER, 33681, A.TRAINER, 8153, A.TRAINER, 17442, A.TRAINER, 16278, A.TRAINER, 3605)

	-- Devilsaur Gauntlets -- 19084
	AddRecipe(19084, 290, 15063, R_COMMON, GAME_ORIG, 290, 310, 320, 330)
	self:addTradeFlags(RecipeDB, 19084, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOE, F.DPS, F.LEATHER)
	self:addTradeAcquire(RecipeDB, 19084, A.VENDOR, 12959)

	-- Black Dragonscale Breastplate -- 19085
	AddRecipe(19085, 290, 15050, R_COMMON, GAME_ORIG, 290, 310, 320, 330)
	self:addTradeFlags(RecipeDB, 19085, F.ALLIANCE, F.HORDE, F.VENDOR, F.INSTANCE, F.IBOE, F.RBOP, F.DPS, F.MAIL)
	self:addTradeAcquire(RecipeDB, 19085, A.VENDOR, 9499)

	-- Ironfeather Breastplate -- 19086
	AddRecipe(19086, 290, 15066, R_RARE, GAME_ORIG, 290, 310, 320, 330)
	self:addTradeFlags(RecipeDB, 19086, F.ALLIANCE, F.HORDE, F.MOB_DROP, F.IBOE, F.RBOE, F.HEALER, F.CASTER, F.LEATHER)
	self:addTradeAcquire(RecipeDB, 19086, A.MOB, 2644)

	-- Frostsaber Gloves -- 19087
	AddRecipe(19087, 295, 15070, R_UNCOMMON, GAME_ORIG, 295, 315, 325, 335)
	self:addTradeFlags(RecipeDB, 19087, F.ALLIANCE, F.HORDE, F.MOB_DROP, F.IBOE, F.RBOE, F.LEATHER)
	self:addTradeAcquire(RecipeDB, 19087, A.MOB, 7441)

	-- Heavy Scorpid Helm -- 19088
	AddRecipe(19088, 295, 15080, R_COMMON, GAME_ORIG, 295, 315, 325, 335)
	self:addTradeFlags(RecipeDB, 19088, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.DPS, F.MAIL)
	self:addTradeAcquire(RecipeDB, 19088, A.VENDOR, 12956)

	-- Blue Dragonscale Shoulders -- 19089
	AddRecipe(19089, 295, 15049, R_RARE, GAME_ORIG, 295, 315, 325, 335)
	self:addTradeFlags(RecipeDB, 19089, F.ALLIANCE, F.HORDE, F.MOB_DROP, F.IBOE, F.RBOE, F.HEALER, F.CASTER, F.MAIL)
	self:addTradeAcquire(RecipeDB, 19089, A.MOB, 6146)

	-- Stormshroud Shoulders -- 19090
	AddRecipe(19090, 295, 15058, R_RARE, GAME_ORIG, 295, 315, 325, 335)
	self:addTradeFlags(RecipeDB, 19090, F.ALLIANCE, F.HORDE, F.MOB_DROP, F.IBOE, F.RBOE, F.DPS, F.TANK, F.LEATHER)
	self:addTradeAcquire(RecipeDB, 19090, A.MOB, 6144)

	-- Runic Leather Pants -- 19091
	AddRecipe(19091, 300, 15095, R_UNCOMMON, GAME_ORIG, 300, 320, 330, 340)
	self:addTradeFlags(RecipeDB, 19091, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOE, F.HEALER, F.CASTER, F.LEATHER)
	self:addTradeAcquire(RecipeDB, 19091, A.TRAINER, 11097, A.TRAINER, 11098, A.TRAINER, 18754, A.TRAINER, 18771, A.TRAINER, 19187, A.TRAINER, 21087, A.TRAINER, 4212, A.TRAINER, 3007, A.TRAINER, 1632, A.TRAINER, 5784, A.TRAINER, 16728, A.TRAINER, 3703, A.TRAINER, 1385, A.TRAINER, 3549, A.TRAINER, 3365, A.TRAINER, 3967, A.TRAINER, 33612, A.TRAINER, 33635, A.TRAINER, 16688, A.TRAINER, 33681, A.TRAINER, 8153, A.TRAINER, 17442, A.TRAINER, 16278, A.TRAINER, 3605, A.TRAINER, 5564, A.TRAINER, 4588)

	-- Wicked Leather Belt -- 19092
	AddRecipe(19092, 300, 15088, R_UNCOMMON, GAME_ORIG, 300, 320, 330, 340)
	self:addTradeFlags(RecipeDB, 19092, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOE, F.DPS, F.LEATHER)
	self:addTradeAcquire(RecipeDB, 19092, A.TRAINER, 1385, A.TRAINER, 3007, A.TRAINER, 3365, A.TRAINER, 3703, A.TRAINER, 3967, A.TRAINER, 4212, A.TRAINER, 4588, A.TRAINER, 5127, A.TRAINER, 5564, A.TRAINER, 11097, A.TRAINER, 11098, A.TRAINER, 16688, A.TRAINER, 16728, A.TRAINER, 18754, A.TRAINER, 18771, A.TRAINER, 19187, A.TRAINER, 21087, A.TRAINER, 1632, A.TRAINER, 5784, A.TRAINER, 3549, A.TRAINER, 33612, A.TRAINER, 33635, A.TRAINER, 33681, A.TRAINER, 8153, A.TRAINER, 17442, A.TRAINER, 16278, A.TRAINER, 3605)

	-- Onyxia Scale Cloak -- 19093
	AddRecipe(19093, 300, 15138, R_RARE, GAME_ORIG, 300, 320, 330, 340)
	self:addTradeFlags(RecipeDB, 19093, F.ALLIANCE, F.HORDE, F.RAID, F.QUEST, F.IBOE, F.RBOP, F.CLOAK)
	self:addTradeAcquire(RecipeDB, 19093, A.QUEST, 7493, A.QUEST, 7497, A.CUSTOM, 10)

	-- Black Dragonscale Shoulders -- 19094
	AddRecipe(19094, 300, 15051, R_RARE, GAME_ORIG, 300, 320, 330, 340)
	self:addTradeFlags(RecipeDB, 19094, F.ALLIANCE, F.HORDE, F.INSTANCE, F.IBOE, F.RBOE, F.DPS, F.MAIL)
	self:addTradeAcquire(RecipeDB, 19094, A.MOB, 8898)

	-- Living Breastplate -- 19095
	AddRecipe(19095, 300, 15059, R_RARE, GAME_ORIG, 300, 320, 330, 340)
	self:addTradeFlags(RecipeDB, 19095, F.ALLIANCE, F.HORDE, F.MOB_DROP, F.IBOE, F.RBOE, F.HEALER, F.CASTER, F.LEATHER)
	self:addTradeAcquire(RecipeDB, 19095, A.MOB, 1813)

	-- Devilsaur Leggings -- 19097
	AddRecipe(19097, 300, 15062, R_RARE, GAME_ORIG, 300, 320, 330, 340)
	self:addTradeFlags(RecipeDB, 19097, F.ALLIANCE, F.HORDE, F.MOB_DROP, F.IBOE, F.RBOE, F.DPS, F.LEATHER)
	self:addTradeAcquire(RecipeDB, 19097, A.MOB, 6556, A.MOB, 6557, A.MOB, 6559, A.MOB, 9477)

	-- Wicked Leather Armor -- 19098
	AddRecipe(19098, 300, 15085, R_UNCOMMON, GAME_ORIG, 300, 320, 330, 340)
	self:addTradeFlags(RecipeDB, 19098, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOE, F.DPS, F.LEATHER)
	self:addTradeAcquire(RecipeDB, 19098, A.TRAINER, 1385, A.TRAINER, 3007, A.TRAINER, 3365, A.TRAINER, 3703, A.TRAINER, 3967, A.TRAINER, 4212, A.TRAINER, 4588, A.TRAINER, 5127, A.TRAINER, 5564, A.TRAINER, 11097, A.TRAINER, 11098, A.TRAINER, 16688, A.TRAINER, 16728, A.TRAINER, 18754, A.TRAINER, 18771, A.TRAINER, 19187, A.TRAINER, 21087, A.TRAINER, 1632, A.TRAINER, 5784, A.TRAINER, 3549, A.TRAINER, 33612, A.TRAINER, 33635, A.TRAINER, 33681, A.TRAINER, 8153, A.TRAINER, 17442, A.TRAINER, 16278)

	-- Heavy Scorpid Shoulders -- 19100
	AddRecipe(19100, 300, 15081, R_UNCOMMON, GAME_ORIG, 300, 320, 330, 340)
	self:addTradeFlags(RecipeDB, 19100, F.ALLIANCE, F.HORDE, F.MOB_DROP, F.IBOE, F.RBOE, F.DPS, F.MAIL)
	self:addTradeAcquire(RecipeDB, 19100, A.MOB, 7029)

	-- Volcanic Shoulders -- 19101
	AddRecipe(19101, 300, 15055, R_UNCOMMON, GAME_ORIG, 300, 320, 330, 340)
	self:addTradeFlags(RecipeDB, 19101, F.ALLIANCE, F.HORDE, F.INSTANCE, F.IBOE, F.RBOE, F.LEATHER)
	self:addTradeAcquire(RecipeDB, 19101, A.MOB, 9260)

	-- Runic Leather Armor -- 19102
	AddRecipe(19102, 300, 15090, R_UNCOMMON, GAME_ORIG, 300, 320, 330, 340)
	self:addTradeFlags(RecipeDB, 19102, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOE, F.LEATHER)
	self:addTradeAcquire(RecipeDB, 19102, A.TRAINER, 1385, A.TRAINER, 3007, A.TRAINER, 3365, A.TRAINER, 3703, A.TRAINER, 3967, A.TRAINER, 4212, A.TRAINER, 4588, A.TRAINER, 5127, A.TRAINER, 5564, A.TRAINER, 11097, A.TRAINER, 11098, A.TRAINER, 16688, A.TRAINER, 16728, A.TRAINER, 18754, A.TRAINER, 18771, A.TRAINER, 19187, A.TRAINER, 21087, A.TRAINER, 1632, A.TRAINER, 5784, A.TRAINER, 3549, A.TRAINER, 33612, A.TRAINER, 33635, A.TRAINER, 33681, A.TRAINER, 8153, A.TRAINER, 17442, A.TRAINER, 16278, A.TRAINER, 3605)

	-- Runic Leather Shoulders -- 19103
	AddRecipe(19103, 300, 15096, R_UNCOMMON, GAME_ORIG, 300, 320, 330, 340)
	self:addTradeFlags(RecipeDB, 19103, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOE, F.LEATHER)
	self:addTradeAcquire(RecipeDB, 19103, A.TRAINER, 1385, A.TRAINER, 3007, A.TRAINER, 3365, A.TRAINER, 3703, A.TRAINER, 3967, A.TRAINER, 4212, A.TRAINER, 4588, A.TRAINER, 5127, A.TRAINER, 5564, A.TRAINER, 11097, A.TRAINER, 11098, A.TRAINER, 16688, A.TRAINER, 16728, A.TRAINER, 18754, A.TRAINER, 18771, A.TRAINER, 19187, A.TRAINER, 21087, A.TRAINER, 1632, A.TRAINER, 5784, A.TRAINER, 3549, A.TRAINER, 33612, A.TRAINER, 33635, A.TRAINER, 33681, A.TRAINER, 8153, A.TRAINER, 17442, A.TRAINER, 16278, A.TRAINER, 3605)

	-- Frostsaber Tunic -- 19104
	AddRecipe(19104, 300, 15068, R_UNCOMMON, GAME_ORIG, 300, 320, 330, 340)
	self:addTradeFlags(RecipeDB, 19104, F.ALLIANCE, F.HORDE, F.MOB_DROP, F.IBOE, F.RBOE, F.LEATHER)
	self:addTradeAcquire(RecipeDB, 19104, A.MOB, 7438)

	-- Black Dragonscale Leggings -- 19107
	AddRecipe(19107, 300, 15052, R_RARE, GAME_ORIG, 300, 320, 330, 340)
	self:addTradeFlags(RecipeDB, 19107, F.ALLIANCE, F.HORDE, F.INSTANCE, F.IBOE, F.RBOE, F.DPS, F.MAIL)
	self:addTradeAcquire(RecipeDB, 19107, A.MOB, 8903)

	-- Medium Leather -- 20648
	AddRecipe(20648, 100, 2319, R_COMMON, GAME_ORIG, 100, 100, 105, 110)
	self:addTradeFlags(RecipeDB, 20648, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.LEATHER)
	self:addTradeAcquire(RecipeDB, 20648, A.TRAINER, 3007, A.TRAINER, 3365, A.TRAINER, 3703, A.TRAINER, 3967, A.TRAINER, 4212, A.TRAINER, 4588, A.TRAINER, 5127, A.TRAINER, 5564, A.TRAINER, 11097, A.TRAINER, 11098, A.TRAINER, 16688, A.TRAINER, 16728, A.TRAINER, 18754, A.TRAINER, 18771, A.TRAINER, 19187, A.TRAINER, 21087, A.TRAINER, 1632, A.TRAINER, 5784, A.TRAINER, 1385, A.TRAINER, 3549, A.TRAINER, 33635, A.TRAINER, 33612, A.TRAINER, 33681, A.TRAINER, 8153, A.TRAINER, 17442, A.TRAINER, 16278, A.TRAINER, 3605)

	-- Heavy Leather -- 20649
	AddRecipe(20649, 150, 4234, R_COMMON, GAME_ORIG, 150, 150, 155, 160)
	self:addTradeFlags(RecipeDB, 20649, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.LEATHER)
	self:addTradeAcquire(RecipeDB, 20649, A.TRAINER, 1385, A.TRAINER, 3007, A.TRAINER, 3365, A.TRAINER, 3703, A.TRAINER, 3967, A.TRAINER, 4212, A.TRAINER, 4588, A.TRAINER, 5127, A.TRAINER, 5564, A.TRAINER, 8153, A.TRAINER, 11097, A.TRAINER, 11098, A.TRAINER, 16688, A.TRAINER, 16728, A.TRAINER, 18754, A.TRAINER, 18771, A.TRAINER, 19187, A.TRAINER, 21087, A.TRAINER, 1632, A.TRAINER, 5784, A.TRAINER, 3549, A.TRAINER, 33612, A.TRAINER, 33635, A.TRAINER, 33681, A.TRAINER, 17442, A.TRAINER, 16278, A.TRAINER, 3605)

	-- Thick Leather -- 20650
	AddRecipe(20650, 200, 4304, R_COMMON, GAME_ORIG, 200, 200, 202, 205)
	self:addTradeFlags(RecipeDB, 20650, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.LEATHER)
	self:addTradeAcquire(RecipeDB, 20650, A.TRAINER, 3007, A.TRAINER, 4212, A.TRAINER, 11097, A.TRAINER, 11098, A.TRAINER, 18754, A.TRAINER, 18771, A.TRAINER, 19187, A.TRAINER, 21087, A.TRAINER, 1632, A.TRAINER, 5784, A.TRAINER, 16728, A.TRAINER, 3703, A.TRAINER, 1385, A.TRAINER, 3549, A.TRAINER, 3365, A.TRAINER, 3967, A.TRAINER, 33612, A.TRAINER, 33635, A.TRAINER, 16688, A.TRAINER, 33681, A.TRAINER, 8153, A.TRAINER, 17442, A.TRAINER, 16278, A.TRAINER, 3605, A.TRAINER, 5564, A.TRAINER, 5127, A.TRAINER, 4588)

	-- Corehound Boots -- 20853
	AddRecipe(20853, 295, 16982, R_COMMON, GAME_ORIG, 295, 315, 325, 335)
	self:addTradeFlags(RecipeDB, 20853, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOP, F.DPS, F.LEATHER)
	self:addTradeAcquire(RecipeDB, 20853, A.VENDOR, 12944)

	-- Molten Helm -- 20854
	AddRecipe(20854, 300, 16983, R_COMMON, GAME_ORIG, 300, 320, 330, 340)
	self:addTradeFlags(RecipeDB, 20854, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOP, F.TANK, F.LEATHER)
	self:addTradeAcquire(RecipeDB, 20854, A.VENDOR, 12944)

	-- Black Dragonscale Boots -- 20855
	AddRecipe(20855, 300, 16984, R_COMMON, GAME_ORIG, 300, 320, 330, 340)
	self:addTradeFlags(RecipeDB, 20855, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOP, F.DPS, F.MAIL, F.THORIUM_BROTHERHOOD)
	self:addTradeAcquire(RecipeDB, 20855, A.REPUTATION, FAC.THORIUM_BROTHERHOOD, REP.HONORED, 12944)

	-- Gloves of the Greatfather -- 21943
	AddRecipe(21943, 190, 17721, R_UNCOMMON, GAME_ORIG, 190, 210, 220, 230)
	self:addTradeFlags(RecipeDB, 21943, F.ALLIANCE, F.HORDE, F.SEASONAL, F.MOB_DROP, F.IBOE, F.RBOE, F.HEALER, F.CASTER, F.LEATHER)
	self:addTradeAcquire(RecipeDB, 21943, A.SEASONAL, 1)

	-- Rugged Leather -- 22331
	AddRecipe(22331, 250, 8170, R_COMMON, GAME_ORIG, 250, 250, 250, 250)
	self:addTradeFlags(RecipeDB, 22331, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.LEATHER)
	self:addTradeAcquire(RecipeDB, 22331, A.TRAINER, 11097, A.TRAINER, 11098, A.TRAINER, 18754, A.TRAINER, 18771, A.TRAINER, 19187, A.TRAINER, 21087, A.TRAINER, 4212, A.TRAINER, 3007, A.TRAINER, 1632, A.TRAINER, 5784, A.TRAINER, 16728, A.TRAINER, 3703, A.TRAINER, 1385, A.TRAINER, 3549, A.TRAINER, 3365, A.TRAINER, 3967, A.TRAINER, 33612, A.TRAINER, 33635, A.TRAINER, 16688, A.TRAINER, 33681, A.TRAINER, 8153, A.TRAINER, 17442, A.TRAINER, 16278, A.TRAINER, 3605, A.TRAINER, 5564, A.TRAINER, 5127, A.TRAINER, 4588)

	-- Shadowskin Gloves -- 22711
	AddRecipe(22711, 200, 18238, R_COMMON, GAME_ORIG, 200, 210, 220, 230)
	self:addTradeFlags(RecipeDB, 22711, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOP, F.LEATHER)
	self:addTradeAcquire(RecipeDB, 22711, A.VENDOR, 2699)

	-- Core Armor Kit -- 22727
	AddRecipe(22727, 300, 18251, R_RARE, GAME_ORIG, 300, 320, 330, 340)
	self:addTradeFlags(RecipeDB, 22727, F.ALLIANCE, F.HORDE, F.RAID, F.IBOE, F.RBOP, F.TANK)
	self:addTradeAcquire(RecipeDB, 22727, A.CUSTOM, 26)

	-- Gordok Ogre Suit -- 22815
	AddRecipe(22815, 275, 18258, R_UNCOMMON, GAME_ORIG, 275, 285, 290, 385)
	self:addTradeFlags(RecipeDB, 22815, F.ALLIANCE, F.HORDE, F.INSTANCE, F.QUEST, F.IBOE, F.RBOP)
	self:addTradeAcquire(RecipeDB, 22815, A.QUEST, 5518)

	-- Girdle of Insight -- 22921
	AddRecipe(22921, 300, 18504, R_RARE, GAME_ORIG, 300, 320, 330, 340)
	self:addTradeFlags(RecipeDB, 22921, F.ALLIANCE, F.HORDE, F.INSTANCE, F.IBOE, F.RBOP, F.LEATHER)
	self:addTradeAcquire(RecipeDB, 22921, A.CUSTOM, 23)

	-- Mongoose Boots -- 22922
	AddRecipe(22922, 300, 18506, R_RARE, GAME_ORIG, 300, 320, 330, 340)
	self:addTradeFlags(RecipeDB, 22922, F.ALLIANCE, F.HORDE, F.INSTANCE, F.IBOE, F.RBOP, F.DPS, F.LEATHER)
	self:addTradeAcquire(RecipeDB, 22922, A.CUSTOM, 23)

	-- Swift Flight Bracers -- 22923
	AddRecipe(22923, 300, 18508, R_RARE, GAME_ORIG, 300, 320, 330, 340)
	self:addTradeFlags(RecipeDB, 22923, F.ALLIANCE, F.HORDE, F.INSTANCE, F.IBOE, F.RBOP, F.DPS, F.MAIL)
	self:addTradeAcquire(RecipeDB, 22923, A.CUSTOM, 23)

	-- Chromatic Cloak -- 22926
	AddRecipe(22926, 300, 18509, R_EPIC, GAME_ORIG, 300, 320, 330, 340)
	self:addTradeFlags(RecipeDB, 22926, F.ALLIANCE, F.HORDE, F.INSTANCE, F.IBOE, F.RBOE, F.CLOAK)
	self:addTradeAcquire(RecipeDB, 22926, A.CUSTOM, 23)

	-- Hide of the Wild -- 22927
	AddRecipe(22927, 300, 18510, R_EPIC, GAME_ORIG, 300, 320, 330, 340)
	self:addTradeFlags(RecipeDB, 22927, F.ALLIANCE, F.HORDE, F.INSTANCE, F.IBOE, F.RBOE, F.HEALER, F.CASTER, F.CLOAK)
	self:addTradeAcquire(RecipeDB, 22927, A.CUSTOM, 23)

	-- Shifting Cloak -- 22928
	AddRecipe(22928, 300, 18511, R_EPIC, GAME_ORIG, 300, 320, 330, 340)
	self:addTradeFlags(RecipeDB, 22928, F.ALLIANCE, F.HORDE, F.INSTANCE, F.IBOE, F.RBOE, F.TANK, F.CLOAK)
	self:addTradeAcquire(RecipeDB, 22928, A.CUSTOM, 23)

	-- Heavy Leather Ball -- 23190
	AddRecipe(23190, 150, 18662, R_COMMON, GAME_ORIG, 150, 150, 155, 160)
	self:addTradeFlags(RecipeDB, 23190, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOE)
	self:addTradeAcquire(RecipeDB, 23190, A.VENDOR, 5128, A.VENDOR, 3366)

	-- Barbaric Bracers -- 23399
	AddRecipe(23399, 155, 18948, R_COMMON, GAME_ORIG, 155, 175, 185, 195)
	self:addTradeFlags(RecipeDB, 23399, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOE, F.DPS, F.LEATHER)
	self:addTradeAcquire(RecipeDB, 23399, A.VENDOR, 4225, A.VENDOR, 4589)

	-- Might of the Timbermaw -- 23703
	AddRecipe(23703, 290, 19044, R_COMMON, GAME_ORIG, 290, 310, 320, 330)
	self:addTradeFlags(RecipeDB, 23703, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOP, F.DPS, F.LEATHER, F.TIMBERMAW_HOLD)
	self:addTradeAcquire(RecipeDB, 23703, A.REPUTATION, FAC.TIMBERMAW_HOLD, REP.HONORED, 11557)

	-- Timbermaw Brawlers -- 23704
	AddRecipe(23704, 300, 19049, R_COMMON, GAME_ORIG, 300, 320, 330, 340)
	self:addTradeFlags(RecipeDB, 23704, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOP, F.DPS, F.LEATHER, F.TIMBERMAW_HOLD)
	self:addTradeAcquire(RecipeDB, 23704, A.REPUTATION, FAC.TIMBERMAW_HOLD, REP.REVERED, 11557)

	-- Dawn Treaders -- 23705
	AddRecipe(23705, 290, 19052, R_COMMON, GAME_ORIG, 290, 310, 320, 330)
	self:addTradeFlags(RecipeDB, 23705, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOP, F.DPS, F.LEATHER, F.ARGENTDAWN)
	self:addTradeAcquire(RecipeDB, 23705, A.REPUTATION, FAC.ARGENTDAWN, REP.HONORED, 10856, A.REPUTATION, FAC.ARGENTDAWN, REP.HONORED, 10857, A.REPUTATION, FAC.ARGENTDAWN, REP.HONORED, 11536)

	-- Golden Mantle of the Dawn -- 23706
	AddRecipe(23706, 300, 19058, R_COMMON, GAME_ORIG, 300, 320, 330, 340)
	self:addTradeFlags(RecipeDB, 23706, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOP, F.TANK, F.LEATHER, F.ARGENTDAWN)
	self:addTradeAcquire(RecipeDB, 23706, A.REPUTATION, FAC.ARGENTDAWN, REP.REVERED, 10856, A.REPUTATION, FAC.ARGENTDAWN, REP.REVERED, 10857, A.REPUTATION, FAC.ARGENTDAWN, REP.REVERED, 11536)

	-- Lava Belt -- 23707
	AddRecipe(23707, 300, 19149, R_COMMON, GAME_ORIG, 300, 320, 330, 340)
	self:addTradeFlags(RecipeDB, 23707, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOP, F.LEATHER, F.THORIUM_BROTHERHOOD)
	self:addTradeAcquire(RecipeDB, 23707, A.REPUTATION, FAC.THORIUM_BROTHERHOOD, REP.HONORED, 12944)

	-- Chromatic Gauntlets -- 23708
	AddRecipe(23708, 300, 19157, R_COMMON, GAME_ORIG, 300, 320, 330, 340)
	self:addTradeFlags(RecipeDB, 23708, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOP, F.DPS, F.MAIL, F.THORIUM_BROTHERHOOD)
	self:addTradeAcquire(RecipeDB, 23708, A.REPUTATION, FAC.THORIUM_BROTHERHOOD, REP.REVERED, 12944)

	-- Corehound Belt -- 23709
	AddRecipe(23709, 300, 19162, R_COMMON, GAME_ORIG, 300, 320, 330, 340)
	self:addTradeFlags(RecipeDB, 23709, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOP, F.HEALER, F.CASTER, F.LEATHER, F.THORIUM_BROTHERHOOD)
	self:addTradeAcquire(RecipeDB, 23709, A.REPUTATION, FAC.THORIUM_BROTHERHOOD, REP.REVERED, 12944)

	-- Molten Belt -- 23710
	AddRecipe(23710, 300, 19163, R_COMMON, GAME_ORIG, 300, 320, 330, 340)
	self:addTradeFlags(RecipeDB, 23710, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOP, F.DPS, F.LEATHER, F.THORIUM_BROTHERHOOD)
	self:addTradeAcquire(RecipeDB, 23710, A.REPUTATION, FAC.THORIUM_BROTHERHOOD, REP.REVERED, 12944)

	-- Primal Batskin Jerkin -- 24121
	AddRecipe(24121, 300, 19685, R_COMMON, GAME_ORIG, 300, 320, 330, 340)
	self:addTradeFlags(RecipeDB, 24121, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOP, F.DPS, F.LEATHER, F.ZANDALAR)
	self:addTradeAcquire(RecipeDB, 24121, A.REPUTATION, FAC.ZANDALAR, REP.REVERED, 14921)

	-- Primal Batskin Gloves -- 24122
	AddRecipe(24122, 300, 19686, R_COMMON, GAME_ORIG, 300, 320, 330, 340)
	self:addTradeFlags(RecipeDB, 24122, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOP, F.DPS, F.LEATHER, F.ZANDALAR)
	self:addTradeAcquire(RecipeDB, 24122, A.REPUTATION, FAC.ZANDALAR, REP.HONORED, 14921)

	-- Primal Batskin Bracers -- 24123
	AddRecipe(24123, 300, 19687, R_COMMON, GAME_ORIG, 300, 320, 330, 340)
	self:addTradeFlags(RecipeDB, 24123, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOP, F.DPS, F.LEATHER, F.ZANDALAR)
	self:addTradeAcquire(RecipeDB, 24123, A.REPUTATION, FAC.ZANDALAR, REP.FRIENDLY, 14921)

	-- Blood Tiger Breastplate -- 24124
	AddRecipe(24124, 300, 19688, R_COMMON, GAME_ORIG, 300, 320, 330, 340)
	self:addTradeFlags(RecipeDB, 24124, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOP, F.HEALER, F.CASTER, F.LEATHER, F.ZANDALAR)
	self:addTradeAcquire(RecipeDB, 24124, A.REPUTATION, FAC.ZANDALAR, REP.REVERED, 14921)

	-- Blood Tiger Shoulders -- 24125
	AddRecipe(24125, 300, 19689, R_COMMON, GAME_ORIG, 300, 320, 330, 340)
	self:addTradeFlags(RecipeDB, 24125, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOP, F.HEALER, F.CASTER, F.LEATHER, F.ZANDALAR)
	self:addTradeAcquire(RecipeDB, 24125, A.REPUTATION, FAC.ZANDALAR, REP.HONORED, 14921)

	-- Blue Dragonscale Leggings -- 24654
	AddRecipe(24654, 300, 20295, R_COMMON, GAME_ORIG, 300, 320, 330, 340)
	self:addTradeFlags(RecipeDB, 24654, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.HEALER, F.CASTER, F.MAIL)
	self:addTradeAcquire(RecipeDB, 24654, A.TRAINER, 7866, A.TRAINER, 7867, A.TRAINER, 29508)

	-- Green Dragonscale Gauntlets -- 24655
	AddRecipe(24655, 260, 20296, R_COMMON, GAME_ORIG, 260, 280, 290, 300)
	self:addTradeFlags(RecipeDB, 24655, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.HEALER, F.CASTER, F.MAIL)
	self:addTradeAcquire(RecipeDB, 24655, A.TRAINER, 7866, A.TRAINER, 7867, A.TRAINER, 29508)

	-- Dreamscale Breastplate -- 24703
	AddRecipe(24703, 300, 20380, R_COMMON, GAME_ORIG, 300, 320, 330, 340)
	self:addTradeFlags(RecipeDB, 24703, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOP, F.DPS, F.MAIL, F.CENARION_CIRCLE)
	self:addTradeAcquire(RecipeDB, 24703, A.REPUTATION, FAC.CENARION_CIRCLE, REP.EXALTED, 15293)

	-- Spitfire Bracers -- 24846
	AddRecipe(24846, 300, 20481, R_COMMON, GAME_ORIG, 300, 320, 330, 340)
	self:addTradeFlags(RecipeDB, 24846, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOP, F.HEALER, F.CASTER, F.MAIL, F.CENARION_CIRCLE)
	self:addTradeAcquire(RecipeDB, 24846, A.REPUTATION, FAC.CENARION_CIRCLE, REP.FRIENDLY, 15293)

	-- Spitfire Gauntlets -- 24847
	AddRecipe(24847, 300, 20480, R_COMMON, GAME_ORIG, 300, 320, 330, 340)
	self:addTradeFlags(RecipeDB, 24847, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOP, F.HEALER, F.CASTER, F.MAIL, F.CENARION_CIRCLE)
	self:addTradeAcquire(RecipeDB, 24847, A.REPUTATION, FAC.CENARION_CIRCLE, REP.HONORED, 15293)

	-- Spitfire Breastplate -- 24848
	AddRecipe(24848, 300, 20479, R_COMMON, GAME_ORIG, 300, 320, 330, 340)
	self:addTradeFlags(RecipeDB, 24848, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOP, F.HEALER, F.CASTER, F.MAIL, F.CENARION_CIRCLE)
	self:addTradeAcquire(RecipeDB, 24848, A.REPUTATION, FAC.CENARION_CIRCLE, REP.REVERED, 15293)

	-- Sandstalker Bracers -- 24849
	AddRecipe(24849, 300, 20476, R_COMMON, GAME_ORIG, 300, 320, 330, 340)
	self:addTradeFlags(RecipeDB, 24849, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOP, F.MAIL, F.CENARION_CIRCLE)
	self:addTradeAcquire(RecipeDB, 24849, A.REPUTATION, FAC.CENARION_CIRCLE, REP.FRIENDLY, 15293)

	-- Sandstalker Gauntlets -- 24850
	AddRecipe(24850, 300, 20477, R_COMMON, GAME_ORIG, 300, 320, 330, 340)
	self:addTradeFlags(RecipeDB, 24850, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOP, F.MAIL, F.CENARION_CIRCLE)
	self:addTradeAcquire(RecipeDB, 24850, A.REPUTATION, FAC.CENARION_CIRCLE, REP.HONORED, 15293)

	-- Sandstalker Breastplate -- 24851
	AddRecipe(24851, 300, 20478, R_COMMON, GAME_ORIG, 300, 320, 330, 340)
	self:addTradeFlags(RecipeDB, 24851, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOP, F.MAIL, F.CENARION_CIRCLE)
	self:addTradeAcquire(RecipeDB, 24851, A.REPUTATION, FAC.CENARION_CIRCLE, REP.REVERED, 15293)

	-- Black Whelp Tunic -- 24940
	AddRecipe(24940, 100, 20575, R_COMMON, GAME_ORIG, 100, 125, 137, 150)
	self:addTradeFlags(RecipeDB, 24940, F.ALLIANCE, F.VENDOR, F.IBOE, F.RBOE, F.DPS, F.LEATHER)
	self:addTradeAcquire(RecipeDB, 24940, A.VENDOR, 777)

	-- Stormshroud Gloves -- 26279
	AddRecipe(26279, 300, 21278, R_RARE, GAME_ORIG, 300, 320, 330, 340)
	self:addTradeFlags(RecipeDB, 26279, F.ALLIANCE, F.HORDE, F.MOB_DROP, F.IBOE, F.RBOE, F.DPS, F.LEATHER)
	self:addTradeAcquire(RecipeDB, 26279, A.MOB, 14454, A.MOB, 14457)

	-- Polar Tunic -- 28219
	AddRecipe(28219, 300, 22661, R_EPIC, GAME_ORIG, 300, 320, 330, 340)
	self:addTradeFlags(RecipeDB, 28219, F.ALLIANCE, F.HORDE, F.VENDOR, F.RAID, F.IBOE, F.RBOP, F.DPS, F.LEATHER)
	self:addTradeAcquire(RecipeDB, 28219, A.REPUTATION, FAC.ARGENTDAWN, REP.EXALTED, 16365, A.CUSTOM, 41)

	-- Polar Gloves -- 28220
	AddRecipe(28220, 300, 22662, R_EPIC, GAME_ORIG, 300, 320, 330, 340)
	self:addTradeFlags(RecipeDB, 28220, F.ALLIANCE, F.HORDE, F.VENDOR, F.RAID, F.IBOE, F.RBOP, F.DPS, F.LEATHER)
	self:addTradeAcquire(RecipeDB, 28220, A.REPUTATION, FAC.ARGENTDAWN, REP.REVERED, 16365, A.CUSTOM, 41)

	-- Polar Bracers -- 28221
	AddRecipe(28221, 300, 22663, R_EPIC, GAME_ORIG, 300, 320, 330, 340)
	self:addTradeFlags(RecipeDB, 28221, F.ALLIANCE, F.HORDE, F.VENDOR, F.RAID, F.IBOE, F.RBOP, F.DPS, F.LEATHER)
	self:addTradeAcquire(RecipeDB, 28221, A.REPUTATION, FAC.ARGENTDAWN, REP.REVERED, 16365, A.CUSTOM, 41)

	-- Icy Scale Breastplate -- 28222
	AddRecipe(28222, 300, 22664, R_EPIC, GAME_ORIG, 300, 320, 330, 340)
	self:addTradeFlags(RecipeDB, 28222, F.ALLIANCE, F.HORDE, F.VENDOR, F.RAID, F.IBOE, F.RBOP, F.DPS, F.MAIL)
	self:addTradeAcquire(RecipeDB, 28222, A.REPUTATION, FAC.ARGENTDAWN, REP.EXALTED, 16365, A.CUSTOM, 41)

	-- Icy Scale Gauntlets -- 28223
	AddRecipe(28223, 300, 22666, R_EPIC, GAME_ORIG, 300, 320, 330, 340)
	self:addTradeFlags(RecipeDB, 28223, F.ALLIANCE, F.HORDE, F.VENDOR, F.RAID, F.IBOE, F.RBOP, F.DPS, F.MAIL)
	self:addTradeAcquire(RecipeDB, 28223, A.REPUTATION, FAC.ARGENTDAWN, REP.REVERED, 16365, A.CUSTOM, 41)

	-- Icy Scale Bracers -- 28224
	AddRecipe(28224, 300, 22665, R_EPIC, GAME_ORIG, 300, 320, 330, 340)
	self:addTradeFlags(RecipeDB, 28224, F.ALLIANCE, F.HORDE, F.VENDOR, F.RAID, F.IBOE, F.RBOP, F.DPS, F.MAIL)
	self:addTradeAcquire(RecipeDB, 28224, A.REPUTATION, FAC.ARGENTDAWN, REP.REVERED, 16365, A.CUSTOM, 41)

	-- Bramblewood Helm -- 28472
	AddRecipe(28472, 300, 22759, R_COMMON, GAME_ORIG, 300, 320, 330, 340)
	self:addTradeFlags(RecipeDB, 28472, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOP, F.LEATHER, F.CENARION_CIRCLE)
	self:addTradeAcquire(RecipeDB, 28472, A.REPUTATION, FAC.CENARION_CIRCLE, REP.REVERED, 15293)

	-- Bramblewood Boots -- 28473
	AddRecipe(28473, 300, 22760, R_COMMON, GAME_ORIG, 300, 320, 330, 340)
	self:addTradeFlags(RecipeDB, 28473, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOP, F.LEATHER, F.CENARION_CIRCLE)
	self:addTradeAcquire(RecipeDB, 28473, A.REPUTATION, FAC.CENARION_CIRCLE, REP.HONORED, 15293)

	-- Bramblewood Belt -- 28474
	AddRecipe(28474, 300, 22761, R_COMMON, GAME_ORIG, 300, 320, 330, 340)
	self:addTradeFlags(RecipeDB, 28474, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOP, F.LEATHER, F.CENARION_CIRCLE)
	self:addTradeAcquire(RecipeDB, 28474, A.REPUTATION, FAC.CENARION_CIRCLE, REP.FRIENDLY, 15293)

	-- Knothide Leather -- 32454
	AddRecipe(32454, 300, 21887, R_COMMON, GAME_TBC, 300, 300, 305, 310)
	self:addTradeFlags(RecipeDB, 32454, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.LEATHER)
	self:addTradeAcquire(RecipeDB, 32454, A.TRAINER, 18754, A.TRAINER, 18771, A.TRAINER, 19187, A.TRAINER, 21087, A.TRAINER, 33635, A.TRAINER, 33612, A.TRAINER, 33681)

	-- Heavy Knothide Leather -- 32455
	AddRecipe(32455, 325, 23793, R_COMMON, GAME_TBC, 325, 325, 330, 335)
	self:addTradeFlags(RecipeDB, 32455, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOE, F.LEATHER)
	self:addTradeAcquire(RecipeDB, 32455, A.VENDOR, 16689, A.VENDOR, 16748, A.VENDOR, 19196)

	-- Knothide Armor Kit -- 32456
	AddRecipe(32456, 300, 25650, R_COMMON, GAME_TBC, 300, 310, 325, 340)
	self:addTradeFlags(RecipeDB, 32456, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP)
	self:addTradeAcquire(RecipeDB, 32456, A.TRAINER, 18754, A.TRAINER, 18771, A.TRAINER, 19187, A.TRAINER, 21087, A.TRAINER, 33635, A.TRAINER, 33612, A.TRAINER, 33681)

	-- Vindicator's Armor Kit -- 32457
	AddRecipe(32457, 325, 25651, R_COMMON, GAME_TBC, 325, 335, 340, 345)
	self:addTradeFlags(RecipeDB, 32457, F.ALLIANCE, F.VENDOR, F.IBOE, F.RBOP, F.TANK, F.ALDOR)
	self:addTradeAcquire(RecipeDB, 32457, A.REPUTATION, FAC.ALDOR, REP.REVERED, 19321)

	-- Magister's Armor Kit -- 32458
	AddRecipe(32458, 325, 25652, R_COMMON, GAME_TBC, 325, 335, 340, 345)
	self:addTradeFlags(RecipeDB, 32458, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOP, F.HEALER, F.CASTER, F.SCRYER)
	self:addTradeAcquire(RecipeDB, 32458, A.REPUTATION, FAC.SCRYER, REP.REVERED, 19331)

	-- Riding Crop -- 32461
	AddRecipe(32461, 350, 25653, R_COMMON, GAME_TBC, 350, 360, 370, 380)
	self:addTradeFlags(RecipeDB, 32461, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOE, F.TRINKET)
	self:addTradeAcquire(RecipeDB, 32461, A.VENDOR, 18672)

	-- Felscale Gloves -- 32462
	AddRecipe(32462, 300, 25654, R_COMMON, GAME_TBC, 300, 310, 320, 330)
	self:addTradeFlags(RecipeDB, 32462, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.DPS, F.MAIL)
	self:addTradeAcquire(RecipeDB, 32462, A.TRAINER, 18754, A.TRAINER, 18771, A.TRAINER, 19187, A.TRAINER, 21087, A.TRAINER, 33635, A.TRAINER, 33612, A.TRAINER, 33681)

	-- Felscale Boots -- 32463
	AddRecipe(32463, 310, 25655, R_COMMON, GAME_TBC, 310, 320, 330, 340)
	self:addTradeFlags(RecipeDB, 32463, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.DPS, F.MAIL)
	self:addTradeAcquire(RecipeDB, 32463, A.TRAINER, 18754, A.TRAINER, 18771, A.TRAINER, 19187, A.TRAINER, 21087, A.TRAINER, 33635, A.TRAINER, 33612, A.TRAINER, 33681)

	-- Felscale Pants -- 32464
	AddRecipe(32464, 320, 25656, R_COMMON, GAME_TBC, 320, 330, 340, 350)
	self:addTradeFlags(RecipeDB, 32464, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.DPS, F.MAIL)
	self:addTradeAcquire(RecipeDB, 32464, A.TRAINER, 18754, A.TRAINER, 18771, A.TRAINER, 19187, A.TRAINER, 21087, A.TRAINER, 33635, A.TRAINER, 33612, A.TRAINER, 33681)

	-- Felscale Breastplate -- 32465
	AddRecipe(32465, 335, 25657, R_COMMON, GAME_TBC, 335, 345, 355, 365)
	self:addTradeFlags(RecipeDB, 32465, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.DPS, F.MAIL)
	self:addTradeAcquire(RecipeDB, 32465, A.TRAINER, 18754, A.TRAINER, 18771, A.TRAINER, 19187, A.TRAINER, 21087, A.TRAINER, 33635, A.TRAINER, 33612, A.TRAINER, 33681)

	-- Scaled Draenic Pants -- 32466
	AddRecipe(32466, 300, 25662, R_COMMON, GAME_TBC, 300, 310, 320, 330)
	self:addTradeFlags(RecipeDB, 32466, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.HEALER, F.CASTER, F.MAIL)
	self:addTradeAcquire(RecipeDB, 32466, A.TRAINER, 18754, A.TRAINER, 18771, A.TRAINER, 19187, A.TRAINER, 21087, A.TRAINER, 33635, A.TRAINER, 33612, A.TRAINER, 33681)

	-- Scaled Draenic Gloves -- 32467
	AddRecipe(32467, 310, 25661, R_COMMON, GAME_TBC, 310, 320, 330, 340)
	self:addTradeFlags(RecipeDB, 32467, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.HEALER, F.CASTER, F.MAIL)
	self:addTradeAcquire(RecipeDB, 32467, A.TRAINER, 18754, A.TRAINER, 18771, A.TRAINER, 19187, A.TRAINER, 21087, A.TRAINER, 33635, A.TRAINER, 33612, A.TRAINER, 33681)

	-- Scaled Draenic Vest -- 32468
	AddRecipe(32468, 325, 25660, R_COMMON, GAME_TBC, 325, 335, 345, 355)
	self:addTradeFlags(RecipeDB, 32468, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.HEALER, F.CASTER, F.MAIL)
	self:addTradeAcquire(RecipeDB, 32468, A.TRAINER, 18754, A.TRAINER, 18771, A.TRAINER, 19187, A.TRAINER, 21087, A.TRAINER, 33635, A.TRAINER, 33612, A.TRAINER, 33681)

	-- Scaled Draenic Boots -- 32469
	AddRecipe(32469, 335, 25659, R_COMMON, GAME_TBC, 335, 345, 355, 365)
	self:addTradeFlags(RecipeDB, 32469, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.HEALER, F.CASTER, F.MAIL)
	self:addTradeAcquire(RecipeDB, 32469, A.TRAINER, 18754, A.TRAINER, 18771, A.TRAINER, 19187, A.TRAINER, 21087, A.TRAINER, 33635, A.TRAINER, 33612, A.TRAINER, 33681)

	-- Thick Draenic Gloves -- 32470
	AddRecipe(32470, 300, 25669, R_COMMON, GAME_TBC, 300, 310, 320, 330)
	self:addTradeFlags(RecipeDB, 32470, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.DPS, F.LEATHER)
	self:addTradeAcquire(RecipeDB, 32470, A.TRAINER, 18754, A.TRAINER, 18771, A.TRAINER, 19187, A.TRAINER, 21087, A.TRAINER, 33635, A.TRAINER, 33612, A.TRAINER, 33681)

	-- Thick Draenic Pants -- 32471
	AddRecipe(32471, 315, 25670, R_COMMON, GAME_TBC, 315, 325, 335, 345)
	self:addTradeFlags(RecipeDB, 32471, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.DPS, F.LEATHER)
	self:addTradeAcquire(RecipeDB, 32471, A.TRAINER, 18754, A.TRAINER, 18771, A.TRAINER, 19187, A.TRAINER, 21087, A.TRAINER, 33635, A.TRAINER, 33612, A.TRAINER, 33681)

	-- Thick Draenic Boots -- 32472
	AddRecipe(32472, 320, 25668, R_COMMON, GAME_TBC, 320, 330, 340, 350)
	self:addTradeFlags(RecipeDB, 32472, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.DPS, F.LEATHER)
	self:addTradeAcquire(RecipeDB, 32472, A.TRAINER, 18754, A.TRAINER, 18771, A.TRAINER, 19187, A.TRAINER, 21087, A.TRAINER, 33635, A.TRAINER, 33612, A.TRAINER, 33681)

	-- Thick Draenic Vest -- 32473
	AddRecipe(32473, 330, 25671, R_COMMON, GAME_TBC, 330, 340, 350, 360)
	self:addTradeFlags(RecipeDB, 32473, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.DPS, F.LEATHER)
	self:addTradeAcquire(RecipeDB, 32473, A.TRAINER, 18754, A.TRAINER, 18771, A.TRAINER, 19187, A.TRAINER, 21087, A.TRAINER, 33635, A.TRAINER, 33612, A.TRAINER, 33681)

	-- Wild Draenish Boots -- 32478
	AddRecipe(32478, 300, 25673, R_COMMON, GAME_TBC, 300, 310, 320, 330)
	self:addTradeFlags(RecipeDB, 32478, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.HEALER, F.CASTER, F.LEATHER)
	self:addTradeAcquire(RecipeDB, 32478, A.TRAINER, 18754, A.TRAINER, 18771, A.TRAINER, 19187, A.TRAINER, 21087, A.TRAINER, 33635, A.TRAINER, 33612, A.TRAINER, 33681)

	-- Wild Draenish Gloves -- 32479
	AddRecipe(32479, 310, 25674, R_COMMON, GAME_TBC, 310, 320, 330, 340)
	self:addTradeFlags(RecipeDB, 32479, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.HEALER, F.CASTER, F.LEATHER)
	self:addTradeAcquire(RecipeDB, 32479, A.TRAINER, 18754, A.TRAINER, 18771, A.TRAINER, 19187, A.TRAINER, 21087, A.TRAINER, 33635, A.TRAINER, 33612, A.TRAINER, 33681)

	-- Wild Draenish Leggings -- 32480
	AddRecipe(32480, 320, 25675, R_COMMON, GAME_TBC, 320, 330, 340, 350)
	self:addTradeFlags(RecipeDB, 32480, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.HEALER, F.CASTER, F.LEATHER)
	self:addTradeAcquire(RecipeDB, 32480, A.TRAINER, 18754, A.TRAINER, 18771, A.TRAINER, 19187, A.TRAINER, 21087, A.TRAINER, 33635, A.TRAINER, 33612, A.TRAINER, 33681)

	-- Wild Draenish Vest -- 32481
	AddRecipe(32481, 330, 25676, R_COMMON, GAME_TBC, 330, 340, 350, 360)
	self:addTradeFlags(RecipeDB, 32481, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.HEALER, F.CASTER, F.LEATHER)
	self:addTradeAcquire(RecipeDB, 32481, A.TRAINER, 18754, A.TRAINER, 18771, A.TRAINER, 19187, A.TRAINER, 21087, A.TRAINER, 33635, A.TRAINER, 33612, A.TRAINER, 33681)

	-- Comfortable Insoles -- 32482
	AddRecipe(32482, 300, 25679, R_COMMON, GAME_TBC, 300, 300, 305, 310)
	self:addTradeFlags(RecipeDB, 32482, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOE)
	self:addTradeAcquire(RecipeDB, 32482, A.VENDOR, 16689, A.VENDOR, 16748)

	-- Stylin' Purple Hat -- 32485
	AddRecipe(32485, 350, 25680, R_RARE, GAME_TBC, 350, 360, 370, 380)
	self:addTradeFlags(RecipeDB, 32485, F.ALLIANCE, F.HORDE, F.INSTANCE, F.IBOE, F.RBOP, F.DPS, F.LEATHER)
	self:addTradeAcquire(RecipeDB, 32485, A.MOB, 18667)

	-- Stylin' Adventure Hat -- 32487
	AddRecipe(32487, 350, 25681, R_RARE, GAME_TBC, 350, 360, 370, 380)
	self:addTradeFlags(RecipeDB, 32487, F.ALLIANCE, F.HORDE, F.INSTANCE, F.IBOE, F.RBOP, F.HEALER, F.CASTER, F.MAIL)
	self:addTradeAcquire(RecipeDB, 32487, A.MOB, 17820, A.MOB, 28132)

	-- Stylin' Crimson Hat -- 32488
	AddRecipe(32488, 350, 25683, R_RARE, GAME_TBC, 350, 360, 370, 380)
	self:addTradeFlags(RecipeDB, 32488, F.ALLIANCE, F.HORDE, F.INSTANCE, F.IBOE, F.RBOP, F.DPS, F.MAIL)
	self:addTradeAcquire(RecipeDB, 32488, A.MOB, 18322)

	-- Stylin' Jungle Hat -- 32489
	AddRecipe(32489, 350, 25682, R_RARE, GAME_TBC, 350, 360, 370, 380)
	self:addTradeFlags(RecipeDB, 32489, F.ALLIANCE, F.HORDE, F.INSTANCE, F.IBOE, F.RBOP, F.HEALER, F.CASTER, F.LEATHER)
	self:addTradeAcquire(RecipeDB, 32489, A.MOB, 17839, A.MOB, 21104)

	-- Fel Leather Gloves -- 32490
	AddRecipe(32490, 340, 25685, R_RARE, GAME_TBC, 340, 350, 360, 370)
	self:addTradeFlags(RecipeDB, 32490, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOP, F.DPS, F.LEATHER, F.CONSORTIUM)
	self:addTradeAcquire(RecipeDB, 32490, A.REPUTATION, FAC.CONSORTIUM, REP.FRIENDLY, 20242, A.REPUTATION, FAC.CONSORTIUM, REP.FRIENDLY, 23007)

	-- Fel Leather Boots -- 32493
	AddRecipe(32493, 350, 25686, R_RARE, GAME_TBC, 350, 360, 370, 380)
	self:addTradeFlags(RecipeDB, 32493, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOP, F.DPS, F.LEATHER, F.CONSORTIUM)
	self:addTradeAcquire(RecipeDB, 32493, A.REPUTATION, FAC.CONSORTIUM, REP.HONORED, 20242, A.REPUTATION, FAC.CONSORTIUM, REP.HONORED, 23007)

	-- Fel Leather Leggings -- 32494
	AddRecipe(32494, 350, 25687, R_RARE, GAME_TBC, 350, 360, 370, 380)
	self:addTradeFlags(RecipeDB, 32494, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOP, F.DPS, F.LEATHER, F.CONSORTIUM)
	self:addTradeAcquire(RecipeDB, 32494, A.REPUTATION, FAC.CONSORTIUM, REP.REVERED, 20242, A.REPUTATION, FAC.CONSORTIUM, REP.REVERED, 23007)

	-- Heavy Clefthoof Vest -- 32495
	AddRecipe(32495, 360, 25689, R_RARE, GAME_TBC, 360, 370, 380, 390)
	self:addTradeFlags(RecipeDB, 32495, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOP, F.TANK, F.LEATHER, F.CENARION_EXPEDITION)
	self:addTradeAcquire(RecipeDB, 32495, A.REPUTATION, FAC.CENARION_EXPEDITION, REP.HONORED, 17904)

	-- Heavy Clefthoof Leggings -- 32496
	AddRecipe(32496, 355, 25690, R_RARE, GAME_TBC, 355, 365, 37, 385)
	self:addTradeFlags(RecipeDB, 32496, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOP, F.TANK, F.LEATHER, F.CENARION_EXPEDITION)
	self:addTradeAcquire(RecipeDB, 32496, A.REPUTATION, FAC.CENARION_EXPEDITION, REP.HONORED, 17904)

	-- Heavy Clefthoof Boots -- 32497
	AddRecipe(32497, 355, 25691, R_RARE, GAME_TBC, 355, 365, 375, 385)
	self:addTradeFlags(RecipeDB, 32497, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOP, F.TANK, F.LEATHER, F.CENARION_EXPEDITION)
	self:addTradeAcquire(RecipeDB, 32497, A.REPUTATION, FAC.CENARION_EXPEDITION, REP.FRIENDLY, 17904)

	-- Felstalker Belt -- 32498
	AddRecipe(32498, 350, 25695, R_RARE, GAME_TBC, 350, 360, 370, 380)
	self:addTradeFlags(RecipeDB, 32498, F.ALLIANCE, F.VENDOR, F.IBOE, F.RBOP, F.DPS, F.MAIL, F.HELLFIRE)
	self:addTradeAcquire(RecipeDB, 32498, A.REPUTATION, FAC.HONOR_HOLD, REP.FRIENDLY, 17657, A.REPUTATION, FAC.THRALLMAR, REP.FRIENDLY, 17585)

	-- Felstalker Bracer -- 32499
	AddRecipe(32499, 360, 25697, R_RARE, GAME_TBC, 360, 370, 380, 390)
	self:addTradeFlags(RecipeDB, 32499, F.ALLIANCE, F.VENDOR, F.IBOE, F.RBOP, F.DPS, F.MAIL, F.HELLFIRE)
	self:addTradeAcquire(RecipeDB, 32499, A.REPUTATION, FAC.HONOR_HOLD, REP.HONORED, 17657, A.REPUTATION, FAC.THRALLMAR, REP.HONORED, 17585)

	-- Felstalker Breastplate -- 32500
	AddRecipe(32500, 360, 25696, R_RARE, GAME_TBC, 360, 370, 380, 390)
	self:addTradeFlags(RecipeDB, 32500, F.ALLIANCE, F.VENDOR, F.IBOE, F.RBOP, F.DPS, F.MAIL, F.HELLFIRE)
	self:addTradeAcquire(RecipeDB, 32500, A.REPUTATION, FAC.HONOR_HOLD, REP.HONORED, 17657, A.REPUTATION, FAC.THRALLMAR, REP.HONORED, 17585)

	-- Netherfury Belt -- 32501
	AddRecipe(32501, 340, 25694, R_RARE, GAME_TBC, 340, 350, 360, 370)
	self:addTradeFlags(RecipeDB, 32501, F.ALLIANCE, F.VENDOR, F.IBOE, F.RBOP, F.HEALER, F.CASTER, F.MAIL, F.NAGRAND)
	self:addTradeAcquire(RecipeDB, 32501, A.REPUTATION, FAC.KURENI, REP.FRIENDLY, 20240)

	-- Netherfury Leggings -- 32502
	AddRecipe(32502, 340, 25692, R_RARE, GAME_TBC, 340, 350, 360, 370)
	self:addTradeFlags(RecipeDB, 32502, F.ALLIANCE, F.VENDOR, F.IBOE, F.RBOP, F.HEALER, F.CASTER, F.MAIL, F.NAGRAND)
	self:addTradeAcquire(RecipeDB, 32502, A.REPUTATION, FAC.KURENI, REP.HONORED, 20240)

	-- Netherfury Boots -- 32503
	AddRecipe(32503, 350, 25693, R_RARE, GAME_TBC, 350, 360, 370, 380)
	self:addTradeFlags(RecipeDB, 32503, F.ALLIANCE, F.VENDOR, F.IBOE, F.RBOP, F.HEALER, F.CASTER, F.MAIL, F.NAGRAND)
	self:addTradeAcquire(RecipeDB, 32503, A.REPUTATION, FAC.KURENI, REP.REVERED, 20240)

	-- Shadow Armor Kit -- 35520
	AddRecipe(35520, 340, 29483, R_UNCOMMON, GAME_TBC, 340, 350, 355, 360)
	self:addTradeFlags(RecipeDB, 35520, F.ALLIANCE, F.HORDE, F.INSTANCE, F.MOB_DROP, F.IBOE, F.RBOP)
	self:addTradeAcquire(RecipeDB, 35520, A.MOB, 18320)

	-- Flame Armor Kit -- 35521
	AddRecipe(35521, 340, 29485, R_UNCOMMON, GAME_TBC, 340, 350, 355, 360)
	self:addTradeFlags(RecipeDB, 35521, F.ALLIANCE, F.HORDE, F.INSTANCE, F.IBOE, F.RBOP)
	self:addTradeAcquire(RecipeDB, 35521, A.MOB, 20898)

	-- Frost Armor Kit -- 35522
	AddRecipe(35522, 340, 29486, R_UNCOMMON, GAME_TBC, 340, 350, 355, 360)
	self:addTradeFlags(RecipeDB, 35522, F.ALLIANCE, F.HORDE, F.INSTANCE, F.IBOE, F.RBOP)
	self:addTradeAcquire(RecipeDB, 35522, A.MOB, 17797)

	-- Nature Armor Kit -- 35523
	AddRecipe(35523, 340, 29487, R_UNCOMMON, GAME_TBC, 340, 350, 355, 360)
	self:addTradeFlags(RecipeDB, 35523, F.ALLIANCE, F.HORDE, F.INSTANCE, F.IBOE, F.RBOP)
	self:addTradeAcquire(RecipeDB, 35523, A.MOB, 17941)

	-- Arcane Armor Kit -- 35524
	AddRecipe(35524, 340, 29488, R_UNCOMMON, GAME_TBC, 340, 350, 355, 360)
	self:addTradeFlags(RecipeDB, 35524, F.ALLIANCE, F.HORDE, F.INSTANCE, F.IBOE, F.RBOP)
	self:addTradeAcquire(RecipeDB, 35524, A.MOB, 17879)

	-- Enchanted Felscale Leggings -- 35525
	AddRecipe(35525, 350, 29489, R_COMMON, GAME_TBC, 350, 360, 370, 380)
	self:addTradeFlags(RecipeDB, 35525, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOP, F.DPS, F.MAIL, F.SCRYER)
	self:addTradeAcquire(RecipeDB, 35525, A.REPUTATION, FAC.SCRYER, REP.EXALTED, 19331)

	-- Enchanted Felscale Gloves -- 35526
	AddRecipe(35526, 350, 29490, R_COMMON, GAME_TBC, 350, 360, 370, 380)
	self:addTradeFlags(RecipeDB, 35526, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOP, F.DPS, F.MAIL, F.SCRYER)
	self:addTradeAcquire(RecipeDB, 35526, A.REPUTATION, FAC.SCRYER, REP.HONORED, 19331)

	-- Enchanted Felscale Boots -- 35527
	AddRecipe(35527, 350, 29491, R_COMMON, GAME_TBC, 350, 360, 370, 380)
	self:addTradeFlags(RecipeDB, 35527, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOP, F.DPS, F.MAIL, F.SCRYER)
	self:addTradeAcquire(RecipeDB, 35527, A.REPUTATION, FAC.SCRYER, REP.REVERED, 19331)

	-- Flamescale Boots -- 35528
	AddRecipe(35528, 350, 29493, R_COMMON, GAME_TBC, 350, 360, 370, 380)
	self:addTradeFlags(RecipeDB, 35528, F.ALLIANCE, F.VENDOR, F.IBOE, F.RBOP, F.DPS, F.MAIL, F.ALDOR)
	self:addTradeAcquire(RecipeDB, 35528, A.REPUTATION, FAC.ALDOR, REP.REVERED, 19321)

	-- Flamescale Leggings -- 35529
	AddRecipe(35529, 350, 29492, R_COMMON, GAME_TBC, 350, 360, 370, 380)
	self:addTradeFlags(RecipeDB, 35529, F.ALLIANCE, F.VENDOR, F.IBOE, F.RBOP, F.DPS, F.MAIL, F.ALDOR)
	self:addTradeAcquire(RecipeDB, 35529, A.REPUTATION, FAC.ALDOR, REP.EXALTED, 19321)

	-- Reinforced Mining Bag -- 35530
	AddRecipe(35530, 325, 29540, R_COMMON, GAME_TBC, 325, 335, 340, 345)
	self:addTradeFlags(RecipeDB, 35530, F.ALLIANCE, F.VENDOR, F.IBOE, F.RBOP, F.NAGRAND)
	self:addTradeAcquire(RecipeDB, 35530, A.REPUTATION, FAC.KURENI, REP.HONORED, 20240)

	-- Flamescale Belt -- 35531
	AddRecipe(35531, 350, 29494, R_COMMON, GAME_TBC, 350, 360, 370, 380)
	self:addTradeFlags(RecipeDB, 35531, F.ALLIANCE, F.VENDOR, F.IBOE, F.RBOP, F.DPS, F.MAIL, F.ALDOR)
	self:addTradeAcquire(RecipeDB, 35531, A.REPUTATION, FAC.ALDOR, REP.HONORED, 19321)

	-- Enchanted Clefthoof Leggings -- 35532
	AddRecipe(35532, 350, 29495, R_COMMON, GAME_TBC, 350, 360, 370, 380)
	self:addTradeFlags(RecipeDB, 35532, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOP, F.DPS, F.LEATHER, F.SCRYER)
	self:addTradeAcquire(RecipeDB, 35532, A.REPUTATION, FAC.SCRYER, REP.EXALTED, 19331)

	-- Enchanted Clefthoof Gloves -- 35533
	AddRecipe(35533, 350, 29496, R_COMMON, GAME_TBC, 350, 360, 370, 380)
	self:addTradeFlags(RecipeDB, 35533, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOP, F.DPS, F.LEATHER, F.SCRYER)
	self:addTradeAcquire(RecipeDB, 35533, A.REPUTATION, FAC.SCRYER, REP.REVERED, 19331)

	-- Enchanted Clefthoof Boots -- 35534
	AddRecipe(35534, 350, 29497, R_COMMON, GAME_TBC, 350, 360, 370, 380)
	self:addTradeFlags(RecipeDB, 35534, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOP, F.DPS, F.LEATHER, F.SCRYER)
	self:addTradeAcquire(RecipeDB, 35534, A.REPUTATION, FAC.SCRYER, REP.HONORED, 19331)

	-- Blastguard Pants -- 35535
	AddRecipe(35535, 350, 29498, R_COMMON, GAME_TBC, 350, 360, 370, 380)
	self:addTradeFlags(RecipeDB, 35535, F.ALLIANCE, F.VENDOR, F.IBOE, F.RBOP, F.DPS, F.LEATHER, F.ALDOR)
	self:addTradeAcquire(RecipeDB, 35535, A.REPUTATION, FAC.ALDOR, REP.EXALTED, 19321)

	-- Blastguard Boots -- 35536
	AddRecipe(35536, 350, 29499, R_COMMON, GAME_TBC, 350, 360, 370, 380)
	self:addTradeFlags(RecipeDB, 35536, F.ALLIANCE, F.VENDOR, F.IBOE, F.RBOP, F.DPS, F.LEATHER, F.ALDOR)
	self:addTradeAcquire(RecipeDB, 35536, A.REPUTATION, FAC.ALDOR, REP.REVERED, 19321)

	-- Blastguard Belt -- 35537
	AddRecipe(35537, 350, 29500, R_COMMON, GAME_TBC, 350, 360, 370, 380)
	self:addTradeFlags(RecipeDB, 35537, F.ALLIANCE, F.VENDOR, F.IBOE, F.RBOP, F.DPS, F.LEATHER, F.ALDOR)
	self:addTradeAcquire(RecipeDB, 35537, A.REPUTATION, FAC.ALDOR, REP.HONORED, 19321)

	-- Drums of Panic -- 35538
	AddRecipe(35538, 370, 29532, R_COMMON, GAME_TBC, 370, 370, 377, 385)
	self:addTradeFlags(RecipeDB, 35538, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOP, F.KOT)
	self:addTradeAcquire(RecipeDB, 35538, A.REPUTATION, FAC.KEEPERS_OF_TIME, REP.HONORED, 21643)

	-- Drums of Restoration -- 35539
	AddRecipe(35539, 350, 29531, R_COMMON, GAME_TBC, 350, 350, 357, 365)
	self:addTradeFlags(RecipeDB, 35539, F.ALLIANCE, F.VENDOR, F.IBOE, F.RBOP, F.NAGRAND)
	self:addTradeAcquire(RecipeDB, 35539, A.REPUTATION, FAC.KURENI, REP.HONORED, 20240)

	-- Drums of War -- 35540
	AddRecipe(35540, 340, 29528, R_COMMON, GAME_TBC, 340, 340, 347, 355)
	self:addTradeFlags(RecipeDB, 35540, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.HEALER, F.CASTER)
	self:addTradeAcquire(RecipeDB, 35540, A.TRAINER, 18754, A.TRAINER, 18771, A.TRAINER, 19187, A.TRAINER, 21087, A.TRAINER, 33681, A.TRAINER, 33612, A.TRAINER, 33635)

	-- Drums of Battle -- 35543
	AddRecipe(35543, 365, 29529, R_COMMON, GAME_TBC, 365, 365, 372, 380)
	self:addTradeFlags(RecipeDB, 35543, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOP, F.DPS, F.SHATAR)
	self:addTradeAcquire(RecipeDB, 35543, A.REPUTATION, FAC.SHATAR, REP.HONORED, 21432)

	-- Drums of Speed -- 35544
	AddRecipe(35544, 345, 29530, R_COMMON, GAME_TBC, 345, 345, 352, 360)
	self:addTradeFlags(RecipeDB, 35544, F.ALLIANCE, F.HORDE, F.VENDOR, F.INSTANCE, F.IBOE, F.RBOP, F.NAGRAND)
	self:addTradeAcquire(RecipeDB, 35544, A.REPUTATION, FAC.MAGHAR, REP.HONORED, 20241, A.REPUTATION, FAC.KURENI, REP.HONORED, 20240)

	-- Cobrahide Leg Armor -- 35549
	AddRecipe(35549, 335, 29533, R_COMMON, GAME_TBC, 335, 335, 345, 355)
	self:addTradeFlags(RecipeDB, 35549, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOP, F.DPS, F.HELLFIRE)
	self:addTradeAcquire(RecipeDB, 35549, A.REPUTATION, FAC.HONOR_HOLD, REP.HONORED, 17657, A.REPUTATION, FAC.THRALLMAR, REP.HONORED, 17585)

	-- Nethercobra Leg Armor -- 35554
	AddRecipe(35554, 365, 29535, R_COMMON, GAME_TBC, 365, 365, 375, 385)
	self:addTradeFlags(RecipeDB, 35554, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOP, F.DPS, F.HELLFIRE)
	self:addTradeAcquire(RecipeDB, 35554, A.REPUTATION, FAC.HONOR_HOLD, REP.EXALTED, 17657, A.REPUTATION, FAC.THRALLMAR, REP.EXALTED, 17585)

	-- Clefthide Leg Armor -- 35555
	AddRecipe(35555, 335, 29534, R_COMMON, GAME_TBC, 335, 335, 345, 355)
	self:addTradeFlags(RecipeDB, 35555, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOP, F.DPS, F.TANK, F.CENARION_EXPEDITION)
	self:addTradeAcquire(RecipeDB, 35555, A.REPUTATION, FAC.CENARION_EXPEDITION, REP.HONORED, 17904)

	-- Nethercleft Leg Armor -- 35557
	AddRecipe(35557, 365, 29536, R_COMMON, GAME_TBC, 365, 365, 375, 385)
	self:addTradeFlags(RecipeDB, 35557, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOP, F.DPS, F.TANK, F.CENARION_EXPEDITION)
	self:addTradeAcquire(RecipeDB, 35557, A.REPUTATION, FAC.CENARION_EXPEDITION, REP.EXALTED, 17904)

	-- Cobrascale Hood -- 35558
	AddRecipe(35558, 365, 29502, R_EPIC, GAME_TBC, 365, 375, 385, 395)
	self:addTradeFlags(RecipeDB, 35558, F.ALLIANCE, F.HORDE, F.WORLD_DROP, F.IBOE, F.RBOE, F.DPS, F.LEATHER)
	self:addTradeAcquire(RecipeDB, 35558, A.WORLD_DROP, 4)

	-- Cobrascale Gloves -- 35559
	AddRecipe(35559, 365, 29503, R_EPIC, GAME_TBC, 365, 375, 385, 395)
	self:addTradeFlags(RecipeDB, 35559, F.ALLIANCE, F.HORDE, F.WORLD_DROP, F.IBOE, F.RBOP, F.DPS, F.LEATHER)
	self:addTradeAcquire(RecipeDB, 35559, A.MOB, 24664, A.WORLD_DROP, 4)

	-- Windscale Hood -- 35560
	AddRecipe(35560, 365, 29504, R_EPIC, GAME_TBC, 365, 375, 385, 395)
	self:addTradeFlags(RecipeDB, 35560, F.ALLIANCE, F.HORDE, F.WORLD_DROP, F.IBOE, F.RBOE, F.HEALER, F.CASTER, F.LEATHER)
	self:addTradeAcquire(RecipeDB, 35560, A.WORLD_DROP, 4)

	-- Hood of Primal Life -- 35561
	AddRecipe(35561, 365, 29505, R_EPIC, GAME_TBC, 365, 375, 385, 395)
	self:addTradeFlags(RecipeDB, 35561, F.ALLIANCE, F.HORDE, F.WORLD_DROP, F.IBOE, F.RBOE, F.HEALER, F.CASTER, F.LEATHER)
	self:addTradeAcquire(RecipeDB, 35561, A.WORLD_DROP, 4)

	-- Gloves of the Living Touch -- 35562
	AddRecipe(35562, 365, 29506, R_EPIC, GAME_TBC, 365, 375, 385, 395)
	self:addTradeFlags(RecipeDB, 35562, F.ALLIANCE, F.HORDE, F.MOB_DROP, F.IBOE, F.RBOP, F.HEALER, F.CASTER, F.LEATHER)
	self:addTradeAcquire(RecipeDB, 35562, A.MOB, 24664)

	-- Windslayer Wraps -- 35563
	AddRecipe(35563, 365, 29507, R_EPIC, GAME_TBC, 365, 375, 385, 395)
	self:addTradeFlags(RecipeDB, 35563, F.ALLIANCE, F.HORDE, F.INSTANCE, F.RAID, F.MOB_DROP, F.IBOE, F.RBOE, F.DPS, F.LEATHER)
	self:addTradeAcquire(RecipeDB, 35563, A.WORLD_DROP, 4)

	-- Living Dragonscale Helm -- 35564
	AddRecipe(35564, 365, 29508, R_EPIC, GAME_TBC, 365, 375, 385, 395)
	self:addTradeFlags(RecipeDB, 35564, F.ALLIANCE, F.HORDE, F.INSTANCE, F.RAID, F.MOB_DROP, F.IBOE, F.RBOE, F.HEALER, F.CASTER, F.MAIL)
	self:addTradeAcquire(RecipeDB, 35564, A.WORLD_DROP, 4)

	-- Earthen Netherscale Boots -- 35567
	AddRecipe(35567, 365, 29512, R_EPIC, GAME_TBC, 365, 375, 385, 395)
	self:addTradeFlags(RecipeDB, 35567, F.ALLIANCE, F.HORDE, F.RAID, F.MOB_DROP, F.IBOE, F.RBOE, F.DPS, F.MAIL)
	self:addTradeAcquire(RecipeDB, 35567, A.WORLD_DROP, 4)

	-- Windstrike Gloves -- 35568
	AddRecipe(35568, 365, 29509, R_EPIC, GAME_TBC, 365, 375, 385, 395)
	self:addTradeFlags(RecipeDB, 35568, F.ALLIANCE, F.HORDE, F.MOB_DROP, F.IBOE, F.RBOP, F.DPS, F.MAIL)
	self:addTradeAcquire(RecipeDB, 35568, A.MOB, 24664)

	-- Netherdrake Helm -- 35572
	AddRecipe(35572, 365, 29510, R_EPIC, GAME_TBC, 365, 375, 385, 395)
	self:addTradeFlags(RecipeDB, 35572, F.ALLIANCE, F.HORDE, F.WORLD_DROP, F.IBOE, F.RBOE, F.DPS, F.MAIL)
	self:addTradeAcquire(RecipeDB, 35572, A.WORLD_DROP, 4)

	-- Netherdrake Gloves -- 35573
	AddRecipe(35573, 365, 29511, R_EPIC, GAME_TBC, 365, 375, 385, 395)
	self:addTradeFlags(RecipeDB, 35573, F.ALLIANCE, F.HORDE, F.MOB_DROP, F.IBOE, F.RBOP, F.DPS, F.MAIL)
	self:addTradeAcquire(RecipeDB, 35573, A.MOB, 24664)

	-- Thick Netherscale Breastplate -- 35574
	AddRecipe(35574, 365, 29514, R_EPIC, GAME_TBC, 365, 375, 385, 395)
	self:addTradeFlags(RecipeDB, 35574, F.ALLIANCE, F.HORDE, F.INSTANCE, F.RAID, F.MOB_DROP, F.IBOE, F.RBOE, F.DPS, F.MAIL)
	self:addTradeAcquire(RecipeDB, 35574, A.WORLD_DROP, 4)

	-- Ebon Netherscale Breastplate -- 35575
	AddRecipe(35575, 375, 29515, R_COMMON, GAME_TBC, 375, 385, 395, 405, 10657)
	self:addTradeFlags(RecipeDB, 35575, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOP, F.RBOP, F.DPS, F.MAIL)
	self:addTradeAcquire(RecipeDB, 35575, A.TRAINER, 7866, A.TRAINER, 7867, A.TRAINER, 29508)

	-- Ebon Netherscale Belt -- 35576
	AddRecipe(35576, 375, 29516, R_COMMON, GAME_TBC, 375, 385, 395, 405, 10657)
	self:addTradeFlags(RecipeDB, 35576, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOP, F.RBOP, F.DPS, F.MAIL)
	self:addTradeAcquire(RecipeDB, 35576, A.TRAINER, 7866, A.TRAINER, 7867, A.TRAINER, 29508)

	-- Ebon Netherscale Bracers -- 35577
	AddRecipe(35577, 375, 29517, R_COMMON, GAME_TBC, 375, 385, 395, 405, 10657)
	self:addTradeFlags(RecipeDB, 35577, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOP, F.RBOP, F.DPS, F.MAIL)
	self:addTradeAcquire(RecipeDB, 35577, A.TRAINER, 7866, A.TRAINER, 7867, A.TRAINER, 29508)

	-- Netherstrike Breastplate -- 35580
	AddRecipe(35580, 375, 29519, R_COMMON, GAME_TBC, 375, 385, 395, 405, 10657)
	self:addTradeFlags(RecipeDB, 35580, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOP, F.RBOP, F.HEALER, F.CASTER, F.MAIL)
	self:addTradeAcquire(RecipeDB, 35580, A.TRAINER, 7866, A.TRAINER, 7867, A.TRAINER, 29508)

	-- Netherstrike Belt -- 35582
	AddRecipe(35582, 375, 29520, R_COMMON, GAME_TBC, 375, 385, 395, 405, 10657)
	self:addTradeFlags(RecipeDB, 35582, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOP, F.RBOP, F.HEALER, F.CASTER, F.MAIL)
	self:addTradeAcquire(RecipeDB, 35582, A.TRAINER, 7866, A.TRAINER, 7867, A.TRAINER, 29508)

	-- Netherstrike Bracers -- 35584
	AddRecipe(35584, 375, 29521, R_COMMON, GAME_TBC, 375, 385, 395, 405, 10657)
	self:addTradeFlags(RecipeDB, 35584, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOP, F.RBOP, F.HEALER, F.CASTER, F.MAIL)
	self:addTradeAcquire(RecipeDB, 35584, A.TRAINER, 7866, A.TRAINER, 7867, A.TRAINER, 29508)

	-- Windhawk Hauberk -- 35585
	AddRecipe(35585, 375, 29522, R_COMMON, GAME_TBC, 375, 385, 395, 405, 10661)
	self:addTradeFlags(RecipeDB, 35585, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOP, F.RBOP, F.HEALER, F.CASTER, F.LEATHER)
	self:addTradeAcquire(RecipeDB, 35585, A.TRAINER, 7870, A.TRAINER, 7871, A.TRAINER, 29509)

	-- Windhawk Belt -- 35587
	AddRecipe(35587, 375, 29524, R_COMMON, GAME_TBC, 375, 385, 395, 405, 10661)
	self:addTradeFlags(RecipeDB, 35587, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOP, F.RBOP, F.HEALER, F.CASTER, F.LEATHER)
	self:addTradeAcquire(RecipeDB, 35587, A.TRAINER, 7870, A.TRAINER, 7871, A.TRAINER, 29509)

	-- Windhawk Bracers -- 35588
	AddRecipe(35588, 375, 29523, R_COMMON, GAME_TBC, 375, 385, 395, 405, 10661)
	self:addTradeFlags(RecipeDB, 35588, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOP, F.RBOP, F.HEALER, F.CASTER, F.LEATHER)
	self:addTradeAcquire(RecipeDB, 35588, A.TRAINER, 7870, A.TRAINER, 7871, A.TRAINER, 29509)

	-- Primalstrike Vest -- 35589
	AddRecipe(35589, 375, 29525, R_COMMON, GAME_TBC, 375, 385, 395, 405, 10659)
	self:addTradeFlags(RecipeDB, 35589, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOP, F.RBOP, F.DPS, F.LEATHER)
	self:addTradeAcquire(RecipeDB, 35589, A.TRAINER, 7868, A.TRAINER, 7869, A.TRAINER, 29507)

	-- Primalstrike Belt -- 35590
	AddRecipe(35590, 375, 29526, R_COMMON, GAME_TBC, 375, 385, 395, 405, 10659)
	self:addTradeFlags(RecipeDB, 35590, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOP, F.RBOP, F.DPS, F.LEATHER)
	self:addTradeAcquire(RecipeDB, 35590, A.TRAINER, 7868, A.TRAINER, 7869, A.TRAINER, 29507)

	-- Primalstrike Bracers -- 35591
	AddRecipe(35591, 375, 29527, R_COMMON, GAME_TBC, 375, 385, 395, 405, 10659)
	self:addTradeFlags(RecipeDB, 35591, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOP, F.RBOP, F.DPS, F.LEATHER)
	self:addTradeAcquire(RecipeDB, 35591, A.TRAINER, 7868, A.TRAINER, 7869, A.TRAINER, 29507)

	-- Blackstorm Leggings -- 36074
	AddRecipe(36074, 260, 29964, R_COMMON, GAME_TBC, 260, 280, 290, 300, 10659)
	self:addTradeFlags(RecipeDB, 36074, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOP, F.RBOP, F.DPS, F.LEATHER)
	self:addTradeAcquire(RecipeDB, 36074, A.TRAINER, 7868, A.TRAINER, 7869, A.TRAINER, 29507)

	-- Wildfeather Leggings -- 36075
	AddRecipe(36075, 260, 29970, R_COMMON, GAME_TBC, 260, 280, 290, 300, 10661)
	self:addTradeFlags(RecipeDB, 36075, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOP, F.RBOP, F.HEALER, F.CASTER, F.LEATHER)
	self:addTradeAcquire(RecipeDB, 36075, A.TRAINER, 7870, A.TRAINER, 7871, A.TRAINER, 29509)

	-- Dragonstrike Leggings -- 36076
	AddRecipe(36076, 260, 29971, R_COMMON, GAME_TBC, 260, 280, 290, 300, 10657)
	self:addTradeFlags(RecipeDB, 36076, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOP, F.RBOP, F.DPS, F.MAIL)
	self:addTradeAcquire(RecipeDB, 36076, A.TRAINER, 7866, A.TRAINER, 7867, A.TRAINER, 29508)

	-- Primalstorm Breastplate -- 36077
	AddRecipe(36077, 330, 29973, R_COMMON, GAME_TBC, 330, 350, 360, 370, 10659)
	self:addTradeFlags(RecipeDB, 36077, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOP, F.RBOP, F.DPS, F.LEATHER)
	self:addTradeAcquire(RecipeDB, 36077, A.TRAINER, 7868, A.TRAINER, 7869, A.TRAINER, 29507)

	-- Living Crystal Breastplate -- 36078
	AddRecipe(36078, 330, 29974, R_COMMON, GAME_TBC, 330, 350, 360, 370, 10661)
	self:addTradeFlags(RecipeDB, 36078, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOP, F.RBOP, F.HEALER, F.CASTER, F.LEATHER)
	self:addTradeAcquire(RecipeDB, 36078, A.TRAINER, 7870, A.TRAINER, 7871, A.TRAINER, 29509)

	-- Golden Dragonstrike Breastplate -- 36079
	AddRecipe(36079, 330, 29975, R_COMMON, GAME_TBC, 330, 350, 360, 370, 10657)
	self:addTradeFlags(RecipeDB, 36079, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOP, F.RBOP, F.DPS, F.MAIL)
	self:addTradeAcquire(RecipeDB, 36079, A.TRAINER, 7866, A.TRAINER, 7867, A.TRAINER, 29508)

	-- Belt of Natural Power -- 36349
	AddRecipe(36349, 375, 30042, R_EPIC, GAME_TBC, 375, 385, 395, 405)
	self:addTradeFlags(RecipeDB, 36349, F.ALLIANCE, F.HORDE, F.RAID, F.IBOE, F.RBOP, F.DPS, F.LEATHER)
	self:addTradeAcquire(RecipeDB, 36349, A.CUSTOM, 37, A.CUSTOM, 43)

	-- Belt of Deep Shadow -- 36351
	AddRecipe(36351, 375, 30040, R_EPIC, GAME_TBC, 375, 385, 395, 405)
	self:addTradeFlags(RecipeDB, 36351, F.ALLIANCE, F.HORDE, F.RAID, F.IBOE, F.RBOP, F.DPS, F.LEATHER)
	self:addTradeAcquire(RecipeDB, 36351, A.CUSTOM, 37, A.CUSTOM, 43)

	-- Belt of the Black Eagle -- 36352
	AddRecipe(36352, 375, 30046, R_EPIC, GAME_TBC, 375, 385, 395, 405)
	self:addTradeFlags(RecipeDB, 36352, F.ALLIANCE, F.HORDE, F.RAID, F.IBOE, F.RBOP, F.DPS, F.MAIL)
	self:addTradeAcquire(RecipeDB, 36352, A.CUSTOM, 37, A.CUSTOM, 43)

	-- Monsoon Belt -- 36353
	AddRecipe(36353, 375, 30044, R_EPIC, GAME_TBC, 375, 385, 395, 405)
	self:addTradeFlags(RecipeDB, 36353, F.ALLIANCE, F.HORDE, F.RAID, F.IBOE, F.RBOP, F.HEALER, F.CASTER, F.MAIL)
	self:addTradeAcquire(RecipeDB, 36353, A.CUSTOM, 37, A.CUSTOM, 43)

	-- Boots of Natural Grace -- 36355
	AddRecipe(36355, 375, 30041, R_EPIC, GAME_TBC, 375, 385, 395, 405)
	self:addTradeFlags(RecipeDB, 36355, F.ALLIANCE, F.HORDE, F.RAID, F.IBOP, F.RBOP, F.DPS, F.LEATHER)
	self:addTradeAcquire(RecipeDB, 36355, A.CUSTOM, 37, A.CUSTOM, 43)

	-- Boots of Utter Darkness -- 36357
	AddRecipe(36357, 375, 30039, R_EPIC, GAME_TBC, 375, 385, 395, 405)
	self:addTradeFlags(RecipeDB, 36357, F.ALLIANCE, F.HORDE, F.RAID, F.IBOP, F.RBOP, F.DPS, F.LEATHER)
	self:addTradeAcquire(RecipeDB, 36357, A.CUSTOM, 37, A.CUSTOM, 43)

	-- Boots of the Crimson Hawk -- 36358
	AddRecipe(36358, 375, 30045, R_EPIC, GAME_TBC, 375, 385, 395, 405)
	self:addTradeFlags(RecipeDB, 36358, F.ALLIANCE, F.HORDE, F.RAID, F.IBOP, F.RBOP, F.DPS, F.MAIL)
	self:addTradeAcquire(RecipeDB, 36358, A.CUSTOM, 37, A.CUSTOM, 43)

	-- Hurricane Boots -- 36359
	AddRecipe(36359, 375, 30043, R_EPIC, GAME_TBC, 375, 385, 395, 405)
	self:addTradeFlags(RecipeDB, 36359, F.ALLIANCE, F.HORDE, F.RAID, F.IBOP, F.RBOP, F.HEALER, F.CASTER, F.MAIL)
	self:addTradeAcquire(RecipeDB, 36359, A.CUSTOM, 37, A.CUSTOM, 43)

	-- Boots of Shackled Souls -- 39997
	AddRecipe(39997, 375, 32398, R_COMMON, GAME_TBC, 375, 385, 395, 405)
	self:addTradeFlags(RecipeDB, 39997, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOP, F.MAIL, F.ASHTONGUE)
	self:addTradeAcquire(RecipeDB, 39997, A.REPUTATION, FAC.ASHTONGUE, REP.FRIENDLY, 23159)

	-- Greaves of Shackled Souls -- 40001
	AddRecipe(40001, 375, 32400, R_COMMON, GAME_TBC, 375, 385, 395, 405)
	self:addTradeFlags(RecipeDB, 40001, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOP, F.MAIL, F.ASHTONGUE)
	self:addTradeAcquire(RecipeDB, 40001, A.REPUTATION, FAC.ASHTONGUE, REP.HONORED, 23159)

	-- Waistguard of Shackled Souls -- 40002
	AddRecipe(40002, 375, 32397, R_COMMON, GAME_TBC, 375, 385, 395, 405)
	self:addTradeFlags(RecipeDB, 40002, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOP, F.MAIL, F.ASHTONGUE)
	self:addTradeAcquire(RecipeDB, 40002, A.REPUTATION, FAC.ASHTONGUE, REP.HONORED, 23159)

	-- Redeemed Soul Moccasins -- 40003
	AddRecipe(40003, 375, 32394, R_COMMON, GAME_TBC, 375, 385, 395, 405)
	self:addTradeFlags(RecipeDB, 40003, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOP, F.LEATHER, F.ASHTONGUE)
	self:addTradeAcquire(RecipeDB, 40003, A.REPUTATION, FAC.ASHTONGUE, REP.HONORED, 23159)

	-- Redeemed Soul Wristguards -- 40004
	AddRecipe(40004, 375, 32395, R_COMMON, GAME_TBC, 375, 385, 395, 405)
	self:addTradeFlags(RecipeDB, 40004, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOP, F.LEATHER, F.ASHTONGUE)
	self:addTradeAcquire(RecipeDB, 40004, A.REPUTATION, FAC.ASHTONGUE, REP.HONORED, 23159)

	-- Redeemed Soul Legguards -- 40005
	AddRecipe(40005, 375, 32396, R_COMMON, GAME_TBC, 375, 385, 395, 405)
	self:addTradeFlags(RecipeDB, 40005, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOP, F.LEATHER, F.ASHTONGUE)
	self:addTradeAcquire(RecipeDB, 40005, A.REPUTATION, FAC.ASHTONGUE, REP.FRIENDLY, 23159)

	-- Redeemed Soul Cinch -- 40006
	AddRecipe(40006, 375, 32393, R_COMMON, GAME_TBC, 375, 385, 395, 405)
	self:addTradeFlags(RecipeDB, 40006, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOP, F.LEATHER, F.ASHTONGUE)
	self:addTradeAcquire(RecipeDB, 40006, A.REPUTATION, FAC.ASHTONGUE, REP.FRIENDLY, 23159)

	-- Bracers of Renewed Life -- 41156
	AddRecipe(41156, 375, 32582, R_EPIC, GAME_TBC, 375, 385, 395, 405)
	self:addTradeFlags(RecipeDB, 41156, F.ALLIANCE, F.HORDE, F.WORLD_DROP, F.IBOE, F.RBOE, F.HEALER, F.CASTER, F.LEATHER)
	self:addTradeAcquire(RecipeDB, 41156, A.WORLD_DROP, 4)

	-- Shoulderpads of Renewed Life -- 41157
	AddRecipe(41157, 375, 32583, R_EPIC, GAME_TBC, 375, 385, 395, 405)
	self:addTradeFlags(RecipeDB, 41157, F.ALLIANCE, F.HORDE, F.RAID, F.IBOP, F.RBOE, F.HEALER, F.CASTER, F.LEATHER)
	self:addTradeAcquire(RecipeDB, 41157, A.CUSTOM, 27, A.CUSTOM, 34)

	-- Swiftstrike Bracers -- 41158
	AddRecipe(41158, 375, 32580, R_EPIC, GAME_TBC, 375, 385, 395, 405)
	self:addTradeFlags(RecipeDB, 41158, F.ALLIANCE, F.HORDE, F.RAID, F.IBOE, F.RBOE, F.DPS, F.LEATHER)
	self:addTradeAcquire(RecipeDB, 41158, A.CUSTOM, 27, A.CUSTOM, 34)

	-- Swiftstrike Shoulders -- 41160
	AddRecipe(41160, 375, 32581, R_EPIC, GAME_TBC, 375, 385, 395, 405)
	self:addTradeFlags(RecipeDB, 41160, F.ALLIANCE, F.HORDE, F.WORLD_DROP, F.IBOP, F.RBOE, F.DPS, F.LEATHER)
	self:addTradeAcquire(RecipeDB, 41160, A.WORLD_DROP, 4)

	-- Bindings of Lightning Reflexes -- 41161
	AddRecipe(41161, 375, 32574, R_EPIC, GAME_TBC, 375, 385, 395, 405)
	self:addTradeFlags(RecipeDB, 41161, F.ALLIANCE, F.HORDE, F.RAID, F.IBOE, F.RBOE, F.DPS, F.MAIL)
	self:addTradeAcquire(RecipeDB, 41161, A.CUSTOM, 27, A.CUSTOM, 34)

	-- Shoulders of Lightning Reflexes -- 41162
	AddRecipe(41162, 375, 32575, R_EPIC, GAME_TBC, 375, 385, 395, 405)
	self:addTradeFlags(RecipeDB, 41162, F.ALLIANCE, F.HORDE, F.WORLD_DROP, F.IBOP, F.RBOE, F.DPS, F.MAIL)
	self:addTradeAcquire(RecipeDB, 41162, A.WORLD_DROP, 4)

	-- Living Earth Bindings -- 41163
	AddRecipe(41163, 375, 32577, R_EPIC, GAME_TBC, 375, 385, 395, 405)
	self:addTradeFlags(RecipeDB, 41163, F.ALLIANCE, F.HORDE, F.WORLD_DROP, F.IBOE, F.RBOE, F.HEALER, F.CASTER, F.MAIL)
	self:addTradeAcquire(RecipeDB, 41163, A.WORLD_DROP, 4)

	-- Living Earth Shoulders -- 41164
	AddRecipe(41164, 375, 32579, R_EPIC, GAME_TBC, 375, 385, 395, 405)
	self:addTradeFlags(RecipeDB, 41164, F.ALLIANCE, F.HORDE, F.RAID, F.IBOP, F.RBOE, F.HEALER, F.CASTER, F.MAIL)
	self:addTradeAcquire(RecipeDB, 41164, A.CUSTOM, 27, A.CUSTOM, 34)

	-- Cloak of Darkness -- 42546
	AddRecipe(42546, 360, 33122, R_RARE, GAME_TBC, 360, 370, 380, 390)
	self:addTradeFlags(RecipeDB, 42546, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOP, F.DPS, F.CLOAK, F.VIOLETEYE)
	self:addTradeAcquire(RecipeDB, 42546, A.REPUTATION, FAC.VIOLETEYE, REP.EXALTED, 18255)

	-- Shadowprowler's Chestguard -- 42731
	AddRecipe(42731, 365, 33204, R_EPIC, GAME_TBC, 365, 375, 385, 395)
	self:addTradeFlags(RecipeDB, 42731, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOP, F.DPS, F.LEATHER, F.VIOLETEYE)
	self:addTradeAcquire(RecipeDB, 42731, A.REPUTATION, FAC.VIOLETEYE, REP.REVERED, 18255)

	-- Knothide Ammo Pouch -- 44343
	AddRecipe(44343, 315, 34099, R_UNCOMMON, GAME_TBC, 315, 325, 335, 345)
	self:addTradeFlags(RecipeDB, 44343, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.AMMO)
	self:addTradeAcquire(RecipeDB, 44343, A.TRAINER, 18754, A.TRAINER, 18771, A.TRAINER, 19187, A.TRAINER, 21087, A.TRAINER, 33681, A.TRAINER, 33612, A.TRAINER, 33635)

	-- Knothide Quiver -- 44344
	AddRecipe(44344, 315, 34100, R_UNCOMMON, GAME_TBC, 315, 325, 335, 345)
	self:addTradeFlags(RecipeDB, 44344, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP)
	self:addTradeAcquire(RecipeDB, 44344, A.TRAINER, 18754, A.TRAINER, 18771, A.TRAINER, 19187, A.TRAINER, 21087, A.TRAINER, 33681, A.TRAINER, 33612, A.TRAINER, 33635)

	-- Quiver of a Thousand Feathers -- 44359
	AddRecipe(44359, 350, 34105, R_COMMON, GAME_TBC, 350, 360, 370, 380)
	self:addTradeFlags(RecipeDB, 44359, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOP, F.LOWERCITY)
	self:addTradeAcquire(RecipeDB, 44359, A.REPUTATION, FAC.LOWERCITY, REP.REVERED, 21655)

	-- Netherscale Ammo Pouch -- 44768
	AddRecipe(44768, 350, 34106, R_COMMON, GAME_TBC, 350, 360, 370, 380)
	self:addTradeFlags(RecipeDB, 44768, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOP, F.AMMO, F.HELLFIRE)
	self:addTradeAcquire(RecipeDB, 44768, A.REPUTATION, FAC.THRALLMAR, REP.REVERED, 17585, A.REPUTATION, FAC.HONOR_HOLD, REP.REVERED, 17657)

	-- Glove Reinforcements -- 44770
	AddRecipe(44770, 350, 34207, R_UNCOMMON, GAME_TBC, 350, 355, 360, 365)
	self:addTradeFlags(RecipeDB, 44770, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP)
	self:addTradeAcquire(RecipeDB, 44770, A.TRAINER, 18754, A.TRAINER, 18771, A.TRAINER, 19187, A.TRAINER, 21087, A.TRAINER, 33681, A.TRAINER, 33612, A.TRAINER, 33635)

	-- Winter Boots -- 44953
	AddRecipe(44953, 285, 34086, R_UNCOMMON, GAME_TBC, 285, 285, 285, 285)
	self:addTradeFlags(RecipeDB, 44953, F.ALLIANCE, F.HORDE, F.VENDOR, F.SEASONAL, F.IBOE, F.RBOP, F.CLOTH)
	self:addTradeAcquire(RecipeDB, 44953, A.SEASONAL, 1, A.VENDOR, 13420, A.VENDOR, 13433)

	-- Heavy Knothide Armor Kit -- 44970
	AddRecipe(44970, 350, 34330, R_COMMON, GAME_TBC, 350, 355, 360, 365)
	self:addTradeFlags(RecipeDB, 44970, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP)
	self:addTradeAcquire(RecipeDB, 44970, A.TRAINER, 18754, A.TRAINER, 18771, A.TRAINER, 19187, A.TRAINER, 21087, A.TRAINER, 33681, A.TRAINER, 33612, A.TRAINER, 33635)

	-- Leatherworker's Satchel -- 45100
	AddRecipe(45100, 300, 34482, R_UNCOMMON, GAME_TBC, 300, 310, 320, 330)
	self:addTradeFlags(RecipeDB, 45100, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP)
	self:addTradeAcquire(RecipeDB, 45100, A.TRAINER, 18754, A.TRAINER, 18771, A.TRAINER, 19187, A.TRAINER, 21087, A.TRAINER, 33681, A.TRAINER, 33612, A.TRAINER, 33635)

	-- Bag of Many Hides -- 45117
	AddRecipe(45117, 360, 34490, R_UNCOMMON, GAME_TBC, 360, 370, 380, 390)
	self:addTradeFlags(RecipeDB, 45117, F.ALLIANCE, F.HORDE, F.MOB_DROP, F.IBOE, F.RBOP)
	self:addTradeAcquire(RecipeDB, 45117, A.MOB, 22143, A.MOB, 22144, A.MOB, 22148, A.MOB, 23022)

	-- Leather Gauntlets of the Sun -- 46132
	AddRecipe(46132, 365, 34372, R_EPIC, GAME_TBC, 365, 375, 392, 410)
	self:addTradeFlags(RecipeDB, 46132, F.ALLIANCE, F.HORDE, F.RAID, F.IBOE, F.RBOE, F.HEALER, F.CASTER, F.LEATHER)
	self:addTradeAcquire(RecipeDB, 46132, A.CUSTOM, 24)

	-- Fletcher's Gloves of the Phoenix -- 46133
	AddRecipe(46133, 365, 34374, R_EPIC, GAME_TBC, 365, 375, 392, 410)
	self:addTradeFlags(RecipeDB, 46133, F.ALLIANCE, F.HORDE, F.RAID, F.IBOE, F.RBOE, F.DPS, F.MAIL)
	self:addTradeAcquire(RecipeDB, 46133, A.CUSTOM, 24)

	-- Gloves of Immortal Dusk -- 46134
	AddRecipe(46134, 365, 34370, R_EPIC, GAME_TBC, 365, 375, 392, 410)
	self:addTradeFlags(RecipeDB, 46134, F.ALLIANCE, F.HORDE, F.RAID, F.IBOE, F.RBOP, F.DPS, F.LEATHER)
	self:addTradeAcquire(RecipeDB, 46134, A.CUSTOM, 24)

	-- Sun-Drenched Scale Gloves -- 46135
	AddRecipe(46135, 365, 34376, R_EPIC, GAME_TBC, 365, 375, 392, 410)
	self:addTradeFlags(RecipeDB, 46135, F.ALLIANCE, F.HORDE, F.RAID, F.IBOE, F.RBOP, F.HEALER, F.CASTER, F.MAIL)
	self:addTradeAcquire(RecipeDB, 46135, A.CUSTOM, 24)

	-- Leather Chestguard of the Sun -- 46136
	AddRecipe(46136, 365, 34371, R_EPIC, GAME_TBC, 365, 375, 392, 410)
	self:addTradeFlags(RecipeDB, 46136, F.ALLIANCE, F.HORDE, F.RAID, F.IBOP, F.RBOE, F.HEALER, F.CASTER, F.LEATHER)
	self:addTradeAcquire(RecipeDB, 46136, A.CUSTOM, 24)

	-- Embrace of the Phoenix -- 46137
	AddRecipe(46137, 365, 34373, R_EPIC, GAME_TBC, 365, 375, 392, 410)
	self:addTradeFlags(RecipeDB, 46137, F.ALLIANCE, F.HORDE, F.RAID, F.IBOP, F.RBOE, F.DPS, F.MAIL)
	self:addTradeAcquire(RecipeDB, 46137, A.CUSTOM, 24)

	-- Carapace of Sun and Shadow -- 46138
	AddRecipe(46138, 365, 34369, R_EPIC, GAME_TBC, 365, 375, 392, 410)
	self:addTradeFlags(RecipeDB, 46138, F.ALLIANCE, F.HORDE, F.RAID, F.IBOP, F.RBOE, F.DPS, F.LEATHER)
	self:addTradeAcquire(RecipeDB, 46138, A.CUSTOM, 24)

	-- Sun-Drenched Scale Chestguard -- 46139
	AddRecipe(46139, 365, 34375, R_EPIC, GAME_TBC, 365, 375, 392, 410)
	self:addTradeFlags(RecipeDB, 46139, F.ALLIANCE, F.HORDE, F.RAID, F.IBOP, F.RBOE, F.HEALER, F.CASTER, F.MAIL)
	self:addTradeAcquire(RecipeDB, 46139, A.CUSTOM, 24)

	-- Heavy Borean Leather -- 50936
	AddRecipe(50936, 390, 38425, R_COMMON, GAME_WOTLK, 390, 390, 395, 405)
	self:addTradeFlags(RecipeDB, 50936, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.LEATHER)
	self:addTradeAcquire(RecipeDB, 50936, A.TRAINER, 26911, A.TRAINER, 26961, A.TRAINER, 26996, A.TRAINER, 26998, A.TRAINER, 28700, A.TRAINER, 33581)

	-- Iceborne Chestguard -- 50938
	AddRecipe(50938, 375, 38408, R_COMMON, GAME_WOTLK, 375, 390, 400, 410)
	self:addTradeFlags(RecipeDB, 50938, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.HEALER, F.CASTER, F.LEATHER)
	self:addTradeAcquire(RecipeDB, 50938, A.TRAINER, 26911, A.TRAINER, 26961, A.TRAINER, 26996, A.TRAINER, 26998, A.TRAINER, 28700, A.TRAINER, 33581)

	-- Iceborne Leggings -- 50939
	AddRecipe(50939, 370, 38410, R_COMMON, GAME_WOTLK, 370, 385, 395, 405)
	self:addTradeFlags(RecipeDB, 50939, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.HEALER, F.CASTER, F.LEATHER)
	self:addTradeAcquire(RecipeDB, 50939, A.TRAINER, 26911, A.TRAINER, 26961, A.TRAINER, 26996, A.TRAINER, 26998, A.TRAINER, 28700, A.TRAINER, 33581)

	-- Iceborne Shoulderpads -- 50940
	AddRecipe(50940, 380, 38411, R_COMMON, GAME_WOTLK, 380, 395, 405, 415)
	self:addTradeFlags(RecipeDB, 50940, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.HEALER, F.CASTER, F.LEATHER)
	self:addTradeAcquire(RecipeDB, 50940, A.TRAINER, 26911, A.TRAINER, 26961, A.TRAINER, 26996, A.TRAINER, 26998, A.TRAINER, 28700, A.TRAINER, 33581)

	-- Iceborne Gloves -- 50941
	AddRecipe(50941, 370, 38409, R_COMMON, GAME_WOTLK, 370, 385, 395, 405)
	self:addTradeFlags(RecipeDB, 50941, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.HEALER, F.CASTER, F.LEATHER)
	self:addTradeAcquire(RecipeDB, 50941, A.TRAINER, 26911, A.TRAINER, 26961, A.TRAINER, 26996, A.TRAINER, 26998, A.TRAINER, 28700, A.TRAINER, 33581)

	-- Iceborne Boots -- 50942
	AddRecipe(50942, 375, 38407, R_COMMON, GAME_WOTLK, 375, 390, 400, 410)
	self:addTradeFlags(RecipeDB, 50942, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.HEALER, F.CASTER, F.LEATHER)
	self:addTradeAcquire(RecipeDB, 50942, A.TRAINER, 26911, A.TRAINER, 26961, A.TRAINER, 26996, A.TRAINER, 26998, A.TRAINER, 28700, A.TRAINER, 33581)

	-- Iceborne Belt -- 50943
	AddRecipe(50943, 380, 38406, R_COMMON, GAME_WOTLK, 380, 380, 387, 395)
	self:addTradeFlags(RecipeDB, 50943, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.HEALER, F.CASTER, F.LEATHER)
	self:addTradeAcquire(RecipeDB, 50943, A.TRAINER, 26911, A.TRAINER, 26961, A.TRAINER, 26996, A.TRAINER, 26998, A.TRAINER, 28700, A.TRAINER, 33581)

	-- Arctic Chestpiece -- 50944
	AddRecipe(50944, 370, 38400, R_UNCOMMON, GAME_WOTLK, 370, 385, 395, 405)
	self:addTradeFlags(RecipeDB, 50944, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.DPS, F.LEATHER)
	self:addTradeAcquire(RecipeDB, 50944, A.TRAINER, 26911, A.TRAINER, 26961, A.TRAINER, 26996, A.TRAINER, 26998, A.TRAINER, 28700, A.TRAINER, 33581)

	-- Arctic Leggings -- 50945
	AddRecipe(50945, 375, 38401, R_UNCOMMON, GAME_WOTLK, 375, 390, 400, 410)
	self:addTradeFlags(RecipeDB, 50945, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.DPS, F.LEATHER)
	self:addTradeAcquire(RecipeDB, 50945, A.TRAINER, 26911, A.TRAINER, 26961, A.TRAINER, 26996, A.TRAINER, 26998, A.TRAINER, 28700, A.TRAINER, 33581)

	-- Arctic Shoulderpads -- 50946
	AddRecipe(50946, 380, 38402, R_UNCOMMON, GAME_WOTLK, 380, 395, 405, 415)
	self:addTradeFlags(RecipeDB, 50946, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.DPS, F.LEATHER)
	self:addTradeAcquire(RecipeDB, 50946, A.TRAINER, 26911, A.TRAINER, 26961, A.TRAINER, 26996, A.TRAINER, 26998, A.TRAINER, 28700, A.TRAINER, 33581)

	-- Arctic Gloves -- 50947
	AddRecipe(50947, 375, 38403, R_UNCOMMON, GAME_WOTLK, 375, 390, 400, 410)
	self:addTradeFlags(RecipeDB, 50947, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.DPS, F.LEATHER)
	self:addTradeAcquire(RecipeDB, 50947, A.TRAINER, 26911, A.TRAINER, 26961, A.TRAINER, 26996, A.TRAINER, 26998, A.TRAINER, 28700, A.TRAINER, 33581)

	-- Arctic Boots -- 50948
	AddRecipe(50948, 370, 38404, R_UNCOMMON, GAME_WOTLK, 370, 385, 395, 405)
	self:addTradeFlags(RecipeDB, 50948, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.DPS, F.LEATHER)
	self:addTradeAcquire(RecipeDB, 50948, A.TRAINER, 26911, A.TRAINER, 26961, A.TRAINER, 26996, A.TRAINER, 26998, A.TRAINER, 28700, A.TRAINER, 33581)

	-- Arctic Belt -- 50949
	AddRecipe(50949, 380, 38405, R_UNCOMMON, GAME_WOTLK, 380, 395, 405, 415)
	self:addTradeFlags(RecipeDB, 50949, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.DPS, F.LEATHER)
	self:addTradeAcquire(RecipeDB, 50949, A.TRAINER, 26911, A.TRAINER, 26961, A.TRAINER, 26996, A.TRAINER, 26998, A.TRAINER, 28700, A.TRAINER, 33581)

	-- Frostscale Chestguard -- 50950
	AddRecipe(50950, 375, 38414, R_COMMON, GAME_WOTLK, 375, 390, 400, 410)
	self:addTradeFlags(RecipeDB, 50950, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.DPS, F.MAIL)
	self:addTradeAcquire(RecipeDB, 50950, A.TRAINER, 26911, A.TRAINER, 26961, A.TRAINER, 26996, A.TRAINER, 26998, A.TRAINER, 28700, A.TRAINER, 33581)

	-- Frostscale Leggings -- 50951
	AddRecipe(50951, 370, 38416, R_COMMON, GAME_WOTLK, 370, 385, 395, 405)
	self:addTradeFlags(RecipeDB, 50951, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.DPS, F.MAIL)
	self:addTradeAcquire(RecipeDB, 50951, A.TRAINER, 26911, A.TRAINER, 26961, A.TRAINER, 26996, A.TRAINER, 26998, A.TRAINER, 28700, A.TRAINER, 33581)

	-- Frostscale Shoulders -- 50952
	AddRecipe(50952, 375, 38424, R_COMMON, GAME_WOTLK, 375, 390, 400, 410)
	self:addTradeFlags(RecipeDB, 50952, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.DPS, F.MAIL)
	self:addTradeAcquire(RecipeDB, 50952, A.TRAINER, 26911, A.TRAINER, 26961, A.TRAINER, 26996, A.TRAINER, 26998, A.TRAINER, 28700, A.TRAINER, 33581)

	-- Frostscale Gloves -- 50953
	AddRecipe(50953, 380, 38415, R_COMMON, GAME_WOTLK, 380, 395, 405, 415)
	self:addTradeFlags(RecipeDB, 50953, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.DPS, F.MAIL)
	self:addTradeAcquire(RecipeDB, 50953, A.TRAINER, 26911, A.TRAINER, 26961, A.TRAINER, 26996, A.TRAINER, 26998, A.TRAINER, 28700, A.TRAINER, 33581)

	-- Frostscale Boots -- 50954
	AddRecipe(50954, 380, 38413, R_COMMON, GAME_WOTLK, 380, 395, 405, 415)
	self:addTradeFlags(RecipeDB, 50954, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.DPS, F.MAIL)
	self:addTradeAcquire(RecipeDB, 50954, A.TRAINER, 26911, A.TRAINER, 26961, A.TRAINER, 26996, A.TRAINER, 26998, A.TRAINER, 28700, A.TRAINER, 33581)

	-- Frostscale Belt -- 50955
	AddRecipe(50955, 370, 38412, R_COMMON, GAME_WOTLK, 370, 385, 395, 405)
	self:addTradeFlags(RecipeDB, 50955, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.DPS, F.MAIL)
	self:addTradeAcquire(RecipeDB, 50955, A.TRAINER, 26911, A.TRAINER, 26961, A.TRAINER, 26996, A.TRAINER, 26998, A.TRAINER, 28700, A.TRAINER, 33581)

	-- Nerubian Chestguard -- 50956
	AddRecipe(50956, 375, 38420, R_COMMON, GAME_WOTLK, 375, 390, 400, 410)
	self:addTradeFlags(RecipeDB, 50956, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.HEALER, F.CASTER, F.MAIL)
	self:addTradeAcquire(RecipeDB, 50956, A.TRAINER, 26911, A.TRAINER, 26961, A.TRAINER, 26996, A.TRAINER, 26998, A.TRAINER, 28700, A.TRAINER, 33581)

	-- Nerubian Legguards -- 50957
	AddRecipe(50957, 370, 38422, R_UNCOMMON, GAME_WOTLK, 370, 385, 395, 405)
	self:addTradeFlags(RecipeDB, 50957, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.HEALER, F.CASTER, F.MAIL)
	self:addTradeAcquire(RecipeDB, 50957, A.TRAINER, 26911, A.TRAINER, 26961, A.TRAINER, 26996, A.TRAINER, 26998, A.TRAINER, 28700, A.TRAINER, 33581)

	-- Nerubian Shoulders -- 50958
	AddRecipe(50958, 380, 38417, R_COMMON, GAME_WOTLK, 380, 395, 405, 415)
	self:addTradeFlags(RecipeDB, 50958, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.HEALER, F.CASTER, F.MAIL)
	self:addTradeAcquire(RecipeDB, 50958, A.TRAINER, 26911, A.TRAINER, 26961, A.TRAINER, 26996, A.TRAINER, 26998, A.TRAINER, 28700, A.TRAINER, 33581)

	-- Nerubian Gloves -- 50959
	AddRecipe(50959, 370, 38421, R_COMMON, GAME_WOTLK, 370, 385, 395, 405)
	self:addTradeFlags(RecipeDB, 50959, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.HEALER, F.CASTER, F.MAIL)
	self:addTradeAcquire(RecipeDB, 50959, A.TRAINER, 26911, A.TRAINER, 26961, A.TRAINER, 26996, A.TRAINER, 26998, A.TRAINER, 28700, A.TRAINER, 33581)

	-- Nerubian Boots -- 50960
	AddRecipe(50960, 380, 38419, R_COMMON, GAME_WOTLK, 380, 395, 405, 415)
	self:addTradeFlags(RecipeDB, 50960, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.HEALER, F.CASTER, F.MAIL)
	self:addTradeAcquire(RecipeDB, 50960, A.TRAINER, 26911, A.TRAINER, 26961, A.TRAINER, 26996, A.TRAINER, 26998, A.TRAINER, 28700, A.TRAINER, 33581)

	-- Nerubian Belt -- 50961
	AddRecipe(50961, 375, 38418, R_COMMON, GAME_WOTLK, 375, 390, 400, 410)
	self:addTradeFlags(RecipeDB, 50961, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.HEALER, F.CASTER, F.MAIL)
	self:addTradeAcquire(RecipeDB, 50961, A.TRAINER, 26911, A.TRAINER, 26961, A.TRAINER, 26996, A.TRAINER, 26998, A.TRAINER, 28700, A.TRAINER, 33581)

	-- Borean Armor Kit -- 50962
	AddRecipe(50962, 350, 38375, R_COMMON, GAME_WOTLK, 350, 375, 380, 385)
	self:addTradeFlags(RecipeDB, 50962, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP)
	self:addTradeAcquire(RecipeDB, 50962, A.TRAINER, 26911, A.TRAINER, 26961, A.TRAINER, 26996, A.TRAINER, 26998, A.TRAINER, 28700, A.TRAINER, 33581)

	-- Heavy Borean Armor Kit -- 50963
	AddRecipe(50963, 395, 38376, R_UNCOMMON, GAME_WOTLK, 395, 400, 402, 405)
	self:addTradeFlags(RecipeDB, 50963, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP)
	self:addTradeAcquire(RecipeDB, 50963, A.TRAINER, 26911, A.TRAINER, 26961, A.TRAINER, 26996, A.TRAINER, 26998, A.TRAINER, 28700, A.TRAINER, 33581)

	-- Jormungar Leg Armor -- 50964
	AddRecipe(50964, 405, 38371, R_COMMON, GAME_WOTLK, 405, 410, 415, 420)
	self:addTradeFlags(RecipeDB, 50964, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.DPS)
	self:addTradeAcquire(RecipeDB, 50964, A.TRAINER, 26911, A.TRAINER, 26961, A.TRAINER, 26996, A.TRAINER, 26998, A.TRAINER, 28700, A.TRAINER, 33581)

	-- Frosthide Leg Armor -- 50965
	AddRecipe(50965, 425, 38373, R_EPIC, GAME_WOTLK, 425, 435, 440, 445)
	self:addTradeFlags(RecipeDB, 50965, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.DPS)
	self:addTradeAcquire(RecipeDB, 50965, A.TRAINER, 26911, A.TRAINER, 26961, A.TRAINER, 26996, A.TRAINER, 26998, A.TRAINER, 28700, A.TRAINER, 33581)

	-- Nerubian Leg Armor -- 50966
	AddRecipe(50966, 400, 38372, R_COMMON, GAME_WOTLK, 400, 405, 410, 415)
	self:addTradeFlags(RecipeDB, 50966, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.DPS)
	self:addTradeAcquire(RecipeDB, 50966, A.TRAINER, 26911, A.TRAINER, 26961, A.TRAINER, 26996, A.TRAINER, 26998, A.TRAINER, 28700, A.TRAINER, 33581)

	-- Icescale Leg Armor -- 50967
	AddRecipe(50967, 425, 38374, R_EPIC, GAME_WOTLK, 425, 435, 440, 445)
	self:addTradeFlags(RecipeDB, 50967, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.DPS)
	self:addTradeAcquire(RecipeDB, 50967, A.TRAINER, 26911, A.TRAINER, 26961, A.TRAINER, 26996, A.TRAINER, 26998, A.TRAINER, 28700, A.TRAINER, 33581)

	-- Trapper's Traveling Pack -- 50970
	AddRecipe(50970, 415, 38399, R_RARE, GAME_WOTLK, 415, 420, 422, 425)
	self:addTradeFlags(RecipeDB, 50970, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOP, F.KALUAK)
	self:addTradeAcquire(RecipeDB, 50970, A.REPUTATION, FAC.KALUAK, REP.REVERED, 31916, A.REPUTATION, FAC.KALUAK, REP.REVERED, 32763)

	-- Mammoth Mining Bag -- 50971
	AddRecipe(50971, 415, 38347, R_RARE, GAME_WOTLK, 415, 420, 422, 425)
	self:addTradeFlags(RecipeDB, 50971, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOP, F.HODIR)
	self:addTradeAcquire(RecipeDB, 50971, A.REPUTATION, FAC.HODIR, REP.HONORED, 32540)

	-- Black Chitinguard Boots -- 51568
	AddRecipe(51568, 400, 38590, R_COMMON, GAME_WOTLK, 400, 415, 425, 435)
	self:addTradeFlags(RecipeDB, 51568, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.DPS, F.LEATHER)
	self:addTradeAcquire(RecipeDB, 51568, A.TRAINER, 26911, A.TRAINER, 26961, A.TRAINER, 26996, A.TRAINER, 26998, A.TRAINER, 28700, A.TRAINER, 33581)

	-- Dark Arctic Leggings -- 51569
	AddRecipe(51569, 395, 38591, R_COMMON, GAME_WOTLK, 395, 410, 420, 430)
	self:addTradeFlags(RecipeDB, 51569, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.DPS, F.LEATHER)
	self:addTradeAcquire(RecipeDB, 51569, A.TRAINER, 26911, A.TRAINER, 26961, A.TRAINER, 26996, A.TRAINER, 26998, A.TRAINER, 28700, A.TRAINER, 33581)

	-- Dark Arctic Chestpiece -- 51570
	AddRecipe(51570, 395, 38592, R_COMMON, GAME_WOTLK, 395, 410, 420, 430)
	self:addTradeFlags(RecipeDB, 51570, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.DPS, F.LEATHER)
	self:addTradeAcquire(RecipeDB, 51570, A.TRAINER, 26911, A.TRAINER, 26961, A.TRAINER, 26996, A.TRAINER, 26998, A.TRAINER, 28700, A.TRAINER, 33581)

	-- Arctic Wristguards -- 51571
	AddRecipe(51571, 385, 38433, R_COMMON, GAME_WOTLK, 385, 400, 410, 420)
	self:addTradeFlags(RecipeDB, 51571, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.DPS, F.LEATHER)
	self:addTradeAcquire(RecipeDB, 51571, A.TRAINER, 26911, A.TRAINER, 26961, A.TRAINER, 26996, A.TRAINER, 26998, A.TRAINER, 28700, A.TRAINER, 33581)

	-- Arctic Helm -- 51572
	AddRecipe(51572, 385, 38437, R_COMMON, GAME_WOTLK, 385, 400, 410, 420)
	self:addTradeFlags(RecipeDB, 51572, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.DPS, F.LEATHER)
	self:addTradeAcquire(RecipeDB, 51572, A.TRAINER, 26911, A.TRAINER, 26961, A.TRAINER, 26996, A.TRAINER, 26998, A.TRAINER, 28700, A.TRAINER, 33581)

	-- Bracers of Shackled Souls -- 52733
	AddRecipe(52733, 375, 32399, R_COMMON, GAME_WOTLK, 375, 385, 395, 405)
	self:addTradeFlags(RecipeDB, 52733, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOP, F.MAIL, F.ASHTONGUE)
	self:addTradeAcquire(RecipeDB, 52733, A.REPUTATION, FAC.ASHTONGUE, REP.FRIENDLY, 23159)

	-- Cloak of Tormented Skies -- 55199
	AddRecipe(55199, 395, 41238, R_COMMON, GAME_WOTLK, 395, 405, 415, 425)
	self:addTradeFlags(RecipeDB, 55199, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.TANK, F.CLOAK)
	self:addTradeAcquire(RecipeDB, 55199, A.TRAINER, 26911, A.TRAINER, 26961, A.TRAINER, 26996, A.TRAINER, 26998, A.TRAINER, 28700, A.TRAINER, 33581)

	-- Fur Lining - Attack Power -- 57683
	AddRecipe(57683, 400, nil, R_COMMON, GAME_WOTLK, 400, 425, 430, 435)
	self:addTradeFlags(RecipeDB, 57683, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.DPS)
	self:addTradeAcquire(RecipeDB, 57683, A.TRAINER, 26911, A.TRAINER, 26961, A.TRAINER, 26996, A.TRAINER, 26998, A.TRAINER, 28700, A.TRAINER, 33581)

	-- Fur Lining - Stamina -- 57690
	AddRecipe(57690, 400, nil, R_COMMON, GAME_WOTLK, 400, 425, 430, 435)
	self:addTradeFlags(RecipeDB, 57690, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP)
	self:addTradeAcquire(RecipeDB, 57690, A.TRAINER, 26911, A.TRAINER, 26961, A.TRAINER, 26996, A.TRAINER, 26998, A.TRAINER, 28700, A.TRAINER, 33581)

	-- Fur Lining - Spell Power -- 57691
	AddRecipe(57691, 400, nil, R_COMMON, GAME_WOTLK, 400, 425, 430, 435)
	self:addTradeFlags(RecipeDB, 57691, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.HEALER, F.CASTER)
	self:addTradeAcquire(RecipeDB, 57691, A.TRAINER, 26911, A.TRAINER, 26961, A.TRAINER, 26996, A.TRAINER, 26998, A.TRAINER, 28700, A.TRAINER, 33581)

	-- Fur Lining - Fire Resist -- 57692
	AddRecipe(57692, 400, nil, R_RARE, GAME_WOTLK, 400, 425, 430, 435)
	self:addTradeFlags(RecipeDB, 57692, F.ALLIANCE, F.HORDE, F.MOB_DROP, F.IBOE, F.RBOP)
	self:addTradeAcquire(RecipeDB, 57692, A.MOB, 30921)

	-- Fur Lining - Frost Resist -- 57694
	AddRecipe(57694, 400, nil, R_RARE, GAME_WOTLK, 400, 425, 430, 435)
	self:addTradeFlags(RecipeDB, 57694, F.ALLIANCE, F.HORDE, F.MOB_DROP, F.IBOE, F.RBOP)
	self:addTradeAcquire(RecipeDB, 57694, A.MOB, 32289)

	-- Fur Lining - Shadow Resist -- 57696
	AddRecipe(57696, 400, nil, R_RARE, GAME_WOTLK, 400, 425, 430, 435)
	self:addTradeFlags(RecipeDB, 57696, F.ALLIANCE, F.HORDE, F.MOB_DROP, F.IBOE, F.RBOP)
	self:addTradeAcquire(RecipeDB, 57696, A.MOB, 32349)

	-- Fur Lining - Nature Resist -- 57699
	AddRecipe(57699, 400, nil, R_RARE, GAME_WOTLK, 400, 425, 430, 435)
	self:addTradeFlags(RecipeDB, 57699, F.ALLIANCE, F.HORDE, F.MOB_DROP, F.IBOE, F.RBOP)
	self:addTradeAcquire(RecipeDB, 57699, A.MOB, 32290)

	-- Fur Lining - Arcane Resist -- 57701
	AddRecipe(57701, 400, nil, R_RARE, GAME_WOTLK, 400, 425, 430, 435)
	self:addTradeFlags(RecipeDB, 57701, F.ALLIANCE, F.HORDE, F.MOB_DROP, F.IBOE, F.RBOP)
	self:addTradeAcquire(RecipeDB, 57701, A.MOB, 31702, A.MOB, 32297)

	-- Jormungar Leg Reinforcements -- 60583
	AddRecipe(60583, 405, nil, R_COMMON, GAME_WOTLK, 405, 405, 405, 410)
	self:addTradeFlags(RecipeDB, 60583, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.DPS)
	self:addTradeAcquire(RecipeDB, 60583, A.TRAINER, 26911, A.TRAINER, 26961, A.TRAINER, 26996, A.TRAINER, 26998, A.TRAINER, 28700, A.TRAINER, 33581)

	-- Nerubian Leg Reinforcements -- 60584
	AddRecipe(60584, 400, nil, R_COMMON, GAME_WOTLK, 400, 400, 400, 405)
	self:addTradeFlags(RecipeDB, 60584, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.DPS)
	self:addTradeAcquire(RecipeDB, 60584, A.TRAINER, 26911, A.TRAINER, 26961, A.TRAINER, 26996, A.TRAINER, 26998, A.TRAINER, 28700, A.TRAINER, 33581)

	-- Frostscale Bracers -- 60599
	AddRecipe(60599, 385, 38436, R_COMMON, GAME_WOTLK, 385, 400, 410, 420)
	self:addTradeFlags(RecipeDB, 60599, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.DPS, F.MAIL)
	self:addTradeAcquire(RecipeDB, 60599, A.TRAINER, 26911, A.TRAINER, 26961, A.TRAINER, 26996, A.TRAINER, 26998, A.TRAINER, 28700, A.TRAINER, 33581)

	-- Frostscale Helm -- 60600
	AddRecipe(60600, 385, 38440, R_COMMON, GAME_WOTLK, 385, 400, 410, 420)
	self:addTradeFlags(RecipeDB, 60600, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.DPS, F.MAIL)
	self:addTradeAcquire(RecipeDB, 60600, A.TRAINER, 26911, A.TRAINER, 26961, A.TRAINER, 26996, A.TRAINER, 26998, A.TRAINER, 28700, A.TRAINER, 33581)

	-- Dark Frostscale Leggings -- 60601
	AddRecipe(60601, 395, 44436, R_COMMON, GAME_WOTLK, 395, 410, 420, 430)
	self:addTradeFlags(RecipeDB, 60601, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.DPS, F.MAIL)
	self:addTradeAcquire(RecipeDB, 60601, A.TRAINER, 26911, A.TRAINER, 26961, A.TRAINER, 26996, A.TRAINER, 26998, A.TRAINER, 28700, A.TRAINER, 33581)

	-- Dark Frostscale Breastplate -- 60604
	AddRecipe(60604, 395, 44437, R_COMMON, GAME_WOTLK, 395, 410, 420, 430)
	self:addTradeFlags(RecipeDB, 60604, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.DPS, F.MAIL)
	self:addTradeAcquire(RecipeDB, 60604, A.TRAINER, 26911, A.TRAINER, 26961, A.TRAINER, 26996, A.TRAINER, 26998, A.TRAINER, 28700, A.TRAINER, 33581)

	-- Dragonstompers -- 60605
	AddRecipe(60605, 400, 44438, R_COMMON, GAME_WOTLK, 400, 415, 425, 435)
	self:addTradeFlags(RecipeDB, 60605, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.DPS, F.MAIL)
	self:addTradeAcquire(RecipeDB, 60605, A.TRAINER, 26911, A.TRAINER, 26961, A.TRAINER, 26996, A.TRAINER, 26998, A.TRAINER, 28700, A.TRAINER, 33581)

	-- Iceborne Wristguards -- 60607
	AddRecipe(60607, 385, 38434, R_COMMON, GAME_WOTLK, 385, 400, 410, 420)
	self:addTradeFlags(RecipeDB, 60607, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.HEALER, F.CASTER, F.LEATHER)
	self:addTradeAcquire(RecipeDB, 60607, A.TRAINER, 26911, A.TRAINER, 26961, A.TRAINER, 26996, A.TRAINER, 26998, A.TRAINER, 28700, A.TRAINER, 33581)

	-- Iceborne Helm -- 60608
	AddRecipe(60608, 385, 38438, R_COMMON, GAME_WOTLK, 385, 400, 410, 420)
	self:addTradeFlags(RecipeDB, 60608, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.HEALER, F.CASTER, F.LEATHER)
	self:addTradeAcquire(RecipeDB, 60608, A.TRAINER, 26911, A.TRAINER, 26961, A.TRAINER, 26996, A.TRAINER, 26998, A.TRAINER, 28700, A.TRAINER, 33581)

	-- Dark Iceborne Leggings -- 60611
	AddRecipe(60611, 395, 44440, R_COMMON, GAME_WOTLK, 395, 410, 420, 430)
	self:addTradeFlags(RecipeDB, 60611, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.HEALER, F.CASTER, F.LEATHER)
	self:addTradeAcquire(RecipeDB, 60611, A.TRAINER, 26911, A.TRAINER, 26961, A.TRAINER, 26996, A.TRAINER, 26998, A.TRAINER, 28700, A.TRAINER, 33581)

	-- Dark Iceborne Chestguard -- 60613
	AddRecipe(60613, 395, 44441, R_COMMON, GAME_WOTLK, 395, 410, 420, 430)
	self:addTradeFlags(RecipeDB, 60613, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.HEALER, F.CASTER, F.LEATHER)
	self:addTradeAcquire(RecipeDB, 60613, A.TRAINER, 26911, A.TRAINER, 26961, A.TRAINER, 26996, A.TRAINER, 26998, A.TRAINER, 28700, A.TRAINER, 33581)

	-- Bugsquashers -- 60620
	AddRecipe(60620, 400, 44442, R_COMMON, GAME_WOTLK, 400, 415, 425, 435)
	self:addTradeFlags(RecipeDB, 60620, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.HEALER, F.CASTER, F.LEATHER)
	self:addTradeAcquire(RecipeDB, 60620, A.TRAINER, 26911, A.TRAINER, 26961, A.TRAINER, 26996, A.TRAINER, 26998, A.TRAINER, 28700, A.TRAINER, 33581)

	-- Nerubian Bracers -- 60622
	AddRecipe(60622, 385, 38435, R_COMMON, GAME_WOTLK, 385, 400, 410, 420)
	self:addTradeFlags(RecipeDB, 60622, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.HEALER, F.CASTER, F.MAIL)
	self:addTradeAcquire(RecipeDB, 60622, A.TRAINER, 26911, A.TRAINER, 26961, A.TRAINER, 26996, A.TRAINER, 26998, A.TRAINER, 28700, A.TRAINER, 33581)

	-- Nerubian Helm -- 60624
	AddRecipe(60624, 385, 38439, R_COMMON, GAME_WOTLK, 385, 400, 410, 420)
	self:addTradeFlags(RecipeDB, 60624, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.HEALER, F.CASTER, F.MAIL)
	self:addTradeAcquire(RecipeDB, 60624, A.TRAINER, 26911, A.TRAINER, 26961, A.TRAINER, 26996, A.TRAINER, 26998, A.TRAINER, 28700, A.TRAINER, 33581)

	-- Dark Nerubian Leggings -- 60627
	AddRecipe(60627, 395, 44443, R_COMMON, GAME_WOTLK, 395, 410, 420, 430)
	self:addTradeFlags(RecipeDB, 60627, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.HEALER, F.CASTER, F.MAIL)
	self:addTradeAcquire(RecipeDB, 60627, A.TRAINER, 26911, A.TRAINER, 26961, A.TRAINER, 26996, A.TRAINER, 26998, A.TRAINER, 28700, A.TRAINER, 33581)

	-- Dark Nerubian Chestpiece -- 60629
	AddRecipe(60629, 395, 44444, R_COMMON, GAME_WOTLK, 395, 410, 420, 430)
	self:addTradeFlags(RecipeDB, 60629, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.HEALER, F.CASTER, F.MAIL)
	self:addTradeAcquire(RecipeDB, 60629, A.TRAINER, 26911, A.TRAINER, 26961, A.TRAINER, 26996, A.TRAINER, 26998, A.TRAINER, 28700, A.TRAINER, 33581)

	-- Scaled Icewalkers -- 60630
	AddRecipe(60630, 400, 44445, R_COMMON, GAME_WOTLK, 400, 415, 425, 435)
	self:addTradeFlags(RecipeDB, 60630, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.HEALER, F.CASTER, F.MAIL)
	self:addTradeAcquire(RecipeDB, 60630, A.TRAINER, 26911, A.TRAINER, 26961, A.TRAINER, 26996, A.TRAINER, 26998, A.TRAINER, 28700, A.TRAINER, 33581)

	-- Cloak of Harsh Winds -- 60631
	AddRecipe(60631, 380, 38441, R_COMMON, GAME_WOTLK, 380, 390, 400, 410)
	self:addTradeFlags(RecipeDB, 60631, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.DPS, F.CLOAK)
	self:addTradeAcquire(RecipeDB, 60631, A.TRAINER, 26911, A.TRAINER, 26961, A.TRAINER, 26996, A.TRAINER, 26998, A.TRAINER, 28700, A.TRAINER, 33581)

	-- Ice Striker's Cloak -- 60637
	AddRecipe(60637, 440, 43566, R_COMMON, GAME_WOTLK, 440, 450, 455, 460)
	self:addTradeFlags(RecipeDB, 60637, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.DPS, F.CLOAK)
	self:addTradeAcquire(RecipeDB, 60637, A.TRAINER, 26911, A.TRAINER, 26961, A.TRAINER, 26996, A.TRAINER, 26998, A.TRAINER, 28700, A.TRAINER, 33581)

	-- Durable Nerubhide Cape -- 60640
	AddRecipe(60640, 440, 43565, R_COMMON, GAME_WOTLK, 440, 450, 455, 460)
	self:addTradeFlags(RecipeDB, 60640, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.DPS, F.TANK, F.CLOAK)
	self:addTradeAcquire(RecipeDB, 60640, A.TRAINER, 26911, A.TRAINER, 26961, A.TRAINER, 26996, A.TRAINER, 26998, A.TRAINER, 28700, A.TRAINER, 33581)

	-- Pack of Endless Pockets -- 60643
	AddRecipe(60643, 415, 44446, R_RARE, GAME_WOTLK, 415, 420, 422, 425)
	self:addTradeFlags(RecipeDB, 60643, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP)
	self:addTradeAcquire(RecipeDB, 60643, A.TRAINER, 26911, A.TRAINER, 26961, A.TRAINER, 26996, A.TRAINER, 26998, A.TRAINER, 28700, A.TRAINER, 33581)

	-- Dragonscale Ammo Pouch -- 60645
	AddRecipe(60645, 415, 44447, R_RARE, GAME_WOTLK, 415, 420, 422, 425)
	self:addTradeFlags(RecipeDB, 60645, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOP, F.AMMO, F.KALUAK)
	self:addTradeAcquire(RecipeDB, 60645, A.REPUTATION, FAC.KALUAK, REP.HONORED, 31916, A.REPUTATION, FAC.KALUAK, REP.HONORED, 32763)

	-- Nerubian Reinforced Quiver -- 60647
	AddRecipe(60647, 415, 44448, R_RARE, GAME_WOTLK, 415, 420, 422, 425)
	self:addTradeFlags(RecipeDB, 60647, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOP, F.EBONBLADE)
	self:addTradeAcquire(RecipeDB, 60647, A.REPUTATION, FAC.EBONBLADE, REP.HONORED, 32538)

	-- Razorstrike Breastplate -- 60649
	AddRecipe(60649, 425, 43129, R_COMMON, GAME_WOTLK, 425, 430, 435, 440)
	self:addTradeFlags(RecipeDB, 60649, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.DPS, F.MAIL)
	self:addTradeAcquire(RecipeDB, 60649, A.TRAINER, 26911, A.TRAINER, 26961, A.TRAINER, 26996, A.TRAINER, 26998, A.TRAINER, 28700, A.TRAINER, 33581)

	-- Virulent Spaulders -- 60651
	AddRecipe(60651, 420, 43130, R_COMMON, GAME_WOTLK, 420, 425, 430, 435)
	self:addTradeFlags(RecipeDB, 60651, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.DPS, F.MAIL)
	self:addTradeAcquire(RecipeDB, 60651, A.TRAINER, 26911, A.TRAINER, 26961, A.TRAINER, 26996, A.TRAINER, 26998, A.TRAINER, 28700, A.TRAINER, 33581)

	-- Eaglebane Bracers -- 60652
	AddRecipe(60652, 420, 43131, R_COMMON, GAME_WOTLK, 420, 425, 430, 435)
	self:addTradeFlags(RecipeDB, 60652, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.DPS, F.MAIL)
	self:addTradeAcquire(RecipeDB, 60652, A.TRAINER, 26911, A.TRAINER, 26961, A.TRAINER, 26996, A.TRAINER, 26998, A.TRAINER, 28700, A.TRAINER, 33581)

	-- Nightshock Hood -- 60655
	AddRecipe(60655, 425, 43132, R_COMMON, GAME_WOTLK, 425, 430, 435, 440)
	self:addTradeFlags(RecipeDB, 60655, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.HEALER, F.CASTER, F.MAIL)
	self:addTradeAcquire(RecipeDB, 60655, A.TRAINER, 26911, A.TRAINER, 26961, A.TRAINER, 26996, A.TRAINER, 26998, A.TRAINER, 28700, A.TRAINER, 33581)

	-- Nightshock Girdle -- 60658
	AddRecipe(60658, 420, 43133, R_COMMON, GAME_WOTLK, 420, 425, 430, 435)
	self:addTradeFlags(RecipeDB, 60658, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.HEALER, F.CASTER, F.MAIL)
	self:addTradeAcquire(RecipeDB, 60658, A.TRAINER, 26911, A.TRAINER, 26961, A.TRAINER, 26996, A.TRAINER, 26998, A.TRAINER, 28700, A.TRAINER, 33581)

	-- Leggings of Visceral Strikes -- 60660
	AddRecipe(60660, 425, 42731, R_COMMON, GAME_WOTLK, 425, 430, 435, 440)
	self:addTradeFlags(RecipeDB, 60660, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.DPS, F.LEATHER)
	self:addTradeAcquire(RecipeDB, 60660, A.TRAINER, 26911, A.TRAINER, 26961, A.TRAINER, 26996, A.TRAINER, 26998, A.TRAINER, 28700, A.TRAINER, 33581)

	-- Seafoam Gauntlets -- 60665
	AddRecipe(60665, 420, 43255, R_COMMON, GAME_WOTLK, 420, 425, 430, 435)
	self:addTradeFlags(RecipeDB, 60665, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.DPS, F.LEATHER)
	self:addTradeAcquire(RecipeDB, 60665, A.TRAINER, 26911, A.TRAINER, 26961, A.TRAINER, 26996, A.TRAINER, 26998, A.TRAINER, 28700, A.TRAINER, 33581)

	-- Jormscale Footpads -- 60666
	AddRecipe(60666, 420, 43256, R_COMMON, GAME_WOTLK, 420, 425, 430, 435)
	self:addTradeFlags(RecipeDB, 60666, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.DPS, F.LEATHER)
	self:addTradeAcquire(RecipeDB, 60666, A.TRAINER, 26911, A.TRAINER, 26961, A.TRAINER, 26996, A.TRAINER, 26998, A.TRAINER, 28700, A.TRAINER, 33581)

	-- Wildscale Breastplate -- 60669
	AddRecipe(60669, 425, 43257, R_COMMON, GAME_WOTLK, 425, 430, 435, 440)
	self:addTradeFlags(RecipeDB, 60669, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.HEALER, F.CASTER, F.LEATHER)
	self:addTradeAcquire(RecipeDB, 60669, A.TRAINER, 26911, A.TRAINER, 26961, A.TRAINER, 26996, A.TRAINER, 26998, A.TRAINER, 28700, A.TRAINER, 33581)

	-- Purehorn Spaulders -- 60671
	AddRecipe(60671, 420, 43258, R_COMMON, GAME_WOTLK, 420, 425, 430, 435)
	self:addTradeFlags(RecipeDB, 60671, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.HEALER, F.CASTER, F.LEATHER)
	self:addTradeAcquire(RecipeDB, 60671, A.TRAINER, 26911, A.TRAINER, 26961, A.TRAINER, 26996, A.TRAINER, 26998, A.TRAINER, 28700, A.TRAINER, 33581)

	-- Eviscerator's Facemask -- 60697
	AddRecipe(60697, 420, 43260, R_RARE, GAME_WOTLK, 420, 425, 430, 435)
	self:addTradeFlags(RecipeDB, 60697, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOP, F.DPS, F.LEATHER)
	self:addTradeAcquire(RecipeDB, 60697, A.VENDOR, 32515)

	-- Eviscerator's Shoulderpads -- 60702
	AddRecipe(60702, 420, 43433, R_RARE, GAME_WOTLK, 420, 425, 430, 435)
	self:addTradeFlags(RecipeDB, 60702, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOP, F.DPS, F.LEATHER)
	self:addTradeAcquire(RecipeDB, 60702, A.VENDOR, 32515)

	-- Eviscerator's Chestguard -- 60703
	AddRecipe(60703, 420, 43434, R_RARE, GAME_WOTLK, 420, 425, 430, 435)
	self:addTradeFlags(RecipeDB, 60703, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOP, F.DPS, F.LEATHER)
	self:addTradeAcquire(RecipeDB, 60703, A.VENDOR, 32515)

	-- Eviscerator's Bindings -- 60704
	AddRecipe(60704, 420, 43435, R_RARE, GAME_WOTLK, 420, 425, 430, 435)
	self:addTradeFlags(RecipeDB, 60704, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOP, F.DPS, F.LEATHER)
	self:addTradeAcquire(RecipeDB, 60704, A.VENDOR, 32515)

	-- Eviscerator's Gauntlets -- 60705
	AddRecipe(60705, 425, 43436, R_RARE, GAME_WOTLK, 425, 430, 435, 440)
	self:addTradeFlags(RecipeDB, 60705, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOP, F.DPS, F.LEATHER)
	self:addTradeAcquire(RecipeDB, 60705, A.VENDOR, 32515)

	-- Eviscerator's Waistguard -- 60706
	AddRecipe(60706, 425, 43437, R_RARE, GAME_WOTLK, 425, 430, 435, 440)
	self:addTradeFlags(RecipeDB, 60706, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOP, F.DPS, F.LEATHER)
	self:addTradeAcquire(RecipeDB, 60706, A.VENDOR, 32515)

	-- Eviscerator's Legguards -- 60711
	AddRecipe(60711, 425, 43438, R_RARE, GAME_WOTLK, 425, 430, 435, 440)
	self:addTradeFlags(RecipeDB, 60711, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOP, F.DPS, F.LEATHER)
	self:addTradeAcquire(RecipeDB, 60711, A.VENDOR, 32515)

	-- Eviscerator's Treads -- 60712
	AddRecipe(60712, 425, 43439, R_RARE, GAME_WOTLK, 425, 430, 435, 440)
	self:addTradeFlags(RecipeDB, 60712, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOP, F.DPS, F.LEATHER)
	self:addTradeAcquire(RecipeDB, 60712, A.VENDOR, 32515)

	-- Overcast Headguard -- 60715
	AddRecipe(60715, 420, 43261, R_RARE, GAME_WOTLK, 420, 425, 430, 435)
	self:addTradeFlags(RecipeDB, 60715, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOP, F.HEALER, F.CASTER, F.LEATHER)
	self:addTradeAcquire(RecipeDB, 60715, A.VENDOR, 32515)

	-- Overcast Spaulders -- 60716
	AddRecipe(60716, 420, 43262, R_RARE, GAME_WOTLK, 420, 425, 430, 435)
	self:addTradeFlags(RecipeDB, 60716, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOP, F.HEALER, F.CASTER, F.LEATHER)
	self:addTradeAcquire(RecipeDB, 60716, A.VENDOR, 32515)

	-- Overcast Chestguard -- 60718
	AddRecipe(60718, 420, 43263, R_RARE, GAME_WOTLK, 420, 425, 430, 435)
	self:addTradeFlags(RecipeDB, 60718, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOP, F.HEALER, F.CASTER, F.LEATHER)
	self:addTradeAcquire(RecipeDB, 60718, A.VENDOR, 32515)

	-- Overcast Bracers -- 60720
	AddRecipe(60720, 420, 43264, R_RARE, GAME_WOTLK, 420, 425, 430, 435)
	self:addTradeFlags(RecipeDB, 60720, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOP, F.HEALER, F.CASTER, F.LEATHER)
	self:addTradeAcquire(RecipeDB, 60720, A.VENDOR, 32515)

	-- Overcast Handwraps -- 60721
	AddRecipe(60721, 425, 43265, R_RARE, GAME_WOTLK, 425, 430, 435, 440)
	self:addTradeFlags(RecipeDB, 60721, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOP, F.HEALER, F.CASTER, F.LEATHER)
	self:addTradeAcquire(RecipeDB, 60721, A.VENDOR, 32515)

	-- Overcast Belt -- 60723
	AddRecipe(60723, 425, 43266, R_RARE, GAME_WOTLK, 425, 430, 435, 440)
	self:addTradeFlags(RecipeDB, 60723, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOP, F.HEALER, F.CASTER, F.LEATHER)
	self:addTradeAcquire(RecipeDB, 60723, A.VENDOR, 32515)

	-- Overcast Leggings -- 60725
	AddRecipe(60725, 425, 43271, R_RARE, GAME_WOTLK, 425, 430, 435, 440)
	self:addTradeFlags(RecipeDB, 60725, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOP, F.HEALER, F.CASTER, F.LEATHER)
	self:addTradeAcquire(RecipeDB, 60725, A.VENDOR, 32515)

	-- Overcast Boots -- 60727
	AddRecipe(60727, 425, 43273, R_RARE, GAME_WOTLK, 425, 430, 435, 440)
	self:addTradeFlags(RecipeDB, 60727, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOP, F.HEALER, F.CASTER, F.LEATHER)
	self:addTradeAcquire(RecipeDB, 60727, A.VENDOR, 32515)

	-- Swiftarrow Helm -- 60728
	AddRecipe(60728, 420, 43447, R_RARE, GAME_WOTLK, 420, 425, 430, 435)
	self:addTradeFlags(RecipeDB, 60728, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOP, F.DPS, F.MAIL)
	self:addTradeAcquire(RecipeDB, 60728, A.VENDOR, 32515)

	-- Swiftarrow Shoulderguards -- 60729
	AddRecipe(60729, 420, 43449, R_RARE, GAME_WOTLK, 420, 425, 430, 435)
	self:addTradeFlags(RecipeDB, 60729, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOP, F.DPS, F.MAIL)
	self:addTradeAcquire(RecipeDB, 60729, A.VENDOR, 32515)

	-- Swiftarrow Hauberk -- 60730
	AddRecipe(60730, 420, 43445, R_RARE, GAME_WOTLK, 420, 425, 430, 435)
	self:addTradeFlags(RecipeDB, 60730, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOP, F.DPS, F.MAIL)
	self:addTradeAcquire(RecipeDB, 60730, A.VENDOR, 32515)

	-- Swiftarrow Bracers -- 60731
	AddRecipe(60731, 420, 43444, R_RARE, GAME_WOTLK, 420, 425, 430, 435)
	self:addTradeFlags(RecipeDB, 60731, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOP, F.DPS, F.MAIL)
	self:addTradeAcquire(RecipeDB, 60731, A.VENDOR, 32515)

	-- Swiftarrow Gauntlets -- 60732
	AddRecipe(60732, 425, 43446, R_RARE, GAME_WOTLK, 425, 430, 435, 440)
	self:addTradeFlags(RecipeDB, 60732, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOP, F.DPS, F.MAIL)
	self:addTradeAcquire(RecipeDB, 60732, A.VENDOR, 32515)

	-- Swiftarrow Belt -- 60734
	AddRecipe(60734, 425, 43442, R_RARE, GAME_WOTLK, 425, 430, 435, 440)
	self:addTradeFlags(RecipeDB, 60734, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOP, F.DPS, F.MAIL)
	self:addTradeAcquire(RecipeDB, 60734, A.VENDOR, 32515)

	-- Swiftarrow Leggings -- 60735
	AddRecipe(60735, 425, 43448, R_RARE, GAME_WOTLK, 425, 430, 435, 440)
	self:addTradeFlags(RecipeDB, 60735, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOP, F.DPS, F.MAIL)
	self:addTradeAcquire(RecipeDB, 60735, A.VENDOR, 32515)

	-- Swiftarrow Boots -- 60737
	AddRecipe(60737, 425, 43443, R_RARE, GAME_WOTLK, 425, 430, 435, 440)
	self:addTradeFlags(RecipeDB, 60737, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOP, F.DPS, F.MAIL)
	self:addTradeAcquire(RecipeDB, 60737, A.VENDOR, 32515)

	-- Stormhide Crown -- 60743
	AddRecipe(60743, 420, 43455, R_RARE, GAME_WOTLK, 420, 425, 430, 435)
	self:addTradeFlags(RecipeDB, 60743, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOP, F.HEALER, F.CASTER, F.MAIL)
	self:addTradeAcquire(RecipeDB, 60743, A.VENDOR, 32515)

	-- Stormhide Shoulders -- 60746
	AddRecipe(60746, 420, 43457, R_RARE, GAME_WOTLK, 420, 425, 430, 435)
	self:addTradeFlags(RecipeDB, 60746, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOP, F.HEALER, F.CASTER, F.MAIL)
	self:addTradeAcquire(RecipeDB, 60746, A.VENDOR, 32515)

	-- Stormhide Hauberk -- 60747
	AddRecipe(60747, 420, 43453, R_RARE, GAME_WOTLK, 420, 425, 430, 435)
	self:addTradeFlags(RecipeDB, 60747, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOP, F.HEALER, F.CASTER, F.MAIL)
	self:addTradeAcquire(RecipeDB, 60747, A.VENDOR, 32515)

	-- Stormhide Wristguards -- 60748
	AddRecipe(60748, 420, 43452, R_RARE, GAME_WOTLK, 420, 425, 430, 435)
	self:addTradeFlags(RecipeDB, 60748, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOP, F.HEALER, F.CASTER, F.MAIL)
	self:addTradeAcquire(RecipeDB, 60748, A.VENDOR, 32515)

	-- Stormhide Grips -- 60749
	AddRecipe(60749, 425, 43454, R_RARE, GAME_WOTLK, 425, 430, 435, 440)
	self:addTradeFlags(RecipeDB, 60749, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOP, F.HEALER, F.CASTER, F.MAIL)
	self:addTradeAcquire(RecipeDB, 60749, A.VENDOR, 32515)

	-- Stormhide Belt -- 60750
	AddRecipe(60750, 425, 43450, R_RARE, GAME_WOTLK, 425, 430, 435, 440)
	self:addTradeFlags(RecipeDB, 60750, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOP, F.HEALER, F.CASTER, F.MAIL)
	self:addTradeAcquire(RecipeDB, 60750, A.VENDOR, 32515)

	-- Stormhide Legguards -- 60751
	AddRecipe(60751, 425, 43456, R_RARE, GAME_WOTLK, 425, 430, 435, 440)
	self:addTradeFlags(RecipeDB, 60751, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOP, F.HEALER, F.CASTER, F.MAIL)
	self:addTradeAcquire(RecipeDB, 60751, A.VENDOR, 32515)

	-- Stormhide Stompers -- 60752
	AddRecipe(60752, 425, 43451, R_RARE, GAME_WOTLK, 425, 430, 435, 440)
	self:addTradeFlags(RecipeDB, 60752, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOP, F.HEALER, F.CASTER, F.MAIL)
	self:addTradeAcquire(RecipeDB, 60752, A.VENDOR, 32515)

	-- Giantmaim Legguards -- 60754
	AddRecipe(60754, 440, 43458, R_EPIC, GAME_WOTLK, 440, 450, 455, 460)
	self:addTradeFlags(RecipeDB, 60754, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOP, F.DPS, F.MAIL)
	self:addTradeAcquire(RecipeDB, 60754, A.VENDOR, 32515)

	-- Giantmaim Bracers -- 60755
	AddRecipe(60755, 440, 43459, R_EPIC, GAME_WOTLK, 440, 450, 455, 460)
	self:addTradeFlags(RecipeDB, 60755, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOP, F.DPS, F.MAIL)
	self:addTradeAcquire(RecipeDB, 60755, A.VENDOR, 32515)

	-- Revenant's Breastplate -- 60756
	AddRecipe(60756, 440, 43461, R_EPIC, GAME_WOTLK, 440, 450, 455, 460)
	self:addTradeFlags(RecipeDB, 60756, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOP, F.HEALER, F.CASTER, F.MAIL)
	self:addTradeAcquire(RecipeDB, 60756, A.VENDOR, 32515)

	-- Revenant's Treads -- 60757
	AddRecipe(60757, 440, 43469, R_EPIC, GAME_WOTLK, 440, 450, 455, 460)
	self:addTradeFlags(RecipeDB, 60757, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOP, F.HEALER, F.CASTER, F.MAIL)
	self:addTradeAcquire(RecipeDB, 60757, A.VENDOR, 32515)

	-- Trollwoven Spaulders -- 60758
	AddRecipe(60758, 440, 43481, R_EPIC, GAME_WOTLK, 440, 450, 455, 460)
	self:addTradeFlags(RecipeDB, 60758, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOP, F.DPS, F.LEATHER)
	self:addTradeAcquire(RecipeDB, 60758, A.VENDOR, 32515)

	-- Trollwoven Girdle -- 60759
	AddRecipe(60759, 440, 43484, R_EPIC, GAME_WOTLK, 440, 450, 455, 460)
	self:addTradeFlags(RecipeDB, 60759, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOP, F.DPS, F.LEATHER)
	self:addTradeAcquire(RecipeDB, 60759, A.VENDOR, 32515)

	-- Earthgiving Legguards -- 60760
	AddRecipe(60760, 440, 43495, R_EPIC, GAME_WOTLK, 440, 450, 455, 460)
	self:addTradeFlags(RecipeDB, 60760, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOP, F.HEALER, F.CASTER, F.LEATHER)
	self:addTradeAcquire(RecipeDB, 60760, A.VENDOR, 32515)

	-- Earthgiving Boots -- 60761
	AddRecipe(60761, 440, 43502, R_EPIC, GAME_WOTLK, 440, 450, 455, 460)
	self:addTradeFlags(RecipeDB, 60761, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOP, F.HEALER, F.CASTER, F.LEATHER)
	self:addTradeAcquire(RecipeDB, 60761, A.VENDOR, 32515)

	-- Polar Vest -- 60996
	AddRecipe(60996, 425, 43590, R_EPIC, GAME_WOTLK, 425, 435, 445, 455)
	self:addTradeFlags(RecipeDB, 60996, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOP, F.LEATHER)
	self:addTradeAcquire(RecipeDB, 60996, A.VENDOR, 32515)

	-- Polar Cord -- 60997
	AddRecipe(60997, 420, 43591, R_EPIC, GAME_WOTLK, 420, 425, 430, 435)
	self:addTradeFlags(RecipeDB, 60997, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOP, F.LEATHER)
	self:addTradeAcquire(RecipeDB, 60997, A.VENDOR, 32515)

	-- Polar Boots -- 60998
	AddRecipe(60998, 420, 43592, R_EPIC, GAME_WOTLK, 420, 425, 430, 435)
	self:addTradeFlags(RecipeDB, 60998, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOP, F.LEATHER)
	self:addTradeAcquire(RecipeDB, 60998, A.VENDOR, 32515)

	-- Icy Scale Chestguard -- 60999
	AddRecipe(60999, 425, 43593, R_EPIC, GAME_WOTLK, 425, 430, 435, 440)
	self:addTradeFlags(RecipeDB, 60999, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOP, F.MAIL)
	self:addTradeAcquire(RecipeDB, 60999, A.VENDOR, 32515)

	-- Icy Scale Belt -- 61000
	AddRecipe(61000, 420, 43594, R_EPIC, GAME_WOTLK, 420, 425, 430, 435)
	self:addTradeFlags(RecipeDB, 61000, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOP, F.MAIL)
	self:addTradeAcquire(RecipeDB, 61000, A.VENDOR, 32515)

	-- Icy Scale Boots -- 61002
	AddRecipe(61002, 420, 43595, R_EPIC, GAME_WOTLK, 420, 425, 430, 435)
	self:addTradeFlags(RecipeDB, 61002, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOP, F.MAIL)
	self:addTradeAcquire(RecipeDB, 61002, A.VENDOR, 32515)

	-- Windripper Boots -- 62176
	AddRecipe(62176, 440, 44930, R_EPIC, GAME_WOTLK, 440, 450, 455, 460)
	self:addTradeFlags(RecipeDB, 62176, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOP, F.HEALER, F.CASTER, F.LEATHER)
	self:addTradeAcquire(RecipeDB, 62176, A.VENDOR, 32515)

	-- Windripper Leggings -- 62177
	AddRecipe(62177, 440, 44931, R_EPIC, GAME_WOTLK, 440, 450, 455, 460)
	self:addTradeFlags(RecipeDB, 62177, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOP, F.HEALER, F.CASTER, F.LEATHER)
	self:addTradeAcquire(RecipeDB, 62177, A.VENDOR, 32515)

	-- Earthen Leg Armor -- 62448
	AddRecipe(62448, 425, 44963, R_EPIC, GAME_WOTLK, 425, 430, 435, 440)
	self:addTradeFlags(RecipeDB, 62448, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP)
	self:addTradeAcquire(RecipeDB, 62448, A.TRAINER, 26911, A.TRAINER, 26961, A.TRAINER, 26996, A.TRAINER, 26998, A.TRAINER, 28700, A.TRAINER, 33581)

	-- Belt of Dragons -- 63194
	AddRecipe(63194, 450, 45553, R_EPIC, GAME_WOTLK, 450, 455, 465, 475)
	self:addTradeFlags(RecipeDB, 63194, F.ALLIANCE, F.HORDE, F.RAID, F.IBOE, F.RBOE, F.DPS, F.MAIL)
	self:addTradeAcquire(RecipeDB, 63194, A.CUSTOM, 39)

	-- Boots of Living Scale -- 63195
	AddRecipe(63195, 450, 45095, R_EPIC, GAME_WOTLK, 450, 455, 465, 475)
	self:addTradeFlags(RecipeDB, 63195, F.ALLIANCE, F.HORDE, F.RAID, F.IBOE, F.RBOE, F.DPS, F.MAIL)
	self:addTradeAcquire(RecipeDB, 63195, A.CUSTOM, 39)

	-- Blue Belt of Chaos -- 63196
	AddRecipe(63196, 450, 45096, R_EPIC, GAME_WOTLK, 450, 455, 465, 475)
	self:addTradeFlags(RecipeDB, 63196, F.ALLIANCE, F.HORDE, F.RAID, F.IBOE, F.RBOE, F.HEALER, F.CASTER, F.MAIL)
	self:addTradeAcquire(RecipeDB, 63196, A.CUSTOM, 39)

	-- Lightning Grounded Boots -- 63197
	AddRecipe(63197, 450, 45097, R_EPIC, GAME_WOTLK, 450, 455, 465, 475)
	self:addTradeFlags(RecipeDB, 63197, F.ALLIANCE, F.HORDE, F.RAID, F.IBOE, F.RBOE, F.HEALER, F.CASTER, F.MAIL)
	self:addTradeAcquire(RecipeDB, 63197, A.CUSTOM, 39)

	-- Death-warmed Belt -- 63198
	AddRecipe(63198, 450, 45098, R_EPIC, GAME_WOTLK, 450, 455, 465, 475)
	self:addTradeFlags(RecipeDB, 63198, F.ALLIANCE, F.HORDE, F.RAID, F.IBOE, F.RBOE, F.DPS, F.LEATHER)
	self:addTradeAcquire(RecipeDB, 63198, A.CUSTOM, 39)

	-- Footpads of Silence -- 63199
	AddRecipe(63199, 450, 45099, R_EPIC, GAME_WOTLK, 450, 455, 465, 475)
	self:addTradeFlags(RecipeDB, 63199, F.ALLIANCE, F.HORDE, F.RAID, F.IBOE, F.RBOE, F.DPS, F.LEATHER)
	self:addTradeAcquire(RecipeDB, 63199, A.CUSTOM, 39)

	-- Belt of Arctic Life -- 63200
	AddRecipe(63200, 450, 45100, R_EPIC, GAME_WOTLK, 450, 455, 465, 475)
	self:addTradeFlags(RecipeDB, 63200, F.ALLIANCE, F.HORDE, F.RAID, F.IBOE, F.RBOE, F.HEALER, F.CASTER, F.LEATHER)
	self:addTradeAcquire(RecipeDB, 63200, A.CUSTOM, 39)

	-- Boots of Wintry Endurance -- 63201
	AddRecipe(63201, 450, 45101, R_EPIC, GAME_WOTLK, 450, 455, 465, 475)
	self:addTradeFlags(RecipeDB, 63201, F.ALLIANCE, F.HORDE, F.RAID, F.IBOE, F.RBOE, F.HEALER, F.CASTER, F.LEATHER)
	self:addTradeAcquire(RecipeDB, 63201, A.CUSTOM, 39)

	-- Borean Leather -- 64661
	AddRecipe(64661, 350, 33568, R_COMMON, GAME_WOTLK, 350, 350, 362, 375)
	self:addTradeFlags(RecipeDB, 64661, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.LEATHER)
	self:addTradeAcquire(RecipeDB, 64661, A.TRAINER, 26911, A.TRAINER, 26961, A.TRAINER, 26996, A.TRAINER, 26998, A.TRAINER, 28700, A.TRAINER, 33581)

	-- Drums of Forgotten Kings -- 69386
	AddRecipe(69386, 450, 49633, R_COMMON, GAME_WOTLK, 450, 450, 455, 470)
	self:addTradeFlags(RecipeDB, 69386, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP)
	self:addTradeAcquire(RecipeDB, 69386, A.TRAINER, 28700, A.TRAINER, 26996, A.TRAINER, 26911, A.TRAINER, 26961, A.TRAINER, 33581, A.TRAINER, 26998)

	-- Drums of the Wild -- 69388
	AddRecipe(69388, 450, 49634, R_COMMON, GAME_WOTLK, 450, 450, 455, 470)
	self:addTradeFlags(RecipeDB, 69388, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP)
	self:addTradeAcquire(RecipeDB, 69388, A.TRAINER, 28700, A.TRAINER, 26996, A.TRAINER, 26911, A.TRAINER, 26961, A.TRAINER, 33581, A.TRAINER, 26998)

	-- Legwraps of Unleashed Nature -- 70554
	AddRecipe(70554, 450, 49898, R_EPIC, GAME_WOTLK, 450, 460, 465, 470)
	self:addTradeFlags(RecipeDB, 70554, F.ALLIANCE, F.HORDE, F.VENDOR, F.ASHEN_VERDICT)
	self:addTradeAcquire(RecipeDB, 70554, A.REPUTATION, FAC.ASHEN_VERDICT, REP.REVERED, 37687)

	-- Blessed Cenarion Boots -- 70555
	AddRecipe(70555, 450, 49894, R_EPIC, GAME_WOTLK, 450, 460, 465, 470)
	self:addTradeFlags(RecipeDB, 70555, F.ALLIANCE, F.HORDE, F.VENDOR, F.ASHEN_VERDICT)
	self:addTradeAcquire(RecipeDB, 70555, A.REPUTATION, FAC.ASHEN_VERDICT, REP.HONORED, 37687)

	-- Bladeborn Leggings -- 70556
	AddRecipe(70556, 450, 49899, R_EPIC, GAME_WOTLK, 450, 460, 465, 470)
	self:addTradeFlags(RecipeDB, 70556, F.ALLIANCE, F.HORDE, F.VENDOR, F.ASHEN_VERDICT)
	self:addTradeAcquire(RecipeDB, 70556, A.REPUTATION, FAC.ASHEN_VERDICT, REP.REVERED, 37687)

	-- Footpads of Impending Death -- 70557
	AddRecipe(70557, 450, 49895, R_EPIC, GAME_WOTLK, 450, 460, 465, 470)
	self:addTradeFlags(RecipeDB, 70557, F.ALLIANCE, F.HORDE, F.VENDOR, F.ASHEN_VERDICT)
	self:addTradeAcquire(RecipeDB, 70557, A.REPUTATION, FAC.ASHEN_VERDICT, REP.HONORED, 37687)

	-- Lightning-Infused Leggings -- 70558
	AddRecipe(70558, 450, 49900, R_EPIC, GAME_WOTLK, 450, 460, 465, 470)
	self:addTradeFlags(RecipeDB, 70558, F.ALLIANCE, F.HORDE, F.VENDOR, F.ASHEN_VERDICT)
	self:addTradeAcquire(RecipeDB, 70558, A.REPUTATION, FAC.ASHEN_VERDICT, REP.REVERED, 37687)

	-- Earthsoul Boots -- 70559
	AddRecipe(70559, 450, 49896, R_EPIC, GAME_WOTLK, 450, 460, 465, 470)
	self:addTradeFlags(RecipeDB, 70559, F.ALLIANCE, F.HORDE, F.VENDOR, F.ASHEN_VERDICT)
	self:addTradeAcquire(RecipeDB, 70559, A.REPUTATION, FAC.ASHEN_VERDICT, REP.HONORED, 37687)

	-- Draconic Bonesplinter Legguards -- 70560
	AddRecipe(70560, 450, 49901, R_EPIC, GAME_WOTLK, 450, 460, 465, 470)
	self:addTradeFlags(RecipeDB, 70560, F.ALLIANCE, F.HORDE, F.VENDOR, F.ASHEN_VERDICT)
	self:addTradeAcquire(RecipeDB, 70560, A.REPUTATION, FAC.ASHEN_VERDICT, REP.REVERED, 37687)

	-- Rock-Steady Treads -- 70561
	AddRecipe(70561, 450, 49897, R_EPIC, GAME_WOTLK, 450, 460, 465, 470)
	self:addTradeFlags(RecipeDB, 70561, F.ALLIANCE, F.HORDE, F.VENDOR, F.ASHEN_VERDICT)
	self:addTradeAcquire(RecipeDB, 70561, A.REPUTATION, FAC.ASHEN_VERDICT, REP.HONORED, 37687)
 
	-- Some recipes are only availible to specific factions.
	-- We only add the faction specific recipes if the user is part of that faction
	local BFAC = LibStub("LibBabble-Faction-3.0"):GetLookupTable()
	local _,faction = UnitFactionGroup("player")

	if faction == BFAC["Alliance"] then

		-- Ensorcelled Nerubian Breastplate -- 67080
		AddRecipe(67080, 450, 47597, R_EPIC, GAME_WOTLK, 450, 460, 467, 475)
		self:addTradeFlags(RecipeDB, 67080, F.ALLIANCE, F.RAID, F.MOB_DROP, F.IBOE, F.RBOE, F.HEALER, F.CASTER, F.MAIL)
		self:addTradeAcquire(RecipeDB, 67080, A.CUSTOM, 42)

		-- Black Chitin Bracers -- 67081
		AddRecipe(67081, 450, 47579, R_EPIC, GAME_WOTLK, 450, 460, 467, 475)
		self:addTradeFlags(RecipeDB, 67081, F.ALLIANCE, F.RAID, F.MOB_DROP)
		self:addTradeAcquire(RecipeDB, 67081, A.CUSTOM, 42)

		-- Crusader's Dragonscale Breastplate -- 67082
		AddRecipe(67082, 450, 47595, R_EPIC, GAME_WOTLK, 450, 460, 467, 475)
		self:addTradeFlags(RecipeDB, 67082, F.ALLIANCE, F.RAID, F.MOB_DROP)
		self:addTradeAcquire(RecipeDB, 67082, A.CUSTOM, 42)

		-- Crusader's Dragonscale Bracers -- 67083
		AddRecipe(67083, 450, 47576, R_EPIC, GAME_WOTLK, 450, 460, 467, 475)
		self:addTradeFlags(RecipeDB, 67083, F.ALLIANCE, F.RAID, F.MOB_DROP, F.IBOE, F.RBOE, F.DPS, F.MAIL)
		self:addTradeAcquire(RecipeDB, 67083, A.CUSTOM, 42)

		-- Lunar Eclipse Chestguard -- 67084
		AddRecipe(67084, 450, 47602, R_EPIC, GAME_WOTLK, 450, 460, 467, 475)
		self:addTradeFlags(RecipeDB, 67084, F.ALLIANCE, F.RAID, F.MOB_DROP)
		self:addTradeAcquire(RecipeDB, 67084, A.CUSTOM, 42)

		-- Moonshadow Armguards -- 67085
		AddRecipe(67085, 450, 47583, R_EPIC, GAME_WOTLK, 450, 460, 467, 475)
		self:addTradeFlags(RecipeDB, 67085, F.ALLIANCE, F.RAID, F.MOB_DROP)
		self:addTradeAcquire(RecipeDB, 67085, A.CUSTOM, 42)

		-- Knightbane Carapace -- 67086
		AddRecipe(67086, 450, 47599, R_EPIC, GAME_WOTLK, 450, 460, 467, 475)
		self:addTradeFlags(RecipeDB, 67086, F.ALLIANCE, F.RAID, F.MOB_DROP)
		self:addTradeAcquire(RecipeDB, 67086, A.CUSTOM, 42)

		-- Bracers of Swift Death -- 67087
		AddRecipe(67087, 450, 47581, R_EPIC, GAME_WOTLK, 450, 460, 467, 475)
		self:addTradeFlags(RecipeDB, 67087, F.ALLIANCE, F.RAID, F.MOB_DROP)
		self:addTradeAcquire(RecipeDB, 67087, A.CUSTOM, 42)
		
	elseif faction == BFAC["Horde"] then

		-- Ensorcelled Nerubian Breastplate -- 67136
		AddRecipe(67136, 450, 47598, R_EPIC, GAME_WOTLK, 450, 460, 467, 475)
		self:addTradeFlags(RecipeDB, 67136, F.HORDE, F.RAID, F.MOB_DROP, F.IBOE, F.RBOE, F.HEALER, F.CASTER, F.MAIL)
		self:addTradeAcquire(RecipeDB, 67136, A.CUSTOM, 42)

		-- Black Chitin Bracers -- 67137
		AddRecipe(67137, 450, 47580, R_EPIC, GAME_WOTLK, 450, 460, 467, 475)
		self:addTradeFlags(RecipeDB, 67137, F.HORDE, F.RAID, F.MOB_DROP, F.IBOE, F.RBOE, F.HEALER, F.CASTER, F.MAIL)
		self:addTradeAcquire(RecipeDB, 67137, A.CUSTOM, 42)

		-- Crusader's Dragonscale Breastplate -- 67138
		AddRecipe(67138, 450, 47596, R_EPIC, GAME_WOTLK, 450, 460, 467, 475)
		self:addTradeFlags(RecipeDB, 67138, F.HORDE, F.RAID, F.MOB_DROP, F.IBOE, F.RBOE, F.DPS, F.MAIL)
		self:addTradeAcquire(RecipeDB, 67138, A.CUSTOM, 42)

		-- Bracers of Swift Death -- 67139
		AddRecipe(67139, 450, 47582, R_EPIC, GAME_WOTLK, 450, 460, 467, 475)
		self:addTradeFlags(RecipeDB, 67139, F.HORDE, F.RAID, F.MOB_DROP, F.IBOE, F.RBOE, F.DPS, F.LEATHER)
		self:addTradeAcquire(RecipeDB, 67139, A.CUSTOM, 42)

		-- Lunar Eclipse Robes -- 67140
		AddRecipe(67140, 450, 47601, R_EPIC, GAME_WOTLK, 450, 460, 467, 475)
		self:addTradeFlags(RecipeDB, 67140, F.HORDE, F.RAID, F.MOB_DROP, F.IBOE, F.RBOE, F.HEALER, F.CASTER, F.LEATHER)
		self:addTradeAcquire(RecipeDB, 67140, A.CUSTOM, 42)

		-- Moonshadow Armguards -- 67141
		AddRecipe(67141, 450, 47584, R_EPIC, GAME_WOTLK, 450, 460, 467, 475)
		self:addTradeFlags(RecipeDB, 67141, F.HORDE, F.RAID, F.MOB_DROP, F.IBOE, F.RBOE, F.HEALER, F.CASTER, F.LEATHER)
		self:addTradeAcquire(RecipeDB, 67141, A.CUSTOM, 42)

		-- Knightbane Carapace -- 67142
		AddRecipe(67142, 450, 47600, R_EPIC, GAME_WOTLK, 450, 460, 467, 475)
		self:addTradeFlags(RecipeDB, 67142, F.HORDE, F.RAID, F.MOB_DROP, F.IBOE, F.RBOE, F.DPS, F.LEATHER)
		self:addTradeAcquire(RecipeDB, 67142, A.CUSTOM, 42)

		-- Crusader's Dragonscale Bracers -- 67143
		AddRecipe(67143, 450, 47577, R_EPIC, GAME_WOTLK, 450, 460, 467, 475)
		self:addTradeFlags(RecipeDB, 67143, F.HORDE, F.RAID, F.MOB_DROP, F.IBOE, F.RBOE, F.DPS, F.MAIL)
		self:addTradeAcquire(RecipeDB, 67143, A.CUSTOM, 42)

	end

	return num_recipes

end
