--[[
************************************************************************
Tailoring.lua
Tailoring data for all of Ackis Recipe List
************************************************************************
File date: 2010-02-06T07:24:17Z
File revision: 2852
Project revision: 2853
Project version: r2853
************************************************************************
Please see http://www.wowace.com/addons/arl/ for more information.
************************************************************************
This source code is released under All Rights Reserved.
************************************************************************
]]--

-------------------------------------------------------------------------------
-- AddOn namespace.
-------------------------------------------------------------------------------
local MODNAME	= "Ackis Recipe List"
local addon	= LibStub("AceAddon-3.0"):GetAddon(MODNAME)
local L		= LibStub("AceLocale-3.0"):GetLocale(MODNAME)

local private	= select(2, ...)

-------------------------------------------------------------------------------
-- Item "rarity"
-------------------------------------------------------------------------------
local R_COMMON, R_UNCOMMON, R_RARE, R_EPIC, R_LEGENDARY, R_ARTIFACT = 1, 2, 3, 4, 5, 6

-------------------------------------------------------------------------------
-- Origin
-------------------------------------------------------------------------------
local GAME_ORIG, GAME_TBC, GAME_WOTLK = 0, 1, 2

-------------------------------------------------------------------------------
-- Filter flags. Acquire types, and Reputation levels.
-------------------------------------------------------------------------------
local F		= private.filter_flags
local A		= private.acquire_types
local REP	= private.rep_levels
local FAC	= private.faction_ids

local FRIENDLY	= 1
local HONORED	= 2
local REVERED	= 3
local EXALTED	= 4

local initialized = false
local num_recipes = 0

function addon:InitTailoring(RecipeDB)
	if initialized then
		return num_recipes
	end
	initialized = true

	--------------------------------------------------------------------------------------------------------------------
	-- Counter and wrapper function
	--------------------------------------------------------------------------------------------------------------------
	local function AddRecipe(SpellID, Skill, ItemID, Rarity, Game, Orange, Yellow, Green, Gray, Speciality)
		num_recipes = num_recipes + 1
		self:addTradeSkill(RecipeDB, SpellID, Skill, ItemID, Rarity, 3908, Speciality, Game, Orange, Yellow, Green, Gray)
	end

	-- Brown Linen Vest -- 2385
	AddRecipe(2385, 10, 2568, R_COMMON, GAME_ORIG, 10, 45, 57, 70)
	self:addTradeFlags(RecipeDB, 2385, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.CLOTH)
	self:addTradeAcquire(RecipeDB, 2385, A.TRAINER, 1103, A.TRAINER, 1346, A.TRAINER, 2399, A.TRAINER, 2627, A.TRAINER, 3004, A.TRAINER, 3363, A.TRAINER, 3484, A.TRAINER, 3523, A.TRAINER, 3704, A.TRAINER, 4159, A.TRAINER, 4193, A.TRAINER, 4576, A.TRAINER, 5153, A.TRAINER, 11052, A.TRAINER, 11557, A.TRAINER, 16366, A.TRAINER, 16640, A.TRAINER, 16729, A.TRAINER, 17487, A.TRAINER, 18749, A.TRAINER, 18772, A.TRAINER, 28699, A.TRAINER, 33580, A.TRAINER, 27001, A.TRAINER, 33613, A.TRAINER, 33636, A.TRAINER, 26914, A.TRAINER, 26969, A.TRAINER, 26964, A.TRAINER, 33684)

	-- Linen Boots -- 2386
	AddRecipe(2386, 65, 2569, R_COMMON, GAME_ORIG, 65, 90, 107, 125)
	self:addTradeFlags(RecipeDB, 2386, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.HEALER, F.CASTER, F.CLOTH)
	self:addTradeAcquire(RecipeDB, 2386, A.TRAINER, 1103, A.TRAINER, 1346, A.TRAINER, 2399, A.TRAINER, 2627, A.TRAINER, 3004, A.TRAINER, 3363, A.TRAINER, 3484, A.TRAINER, 3523, A.TRAINER, 3704, A.TRAINER, 4159, A.TRAINER, 4193, A.TRAINER, 4576, A.TRAINER, 5153, A.TRAINER, 11052, A.TRAINER, 11557, A.TRAINER, 16366, A.TRAINER, 16640, A.TRAINER, 16729, A.TRAINER, 17487, A.TRAINER, 18749, A.TRAINER, 18772, A.TRAINER, 28699, A.TRAINER, 33580, A.TRAINER, 27001, A.TRAINER, 33613, A.TRAINER, 33636, A.TRAINER, 26914, A.TRAINER, 26969, A.TRAINER, 26964, A.TRAINER, 33684)

	-- Linen Cloak -- 2387
	AddRecipe(2387, 1, 2570, R_COMMON, GAME_ORIG, 1, 35, 47, 60)
	self:addTradeFlags(RecipeDB, 2387, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.CLOAK)
	self:addTradeAcquire(RecipeDB, 2387, A.CUSTOM, 8)

	-- Red Linen Robe -- 2389
	AddRecipe(2389, 40, 2572, R_UNCOMMON, GAME_ORIG, 40, 65, 82, 100)
	self:addTradeFlags(RecipeDB, 2389, F.ALLIANCE, F.HORDE, F.WORLD_DROP, F.IBOE, F.RBOE, F.CLOTH)
	self:addTradeAcquire(RecipeDB, 2389, A.WORLD_DROP, 2)

	-- Red Linen Shirt -- 2392
	AddRecipe(2392, 40, 2575, R_COMMON, GAME_ORIG, 40, 65, 82, 100)
	self:addTradeFlags(RecipeDB, 2392, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP)
	self:addTradeAcquire(RecipeDB, 2392, A.TRAINER, 1103, A.TRAINER, 1346, A.TRAINER, 2399, A.TRAINER, 2627, A.TRAINER, 3004, A.TRAINER, 3363, A.TRAINER, 3484, A.TRAINER, 3523, A.TRAINER, 3704, A.TRAINER, 4159, A.TRAINER, 4193, A.TRAINER, 4576, A.TRAINER, 5153, A.TRAINER, 11052, A.TRAINER, 11557, A.TRAINER, 16366, A.TRAINER, 16640, A.TRAINER, 16729, A.TRAINER, 17487, A.TRAINER, 18749, A.TRAINER, 18772, A.TRAINER, 28699, A.TRAINER, 33580, A.TRAINER, 27001, A.TRAINER, 33613, A.TRAINER, 33636, A.TRAINER, 26914, A.TRAINER, 26969, A.TRAINER, 26964, A.TRAINER, 33684)

	-- White Linen Shirt -- 2393
	AddRecipe(2393, 1, 2576, R_COMMON, GAME_ORIG, 1, 35, 47, 60)
	self:addTradeFlags(RecipeDB, 2393, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP)
	self:addTradeAcquire(RecipeDB, 2393, A.TRAINER, 1103, A.TRAINER, 1346, A.TRAINER, 2399, A.TRAINER, 2627, A.TRAINER, 3004, A.TRAINER, 3363, A.TRAINER, 3484, A.TRAINER, 3523, A.TRAINER, 3704, A.TRAINER, 4159, A.TRAINER, 4193, A.TRAINER, 4576, A.TRAINER, 5153, A.TRAINER, 11052, A.TRAINER, 11557, A.TRAINER, 16366, A.TRAINER, 16640, A.TRAINER, 16729, A.TRAINER, 17487, A.TRAINER, 18749, A.TRAINER, 18772, A.TRAINER, 28699, A.TRAINER, 33580, A.TRAINER, 27001, A.TRAINER, 33613, A.TRAINER, 33636, A.TRAINER, 26914, A.TRAINER, 26969, A.TRAINER, 26964, A.TRAINER, 33684)

	-- Blue Linen Shirt -- 2394
	AddRecipe(2394, 40, 2577, R_COMMON, GAME_ORIG, 40, 65, 82, 100)
	self:addTradeFlags(RecipeDB, 2394, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP)
	self:addTradeAcquire(RecipeDB, 2394, A.TRAINER, 1103, A.TRAINER, 1346, A.TRAINER, 2399, A.TRAINER, 2627, A.TRAINER, 3004, A.TRAINER, 3363, A.TRAINER, 3484, A.TRAINER, 3523, A.TRAINER, 3704, A.TRAINER, 4159, A.TRAINER, 4193, A.TRAINER, 4576, A.TRAINER, 5153, A.TRAINER, 11052, A.TRAINER, 11557, A.TRAINER, 16366, A.TRAINER, 16640, A.TRAINER, 16729, A.TRAINER, 17487, A.TRAINER, 18749, A.TRAINER, 18772, A.TRAINER, 28699, A.TRAINER, 33580, A.TRAINER, 27001, A.TRAINER, 33613, A.TRAINER, 33636, A.TRAINER, 26914, A.TRAINER, 26969, A.TRAINER, 26964, A.TRAINER, 33684)

	-- Barbaric Linen Vest -- 2395
	AddRecipe(2395, 70, 2578, R_COMMON, GAME_ORIG, 70, 95, 112, 130)
	self:addTradeFlags(RecipeDB, 2395, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.HEALER, F.CASTER, F.CLOTH)
	self:addTradeAcquire(RecipeDB, 2395, A.TRAINER, 1103, A.TRAINER, 1346, A.TRAINER, 2399, A.TRAINER, 2627, A.TRAINER, 3004, A.TRAINER, 3363, A.TRAINER, 3484, A.TRAINER, 3523, A.TRAINER, 3704, A.TRAINER, 4159, A.TRAINER, 4193, A.TRAINER, 4576, A.TRAINER, 5153, A.TRAINER, 11052, A.TRAINER, 11557, A.TRAINER, 16366, A.TRAINER, 16640, A.TRAINER, 16729, A.TRAINER, 17487, A.TRAINER, 18749, A.TRAINER, 18772, A.TRAINER, 28699, A.TRAINER, 33580, A.TRAINER, 27001, A.TRAINER, 33613, A.TRAINER, 33636, A.TRAINER, 26914, A.TRAINER, 26969, A.TRAINER, 26964, A.TRAINER, 33684)

	-- Green Linen Shirt -- 2396
	AddRecipe(2396, 70, 2579, R_COMMON, GAME_ORIG, 70, 95, 112, 130)
	self:addTradeFlags(RecipeDB, 2396, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP)
	self:addTradeAcquire(RecipeDB, 2396, A.TRAINER, 1103, A.TRAINER, 1346, A.TRAINER, 2399, A.TRAINER, 2627, A.TRAINER, 3004, A.TRAINER, 3363, A.TRAINER, 3484, A.TRAINER, 3523, A.TRAINER, 3704, A.TRAINER, 4159, A.TRAINER, 4193, A.TRAINER, 4576, A.TRAINER, 5153, A.TRAINER, 11052, A.TRAINER, 11557, A.TRAINER, 16366, A.TRAINER, 16640, A.TRAINER, 16729, A.TRAINER, 17487, A.TRAINER, 18749, A.TRAINER, 18772, A.TRAINER, 28699, A.TRAINER, 33580, A.TRAINER, 27001, A.TRAINER, 33613, A.TRAINER, 33636, A.TRAINER, 26914, A.TRAINER, 26969, A.TRAINER, 26964, A.TRAINER, 33684)

	-- Reinforced Linen Cape -- 2397
	AddRecipe(2397, 60, 2580, R_COMMON, GAME_ORIG, 60, 85, 102, 120)
	self:addTradeFlags(RecipeDB, 2397, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.CLOAK)
	self:addTradeAcquire(RecipeDB, 2397, A.TRAINER, 1103, A.TRAINER, 1346, A.TRAINER, 2399, A.TRAINER, 2627, A.TRAINER, 3004, A.TRAINER, 3363, A.TRAINER, 3484, A.TRAINER, 3523, A.TRAINER, 3704, A.TRAINER, 4159, A.TRAINER, 4193, A.TRAINER, 4576, A.TRAINER, 5153, A.TRAINER, 11052, A.TRAINER, 11557, A.TRAINER, 16366, A.TRAINER, 16640, A.TRAINER, 16729, A.TRAINER, 17487, A.TRAINER, 18749, A.TRAINER, 18772, A.TRAINER, 28699, A.TRAINER, 33580, A.TRAINER, 27001, A.TRAINER, 33613, A.TRAINER, 33636, A.TRAINER, 26914, A.TRAINER, 26969, A.TRAINER, 26964, A.TRAINER, 33684)

	-- Green Woolen Vest -- 2399
	AddRecipe(2399, 85, 2582, R_COMMON, GAME_ORIG, 85, 110, 127, 145)
	self:addTradeFlags(RecipeDB, 2399, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.CLOTH)
	self:addTradeAcquire(RecipeDB, 2399, A.TRAINER, 1346, A.TRAINER, 2399, A.TRAINER, 2627, A.TRAINER, 3004, A.TRAINER, 3363, A.TRAINER, 3704, A.TRAINER, 4159, A.TRAINER, 4576, A.TRAINER, 5153, A.TRAINER, 11052, A.TRAINER, 11557, A.TRAINER, 16640, A.TRAINER, 16729, A.TRAINER, 17487, A.TRAINER, 18749, A.TRAINER, 18772, A.TRAINER, 28699, A.TRAINER, 3484, A.TRAINER, 33580, A.TRAINER, 1103, A.TRAINER, 27001, A.TRAINER, 33613, A.TRAINER, 33636, A.TRAINER, 26914, A.TRAINER, 16366, A.TRAINER, 26969, A.TRAINER, 4193, A.TRAINER, 26964, A.TRAINER, 3523, A.TRAINER, 33684)

	-- Woolen Boots -- 2401
	AddRecipe(2401, 95, 2583, R_COMMON, GAME_ORIG, 95, 120, 137, 155)
	self:addTradeFlags(RecipeDB, 2401, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.HEALER, F.CASTER, F.CLOTH)
	self:addTradeAcquire(RecipeDB, 2401, A.TRAINER, 1346, A.TRAINER, 2399, A.TRAINER, 2627, A.TRAINER, 3004, A.TRAINER, 3363, A.TRAINER, 3704, A.TRAINER, 4159, A.TRAINER, 4576, A.TRAINER, 5153, A.TRAINER, 11052, A.TRAINER, 11557, A.TRAINER, 16640, A.TRAINER, 16729, A.TRAINER, 17487, A.TRAINER, 18749, A.TRAINER, 18772, A.TRAINER, 28699, A.TRAINER, 3484, A.TRAINER, 33580, A.TRAINER, 1103, A.TRAINER, 27001, A.TRAINER, 33613, A.TRAINER, 33636, A.TRAINER, 26914, A.TRAINER, 16366, A.TRAINER, 26969, A.TRAINER, 4193, A.TRAINER, 26964, A.TRAINER, 3523, A.TRAINER, 33684)

	-- Woolen Cape -- 2402
	AddRecipe(2402, 75, 2584, R_COMMON, GAME_ORIG, 75, 100, 117, 135)
	self:addTradeFlags(RecipeDB, 2402, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.CLOAK)
	self:addTradeAcquire(RecipeDB, 2402, A.TRAINER, 1103, A.TRAINER, 1346, A.TRAINER, 2399, A.TRAINER, 2627, A.TRAINER, 3004, A.TRAINER, 3363, A.TRAINER, 3484, A.TRAINER, 3523, A.TRAINER, 3704, A.TRAINER, 4159, A.TRAINER, 4193, A.TRAINER, 4576, A.TRAINER, 5153, A.TRAINER, 11052, A.TRAINER, 11557, A.TRAINER, 16366, A.TRAINER, 16640, A.TRAINER, 16729, A.TRAINER, 17487, A.TRAINER, 18749, A.TRAINER, 18772, A.TRAINER, 28699, A.TRAINER, 33580, A.TRAINER, 27001, A.TRAINER, 33613, A.TRAINER, 33636, A.TRAINER, 26914, A.TRAINER, 26969, A.TRAINER, 26964, A.TRAINER, 33684)

	-- Gray Woolen Robe -- 2403
	AddRecipe(2403, 105, 2585, R_UNCOMMON, GAME_ORIG, 105, 130, 147, 165)
	self:addTradeFlags(RecipeDB, 2403, F.ALLIANCE, F.HORDE, F.WORLD_DROP, F.IBOE, F.RBOE, F.CLOTH)
	self:addTradeAcquire(RecipeDB, 2403, A.WORLD_DROP, 2)

	-- Gray Woolen Shirt -- 2406
	AddRecipe(2406, 100, 2587, R_COMMON, GAME_ORIG, 100, 110, 120, 130)
	self:addTradeFlags(RecipeDB, 2406, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP)
	self:addTradeAcquire(RecipeDB, 2406, A.TRAINER, 1346, A.TRAINER, 2399, A.TRAINER, 2627, A.TRAINER, 3004, A.TRAINER, 3363, A.TRAINER, 3704, A.TRAINER, 4159, A.TRAINER, 4576, A.TRAINER, 5153, A.TRAINER, 11052, A.TRAINER, 11557, A.TRAINER, 16640, A.TRAINER, 16729, A.TRAINER, 17487, A.TRAINER, 18749, A.TRAINER, 18772, A.TRAINER, 28699, A.TRAINER, 3484, A.TRAINER, 33580, A.TRAINER, 1103, A.TRAINER, 27001, A.TRAINER, 33613, A.TRAINER, 33636, A.TRAINER, 26914, A.TRAINER, 16366, A.TRAINER, 26969, A.TRAINER, 4193, A.TRAINER, 26964, A.TRAINER, 3523, A.TRAINER, 33684)

	-- Bolt of Linen Cloth -- 2963
	AddRecipe(2963, 1, 2996, R_COMMON, GAME_ORIG, 1, 25, 37, 50)
	self:addTradeFlags(RecipeDB, 2963, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.CLOTH)
	self:addTradeAcquire(RecipeDB, 2963, A.CUSTOM, 8)

	-- Bolt of Woolen Cloth -- 2964
	AddRecipe(2964, 75, 2997, R_COMMON, GAME_ORIG, 75, 90, 97, 105)
	self:addTradeFlags(RecipeDB, 2964, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.CLOTH)
	self:addTradeAcquire(RecipeDB, 2964, A.TRAINER, 1103, A.TRAINER, 1346, A.TRAINER, 2399, A.TRAINER, 2627, A.TRAINER, 3004, A.TRAINER, 3363, A.TRAINER, 3484, A.TRAINER, 3523, A.TRAINER, 3704, A.TRAINER, 4159, A.TRAINER, 4193, A.TRAINER, 4576, A.TRAINER, 5153, A.TRAINER, 11052, A.TRAINER, 11557, A.TRAINER, 16366, A.TRAINER, 16640, A.TRAINER, 16729, A.TRAINER, 17487, A.TRAINER, 18749, A.TRAINER, 18772, A.TRAINER, 28699, A.TRAINER, 33580, A.TRAINER, 27001, A.TRAINER, 33613, A.TRAINER, 33636, A.TRAINER, 26914, A.TRAINER, 26969, A.TRAINER, 26964, A.TRAINER, 33684)

	-- Linen Bag -- 3755
	AddRecipe(3755, 45, 4238, R_COMMON, GAME_ORIG, 45, 70, 87, 105)
	self:addTradeFlags(RecipeDB, 3755, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP)
	self:addTradeAcquire(RecipeDB, 3755, A.TRAINER, 1103, A.TRAINER, 1346, A.TRAINER, 2399, A.TRAINER, 2627, A.TRAINER, 3004, A.TRAINER, 3363, A.TRAINER, 3484, A.TRAINER, 3523, A.TRAINER, 4159, A.TRAINER, 4193, A.TRAINER, 4576, A.TRAINER, 5153, A.TRAINER, 11052, A.TRAINER, 11557, A.TRAINER, 16366, A.TRAINER, 16640, A.TRAINER, 16729, A.TRAINER, 17487, A.TRAINER, 18749, A.TRAINER, 18772, A.TRAINER, 28699, A.TRAINER, 3704, A.TRAINER, 33580, A.TRAINER, 27001, A.TRAINER, 33613, A.TRAINER, 33636, A.TRAINER, 26914, A.TRAINER, 26969, A.TRAINER, 26964, A.TRAINER, 33684)

	-- Woolen Bag -- 3757
	AddRecipe(3757, 80, 4240, R_COMMON, GAME_ORIG, 80, 105, 122, 140)
	self:addTradeFlags(RecipeDB, 3757, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP)
	self:addTradeAcquire(RecipeDB, 3757, A.TRAINER, 1346, A.TRAINER, 2399, A.TRAINER, 2627, A.TRAINER, 3004, A.TRAINER, 3363, A.TRAINER, 3704, A.TRAINER, 4159, A.TRAINER, 4576, A.TRAINER, 5153, A.TRAINER, 11052, A.TRAINER, 11557, A.TRAINER, 16640, A.TRAINER, 16729, A.TRAINER, 17487, A.TRAINER, 18749, A.TRAINER, 18772, A.TRAINER, 28699, A.TRAINER, 3484, A.TRAINER, 33580, A.TRAINER, 1103, A.TRAINER, 27001, A.TRAINER, 33613, A.TRAINER, 33636, A.TRAINER, 26914, A.TRAINER, 16366, A.TRAINER, 26969, A.TRAINER, 4193, A.TRAINER, 26964, A.TRAINER, 3523, A.TRAINER, 33684)

	-- Green Woolen Bag -- 3758
	AddRecipe(3758, 95, 4241, R_UNCOMMON, GAME_ORIG, 95, 120, 137, 155)
	self:addTradeFlags(RecipeDB, 3758, F.ALLIANCE, F.HORDE, F.WORLD_DROP, F.IBOE, F.RBOE)
	self:addTradeAcquire(RecipeDB, 3758, A.WORLD_DROP, 2)

	-- Small Silk Pack -- 3813
	AddRecipe(3813, 150, 4245, R_COMMON, GAME_ORIG, 150, 170, 185, 200)
	self:addTradeFlags(RecipeDB, 3813, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP)
	self:addTradeAcquire(RecipeDB, 3813, A.TRAINER, 1346, A.TRAINER, 2399, A.TRAINER, 2627, A.TRAINER, 3004, A.TRAINER, 3363, A.TRAINER, 3704, A.TRAINER, 4159, A.TRAINER, 4576, A.TRAINER, 5153, A.TRAINER, 11052, A.TRAINER, 11557, A.TRAINER, 16640, A.TRAINER, 16729, A.TRAINER, 17487, A.TRAINER, 18749, A.TRAINER, 18772, A.TRAINER, 28699, A.TRAINER, 3484, A.TRAINER, 33580, A.TRAINER, 1103, A.TRAINER, 27001, A.TRAINER, 33613, A.TRAINER, 33636, A.TRAINER, 26914, A.TRAINER, 16366, A.TRAINER, 26969, A.TRAINER, 4193, A.TRAINER, 26964, A.TRAINER, 3523, A.TRAINER, 33684)

	-- Bolt of Silk Cloth -- 3839
	AddRecipe(3839, 125, 4305, R_COMMON, GAME_ORIG, 125, 135, 140, 145)
	self:addTradeFlags(RecipeDB, 3839, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.CLOTH)
	self:addTradeAcquire(RecipeDB, 3839, A.TRAINER, 1346, A.TRAINER, 3004, A.TRAINER, 3363, A.TRAINER, 4576, A.TRAINER, 5153, A.TRAINER, 11557, A.TRAINER, 16640, A.TRAINER, 16729, A.TRAINER, 17487, A.TRAINER, 18749, A.TRAINER, 18772, A.TRAINER, 28699, A.TRAINER, 4159, A.TRAINER, 3484, A.TRAINER, 3704, A.TRAINER, 2627, A.TRAINER, 33580, A.TRAINER, 1103, A.TRAINER, 27001, A.TRAINER, 33613, A.TRAINER, 33636, A.TRAINER, 11052, A.TRAINER, 2399, A.TRAINER, 26914, A.TRAINER, 16366, A.TRAINER, 26969, A.TRAINER, 4193, A.TRAINER, 26964, A.TRAINER, 3523, A.TRAINER, 33684)

	-- Heavy Linen Gloves -- 3840
	AddRecipe(3840, 35, 4307, R_COMMON, GAME_ORIG, 35, 60, 77, 95)
	self:addTradeFlags(RecipeDB, 3840, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.HEALER, F.CASTER, F.CLOTH)
	self:addTradeAcquire(RecipeDB, 3840, A.TRAINER, 1103, A.TRAINER, 1346, A.TRAINER, 2399, A.TRAINER, 2627, A.TRAINER, 3004, A.TRAINER, 3363, A.TRAINER, 3484, A.TRAINER, 3523, A.TRAINER, 3704, A.TRAINER, 4159, A.TRAINER, 4193, A.TRAINER, 4576, A.TRAINER, 5153, A.TRAINER, 11052, A.TRAINER, 11557, A.TRAINER, 16366, A.TRAINER, 16640, A.TRAINER, 16729, A.TRAINER, 17487, A.TRAINER, 18749, A.TRAINER, 18772, A.TRAINER, 28699, A.TRAINER, 33580, A.TRAINER, 27001, A.TRAINER, 33613, A.TRAINER, 33636, A.TRAINER, 26914, A.TRAINER, 26969, A.TRAINER, 26964, A.TRAINER, 33684)

	-- Green Linen Bracers -- 3841
	AddRecipe(3841, 60, 4308, R_COMMON, GAME_ORIG, 60, 85, 102, 120)
	self:addTradeFlags(RecipeDB, 3841, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.CLOTH)
	self:addTradeAcquire(RecipeDB, 3841, A.TRAINER, 1103, A.TRAINER, 1346, A.TRAINER, 2399, A.TRAINER, 2627, A.TRAINER, 3004, A.TRAINER, 3363, A.TRAINER, 3484, A.TRAINER, 3523, A.TRAINER, 3704, A.TRAINER, 4159, A.TRAINER, 4193, A.TRAINER, 4576, A.TRAINER, 5153, A.TRAINER, 11052, A.TRAINER, 11557, A.TRAINER, 16366, A.TRAINER, 16640, A.TRAINER, 16729, A.TRAINER, 17487, A.TRAINER, 18749, A.TRAINER, 18772, A.TRAINER, 28699, A.TRAINER, 33580, A.TRAINER, 27001, A.TRAINER, 33613, A.TRAINER, 33636, A.TRAINER, 26914, A.TRAINER, 26969, A.TRAINER, 26964, A.TRAINER, 33684)

	-- Handstitched Linen Britches -- 3842
	AddRecipe(3842, 70, 4309, R_COMMON, GAME_ORIG, 70, 95, 112, 130)
	self:addTradeFlags(RecipeDB, 3842, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.HEALER, F.CASTER, F.CLOTH)
	self:addTradeAcquire(RecipeDB, 3842, A.TRAINER, 1103, A.TRAINER, 1346, A.TRAINER, 2399, A.TRAINER, 2627, A.TRAINER, 3004, A.TRAINER, 3363, A.TRAINER, 3484, A.TRAINER, 3523, A.TRAINER, 3704, A.TRAINER, 4159, A.TRAINER, 4193, A.TRAINER, 4576, A.TRAINER, 5153, A.TRAINER, 11052, A.TRAINER, 11557, A.TRAINER, 16366, A.TRAINER, 16640, A.TRAINER, 16729, A.TRAINER, 17487, A.TRAINER, 18749, A.TRAINER, 18772, A.TRAINER, 28699, A.TRAINER, 33580, A.TRAINER, 27001, A.TRAINER, 33613, A.TRAINER, 33636, A.TRAINER, 26914, A.TRAINER, 26969, A.TRAINER, 26964, A.TRAINER, 33684)

	-- Heavy Woolen Gloves -- 3843
	AddRecipe(3843, 85, 4310, R_COMMON, GAME_ORIG, 85, 110, 127, 145)
	self:addTradeFlags(RecipeDB, 3843, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.HEALER, F.CASTER, F.CLOTH)
	self:addTradeAcquire(RecipeDB, 3843, A.TRAINER, 1346, A.TRAINER, 2399, A.TRAINER, 2627, A.TRAINER, 3004, A.TRAINER, 3363, A.TRAINER, 3704, A.TRAINER, 4159, A.TRAINER, 4576, A.TRAINER, 5153, A.TRAINER, 11052, A.TRAINER, 11557, A.TRAINER, 16640, A.TRAINER, 16729, A.TRAINER, 17487, A.TRAINER, 18749, A.TRAINER, 18772, A.TRAINER, 28699, A.TRAINER, 3484, A.TRAINER, 33580, A.TRAINER, 1103, A.TRAINER, 27001, A.TRAINER, 33613, A.TRAINER, 33636, A.TRAINER, 26914, A.TRAINER, 16366, A.TRAINER, 26969, A.TRAINER, 4193, A.TRAINER, 26964, A.TRAINER, 3523, A.TRAINER, 33684)

	-- Heavy Woolen Cloak -- 3844
	AddRecipe(3844, 100, 4311, R_UNCOMMON, GAME_ORIG, 100, 125, 142, 160)
	self:addTradeFlags(RecipeDB, 3844, F.ALLIANCE, F.HORDE, F.WORLD_DROP, F.IBOE, F.RBOE, F.HEALER, F.CASTER, F.CLOAK)
	self:addTradeAcquire(RecipeDB, 3844, A.WORLD_DROP, 2)

	-- Soft-soled Linen Boots -- 3845
	AddRecipe(3845, 80, 4312, R_COMMON, GAME_ORIG, 80, 105, 122, 140)
	self:addTradeFlags(RecipeDB, 3845, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.CLOTH)
	self:addTradeAcquire(RecipeDB, 3845, A.TRAINER, 1346, A.TRAINER, 2399, A.TRAINER, 2627, A.TRAINER, 3004, A.TRAINER, 3363, A.TRAINER, 3704, A.TRAINER, 4159, A.TRAINER, 4576, A.TRAINER, 5153, A.TRAINER, 11052, A.TRAINER, 11557, A.TRAINER, 16640, A.TRAINER, 16729, A.TRAINER, 17487, A.TRAINER, 18749, A.TRAINER, 18772, A.TRAINER, 28699, A.TRAINER, 3484, A.TRAINER, 33580, A.TRAINER, 1103, A.TRAINER, 27001, A.TRAINER, 33613, A.TRAINER, 33636, A.TRAINER, 26914, A.TRAINER, 16366, A.TRAINER, 26969, A.TRAINER, 4193, A.TRAINER, 26964, A.TRAINER, 3523, A.TRAINER, 33684)

	-- Red Woolen Boots -- 3847
	AddRecipe(3847, 95, 4313, R_UNCOMMON, GAME_ORIG, 95, 120, 137, 155)
	self:addTradeFlags(RecipeDB, 3847, F.ALLIANCE, F.HORDE, F.WORLD_DROP, F.IBOE, F.RBOE, F.HEALER, F.CASTER, F.CLOTH)
	self:addTradeAcquire(RecipeDB, 3847, A.WORLD_DROP, 2)

	-- Double-stitched Woolen Shoulders -- 3848
	AddRecipe(3848, 110, 4314, R_COMMON, GAME_ORIG, 110, 135, 152, 170)
	self:addTradeFlags(RecipeDB, 3848, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.CLOTH)
	self:addTradeAcquire(RecipeDB, 3848, A.TRAINER, 1346, A.TRAINER, 2399, A.TRAINER, 2627, A.TRAINER, 3004, A.TRAINER, 3363, A.TRAINER, 3704, A.TRAINER, 4159, A.TRAINER, 4576, A.TRAINER, 5153, A.TRAINER, 11052, A.TRAINER, 11557, A.TRAINER, 16640, A.TRAINER, 16729, A.TRAINER, 17487, A.TRAINER, 18749, A.TRAINER, 18772, A.TRAINER, 28699, A.TRAINER, 3484, A.TRAINER, 33580, A.TRAINER, 1103, A.TRAINER, 27001, A.TRAINER, 33613, A.TRAINER, 33636, A.TRAINER, 26914, A.TRAINER, 16366, A.TRAINER, 26969, A.TRAINER, 4193, A.TRAINER, 26964, A.TRAINER, 3523, A.TRAINER, 33684)

	-- Reinforced Woolen Shoulders -- 3849
	AddRecipe(3849, 120, 4315, R_UNCOMMON, GAME_ORIG, 120, 145, 162, 180)
	self:addTradeFlags(RecipeDB, 3849, F.ALLIANCE, F.HORDE, F.WORLD_DROP, F.IBOE, F.RBOE, F.HEALER, F.CASTER, F.CLOTH)
	self:addTradeAcquire(RecipeDB, 3849, A.WORLD_DROP, 2)

	-- Heavy Woolen Pants -- 3850
	AddRecipe(3850, 110, 4316, R_COMMON, GAME_ORIG, 110, 135, 152, 170)
	self:addTradeFlags(RecipeDB, 3850, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.HEALER, F.CASTER, F.CLOTH)
	self:addTradeAcquire(RecipeDB, 3850, A.TRAINER, 1346, A.TRAINER, 2399, A.TRAINER, 2627, A.TRAINER, 3004, A.TRAINER, 3363, A.TRAINER, 3704, A.TRAINER, 4159, A.TRAINER, 4576, A.TRAINER, 5153, A.TRAINER, 11052, A.TRAINER, 11557, A.TRAINER, 16640, A.TRAINER, 16729, A.TRAINER, 17487, A.TRAINER, 18749, A.TRAINER, 18772, A.TRAINER, 28699, A.TRAINER, 3484, A.TRAINER, 33580, A.TRAINER, 1103, A.TRAINER, 27001, A.TRAINER, 33613, A.TRAINER, 33636, A.TRAINER, 26914, A.TRAINER, 16366, A.TRAINER, 26969, A.TRAINER, 4193, A.TRAINER, 26964, A.TRAINER, 3523, A.TRAINER, 33684)

	-- Phoenix Pants -- 3851
	AddRecipe(3851, 125, 4317, R_UNCOMMON, GAME_ORIG, 125, 150, 167, 185)
	self:addTradeFlags(RecipeDB, 3851, F.ALLIANCE, F.HORDE, F.WORLD_DROP, F.IBOE, F.RBOE, F.HEALER, F.CASTER, F.CLOTH)
	self:addTradeAcquire(RecipeDB, 3851, A.WORLD_DROP, 2)

	-- Gloves of Meditation -- 3852
	AddRecipe(3852, 130, 4318, R_COMMON, GAME_ORIG, 130, 150, 165, 180)
	self:addTradeFlags(RecipeDB, 3852, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.HEALER, F.CASTER, F.CLOTH)
	self:addTradeAcquire(RecipeDB, 3852, A.TRAINER, 1346, A.TRAINER, 2399, A.TRAINER, 2627, A.TRAINER, 3004, A.TRAINER, 3363, A.TRAINER, 3704, A.TRAINER, 4159, A.TRAINER, 4576, A.TRAINER, 5153, A.TRAINER, 11052, A.TRAINER, 11557, A.TRAINER, 16640, A.TRAINER, 16729, A.TRAINER, 17487, A.TRAINER, 18749, A.TRAINER, 18772, A.TRAINER, 28699, A.TRAINER, 3484, A.TRAINER, 33580, A.TRAINER, 1103, A.TRAINER, 27001, A.TRAINER, 33613, A.TRAINER, 33636, A.TRAINER, 26914, A.TRAINER, 16366, A.TRAINER, 26969, A.TRAINER, 4193, A.TRAINER, 26964, A.TRAINER, 3523, A.TRAINER, 33684)

	-- Azure Silk Gloves -- 3854
	AddRecipe(3854, 145, 4319, R_COMMON, GAME_ORIG, 145, 165, 180, 195)
	self:addTradeFlags(RecipeDB, 3854, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOE, F.HEALER, F.CASTER, F.CLOTH)
	self:addTradeAcquire(RecipeDB, 3854, A.VENDOR, 2679, A.VENDOR, 9636)

	-- Spidersilk Boots -- 3855
	AddRecipe(3855, 125, 4320, R_COMMON, GAME_ORIG, 125, 150, 167, 185)
	self:addTradeFlags(RecipeDB, 3855, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.HEALER, F.CASTER, F.CLOTH)
	self:addTradeAcquire(RecipeDB, 3855, A.TRAINER, 1346, A.TRAINER, 2399, A.TRAINER, 2627, A.TRAINER, 3004, A.TRAINER, 3363, A.TRAINER, 3704, A.TRAINER, 4159, A.TRAINER, 4576, A.TRAINER, 5153, A.TRAINER, 11052, A.TRAINER, 11557, A.TRAINER, 16640, A.TRAINER, 16729, A.TRAINER, 17487, A.TRAINER, 18749, A.TRAINER, 18772, A.TRAINER, 28699, A.TRAINER, 3484, A.TRAINER, 33580, A.TRAINER, 1103, A.TRAINER, 27001, A.TRAINER, 33613, A.TRAINER, 33636, A.TRAINER, 26914, A.TRAINER, 16366, A.TRAINER, 26969, A.TRAINER, 4193, A.TRAINER, 26964, A.TRAINER, 3523, A.TRAINER, 33684)

	-- Spider Silk Slippers -- 3856
	AddRecipe(3856, 140, 4321, R_UNCOMMON, GAME_ORIG, 140, 160, 175, 190)
	self:addTradeFlags(RecipeDB, 3856, F.ALLIANCE, F.HORDE, F.WORLD_DROP, F.IBOE, F.RBOE, F.HEALER, F.CASTER, F.CLOTH)
	self:addTradeAcquire(RecipeDB, 3856, A.WORLD_DROP, 2)

	-- Enchanter's Cowl -- 3857
	AddRecipe(3857, 165, 4322, R_COMMON, GAME_ORIG, 165, 185, 200, 215)
	self:addTradeFlags(RecipeDB, 3857, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOE, F.HEALER, F.CASTER, F.CLOTH)
	self:addTradeAcquire(RecipeDB, 3857, A.VENDOR, 2670)

	-- Shadow Hood -- 3858
	AddRecipe(3858, 170, 4323, R_UNCOMMON, GAME_ORIG, 170, 190, 205, 220)
	self:addTradeFlags(RecipeDB, 3858, F.ALLIANCE, F.HORDE, F.WORLD_DROP, F.IBOE, F.RBOE, F.HEALER, F.CASTER, F.CLOTH)
	self:addTradeAcquire(RecipeDB, 3858, A.WORLD_DROP, 2)

	-- Azure Silk Vest -- 3859
	AddRecipe(3859, 150, 4324, R_COMMON, GAME_ORIG, 150, 170, 185, 200)
	self:addTradeFlags(RecipeDB, 3859, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.HEALER, F.CASTER, F.CLOTH)
	self:addTradeAcquire(RecipeDB, 3859, A.TRAINER, 1346, A.TRAINER, 2399, A.TRAINER, 2627, A.TRAINER, 3004, A.TRAINER, 3363, A.TRAINER, 3704, A.TRAINER, 4159, A.TRAINER, 4576, A.TRAINER, 5153, A.TRAINER, 11052, A.TRAINER, 11557, A.TRAINER, 16640, A.TRAINER, 16729, A.TRAINER, 17487, A.TRAINER, 18749, A.TRAINER, 18772, A.TRAINER, 28699, A.TRAINER, 3484, A.TRAINER, 33580, A.TRAINER, 1103, A.TRAINER, 27001, A.TRAINER, 33613, A.TRAINER, 33636, A.TRAINER, 26914, A.TRAINER, 16366, A.TRAINER, 26969, A.TRAINER, 4193, A.TRAINER, 26964, A.TRAINER, 3523, A.TRAINER, 33684)

	-- Boots of the Enchanter -- 3860
	AddRecipe(3860, 175, 4325, R_UNCOMMON, GAME_ORIG, 175, 195, 210, 225)
	self:addTradeFlags(RecipeDB, 3860, F.ALLIANCE, F.HORDE, F.WORLD_DROP, F.IBOE, F.RBOE, F.HEALER, F.CASTER, F.CLOTH)
	self:addTradeAcquire(RecipeDB, 3860, A.WORLD_DROP, 2)

	-- Long Silken Cloak -- 3861
	AddRecipe(3861, 185, 4326, R_COMMON, GAME_ORIG, 185, 205, 220, 235)
	self:addTradeFlags(RecipeDB, 3861, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.HEALER, F.CASTER, F.CLOAK)
	self:addTradeAcquire(RecipeDB, 3861, A.TRAINER, 1346, A.TRAINER, 2399, A.TRAINER, 4576, A.TRAINER, 11052, A.TRAINER, 11557, A.TRAINER, 18749, A.TRAINER, 18772, A.TRAINER, 28699, A.TRAINER, 4159, A.TRAINER, 16729, A.TRAINER, 3004, A.TRAINER, 3484, A.TRAINER, 3704, A.TRAINER, 2627, A.TRAINER, 33580, A.TRAINER, 3363, A.TRAINER, 1103, A.TRAINER, 27001, A.TRAINER, 33613, A.TRAINER, 33636, A.TRAINER, 26914, A.TRAINER, 17487, A.TRAINER, 16640, A.TRAINER, 16366, A.TRAINER, 26969, A.TRAINER, 5153, A.TRAINER, 4193, A.TRAINER, 26964, A.TRAINER, 3523, A.TRAINER, 33684)

	-- Icy Cloak -- 3862
	AddRecipe(3862, 200, 4327, R_COMMON, GAME_ORIG, 200, 220, 235, 250)
	self:addTradeFlags(RecipeDB, 3862, F.ALLIANCE, F.VENDOR, F.IBOE, F.RBOE, F.HEALER, F.CASTER, F.CLOAK)
	self:addTradeAcquire(RecipeDB, 3862, A.VENDOR, 2381)

	-- Spider Belt -- 3863
	AddRecipe(3863, 180, 4328, R_UNCOMMON, GAME_ORIG, 180, 200, 215, 230)
	self:addTradeFlags(RecipeDB, 3863, F.ALLIANCE, F.HORDE, F.WORLD_DROP, F.IBOE, F.RBOE, F.CLOTH)
	self:addTradeAcquire(RecipeDB, 3863, A.WORLD_DROP, 2)

	-- Star Belt -- 3864
	AddRecipe(3864, 200, 4329, R_UNCOMMON, GAME_ORIG, 200, 220, 235, 250)
	self:addTradeFlags(RecipeDB, 3864, F.ALLIANCE, F.HORDE, F.WORLD_DROP, F.IBOE, F.RBOE, F.HEALER, F.CASTER, F.CLOTH)
	self:addTradeAcquire(RecipeDB, 3864, A.WORLD_DROP, 2)

	-- Bolt of Mageweave -- 3865
	AddRecipe(3865, 175, 4339, R_COMMON, GAME_ORIG, 175, 180, 182, 185)
	self:addTradeFlags(RecipeDB, 3865, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP)
	self:addTradeAcquire(RecipeDB, 3865, A.TRAINER, 1346, A.TRAINER, 2399, A.TRAINER, 4576, A.TRAINER, 11052, A.TRAINER, 11557, A.TRAINER, 18749, A.TRAINER, 18772, A.TRAINER, 28699, A.TRAINER, 4159, A.TRAINER, 16729, A.TRAINER, 3004, A.TRAINER, 3484, A.TRAINER, 3704, A.TRAINER, 2627, A.TRAINER, 33580, A.TRAINER, 3363, A.TRAINER, 1103, A.TRAINER, 27001, A.TRAINER, 33613, A.TRAINER, 33636, A.TRAINER, 26914, A.TRAINER, 17487, A.TRAINER, 16640, A.TRAINER, 16366, A.TRAINER, 26969, A.TRAINER, 5153, A.TRAINER, 4193, A.TRAINER, 26964, A.TRAINER, 3523, A.TRAINER, 33684)

	-- Stylish Red Shirt -- 3866
	AddRecipe(3866, 110, 4330, R_COMMON, GAME_ORIG, 110, 135, 152, 170)
	self:addTradeFlags(RecipeDB, 3866, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP)
	self:addTradeAcquire(RecipeDB, 3866, A.TRAINER, 1346, A.TRAINER, 2399, A.TRAINER, 2627, A.TRAINER, 3004, A.TRAINER, 3363, A.TRAINER, 3704, A.TRAINER, 4159, A.TRAINER, 4576, A.TRAINER, 5153, A.TRAINER, 11052, A.TRAINER, 11557, A.TRAINER, 16640, A.TRAINER, 16729, A.TRAINER, 17487, A.TRAINER, 18749, A.TRAINER, 18772, A.TRAINER, 28699, A.TRAINER, 3484, A.TRAINER, 33580, A.TRAINER, 1103, A.TRAINER, 27001, A.TRAINER, 33613, A.TRAINER, 33636, A.TRAINER, 26914, A.TRAINER, 16366, A.TRAINER, 26969, A.TRAINER, 4193, A.TRAINER, 26964, A.TRAINER, 3523, A.TRAINER, 33684)

	-- Phoenix Gloves -- 3868
	AddRecipe(3868, 125, 4331, R_UNCOMMON, GAME_ORIG, 125, 150, 167, 185)
	self:addTradeFlags(RecipeDB, 3868, F.ALLIANCE, F.HORDE, F.WORLD_DROP, F.IBOE, F.RBOE, F.HEALER, F.CASTER, F.CLOTH)
	self:addTradeAcquire(RecipeDB, 3868, A.WORLD_DROP, 2)

	-- Bright Yellow Shirt -- 3869
	AddRecipe(3869, 135, 4332, R_COMMON, GAME_ORIG, 135, 145, 150, 155)
	self:addTradeFlags(RecipeDB, 3869, F.ALLIANCE, F.VENDOR, F.IBOE, F.RBOE)
	self:addTradeAcquire(RecipeDB, 3869, A.VENDOR, 2668)

	-- Dark Silk Shirt -- 3870
	AddRecipe(3870, 155, 4333, R_COMMON, GAME_ORIG, 155, 165, 170, 175)
	self:addTradeFlags(RecipeDB, 3870, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOE)
	self:addTradeAcquire(RecipeDB, 3870, A.VENDOR, 2394, A.VENDOR, 2669)

	-- Formal White Shirt -- 3871
	AddRecipe(3871, 170, 4334, R_COMMON, GAME_ORIG, 170, 180, 185, 190)
	self:addTradeFlags(RecipeDB, 3871, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP)
	self:addTradeAcquire(RecipeDB, 3871, A.TRAINER, 1346, A.TRAINER, 2399, A.TRAINER, 4576, A.TRAINER, 11052, A.TRAINER, 11557, A.TRAINER, 18749, A.TRAINER, 18772, A.TRAINER, 28699, A.TRAINER, 4159, A.TRAINER, 16729, A.TRAINER, 3004, A.TRAINER, 3484, A.TRAINER, 3704, A.TRAINER, 2627, A.TRAINER, 33580, A.TRAINER, 3363, A.TRAINER, 1103, A.TRAINER, 27001, A.TRAINER, 33613, A.TRAINER, 33636, A.TRAINER, 26914, A.TRAINER, 17487, A.TRAINER, 16640, A.TRAINER, 16366, A.TRAINER, 26969, A.TRAINER, 5153, A.TRAINER, 4193, A.TRAINER, 26964, A.TRAINER, 3523, A.TRAINER, 33684)

	-- Rich Purple Silk Shirt -- 3872
	AddRecipe(3872, 185, 4335, R_RARE, GAME_ORIG, 185, 195, 200, 205)
	self:addTradeFlags(RecipeDB, 3872, F.ALLIANCE, F.HORDE, F.WORLD_DROP, F.IBOE, F.RBOE)
	self:addTradeAcquire(RecipeDB, 3872, A.WORLD_DROP, 2)

	-- Black Swashbuckler's Shirt -- 3873
	AddRecipe(3873, 200, 4336, R_COMMON, GAME_ORIG, 200, 210, 215, 220)
	self:addTradeFlags(RecipeDB, 3873, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOP)
	self:addTradeAcquire(RecipeDB, 3873, A.VENDOR, 2663)

	-- Brown Linen Pants -- 3914
	AddRecipe(3914, 30, 4343, R_COMMON, GAME_ORIG, 30, 55, 72, 90)
	self:addTradeFlags(RecipeDB, 3914, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.CLOTH)
	self:addTradeAcquire(RecipeDB, 3914, A.TRAINER, 1103, A.TRAINER, 1346, A.TRAINER, 2399, A.TRAINER, 2627, A.TRAINER, 3004, A.TRAINER, 3363, A.TRAINER, 3484, A.TRAINER, 3523, A.TRAINER, 3704, A.TRAINER, 4159, A.TRAINER, 4193, A.TRAINER, 4576, A.TRAINER, 5153, A.TRAINER, 11052, A.TRAINER, 11557, A.TRAINER, 16366, A.TRAINER, 16640, A.TRAINER, 16729, A.TRAINER, 17487, A.TRAINER, 18749, A.TRAINER, 18772, A.TRAINER, 28699, A.TRAINER, 33580, A.TRAINER, 27001, A.TRAINER, 33613, A.TRAINER, 33636, A.TRAINER, 26914, A.TRAINER, 26969, A.TRAINER, 26964, A.TRAINER, 33684)

	-- Brown Linen Shirt -- 3915
	AddRecipe(3915, 1, 4344, R_COMMON, GAME_ORIG, 1, 35, 47, 60)
	self:addTradeFlags(RecipeDB, 3915, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP)
	self:addTradeAcquire(RecipeDB, 3915, A.CUSTOM, 8)

	-- Pearl-clasped Cloak -- 6521
	AddRecipe(6521, 90, 5542, R_COMMON, GAME_ORIG, 90, 115, 132, 150)
	self:addTradeFlags(RecipeDB, 6521, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.CLOAK)
	self:addTradeAcquire(RecipeDB, 6521, A.TRAINER, 1346, A.TRAINER, 2399, A.TRAINER, 2627, A.TRAINER, 3004, A.TRAINER, 3363, A.TRAINER, 3704, A.TRAINER, 4159, A.TRAINER, 4576, A.TRAINER, 5153, A.TRAINER, 11052, A.TRAINER, 11557, A.TRAINER, 16640, A.TRAINER, 16729, A.TRAINER, 17487, A.TRAINER, 18749, A.TRAINER, 18772, A.TRAINER, 28699, A.TRAINER, 3484, A.TRAINER, 33580, A.TRAINER, 1103, A.TRAINER, 27001, A.TRAINER, 33613, A.TRAINER, 33636, A.TRAINER, 26914, A.TRAINER, 16366, A.TRAINER, 26969, A.TRAINER, 4193, A.TRAINER, 26964, A.TRAINER, 3523, A.TRAINER, 33684)

	-- Red Linen Bag -- 6686
	AddRecipe(6686, 70, 5762, R_COMMON, GAME_ORIG, 70, 95, 112, 130)
	self:addTradeFlags(RecipeDB, 6686, F.ALLIANCE, F.HORDE, F.VENDOR, F.INSTANCE, F.MOB_DROP, F.IBOE, F.RBOE)
	self:addTradeAcquire(RecipeDB, 6686, A.MOB, 590, A.MOB, 3530, A.MOB, 3531, A.VENDOR, 843, A.VENDOR, 3005, A.VENDOR, 4189, A.VENDOR, 16224, A.VENDOR, 3556)

	-- Red Woolen Bag -- 6688
	AddRecipe(6688, 115, 5763, R_COMMON, GAME_ORIG, 115, 140, 157, 175)
	self:addTradeFlags(RecipeDB, 6688, F.ALLIANCE, F.HORDE, F.VENDOR, F.INSTANCE, F.MOB_DROP, F.IBOE, F.RBOE)
	self:addTradeAcquire(RecipeDB, 6688, A.MOB, 450, A.MOB, 2264, A.VENDOR, 777, A.VENDOR, 1454, A.VENDOR, 1474, A.VENDOR, 3005, A.VENDOR, 3364, A.VENDOR, 3485, A.VENDOR, 3537, A.VENDOR, 3683, A.VENDOR, 4189, A.VENDOR, 4577, A.VENDOR, 5944)

	-- Lesser Wizard's Robe -- 6690
	AddRecipe(6690, 135, 5766, R_COMMON, GAME_ORIG, 135, 155, 170, 185)
	self:addTradeFlags(RecipeDB, 6690, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.HEALER, F.CASTER, F.CLOTH)
	self:addTradeAcquire(RecipeDB, 6690, A.TRAINER, 1346, A.TRAINER, 2399, A.TRAINER, 2627, A.TRAINER, 3004, A.TRAINER, 3363, A.TRAINER, 3704, A.TRAINER, 4159, A.TRAINER, 4576, A.TRAINER, 5153, A.TRAINER, 11052, A.TRAINER, 11557, A.TRAINER, 16640, A.TRAINER, 16729, A.TRAINER, 17487, A.TRAINER, 18749, A.TRAINER, 18772, A.TRAINER, 28699, A.TRAINER, 3484, A.TRAINER, 33580, A.TRAINER, 1103, A.TRAINER, 27001, A.TRAINER, 33613, A.TRAINER, 33636, A.TRAINER, 26914, A.TRAINER, 16366, A.TRAINER, 26969, A.TRAINER, 4193, A.TRAINER, 26964, A.TRAINER, 3523, A.TRAINER, 33684)

	-- Robes of Arcana -- 6692
	AddRecipe(6692, 150, 5770, R_UNCOMMON, GAME_ORIG, 150, 170, 185, 200)
	self:addTradeFlags(RecipeDB, 6692, F.ALLIANCE, F.HORDE, F.MOB_DROP, F.IBOE, F.RBOE, F.HEALER, F.CASTER, F.CLOTH)
	self:addTradeAcquire(RecipeDB, 6692, A.MOB, 910, A.MOB, 2337, A.MOB, 10760)

	-- Green Silk Pack -- 6693
	AddRecipe(6693, 175, 5764, R_UNCOMMON, GAME_ORIG, 175, 195, 210, 225)
	self:addTradeFlags(RecipeDB, 6693, F.ALLIANCE, F.HORDE, F.WORLD_DROP, F.IBOE, F.RBOE)
	self:addTradeAcquire(RecipeDB, 6693, A.WORLD_DROP, 2)

	-- Black Silk Pack -- 6695
	AddRecipe(6695, 185, 5765, R_UNCOMMON, GAME_ORIG, 185, 205, 220, 235)
	self:addTradeFlags(RecipeDB, 6695, F.ALLIANCE, F.HORDE, F.MOB_DROP, F.IBOE, F.RBOE)
	self:addTradeAcquire(RecipeDB, 6695, A.MOB, 2242, A.MOB, 2434, A.MOB, 4834)

	-- Brown Linen Robe -- 7623
	AddRecipe(7623, 30, 6238, R_COMMON, GAME_ORIG, 30, 55, 72, 90)
	self:addTradeFlags(RecipeDB, 7623, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOE, F.HEALER, F.CASTER, F.CLOTH)
	self:addTradeAcquire(RecipeDB, 7623, A.TRAINER, 1103, A.TRAINER, 1346, A.TRAINER, 2399, A.TRAINER, 2627, A.TRAINER, 3004, A.TRAINER, 3363, A.TRAINER, 3484, A.TRAINER, 3523, A.TRAINER, 3704, A.TRAINER, 4159, A.TRAINER, 4193, A.TRAINER, 4576, A.TRAINER, 5153, A.TRAINER, 11052, A.TRAINER, 11557, A.TRAINER, 16366, A.TRAINER, 16640, A.TRAINER, 16729, A.TRAINER, 17487, A.TRAINER, 18749, A.TRAINER, 18772, A.TRAINER, 28699, A.TRAINER, 33580, A.TRAINER, 27001, A.TRAINER, 33613, A.TRAINER, 33636, A.TRAINER, 26914, A.TRAINER, 26969, A.TRAINER, 26964, A.TRAINER, 33684)

	-- White Linen Robe -- 7624
	AddRecipe(7624, 30, 6241, R_COMMON, GAME_ORIG, 30, 55, 72, 90)
	self:addTradeFlags(RecipeDB, 7624, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.CLOTH)
	self:addTradeAcquire(RecipeDB, 7624, A.TRAINER, 1103, A.TRAINER, 1346, A.TRAINER, 2399, A.TRAINER, 2627, A.TRAINER, 3004, A.TRAINER, 3363, A.TRAINER, 3484, A.TRAINER, 3523, A.TRAINER, 3704, A.TRAINER, 4159, A.TRAINER, 4193, A.TRAINER, 4576, A.TRAINER, 5153, A.TRAINER, 11052, A.TRAINER, 11557, A.TRAINER, 16366, A.TRAINER, 16640, A.TRAINER, 16729, A.TRAINER, 17487, A.TRAINER, 18749, A.TRAINER, 18772, A.TRAINER, 28699, A.TRAINER, 33580, A.TRAINER, 27001, A.TRAINER, 33613, A.TRAINER, 33636, A.TRAINER, 26914, A.TRAINER, 26969, A.TRAINER, 26964, A.TRAINER, 33684)

	-- Red Linen Vest -- 7629
	AddRecipe(7629, 55, 6239, R_UNCOMMON, GAME_ORIG, 55, 80, 97, 115)
	self:addTradeFlags(RecipeDB, 7629, F.ALLIANCE, F.HORDE, F.WORLD_DROP, F.IBOE, F.RBOE, F.HEALER, F.CASTER, F.CLOTH)
	self:addTradeAcquire(RecipeDB, 7629, A.WORLD_DROP, 2)

	-- Blue Linen Vest -- 7630
	AddRecipe(7630, 55, 6240, R_COMMON, GAME_ORIG, 55, 80, 97, 115)
	self:addTradeFlags(RecipeDB, 7630, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOE, F.HEALER, F.CASTER, F.CLOTH)
	self:addTradeAcquire(RecipeDB, 7630, A.VENDOR, 66, A.VENDOR, 3364, A.VENDOR, 3485, A.VENDOR, 3522, A.VENDOR, 4189)

	-- Blue Linen Robe -- 7633
	AddRecipe(7633, 70, 6242, R_COMMON, GAME_ORIG, 70, 95, 112, 130)
	self:addTradeFlags(RecipeDB, 7633, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOE, F.HEALER, F.CASTER, F.CLOTH)
	self:addTradeAcquire(RecipeDB, 7633, A.VENDOR, 1250, A.VENDOR, 3485, A.VENDOR, 4168, A.VENDOR, 3499, A.VENDOR, 3556)

	-- Blue Overalls -- 7639
	AddRecipe(7639, 100, 6263, R_COMMON, GAME_ORIG, 100, 125, 142, 160)
	self:addTradeFlags(RecipeDB, 7639, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOE, F.HEALER, F.CASTER, F.CLOTH)
	self:addTradeAcquire(RecipeDB, 7639, A.VENDOR, 843, A.VENDOR, 1347, A.VENDOR, 2394, A.VENDOR, 3364, A.VENDOR, 5944)

	-- Greater Adept's Robe -- 7643
	AddRecipe(7643, 115, 6264, R_COMMON, GAME_ORIG, 115, 140, 157, 175)
	self:addTradeFlags(RecipeDB, 7643, F.ALLIANCE, F.VENDOR, F.IBOE, F.RBOE, F.HEALER, F.CASTER, F.CLOTH)
	self:addTradeAcquire(RecipeDB, 7643, A.VENDOR, 1454, A.VENDOR, 1474, A.VENDOR, 4168, A.VENDOR, 2669, A.VENDOR, 3499, A.VENDOR, 4577)

	-- Stylish Blue Shirt -- 7892
	AddRecipe(7892, 120, 6384, R_UNCOMMON, GAME_ORIG, 120, 145, 162, 180)
	self:addTradeFlags(RecipeDB, 7892, F.ALLIANCE, F.HORDE, F.WORLD_DROP, F.IBOE, F.RBOE)
	self:addTradeAcquire(RecipeDB, 7892, A.WORLD_DROP, 2)

	-- Stylish Green Shirt -- 7893
	AddRecipe(7893, 120, 6385, R_UNCOMMON, GAME_ORIG, 120, 145, 162, 180)
	self:addTradeFlags(RecipeDB, 7893, F.ALLIANCE, F.HORDE, F.WORLD_DROP, F.IBOE, F.RBOE)
	self:addTradeAcquire(RecipeDB, 7893, A.WORLD_DROP, 2)

	-- Simple Dress -- 8465
	AddRecipe(8465, 40, 6786, R_COMMON, GAME_ORIG, 40, 65, 82, 100)
	self:addTradeFlags(RecipeDB, 8465, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP)
	self:addTradeAcquire(RecipeDB, 8465, A.TRAINER, 1103, A.TRAINER, 1346, A.TRAINER, 2399, A.TRAINER, 2627, A.TRAINER, 3004, A.TRAINER, 3363, A.TRAINER, 3484, A.TRAINER, 3523, A.TRAINER, 3704, A.TRAINER, 4159, A.TRAINER, 4193, A.TRAINER, 4576, A.TRAINER, 5153, A.TRAINER, 11052, A.TRAINER, 11557, A.TRAINER, 16366, A.TRAINER, 16640, A.TRAINER, 16729, A.TRAINER, 17487, A.TRAINER, 18749, A.TRAINER, 18772, A.TRAINER, 28699, A.TRAINER, 33580, A.TRAINER, 27001, A.TRAINER, 33613, A.TRAINER, 33636, A.TRAINER, 26914, A.TRAINER, 26969, A.TRAINER, 26964, A.TRAINER, 33684)

	-- White Woolen Dress -- 8467
	AddRecipe(8467, 110, 6787, R_COMMON, GAME_ORIG, 110, 135, 152, 170)
	self:addTradeFlags(RecipeDB, 8467, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP)
	self:addTradeAcquire(RecipeDB, 8467, A.TRAINER, 1346, A.TRAINER, 2399, A.TRAINER, 2627, A.TRAINER, 3004, A.TRAINER, 3363, A.TRAINER, 3704, A.TRAINER, 4159, A.TRAINER, 4576, A.TRAINER, 5153, A.TRAINER, 11052, A.TRAINER, 11557, A.TRAINER, 16640, A.TRAINER, 16729, A.TRAINER, 17487, A.TRAINER, 18749, A.TRAINER, 18772, A.TRAINER, 28699, A.TRAINER, 3484, A.TRAINER, 33580, A.TRAINER, 1103, A.TRAINER, 27001, A.TRAINER, 33613, A.TRAINER, 33636, A.TRAINER, 26914, A.TRAINER, 16366, A.TRAINER, 26969, A.TRAINER, 4193, A.TRAINER, 26964, A.TRAINER, 3523, A.TRAINER, 33684)

	-- White Swashbuckler's Shirt -- 8483
	AddRecipe(8483, 160, 6795, R_COMMON, GAME_ORIG, 160, 170, 175, 180)
	self:addTradeFlags(RecipeDB, 8483, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP)
	self:addTradeAcquire(RecipeDB, 8483, A.TRAINER, 1346, A.TRAINER, 2399, A.TRAINER, 4576, A.TRAINER, 11052, A.TRAINER, 11557, A.TRAINER, 18749, A.TRAINER, 18772, A.TRAINER, 28699, A.TRAINER, 4159, A.TRAINER, 16729, A.TRAINER, 3004, A.TRAINER, 3484, A.TRAINER, 3704, A.TRAINER, 2627, A.TRAINER, 33580, A.TRAINER, 3363, A.TRAINER, 1103, A.TRAINER, 27001, A.TRAINER, 33613, A.TRAINER, 33636, A.TRAINER, 26914, A.TRAINER, 17487, A.TRAINER, 16640, A.TRAINER, 16366, A.TRAINER, 26969, A.TRAINER, 5153, A.TRAINER, 4193, A.TRAINER, 26964, A.TRAINER, 3523, A.TRAINER, 33684)

	-- Red Swashbuckler's Shirt -- 8489
	AddRecipe(8489, 175, 6796, R_COMMON, GAME_ORIG, 175, 185, 190, 195)
	self:addTradeFlags(RecipeDB, 8489, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP)
	self:addTradeAcquire(RecipeDB, 8489, A.TRAINER, 1346, A.TRAINER, 2399, A.TRAINER, 4576, A.TRAINER, 11052, A.TRAINER, 11557, A.TRAINER, 18749, A.TRAINER, 18772, A.TRAINER, 28699, A.TRAINER, 4159, A.TRAINER, 16729, A.TRAINER, 3004, A.TRAINER, 3484, A.TRAINER, 3704, A.TRAINER, 2627, A.TRAINER, 33580, A.TRAINER, 3363, A.TRAINER, 1103, A.TRAINER, 27001, A.TRAINER, 33613, A.TRAINER, 33636, A.TRAINER, 26914, A.TRAINER, 17487, A.TRAINER, 16640, A.TRAINER, 16366, A.TRAINER, 26969, A.TRAINER, 5153, A.TRAINER, 4193, A.TRAINER, 26964, A.TRAINER, 3523, A.TRAINER, 33684)

	-- Azure Silk Pants -- 8758
	AddRecipe(8758, 140, 7046, R_COMMON, GAME_ORIG, 140, 160, 175, 190)
	self:addTradeFlags(RecipeDB, 8758, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.HEALER, F.CASTER, F.CLOTH)
	self:addTradeAcquire(RecipeDB, 8758, A.TRAINER, 1346, A.TRAINER, 2399, A.TRAINER, 2627, A.TRAINER, 3004, A.TRAINER, 3363, A.TRAINER, 3704, A.TRAINER, 4159, A.TRAINER, 4576, A.TRAINER, 5153, A.TRAINER, 11052, A.TRAINER, 11557, A.TRAINER, 16640, A.TRAINER, 16729, A.TRAINER, 17487, A.TRAINER, 18749, A.TRAINER, 18772, A.TRAINER, 28699, A.TRAINER, 3484, A.TRAINER, 33580, A.TRAINER, 1103, A.TRAINER, 27001, A.TRAINER, 33613, A.TRAINER, 33636, A.TRAINER, 26914, A.TRAINER, 16366, A.TRAINER, 26969, A.TRAINER, 4193, A.TRAINER, 26964, A.TRAINER, 3523, A.TRAINER, 33684)

	-- Azure Silk Hood -- 8760
	AddRecipe(8760, 145, 7048, R_COMMON, GAME_ORIG, 145, 155, 160, 165)
	self:addTradeFlags(RecipeDB, 8760, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.CLOTH)
	self:addTradeAcquire(RecipeDB, 8760, A.TRAINER, 1346, A.TRAINER, 2399, A.TRAINER, 2627, A.TRAINER, 3004, A.TRAINER, 3363, A.TRAINER, 3704, A.TRAINER, 4159, A.TRAINER, 4576, A.TRAINER, 5153, A.TRAINER, 11052, A.TRAINER, 11557, A.TRAINER, 16640, A.TRAINER, 16729, A.TRAINER, 17487, A.TRAINER, 18749, A.TRAINER, 18772, A.TRAINER, 28699, A.TRAINER, 3484, A.TRAINER, 33580, A.TRAINER, 1103, A.TRAINER, 27001, A.TRAINER, 33613, A.TRAINER, 33636, A.TRAINER, 26914, A.TRAINER, 16366, A.TRAINER, 26969, A.TRAINER, 4193, A.TRAINER, 26964, A.TRAINER, 3523, A.TRAINER, 33684)

	-- Silk Headband -- 8762
	AddRecipe(8762, 160, 7050, R_COMMON, GAME_ORIG, 160, 170, 175, 180)
	self:addTradeFlags(RecipeDB, 8762, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.HEALER, F.CASTER, F.CLOTH)
	self:addTradeAcquire(RecipeDB, 8762, A.TRAINER, 1346, A.TRAINER, 2399, A.TRAINER, 4576, A.TRAINER, 11052, A.TRAINER, 11557, A.TRAINER, 18749, A.TRAINER, 18772, A.TRAINER, 28699, A.TRAINER, 4159, A.TRAINER, 16729, A.TRAINER, 3004, A.TRAINER, 3484, A.TRAINER, 3704, A.TRAINER, 2627, A.TRAINER, 33580, A.TRAINER, 3363, A.TRAINER, 1103, A.TRAINER, 27001, A.TRAINER, 33613, A.TRAINER, 33636, A.TRAINER, 26914, A.TRAINER, 17487, A.TRAINER, 16640, A.TRAINER, 16366, A.TRAINER, 26969, A.TRAINER, 5153, A.TRAINER, 4193, A.TRAINER, 26964, A.TRAINER, 3523, A.TRAINER, 33684)

	-- Earthen Vest -- 8764
	AddRecipe(8764, 170, 7051, R_COMMON, GAME_ORIG, 170, 190, 205, 220)
	self:addTradeFlags(RecipeDB, 8764, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.HEALER, F.CASTER, F.CLOTH)
	self:addTradeAcquire(RecipeDB, 8764, A.TRAINER, 1346, A.TRAINER, 2399, A.TRAINER, 4576, A.TRAINER, 11052, A.TRAINER, 11557, A.TRAINER, 18749, A.TRAINER, 18772, A.TRAINER, 28699, A.TRAINER, 4159, A.TRAINER, 16729, A.TRAINER, 3004, A.TRAINER, 3484, A.TRAINER, 3704, A.TRAINER, 2627, A.TRAINER, 33580, A.TRAINER, 3363, A.TRAINER, 1103, A.TRAINER, 27001, A.TRAINER, 33613, A.TRAINER, 33636, A.TRAINER, 26914, A.TRAINER, 17487, A.TRAINER, 16640, A.TRAINER, 16366, A.TRAINER, 26969, A.TRAINER, 5153, A.TRAINER, 4193, A.TRAINER, 26964, A.TRAINER, 3523, A.TRAINER, 33684)

	-- Azure Silk Belt -- 8766
	AddRecipe(8766, 175, 7052, R_COMMON, GAME_ORIG, 175, 195, 210, 225)
	self:addTradeFlags(RecipeDB, 8766, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.CLOTH)
	self:addTradeAcquire(RecipeDB, 8766, A.TRAINER, 1346, A.TRAINER, 2399, A.TRAINER, 4576, A.TRAINER, 11052, A.TRAINER, 11557, A.TRAINER, 18749, A.TRAINER, 18772, A.TRAINER, 28699, A.TRAINER, 16729, A.TRAINER, 3004, A.TRAINER, 3484, A.TRAINER, 3704, A.TRAINER, 2627, A.TRAINER, 33580, A.TRAINER, 3363, A.TRAINER, 1103, A.TRAINER, 27001, A.TRAINER, 33613, A.TRAINER, 33636, A.TRAINER, 4159, A.TRAINER, 26914, A.TRAINER, 17487, A.TRAINER, 16640, A.TRAINER, 16366, A.TRAINER, 26969, A.TRAINER, 5153, A.TRAINER, 4193, A.TRAINER, 26964, A.TRAINER, 3523, A.TRAINER, 33684)

	-- Robe of Power -- 8770
	AddRecipe(8770, 190, 7054, R_COMMON, GAME_ORIG, 190, 210, 225, 240)
	self:addTradeFlags(RecipeDB, 8770, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOP, F.RBOP, F.HEALER, F.CASTER, F.CLOTH)
	self:addTradeAcquire(RecipeDB, 8770, A.TRAINER, 1346, A.TRAINER, 2399, A.TRAINER, 4576, A.TRAINER, 11052, A.TRAINER, 11557, A.TRAINER, 18749, A.TRAINER, 18772, A.TRAINER, 28699, A.TRAINER, 16729, A.TRAINER, 3004, A.TRAINER, 3484, A.TRAINER, 3704, A.TRAINER, 2627, A.TRAINER, 33580, A.TRAINER, 3363, A.TRAINER, 1103, A.TRAINER, 27001, A.TRAINER, 33613, A.TRAINER, 33636, A.TRAINER, 4159, A.TRAINER, 26914, A.TRAINER, 17487, A.TRAINER, 16640, A.TRAINER, 16366, A.TRAINER, 26969, A.TRAINER, 5153, A.TRAINER, 4193, A.TRAINER, 26964, A.TRAINER, 3523, A.TRAINER, 33684)

	-- Crimson Silk Belt -- 8772
	AddRecipe(8772, 175, 7055, R_COMMON, GAME_ORIG, 175, 195, 210, 225)
	self:addTradeFlags(RecipeDB, 8772, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.HEALER, F.CASTER, F.CLOTH)
	self:addTradeAcquire(RecipeDB, 8772, A.TRAINER, 1346, A.TRAINER, 2399, A.TRAINER, 4576, A.TRAINER, 11052, A.TRAINER, 11557, A.TRAINER, 18749, A.TRAINER, 18772, A.TRAINER, 28699, A.TRAINER, 4159, A.TRAINER, 16729, A.TRAINER, 3004, A.TRAINER, 3484, A.TRAINER, 3704, A.TRAINER, 2627, A.TRAINER, 33580, A.TRAINER, 3363, A.TRAINER, 1103, A.TRAINER, 27001, A.TRAINER, 33613, A.TRAINER, 33636, A.TRAINER, 26914, A.TRAINER, 17487, A.TRAINER, 16640, A.TRAINER, 16366, A.TRAINER, 26969, A.TRAINER, 5153, A.TRAINER, 4193, A.TRAINER, 26964, A.TRAINER, 33684)

	-- Green Silken Shoulders -- 8774
	AddRecipe(8774, 180, 7057, R_COMMON, GAME_ORIG, 180, 200, 215, 230)
	self:addTradeFlags(RecipeDB, 8774, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.CLOTH)
	self:addTradeAcquire(RecipeDB, 8774, A.TRAINER, 1346, A.TRAINER, 2399, A.TRAINER, 4576, A.TRAINER, 11052, A.TRAINER, 11557, A.TRAINER, 18749, A.TRAINER, 18772, A.TRAINER, 28699, A.TRAINER, 16729, A.TRAINER, 3004, A.TRAINER, 3484, A.TRAINER, 3704, A.TRAINER, 2627, A.TRAINER, 33580, A.TRAINER, 3363, A.TRAINER, 1103, A.TRAINER, 27001, A.TRAINER, 33613, A.TRAINER, 33636, A.TRAINER, 4159, A.TRAINER, 26914, A.TRAINER, 17487, A.TRAINER, 16640, A.TRAINER, 16366, A.TRAINER, 26969, A.TRAINER, 5153, A.TRAINER, 4193, A.TRAINER, 26964, A.TRAINER, 3523, A.TRAINER, 33684)

	-- Linen Belt -- 8776
	AddRecipe(8776, 15, 7026, R_COMMON, GAME_ORIG, 15, 50, 67, 85)
	self:addTradeFlags(RecipeDB, 8776, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOE, F.CLOTH)
	self:addTradeAcquire(RecipeDB, 8776, A.TRAINER, 1103, A.TRAINER, 1346, A.TRAINER, 2399, A.TRAINER, 2627, A.TRAINER, 3004, A.TRAINER, 3363, A.TRAINER, 3484, A.TRAINER, 3523, A.TRAINER, 3704, A.TRAINER, 4159, A.TRAINER, 4193, A.TRAINER, 4576, A.TRAINER, 5153, A.TRAINER, 11052, A.TRAINER, 11557, A.TRAINER, 16366, A.TRAINER, 16640, A.TRAINER, 16729, A.TRAINER, 17487, A.TRAINER, 18749, A.TRAINER, 18772, A.TRAINER, 28699, A.TRAINER, 33580, A.TRAINER, 27001, A.TRAINER, 33613, A.TRAINER, 33636, A.TRAINER, 26914, A.TRAINER, 26969, A.TRAINER, 26964, A.TRAINER, 33684)

	-- Hands of Darkness -- 8780
	AddRecipe(8780, 145, 7047, R_UNCOMMON, GAME_ORIG, 145, 165, 180, 195)
	self:addTradeFlags(RecipeDB, 8780, F.ALLIANCE, F.HORDE, F.WORLD_DROP, F.IBOE, F.RBOE, F.HEALER, F.CASTER, F.CLOTH)
	self:addTradeAcquire(RecipeDB, 8780, A.WORLD_DROP, 2)

	-- Truefaith Gloves -- 8782
	AddRecipe(8782, 150, 7049, R_UNCOMMON, GAME_ORIG, 150, 170, 185, 200)
	self:addTradeFlags(RecipeDB, 8782, F.ALLIANCE, F.HORDE, F.WORLD_DROP, F.IBOE, F.RBOE, F.HEALER, F.CASTER, F.CLOTH)
	self:addTradeAcquire(RecipeDB, 8782, A.WORLD_DROP, 2)

	-- Green Silk Armor -- 8784
	AddRecipe(8784, 165, 7065, R_UNCOMMON, GAME_ORIG, 165, 185, 200, 215)
	self:addTradeFlags(RecipeDB, 8784, F.ALLIANCE, F.HORDE, F.WORLD_DROP, F.IBOE, F.RBOE, F.CLOTH)
	self:addTradeAcquire(RecipeDB, 8784, A.WORLD_DROP, 2)

	-- Azure Silk Cloak -- 8786
	AddRecipe(8786, 175, 7053, R_COMMON, GAME_ORIG, 175, 195, 210, 225)
	self:addTradeFlags(RecipeDB, 8786, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOP, F.HEALER, F.CASTER, F.CLOAK)
	self:addTradeAcquire(RecipeDB, 8786, A.VENDOR, 6574, A.VENDOR, 6576)

	-- Crimson Silk Cloak -- 8789
	AddRecipe(8789, 180, 7056, R_COMMON, GAME_ORIG, 180, 200, 215, 230)
	self:addTradeFlags(RecipeDB, 8789, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOP, F.CLOAK)
	self:addTradeAcquire(RecipeDB, 8789, A.VENDOR, 2670)

	-- Crimson Silk Vest -- 8791
	AddRecipe(8791, 185, 7058, R_COMMON, GAME_ORIG, 185, 205, 215, 225)
	self:addTradeFlags(RecipeDB, 8791, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.HEALER, F.CASTER, F.CLOTH)
	self:addTradeAcquire(RecipeDB, 8791, A.TRAINER, 1346, A.TRAINER, 2399, A.TRAINER, 4576, A.TRAINER, 11052, A.TRAINER, 11557, A.TRAINER, 18749, A.TRAINER, 18772, A.TRAINER, 28699, A.TRAINER, 16729, A.TRAINER, 3004, A.TRAINER, 3484, A.TRAINER, 3704, A.TRAINER, 2627, A.TRAINER, 33580, A.TRAINER, 3363, A.TRAINER, 1103, A.TRAINER, 27001, A.TRAINER, 33613, A.TRAINER, 33636, A.TRAINER, 4159, A.TRAINER, 26914, A.TRAINER, 17487, A.TRAINER, 16640, A.TRAINER, 16366, A.TRAINER, 26969, A.TRAINER, 5153, A.TRAINER, 4193, A.TRAINER, 26964, A.TRAINER, 3523, A.TRAINER, 33684)

	-- Crimson Silk Shoulders -- 8793
	AddRecipe(8793, 190, 7059, R_UNCOMMON, GAME_ORIG, 190, 210, 225, 240)
	self:addTradeFlags(RecipeDB, 8793, F.ALLIANCE, F.HORDE, F.WORLD_DROP, F.IBOE, F.RBOE, F.HEALER, F.CASTER, F.CLOTH)
	self:addTradeAcquire(RecipeDB, 8793, A.WORLD_DROP, 2)

	-- Azure Shoulders -- 8795
	AddRecipe(8795, 190, 7060, R_UNCOMMON, GAME_ORIG, 190, 210, 225, 240)
	self:addTradeFlags(RecipeDB, 8795, F.ALLIANCE, F.HORDE, F.WORLD_DROP, F.IBOE, F.RBOE, F.HEALER, F.CASTER, F.CLOTH)
	self:addTradeAcquire(RecipeDB, 8795, A.WORLD_DROP, 2)

	-- Earthen Silk Belt -- 8797
	AddRecipe(8797, 195, 7061, R_UNCOMMON, GAME_ORIG, 195, 215, 230, 245)
	self:addTradeFlags(RecipeDB, 8797, F.ALLIANCE, F.HORDE, F.WORLD_DROP, F.IBOE, F.RBOE, F.HEALER, F.CASTER, F.CLOTH)
	self:addTradeAcquire(RecipeDB, 8797, A.WORLD_DROP, 2)

	-- Crimson Silk Pantaloons -- 8799
	AddRecipe(8799, 195, 7062, R_COMMON, GAME_ORIG, 195, 215, 225, 235)
	self:addTradeFlags(RecipeDB, 8799, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOE, F.CLOTH)
	self:addTradeAcquire(RecipeDB, 8799, A.TRAINER, 1346, A.TRAINER, 2399, A.TRAINER, 4576, A.TRAINER, 11052, A.TRAINER, 11557, A.TRAINER, 18749, A.TRAINER, 18772, A.TRAINER, 28699, A.TRAINER, 4159, A.TRAINER, 16729, A.TRAINER, 3004, A.TRAINER, 3484, A.TRAINER, 3704, A.TRAINER, 2627, A.TRAINER, 33580, A.TRAINER, 3363, A.TRAINER, 1103, A.TRAINER, 27001, A.TRAINER, 33613, A.TRAINER, 33636, A.TRAINER, 26914, A.TRAINER, 17487, A.TRAINER, 16640, A.TRAINER, 16366, A.TRAINER, 26969, A.TRAINER, 5153, A.TRAINER, 4193, A.TRAINER, 26964, A.TRAINER, 3523, A.TRAINER, 33684)

	-- Crimson Silk Robe -- 8802
	AddRecipe(8802, 205, 7063, R_COMMON, GAME_ORIG, 205, 220, 235, 250)
	self:addTradeFlags(RecipeDB, 8802, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOE, F.HEALER, F.CASTER, F.CLOTH)
	self:addTradeAcquire(RecipeDB, 8802, A.VENDOR, 6568)

	-- Crimson Silk Gloves -- 8804
	AddRecipe(8804, 210, 7064, R_COMMON, GAME_ORIG, 210, 225, 240, 255)
	self:addTradeFlags(RecipeDB, 8804, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.HEALER, F.CASTER, F.CLOTH)
	self:addTradeAcquire(RecipeDB, 8804, A.TRAINER, 1346, A.TRAINER, 2399, A.TRAINER, 4576, A.TRAINER, 11052, A.TRAINER, 11557, A.TRAINER, 18749, A.TRAINER, 18772, A.TRAINER, 28699, A.TRAINER, 4159, A.TRAINER, 16729, A.TRAINER, 3004, A.TRAINER, 3484, A.TRAINER, 3704, A.TRAINER, 2627, A.TRAINER, 33580, A.TRAINER, 3363, A.TRAINER, 1103, A.TRAINER, 33613, A.TRAINER, 33636, A.TRAINER, 27001, A.TRAINER, 26914, A.TRAINER, 17487, A.TRAINER, 16640, A.TRAINER, 16366, A.TRAINER, 26969, A.TRAINER, 5153, A.TRAINER, 4193, A.TRAINER, 26964, A.TRAINER, 3523, A.TRAINER, 33684)

	-- Simple Linen Pants -- 12044
	AddRecipe(12044, 1, 10045, R_COMMON, GAME_ORIG, 1, 35, 47, 60)
	self:addTradeFlags(RecipeDB, 12044, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.CLOTH)
	self:addTradeAcquire(RecipeDB, 12044, A.CUSTOM, 8)

	-- Simple Linen Boots -- 12045
	AddRecipe(12045, 20, 10046, R_COMMON, GAME_ORIG, 20, 50, 67, 85)
	self:addTradeFlags(RecipeDB, 12045, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.CLOTH)
	self:addTradeAcquire(RecipeDB, 12045, A.TRAINER, 1103, A.TRAINER, 1346, A.TRAINER, 2399, A.TRAINER, 2627, A.TRAINER, 3004, A.TRAINER, 3363, A.TRAINER, 3484, A.TRAINER, 3523, A.TRAINER, 3704, A.TRAINER, 4159, A.TRAINER, 4193, A.TRAINER, 4576, A.TRAINER, 5153, A.TRAINER, 11052, A.TRAINER, 11557, A.TRAINER, 16366, A.TRAINER, 16640, A.TRAINER, 16729, A.TRAINER, 17487, A.TRAINER, 18749, A.TRAINER, 18772, A.TRAINER, 28699, A.TRAINER, 33580, A.TRAINER, 27001, A.TRAINER, 33613, A.TRAINER, 33636, A.TRAINER, 26914, A.TRAINER, 26969, A.TRAINER, 26964, A.TRAINER, 33684)

	-- Simple Kilt -- 12046
	AddRecipe(12046, 75, 10047, R_COMMON, GAME_ORIG, 75, 100, 117, 135)
	self:addTradeFlags(RecipeDB, 12046, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.HEALER, F.CASTER, F.CLOTH)
	self:addTradeAcquire(RecipeDB, 12046, A.TRAINER, 1103, A.TRAINER, 1346, A.TRAINER, 2399, A.TRAINER, 2627, A.TRAINER, 3004, A.TRAINER, 3363, A.TRAINER, 3484, A.TRAINER, 3523, A.TRAINER, 3704, A.TRAINER, 4159, A.TRAINER, 4193, A.TRAINER, 4576, A.TRAINER, 5153, A.TRAINER, 11052, A.TRAINER, 11557, A.TRAINER, 16366, A.TRAINER, 16640, A.TRAINER, 16729, A.TRAINER, 17487, A.TRAINER, 18749, A.TRAINER, 18772, A.TRAINER, 28699, A.TRAINER, 33580, A.TRAINER, 27001, A.TRAINER, 33613, A.TRAINER, 33636, A.TRAINER, 26914, A.TRAINER, 26969, A.TRAINER, 26964, A.TRAINER, 33684)

	-- Colorful Kilt -- 12047
	AddRecipe(12047, 120, 10048, R_UNCOMMON, GAME_ORIG, 120, 145, 162, 180)
	self:addTradeFlags(RecipeDB, 12047, F.ALLIANCE, F.HORDE, F.WORLD_DROP, F.IBOE, F.RBOE, F.HEALER, F.CASTER, F.CLOTH)
	self:addTradeAcquire(RecipeDB, 12047, A.WORLD_DROP, 2)

	-- Black Mageweave Vest -- 12048
	AddRecipe(12048, 205, 9998, R_COMMON, GAME_ORIG, 205, 220, 235, 250)
	self:addTradeFlags(RecipeDB, 12048, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.HEALER, F.CASTER, F.CLOTH)
	self:addTradeAcquire(RecipeDB, 12048, A.TRAINER, 1346, A.TRAINER, 2399, A.TRAINER, 4576, A.TRAINER, 11052, A.TRAINER, 11557, A.TRAINER, 18749, A.TRAINER, 18772, A.TRAINER, 28699, A.TRAINER, 4159, A.TRAINER, 16729, A.TRAINER, 3004, A.TRAINER, 3484, A.TRAINER, 3704, A.TRAINER, 2627, A.TRAINER, 33580, A.TRAINER, 3363, A.TRAINER, 1103, A.TRAINER, 27001, A.TRAINER, 33613, A.TRAINER, 33636, A.TRAINER, 26914, A.TRAINER, 17487, A.TRAINER, 16640, A.TRAINER, 16366, A.TRAINER, 26969, A.TRAINER, 5153, A.TRAINER, 4193, A.TRAINER, 26964, A.TRAINER, 3523, A.TRAINER, 33684)

	-- Black Mageweave Leggings -- 12049
	AddRecipe(12049, 205, 9999, R_COMMON, GAME_ORIG, 205, 220, 235, 250)
	self:addTradeFlags(RecipeDB, 12049, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.HEALER, F.CASTER, F.CLOTH)
	self:addTradeAcquire(RecipeDB, 12049, A.TRAINER, 1346, A.TRAINER, 2399, A.TRAINER, 4576, A.TRAINER, 11052, A.TRAINER, 11557, A.TRAINER, 18749, A.TRAINER, 18772, A.TRAINER, 28699, A.TRAINER, 4159, A.TRAINER, 16729, A.TRAINER, 3004, A.TRAINER, 3484, A.TRAINER, 3704, A.TRAINER, 2627, A.TRAINER, 33580, A.TRAINER, 3363, A.TRAINER, 1103, A.TRAINER, 27001, A.TRAINER, 33613, A.TRAINER, 33636, A.TRAINER, 26914, A.TRAINER, 17487, A.TRAINER, 16640, A.TRAINER, 16366, A.TRAINER, 26969, A.TRAINER, 5153, A.TRAINER, 4193, A.TRAINER, 26964, A.TRAINER, 3523, A.TRAINER, 33684)

	-- Black Mageweave Robe -- 12050
	AddRecipe(12050, 210, 10001, R_COMMON, GAME_ORIG, 210, 225, 240, 255)
	self:addTradeFlags(RecipeDB, 12050, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.HEALER, F.CASTER, F.CLOTH)
	self:addTradeAcquire(RecipeDB, 12050, A.TRAINER, 1346, A.TRAINER, 2399, A.TRAINER, 4576, A.TRAINER, 11052, A.TRAINER, 11557, A.TRAINER, 18749, A.TRAINER, 18772, A.TRAINER, 28699, A.TRAINER, 4159, A.TRAINER, 16729, A.TRAINER, 3004, A.TRAINER, 3484, A.TRAINER, 3704, A.TRAINER, 2627, A.TRAINER, 33580, A.TRAINER, 3363, A.TRAINER, 1103, A.TRAINER, 27001, A.TRAINER, 33613, A.TRAINER, 33636, A.TRAINER, 26914, A.TRAINER, 17487, A.TRAINER, 16640, A.TRAINER, 16366, A.TRAINER, 26969, A.TRAINER, 5153, A.TRAINER, 4193, A.TRAINER, 26964, A.TRAINER, 3523, A.TRAINER, 33684)

	-- Shadoweave Pants -- 12052
	AddRecipe(12052, 210, 10002, R_COMMON, GAME_ORIG, 210, 225, 240, 255)
	self:addTradeFlags(RecipeDB, 12052, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.HEALER, F.CASTER, F.CLOTH)
	self:addTradeAcquire(RecipeDB, 12052, A.TRAINER, 4578, A.TRAINER, 9584)

	-- Black Mageweave Gloves -- 12053
	AddRecipe(12053, 215, 10003, R_COMMON, GAME_ORIG, 215, 230, 245, 260)
	self:addTradeFlags(RecipeDB, 12053, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.HEALER, F.CASTER, F.CLOTH)
	self:addTradeAcquire(RecipeDB, 12053, A.TRAINER, 1346, A.TRAINER, 2399, A.TRAINER, 4576, A.TRAINER, 11052, A.TRAINER, 11557, A.TRAINER, 18749, A.TRAINER, 18772, A.TRAINER, 28699, A.TRAINER, 4159, A.TRAINER, 16729, A.TRAINER, 3004, A.TRAINER, 3484, A.TRAINER, 3704, A.TRAINER, 2627, A.TRAINER, 33580, A.TRAINER, 3363, A.TRAINER, 1103, A.TRAINER, 27001, A.TRAINER, 33613, A.TRAINER, 33636, A.TRAINER, 26914, A.TRAINER, 17487, A.TRAINER, 16640, A.TRAINER, 16366, A.TRAINER, 26969, A.TRAINER, 5153, A.TRAINER, 4193, A.TRAINER, 26964, A.TRAINER, 3523, A.TRAINER, 33684)

	-- Shadoweave Robe -- 12055
	AddRecipe(12055, 215, 10004, R_COMMON, GAME_ORIG, 215, 230, 245, 260)
	self:addTradeFlags(RecipeDB, 12055, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.HEALER, F.CASTER, F.CLOTH)
	self:addTradeAcquire(RecipeDB, 12055, A.TRAINER, 4578, A.TRAINER, 9584)

	-- Red Mageweave Vest -- 12056
	AddRecipe(12056, 215, 10007, R_UNCOMMON, GAME_ORIG, 215, 230, 245, 260)
	self:addTradeFlags(RecipeDB, 12056, F.ALLIANCE, F.HORDE, F.WORLD_DROP, F.IBOE, F.RBOE, F.CLOTH)
	self:addTradeAcquire(RecipeDB, 12056, A.WORLD_DROP, 2)

	-- White Bandit Mask -- 12059
	AddRecipe(12059, 215, 10008, R_UNCOMMON, GAME_ORIG, 215, 220, 225, 230)
	self:addTradeFlags(RecipeDB, 12059, F.ALLIANCE, F.HORDE, F.WORLD_DROP, F.IBOE, F.RBOE, F.HEALER, F.CASTER, F.CLOTH)
	self:addTradeAcquire(RecipeDB, 12059, A.WORLD_DROP, 2)

	-- Red Mageweave Pants -- 12060
	AddRecipe(12060, 215, 10009, R_UNCOMMON, GAME_ORIG, 215, 230, 245, 260)
	self:addTradeFlags(RecipeDB, 12060, F.ALLIANCE, F.HORDE, F.WORLD_DROP, F.IBOE, F.RBOE, F.HEALER, F.CASTER, F.CLOTH)
	self:addTradeAcquire(RecipeDB, 12060, A.WORLD_DROP, 2)

	-- Orange Mageweave Shirt -- 12061
	AddRecipe(12061, 215, 10056, R_COMMON, GAME_ORIG, 215, 220, 225, 230)
	self:addTradeFlags(RecipeDB, 12061, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP)
	self:addTradeAcquire(RecipeDB, 12061, A.TRAINER, 1346, A.TRAINER, 2399, A.TRAINER, 4576, A.TRAINER, 11052, A.TRAINER, 11557, A.TRAINER, 18749, A.TRAINER, 18772, A.TRAINER, 28699, A.TRAINER, 4159, A.TRAINER, 16729, A.TRAINER, 3004, A.TRAINER, 3484, A.TRAINER, 3704, A.TRAINER, 2627, A.TRAINER, 33580, A.TRAINER, 3363, A.TRAINER, 1103, A.TRAINER, 27001, A.TRAINER, 33613, A.TRAINER, 33636, A.TRAINER, 26914, A.TRAINER, 17487, A.TRAINER, 16640, A.TRAINER, 16366, A.TRAINER, 26969, A.TRAINER, 5153, A.TRAINER, 4193, A.TRAINER, 26964, A.TRAINER, 3523, A.TRAINER, 33684)

	-- Orange Martial Shirt -- 12064
	AddRecipe(12064, 220, 10052, R_COMMON, GAME_ORIG, 220, 225, 230, 235)
	self:addTradeFlags(RecipeDB, 12064, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOE)
	self:addTradeAcquire(RecipeDB, 12064, A.VENDOR, 3005, A.VENDOR, 4168)

	-- Mageweave Bag -- 12065
	AddRecipe(12065, 225, 10050, R_COMMON, GAME_ORIG, 225, 240, 255, 270)
	self:addTradeFlags(RecipeDB, 12065, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP)
	self:addTradeAcquire(RecipeDB, 12065, A.TRAINER, 1346, A.TRAINER, 2399, A.TRAINER, 4576, A.TRAINER, 11052, A.TRAINER, 11557, A.TRAINER, 18749, A.TRAINER, 18772, A.TRAINER, 28699, A.TRAINER, 4159, A.TRAINER, 16729, A.TRAINER, 3004, A.TRAINER, 3484, A.TRAINER, 3704, A.TRAINER, 2627, A.TRAINER, 33580, A.TRAINER, 3363, A.TRAINER, 1103, A.TRAINER, 27001, A.TRAINER, 33613, A.TRAINER, 33636, A.TRAINER, 26914, A.TRAINER, 17487, A.TRAINER, 16640, A.TRAINER, 16366, A.TRAINER, 26969, A.TRAINER, 5153, A.TRAINER, 4193, A.TRAINER, 26964, A.TRAINER, 3523, A.TRAINER, 33684)

	-- Red Mageweave Gloves -- 12066
	AddRecipe(12066, 225, 10018, R_UNCOMMON, GAME_ORIG, 225, 240, 255, 270)
	self:addTradeFlags(RecipeDB, 12066, F.ALLIANCE, F.HORDE, F.WORLD_DROP, F.IBOE, F.RBOE, F.HEALER, F.CASTER, F.CLOTH)
	self:addTradeAcquire(RecipeDB, 12066, A.WORLD_DROP, 2)

	-- Dreamweave Gloves -- 12067
	AddRecipe(12067, 225, 10019, R_COMMON, GAME_ORIG, 225, 240, 255, 270)
	self:addTradeFlags(RecipeDB, 12067, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.HEALER, F.CASTER, F.CLOTH)
	self:addTradeAcquire(RecipeDB, 12067, A.TRAINER, 1346, A.TRAINER, 2399, A.TRAINER, 4576, A.TRAINER, 11052, A.TRAINER, 11557, A.TRAINER, 18749, A.TRAINER, 18772, A.TRAINER, 28699, A.TRAINER, 4159, A.TRAINER, 16729, A.TRAINER, 3004, A.TRAINER, 3484, A.TRAINER, 3704, A.TRAINER, 2627, A.TRAINER, 33580, A.TRAINER, 3363, A.TRAINER, 1103, A.TRAINER, 27001, A.TRAINER, 33613, A.TRAINER, 33636, A.TRAINER, 26914, A.TRAINER, 17487, A.TRAINER, 16640, A.TRAINER, 16366, A.TRAINER, 26969, A.TRAINER, 5153, A.TRAINER, 4193, A.TRAINER, 26964, A.TRAINER, 3523, A.TRAINER, 33684)

	-- Cindercloth Robe -- 12069
	AddRecipe(12069, 225, 10042, R_COMMON, GAME_ORIG, 225, 240, 255, 270)
	self:addTradeFlags(RecipeDB, 12069, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.HEALER, F.CASTER, F.CLOTH)
	self:addTradeAcquire(RecipeDB, 12069, A.TRAINER, 1346, A.TRAINER, 2399, A.TRAINER, 4576, A.TRAINER, 11052, A.TRAINER, 11557, A.TRAINER, 18749, A.TRAINER, 18772, A.TRAINER, 28699, A.TRAINER, 4159, A.TRAINER, 16729, A.TRAINER, 3004, A.TRAINER, 3484, A.TRAINER, 3704, A.TRAINER, 2627, A.TRAINER, 33580, A.TRAINER, 3363, A.TRAINER, 1103, A.TRAINER, 27001, A.TRAINER, 33613, A.TRAINER, 33636, A.TRAINER, 26914, A.TRAINER, 17487, A.TRAINER, 16640, A.TRAINER, 16366, A.TRAINER, 26969, A.TRAINER, 5153, A.TRAINER, 4193, A.TRAINER, 26964, A.TRAINER, 3523, A.TRAINER, 33684)

	-- Dreamweave Vest -- 12070
	AddRecipe(12070, 225, 10021, R_COMMON, GAME_ORIG, 225, 240, 255, 270)
	self:addTradeFlags(RecipeDB, 12070, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.HEALER, F.CASTER, F.CLOTH)
	self:addTradeAcquire(RecipeDB, 12070, A.TRAINER, 1346, A.TRAINER, 2399, A.TRAINER, 4576, A.TRAINER, 11052, A.TRAINER, 11557, A.TRAINER, 18749, A.TRAINER, 18772, A.TRAINER, 28699, A.TRAINER, 4159, A.TRAINER, 16729, A.TRAINER, 3004, A.TRAINER, 3484, A.TRAINER, 3704, A.TRAINER, 2627, A.TRAINER, 33580, A.TRAINER, 3363, A.TRAINER, 1103, A.TRAINER, 27001, A.TRAINER, 33613, A.TRAINER, 33636, A.TRAINER, 26914, A.TRAINER, 17487, A.TRAINER, 16640, A.TRAINER, 16366, A.TRAINER, 26969, A.TRAINER, 5153, A.TRAINER, 4193, A.TRAINER, 26964, A.TRAINER, 3523, A.TRAINER, 33684)

	-- Shadoweave Gloves -- 12071
	AddRecipe(12071, 225, 10023, R_COMMON, GAME_ORIG, 225, 240, 255, 270)
	self:addTradeFlags(RecipeDB, 12071, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.HEALER, F.CASTER, F.CLOTH)
	self:addTradeAcquire(RecipeDB, 12071, A.TRAINER, 4578, A.TRAINER, 9584)

	-- Black Mageweave Headband -- 12072
	AddRecipe(12072, 230, 10024, R_COMMON, GAME_ORIG, 230, 245, 260, 275)
	self:addTradeFlags(RecipeDB, 12072, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.HEALER, F.CASTER, F.CLOTH)
	self:addTradeAcquire(RecipeDB, 12072, A.TRAINER, 2399, A.TRAINER, 11052, A.TRAINER, 11557, A.TRAINER, 18749, A.TRAINER, 18772, A.TRAINER, 28699, A.TRAINER, 1346, A.TRAINER, 4159, A.TRAINER, 16729, A.TRAINER, 3004, A.TRAINER, 3484, A.TRAINER, 3704, A.TRAINER, 2627, A.TRAINER, 33580, A.TRAINER, 3363, A.TRAINER, 1103, A.TRAINER, 27001, A.TRAINER, 33613, A.TRAINER, 33636, A.TRAINER, 26914, A.TRAINER, 4576, A.TRAINER, 17487, A.TRAINER, 16640, A.TRAINER, 16366, A.TRAINER, 26969, A.TRAINER, 5153, A.TRAINER, 4193, A.TRAINER, 26964, A.TRAINER, 3523, A.TRAINER, 33684)

	-- Black Mageweave Boots -- 12073
	AddRecipe(12073, 230, 10026, R_COMMON, GAME_ORIG, 230, 245, 260, 275)
	self:addTradeFlags(RecipeDB, 12073, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.HEALER, F.CASTER, F.CLOTH)
	self:addTradeAcquire(RecipeDB, 12073, A.TRAINER, 2399, A.TRAINER, 11052, A.TRAINER, 11557, A.TRAINER, 18749, A.TRAINER, 18772, A.TRAINER, 28699, A.TRAINER, 1346, A.TRAINER, 4159, A.TRAINER, 16729, A.TRAINER, 3004, A.TRAINER, 3484, A.TRAINER, 3704, A.TRAINER, 2627, A.TRAINER, 33580, A.TRAINER, 3363, A.TRAINER, 1103, A.TRAINER, 27001, A.TRAINER, 33613, A.TRAINER, 33636, A.TRAINER, 26914, A.TRAINER, 4576, A.TRAINER, 17487, A.TRAINER, 16640, A.TRAINER, 16366, A.TRAINER, 26969, A.TRAINER, 5153, A.TRAINER, 4193, A.TRAINER, 26964, A.TRAINER, 3523, A.TRAINER, 33684)

	-- Black Mageweave Shoulders -- 12074
	AddRecipe(12074, 230, 10027, R_COMMON, GAME_ORIG, 230, 245, 260, 275)
	self:addTradeFlags(RecipeDB, 12074, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.HEALER, F.CASTER, F.CLOTH)
	self:addTradeAcquire(RecipeDB, 12074, A.TRAINER, 2399, A.TRAINER, 11052, A.TRAINER, 11557, A.TRAINER, 18749, A.TRAINER, 18772, A.TRAINER, 28699, A.TRAINER, 1346, A.TRAINER, 4159, A.TRAINER, 16729, A.TRAINER, 3004, A.TRAINER, 3484, A.TRAINER, 3704, A.TRAINER, 2627, A.TRAINER, 33580, A.TRAINER, 3363, A.TRAINER, 1103, A.TRAINER, 27001, A.TRAINER, 33613, A.TRAINER, 33636, A.TRAINER, 26914, A.TRAINER, 4576, A.TRAINER, 17487, A.TRAINER, 16640, A.TRAINER, 16366, A.TRAINER, 26969, A.TRAINER, 5153, A.TRAINER, 4193, A.TRAINER, 26964, A.TRAINER, 3523, A.TRAINER, 33684)

	-- Lavender Mageweave Shirt -- 12075
	AddRecipe(12075, 230, 10054, R_COMMON, GAME_ORIG, 230, 235, 240, 245)
	self:addTradeFlags(RecipeDB, 12075, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOE)
	self:addTradeAcquire(RecipeDB, 12075, A.VENDOR, 3364, A.VENDOR, 8681)

	-- Shadoweave Shoulders -- 12076
	AddRecipe(12076, 235, 10028, R_COMMON, GAME_ORIG, 235, 250, 265, 280)
	self:addTradeFlags(RecipeDB, 12076, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.HEALER, F.CASTER, F.CLOTH)
	self:addTradeAcquire(RecipeDB, 12076, A.TRAINER, 4578, A.TRAINER, 9584)

	-- Simple Black Dress -- 12077
	AddRecipe(12077, 235, 10053, R_COMMON, GAME_ORIG, 235, 240, 245, 250)
	self:addTradeFlags(RecipeDB, 12077, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP)
	self:addTradeAcquire(RecipeDB, 12077, A.TRAINER, 2399, A.TRAINER, 11052, A.TRAINER, 11557, A.TRAINER, 18749, A.TRAINER, 18772, A.TRAINER, 28699, A.TRAINER, 1346, A.TRAINER, 4159, A.TRAINER, 16729, A.TRAINER, 3004, A.TRAINER, 3484, A.TRAINER, 3704, A.TRAINER, 2627, A.TRAINER, 33580, A.TRAINER, 3363, A.TRAINER, 1103, A.TRAINER, 27001, A.TRAINER, 33613, A.TRAINER, 33636, A.TRAINER, 26914, A.TRAINER, 4576, A.TRAINER, 17487, A.TRAINER, 16640, A.TRAINER, 16366, A.TRAINER, 26969, A.TRAINER, 5153, A.TRAINER, 4193, A.TRAINER, 26964, A.TRAINER, 3523, A.TRAINER, 33684)

	-- Red Mageweave Shoulders -- 12078
	AddRecipe(12078, 235, 10029, R_UNCOMMON, GAME_ORIG, 235, 250, 265, 280)
	self:addTradeFlags(RecipeDB, 12078, F.ALLIANCE, F.HORDE, F.WORLD_DROP, F.IBOE, F.RBOE, F.CLOTH)
	self:addTradeAcquire(RecipeDB, 12078, A.WORLD_DROP, 2)

	-- Red Mageweave Bag -- 12079
	AddRecipe(12079, 235, 10051, R_COMMON, GAME_ORIG, 235, 250, 265, 280)
	self:addTradeFlags(RecipeDB, 12079, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP)
	self:addTradeAcquire(RecipeDB, 12079, A.TRAINER, 2399, A.TRAINER, 11052, A.TRAINER, 11557, A.TRAINER, 18749, A.TRAINER, 18772, A.TRAINER, 28699, A.TRAINER, 1346, A.TRAINER, 4159, A.TRAINER, 16729, A.TRAINER, 3004, A.TRAINER, 3484, A.TRAINER, 3704, A.TRAINER, 2627, A.TRAINER, 33580, A.TRAINER, 3363, A.TRAINER, 1103, A.TRAINER, 27001, A.TRAINER, 33613, A.TRAINER, 33636, A.TRAINER, 26914, A.TRAINER, 4576, A.TRAINER, 17487, A.TRAINER, 16640, A.TRAINER, 16366, A.TRAINER, 26969, A.TRAINER, 5153, A.TRAINER, 4193, A.TRAINER, 26964, A.TRAINER, 3523)

	-- Pink Mageweave Shirt -- 12080
	AddRecipe(12080, 235, 10055, R_COMMON, GAME_ORIG, 235, 240, 245, 250)
	self:addTradeFlags(RecipeDB, 12080, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOE)
	self:addTradeAcquire(RecipeDB, 12080, A.VENDOR, 3364, A.VENDOR, 8681)

	-- Admiral's Hat -- 12081
	AddRecipe(12081, 240, 10030, R_COMMON, GAME_ORIG, 240, 255, 270, 285)
	self:addTradeFlags(RecipeDB, 12081, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOP, F.CLOTH)
	self:addTradeAcquire(RecipeDB, 12081, A.VENDOR, 2672)

	-- Shadoweave Boots -- 12082
	AddRecipe(12082, 240, 10031, R_COMMON, GAME_ORIG, 240, 255, 270, 285)
	self:addTradeFlags(RecipeDB, 12082, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.HEALER, F.CASTER, F.CLOTH)
	self:addTradeAcquire(RecipeDB, 12082, A.TRAINER, 4578, A.TRAINER, 9584)

	-- Red Mageweave Headband -- 12084
	AddRecipe(12084, 240, 10033, R_UNCOMMON, GAME_ORIG, 240, 255, 270, 285)
	self:addTradeFlags(RecipeDB, 12084, F.ALLIANCE, F.HORDE, F.WORLD_DROP, F.IBOE, F.RBOE, F.CLOTH)
	self:addTradeAcquire(RecipeDB, 12084, A.WORLD_DROP, 2)

	-- Tuxedo Shirt -- 12085
	AddRecipe(12085, 240, 10034, R_COMMON, GAME_ORIG, 240, 245, 250, 255)
	self:addTradeFlags(RecipeDB, 12085, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOE)
	self:addTradeAcquire(RecipeDB, 12085, A.VENDOR, 4577, A.VENDOR, 8681)

	-- Shadoweave Mask -- 12086
	AddRecipe(12086, 245, 10025, R_UNCOMMON, GAME_ORIG, 245, 260, 275, 290)
	self:addTradeFlags(RecipeDB, 12086, F.ALLIANCE, F.HORDE, F.QUEST, F.IBOE, F.RBOE, F.HEALER, F.CASTER, F.CLOTH)
	self:addTradeAcquire(RecipeDB, 12086, A.QUEST, 3402)

	-- Cindercloth Boots -- 12088
	AddRecipe(12088, 245, 10044, R_COMMON, GAME_ORIG, 245, 260, 275, 290)
	self:addTradeFlags(RecipeDB, 12088, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.HEALER, F.CASTER, F.CLOTH)
	self:addTradeAcquire(RecipeDB, 12088, A.TRAINER, 2399, A.TRAINER, 11052, A.TRAINER, 11557, A.TRAINER, 18749, A.TRAINER, 18772, A.TRAINER, 28699, A.TRAINER, 1346, A.TRAINER, 4159, A.TRAINER, 16729, A.TRAINER, 3004, A.TRAINER, 3484, A.TRAINER, 3704, A.TRAINER, 2627, A.TRAINER, 33580, A.TRAINER, 3363, A.TRAINER, 1103, A.TRAINER, 27001, A.TRAINER, 33613, A.TRAINER, 33636, A.TRAINER, 26914, A.TRAINER, 4576, A.TRAINER, 17487, A.TRAINER, 16640, A.TRAINER, 16366, A.TRAINER, 26969, A.TRAINER, 5153, A.TRAINER, 4193, A.TRAINER, 26964, A.TRAINER, 3523, A.TRAINER, 33684)

	-- Tuxedo Pants -- 12089
	AddRecipe(12089, 245, 10035, R_COMMON, GAME_ORIG, 245, 250, 255, 260)
	self:addTradeFlags(RecipeDB, 12089, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOE, F.CLOTH)
	self:addTradeAcquire(RecipeDB, 12089, A.VENDOR, 4577, A.VENDOR, 8681)

	-- White Wedding Dress -- 12091
	AddRecipe(12091, 250, 10040, R_COMMON, GAME_ORIG, 250, 255, 260, 265)
	self:addTradeFlags(RecipeDB, 12091, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOE, F.CLOTH)
	self:addTradeAcquire(RecipeDB, 12091, A.VENDOR, 1347, A.VENDOR, 3005)

	-- Dreamweave Circlet -- 12092
	AddRecipe(12092, 250, 10041, R_COMMON, GAME_ORIG, 250, 265, 280, 295)
	self:addTradeFlags(RecipeDB, 12092, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.HEALER, F.CASTER, F.CLOTH)
	self:addTradeAcquire(RecipeDB, 12092, A.TRAINER, 2399, A.TRAINER, 11052, A.TRAINER, 11557, A.TRAINER, 18749, A.TRAINER, 18772, A.TRAINER, 28699, A.TRAINER, 1346, A.TRAINER, 4159, A.TRAINER, 16729, A.TRAINER, 3004, A.TRAINER, 3484, A.TRAINER, 3704, A.TRAINER, 2627, A.TRAINER, 33580, A.TRAINER, 3363, A.TRAINER, 1103, A.TRAINER, 27001, A.TRAINER, 33613, A.TRAINER, 33636, A.TRAINER, 26914, A.TRAINER, 4576, A.TRAINER, 16640, A.TRAINER, 16366, A.TRAINER, 26969, A.TRAINER, 5153, A.TRAINER, 4193, A.TRAINER, 26964, A.TRAINER, 3523, A.TRAINER, 33684)

	-- Tuxedo Jacket -- 12093
	AddRecipe(12093, 250, 10036, R_COMMON, GAME_ORIG, 250, 265, 280, 295)
	self:addTradeFlags(RecipeDB, 12093, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOE, F.CLOTH)
	self:addTradeAcquire(RecipeDB, 12093, A.VENDOR, 4577, A.VENDOR, 8681)

	-- Bolt of Runecloth -- 18401
	AddRecipe(18401, 250, 14048, R_COMMON, GAME_ORIG, 250, 255, 257, 260)
	self:addTradeFlags(RecipeDB, 18401, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.CLOTH)
	self:addTradeAcquire(RecipeDB, 18401, A.TRAINER, 2399, A.TRAINER, 11052, A.TRAINER, 11557, A.TRAINER, 18749, A.TRAINER, 18772, A.TRAINER, 28699, A.TRAINER, 1346, A.TRAINER, 4159, A.TRAINER, 16729, A.TRAINER, 3004, A.TRAINER, 3484, A.TRAINER, 3704, A.TRAINER, 2627, A.TRAINER, 33580, A.TRAINER, 3363, A.TRAINER, 1103, A.TRAINER, 27001, A.TRAINER, 33613, A.TRAINER, 33636, A.TRAINER, 26914, A.TRAINER, 4576, A.TRAINER, 17487, A.TRAINER, 16640, A.TRAINER, 16366, A.TRAINER, 26969, A.TRAINER, 5153, A.TRAINER, 4193, A.TRAINER, 26964, A.TRAINER, 3523, A.TRAINER, 33684)

	-- Runecloth Belt -- 18402
	AddRecipe(18402, 255, 13856, R_COMMON, GAME_ORIG, 255, 270, 285, 300)
	self:addTradeFlags(RecipeDB, 18402, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.HEALER, F.CASTER, F.CLOTH)
	self:addTradeAcquire(RecipeDB, 18402, A.TRAINER, 2399, A.TRAINER, 11052, A.TRAINER, 11557, A.TRAINER, 18749, A.TRAINER, 18772, A.TRAINER, 28699, A.TRAINER, 1346, A.TRAINER, 4159, A.TRAINER, 16729, A.TRAINER, 3004, A.TRAINER, 3484, A.TRAINER, 3704, A.TRAINER, 2627, A.TRAINER, 33580, A.TRAINER, 3363, A.TRAINER, 1103, A.TRAINER, 27001, A.TRAINER, 33613, A.TRAINER, 33636, A.TRAINER, 26914, A.TRAINER, 4576, A.TRAINER, 17487, A.TRAINER, 16640, A.TRAINER, 16366, A.TRAINER, 26969, A.TRAINER, 5153, A.TRAINER, 4193, A.TRAINER, 26964, A.TRAINER, 3523, A.TRAINER, 33684)

	-- Frostweave Tunic -- 18403
	AddRecipe(18403, 255, 13869, R_UNCOMMON, GAME_ORIG, 255, 270, 285, 300)
	self:addTradeFlags(RecipeDB, 18403, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOE, F.HEALER, F.CASTER, F.CLOTH)
	self:addTradeAcquire(RecipeDB, 18403, A.TRAINER, 2399, A.TRAINER, 11052, A.TRAINER, 18749, A.TRAINER, 18772, A.TRAINER, 28699, A.TRAINER, 1346, A.TRAINER, 4159, A.TRAINER, 16729, A.TRAINER, 3004, A.TRAINER, 3484, A.TRAINER, 3704, A.TRAINER, 2627, A.TRAINER, 33580, A.TRAINER, 3363, A.TRAINER, 1103, A.TRAINER, 27001, A.TRAINER, 33613, A.TRAINER, 33636, A.TRAINER, 26914, A.TRAINER, 4576, A.TRAINER, 17487, A.TRAINER, 16640, A.TRAINER, 16366, A.TRAINER, 26969, A.TRAINER, 5153, A.TRAINER, 4193, A.TRAINER, 26964, A.TRAINER, 3523, A.TRAINER, 33684, A.TRAINER, 11557)

	-- Frostweave Robe -- 18404
	AddRecipe(18404, 255, 13868, R_UNCOMMON, GAME_ORIG, 255, 270, 285, 300)
	self:addTradeFlags(RecipeDB, 18404, F.ALLIANCE, F.HORDE, F.WORLD_DROP, F.IBOE, F.RBOE, F.HEALER, F.CASTER, F.CLOTH)
	self:addTradeAcquire(RecipeDB, 18404, A.WORLD_DROP, 2)

	-- Runecloth Bag -- 18405
	AddRecipe(18405, 260, 14046, R_COMMON, GAME_ORIG, 260, 275, 290, 305)
	self:addTradeFlags(RecipeDB, 18405, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOP)
	self:addTradeAcquire(RecipeDB, 18405, A.VENDOR, 11189)

	-- Runecloth Robe -- 18406
	AddRecipe(18406, 260, 13858, R_COMMON, GAME_ORIG, 260, 275, 290, 305)
	self:addTradeFlags(RecipeDB, 18406, F.ALLIANCE, F.HORDE, F.TRAINER, F.VENDOR, F.IBOE, F.RBOE, F.HEALER, F.CASTER, F.CLOTH)
	self:addTradeAcquire(RecipeDB, 18406, A.TRAINER, 2399, A.TRAINER, 11052, A.TRAINER, 18749, A.TRAINER, 18772, A.VENDOR, 7940, A.TRAINER, 28699, A.TRAINER, 1346, A.TRAINER, 4159, A.TRAINER, 16729, A.TRAINER, 3004, A.TRAINER, 3484, A.TRAINER, 3704, A.TRAINER, 2627, A.TRAINER, 33580, A.TRAINER, 3363, A.TRAINER, 1103, A.TRAINER, 27001, A.TRAINER, 33613, A.TRAINER, 33636, A.TRAINER, 26914, A.TRAINER, 4576, A.TRAINER, 17487, A.TRAINER, 16640, A.TRAINER, 16366, A.TRAINER, 26969, A.TRAINER, 5153, A.TRAINER, 4193, A.TRAINER, 26964, A.TRAINER, 3523, A.TRAINER, 33684, A.TRAINER, 11557)

	-- Runecloth Tunic -- 18407
	AddRecipe(18407, 260, 13857, R_UNCOMMON, GAME_ORIG, 260, 275, 290, 305)
	self:addTradeFlags(RecipeDB, 18407, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOE, F.HEALER, F.CASTER, F.CLOTH)
	self:addTradeAcquire(RecipeDB, 18407, A.TRAINER, 2399, A.TRAINER, 11052, A.TRAINER, 18749, A.TRAINER, 18772, A.TRAINER, 28699, A.TRAINER, 1346, A.TRAINER, 4159, A.TRAINER, 16729, A.TRAINER, 3004, A.TRAINER, 3484, A.TRAINER, 3704, A.TRAINER, 2627, A.TRAINER, 33580, A.TRAINER, 3363, A.TRAINER, 1103, A.TRAINER, 27001, A.TRAINER, 33613, A.TRAINER, 33636, A.TRAINER, 26914, A.TRAINER, 4576, A.TRAINER, 17487, A.TRAINER, 16640, A.TRAINER, 16366, A.TRAINER, 26969, A.TRAINER, 5153, A.TRAINER, 4193, A.TRAINER, 26964, A.TRAINER, 3523, A.TRAINER, 33684, A.TRAINER, 11557)

	-- Cindercloth Vest -- 18408
	AddRecipe(18408, 260, 14042, R_UNCOMMON, GAME_ORIG, 260, 275, 290, 305)
	self:addTradeFlags(RecipeDB, 18408, F.ALLIANCE, F.HORDE, F.MOB_DROP, F.IBOE, F.RBOE, F.HEALER, F.CASTER, F.CLOTH)
	self:addTradeAcquire(RecipeDB, 18408, A.MOB, 5861)

	-- Runecloth Cloak -- 18409
	AddRecipe(18409, 265, 13860, R_COMMON, GAME_ORIG, 265, 280, 295, 310)
	self:addTradeFlags(RecipeDB, 18409, F.ALLIANCE, F.HORDE, F.TRAINER, F.VENDOR, F.IBOE, F.RBOP, F.HEALER, F.CASTER, F.CLOAK)
	self:addTradeAcquire(RecipeDB, 18409, A.TRAINER, 2399, A.TRAINER, 11052, A.TRAINER, 18749, A.TRAINER, 18772, A.VENDOR, 7940, A.TRAINER, 28699, A.TRAINER, 1346, A.TRAINER, 4159, A.TRAINER, 16729, A.TRAINER, 3004, A.TRAINER, 3484, A.TRAINER, 3704, A.TRAINER, 2627, A.TRAINER, 33580, A.TRAINER, 3363, A.TRAINER, 1103, A.TRAINER, 27001, A.TRAINER, 33613, A.TRAINER, 33636, A.TRAINER, 26914, A.TRAINER, 4576, A.TRAINER, 17487, A.TRAINER, 16640, A.TRAINER, 16366, A.TRAINER, 26969, A.TRAINER, 5153, A.TRAINER, 4193, A.TRAINER, 26964, A.TRAINER, 3523, A.TRAINER, 33684, A.TRAINER, 11557)

	-- Ghostweave Belt -- 18410
	AddRecipe(18410, 265, 14143, R_UNCOMMON, GAME_ORIG, 265, 280, 295, 310)
	self:addTradeFlags(RecipeDB, 18410, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOE, F.CLOTH)
	self:addTradeAcquire(RecipeDB, 18410, A.TRAINER, 2399, A.TRAINER, 11052, A.TRAINER, 18749, A.TRAINER, 18772, A.TRAINER, 28699, A.TRAINER, 1346, A.TRAINER, 4159, A.TRAINER, 16729, A.TRAINER, 3004, A.TRAINER, 3484, A.TRAINER, 3704, A.TRAINER, 2627, A.TRAINER, 33580, A.TRAINER, 3363, A.TRAINER, 1103, A.TRAINER, 27001, A.TRAINER, 33613, A.TRAINER, 33636, A.TRAINER, 26914, A.TRAINER, 4576, A.TRAINER, 17487, A.TRAINER, 16640, A.TRAINER, 16366, A.TRAINER, 26969, A.TRAINER, 5153, A.TRAINER, 4193, A.TRAINER, 26964, A.TRAINER, 3523, A.TRAINER, 33684, A.TRAINER, 11557)

	-- Frostweave Gloves -- 18411
	AddRecipe(18411, 265, 13870, R_UNCOMMON, GAME_ORIG, 265, 280, 295, 310)
	self:addTradeFlags(RecipeDB, 18411, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOE, F.HEALER, F.CASTER, F.CLOTH)
	self:addTradeAcquire(RecipeDB, 18411, A.TRAINER, 2399, A.TRAINER, 11052, A.TRAINER, 18749, A.TRAINER, 18772, A.TRAINER, 28699, A.TRAINER, 1346, A.TRAINER, 4159, A.TRAINER, 16729, A.TRAINER, 3004, A.TRAINER, 3484, A.TRAINER, 3704, A.TRAINER, 2627, A.TRAINER, 33580, A.TRAINER, 3363, A.TRAINER, 1103, A.TRAINER, 27001, A.TRAINER, 33613, A.TRAINER, 33636, A.TRAINER, 26914, A.TRAINER, 4576, A.TRAINER, 17487, A.TRAINER, 16640, A.TRAINER, 16366, A.TRAINER, 26969, A.TRAINER, 5153, A.TRAINER, 4193, A.TRAINER, 26964, A.TRAINER, 3523, A.TRAINER, 33684, A.TRAINER, 11557)

	-- Cindercloth Gloves -- 18412
	AddRecipe(18412, 270, 14043, R_UNCOMMON, GAME_ORIG, 270, 285, 300, 315)
	self:addTradeFlags(RecipeDB, 18412, F.ALLIANCE, F.HORDE, F.MOB_DROP, F.IBOE, F.RBOE, F.HEALER, F.CASTER, F.CLOTH)
	self:addTradeAcquire(RecipeDB, 18412, A.MOB, 5861)

	-- Ghostweave Gloves -- 18413
	AddRecipe(18413, 270, 14142, R_UNCOMMON, GAME_ORIG, 270, 285, 300, 315)
	self:addTradeFlags(RecipeDB, 18413, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOE, F.CLOTH)
	self:addTradeAcquire(RecipeDB, 18413, A.TRAINER, 2399, A.TRAINER, 11052, A.TRAINER, 18749, A.TRAINER, 18772, A.TRAINER, 28699, A.TRAINER, 1346, A.TRAINER, 4159, A.TRAINER, 16729, A.TRAINER, 3004, A.TRAINER, 3484, A.TRAINER, 3704, A.TRAINER, 2627, A.TRAINER, 33580, A.TRAINER, 3363, A.TRAINER, 1103, A.TRAINER, 27001, A.TRAINER, 33613, A.TRAINER, 33636, A.TRAINER, 26914, A.TRAINER, 4576, A.TRAINER, 17487, A.TRAINER, 16640, A.TRAINER, 16366, A.TRAINER, 26969, A.TRAINER, 5153, A.TRAINER, 4193, A.TRAINER, 26964, A.TRAINER, 3523, A.TRAINER, 33684, A.TRAINER, 11557)

	-- Brightcloth Robe -- 18414
	AddRecipe(18414, 270, 14100, R_UNCOMMON, GAME_ORIG, 270, 285, 300, 315)
	self:addTradeFlags(RecipeDB, 18414, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOE, F.CLOTH)
	self:addTradeAcquire(RecipeDB, 18414, A.TRAINER, 2399, A.TRAINER, 11052, A.TRAINER, 18749, A.TRAINER, 18772, A.TRAINER, 28699, A.TRAINER, 1346, A.TRAINER, 4159, A.TRAINER, 16729, A.TRAINER, 3004, A.TRAINER, 3484, A.TRAINER, 3704, A.TRAINER, 2627, A.TRAINER, 33580, A.TRAINER, 3363, A.TRAINER, 1103, A.TRAINER, 27001, A.TRAINER, 33613, A.TRAINER, 33636, A.TRAINER, 26914, A.TRAINER, 4576, A.TRAINER, 17487, A.TRAINER, 16640, A.TRAINER, 16366, A.TRAINER, 26969, A.TRAINER, 5153, A.TRAINER, 4193, A.TRAINER, 26964, A.TRAINER, 3523, A.TRAINER, 33684, A.TRAINER, 11557)

	-- Brightcloth Gloves -- 18415
	AddRecipe(18415, 270, 14101, R_UNCOMMON, GAME_ORIG, 270, 285, 300, 315)
	self:addTradeFlags(RecipeDB, 18415, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOE, F.CLOTH)
	self:addTradeAcquire(RecipeDB, 18415, A.TRAINER, 2399, A.TRAINER, 11052, A.TRAINER, 18749, A.TRAINER, 18772, A.TRAINER, 28699, A.TRAINER, 1346, A.TRAINER, 4159, A.TRAINER, 16729, A.TRAINER, 3004, A.TRAINER, 3484, A.TRAINER, 3704, A.TRAINER, 2627, A.TRAINER, 33580, A.TRAINER, 3363, A.TRAINER, 1103, A.TRAINER, 27001, A.TRAINER, 33613, A.TRAINER, 33636, A.TRAINER, 26914, A.TRAINER, 4576, A.TRAINER, 17487, A.TRAINER, 16640, A.TRAINER, 16366, A.TRAINER, 26969, A.TRAINER, 5153, A.TRAINER, 4193, A.TRAINER, 26964, A.TRAINER, 3523, A.TRAINER, 33684, A.TRAINER, 11557)

	-- Ghostweave Vest -- 18416
	AddRecipe(18416, 275, 14141, R_UNCOMMON, GAME_ORIG, 275, 290, 305, 320)
	self:addTradeFlags(RecipeDB, 18416, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOE, F.CLOTH)
	self:addTradeAcquire(RecipeDB, 18416, A.TRAINER, 2399, A.TRAINER, 11052, A.TRAINER, 18749, A.TRAINER, 18772, A.TRAINER, 28699, A.TRAINER, 1346, A.TRAINER, 4159, A.TRAINER, 16729, A.TRAINER, 3004, A.TRAINER, 3484, A.TRAINER, 3704, A.TRAINER, 2627, A.TRAINER, 33580, A.TRAINER, 3363, A.TRAINER, 1103, A.TRAINER, 27001, A.TRAINER, 33613, A.TRAINER, 33636, A.TRAINER, 26914, A.TRAINER, 4576, A.TRAINER, 17487, A.TRAINER, 16640, A.TRAINER, 16366, A.TRAINER, 26969, A.TRAINER, 5153, A.TRAINER, 4193, A.TRAINER, 26964, A.TRAINER, 3523, A.TRAINER, 33684, A.TRAINER, 11557)

	-- Runecloth Gloves -- 18417
	AddRecipe(18417, 275, 13863, R_COMMON, GAME_ORIG, 275, 290, 305, 320)
	self:addTradeFlags(RecipeDB, 18417, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOE, F.HEALER, F.CASTER, F.CLOTH)
	self:addTradeAcquire(RecipeDB, 18417, A.TRAINER, 2399, A.TRAINER, 11052, A.TRAINER, 18749, A.TRAINER, 18772, A.TRAINER, 28699, A.TRAINER, 1346, A.TRAINER, 4159, A.TRAINER, 16729, A.TRAINER, 3004, A.TRAINER, 3484, A.TRAINER, 3704, A.TRAINER, 2627, A.TRAINER, 33580, A.TRAINER, 3363, A.TRAINER, 1103, A.TRAINER, 27001, A.TRAINER, 33613, A.TRAINER, 33636, A.TRAINER, 26914, A.TRAINER, 4576, A.TRAINER, 17487, A.TRAINER, 16640, A.TRAINER, 16366, A.TRAINER, 26969, A.TRAINER, 5153, A.TRAINER, 4193, A.TRAINER, 26964, A.TRAINER, 3523, A.TRAINER, 33684, A.TRAINER, 11557)

	-- Cindercloth Cloak -- 18418
	AddRecipe(18418, 275, 14044, R_UNCOMMON, GAME_ORIG, 275, 290, 305, 320)
	self:addTradeFlags(RecipeDB, 18418, F.ALLIANCE, F.HORDE, F.MOB_DROP, F.IBOE, F.RBOE, F.HEALER, F.CASTER, F.CLOAK)
	self:addTradeAcquire(RecipeDB, 18418, A.MOB, 7037)

	-- Felcloth Pants -- 18419
	AddRecipe(18419, 275, 14107, R_COMMON, GAME_ORIG, 275, 290, 305, 320)
	self:addTradeFlags(RecipeDB, 18419, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOP, F.HEALER, F.CASTER, F.CLOTH)
	self:addTradeAcquire(RecipeDB, 18419, A.VENDOR, 12022)

	-- Brightcloth Cloak -- 18420
	AddRecipe(18420, 275, 14103, R_UNCOMMON, GAME_ORIG, 275, 290, 305, 320)
	self:addTradeFlags(RecipeDB, 18420, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOE, F.HEALER, F.CASTER, F.CLOAK)
	self:addTradeAcquire(RecipeDB, 18420, A.TRAINER, 2399, A.TRAINER, 11052, A.TRAINER, 18749, A.TRAINER, 18772, A.TRAINER, 28699, A.TRAINER, 1346, A.TRAINER, 4159, A.TRAINER, 16729, A.TRAINER, 3004, A.TRAINER, 3484, A.TRAINER, 3704, A.TRAINER, 2627, A.TRAINER, 33580, A.TRAINER, 3363, A.TRAINER, 1103, A.TRAINER, 27001, A.TRAINER, 33613, A.TRAINER, 33636, A.TRAINER, 26914, A.TRAINER, 4576, A.TRAINER, 17487, A.TRAINER, 16640, A.TRAINER, 16366, A.TRAINER, 26969, A.TRAINER, 5153, A.TRAINER, 4193, A.TRAINER, 26964, A.TRAINER, 3523, A.TRAINER, 33684, A.TRAINER, 11557)

	-- Wizardweave Leggings -- 18421
	AddRecipe(18421, 275, 14132, R_UNCOMMON, GAME_ORIG, 275, 290, 305, 320)
	self:addTradeFlags(RecipeDB, 18421, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOE, F.CLOTH)
	self:addTradeAcquire(RecipeDB, 18421, A.TRAINER, 2399, A.TRAINER, 11052, A.TRAINER, 18749, A.TRAINER, 18772, A.TRAINER, 28699, A.TRAINER, 1346, A.TRAINER, 4159, A.TRAINER, 16729, A.TRAINER, 3004, A.TRAINER, 3484, A.TRAINER, 3704, A.TRAINER, 2627, A.TRAINER, 33580, A.TRAINER, 3363, A.TRAINER, 1103, A.TRAINER, 27001, A.TRAINER, 33613, A.TRAINER, 33636, A.TRAINER, 26914, A.TRAINER, 4576, A.TRAINER, 17487, A.TRAINER, 16640, A.TRAINER, 16366, A.TRAINER, 26969, A.TRAINER, 5153, A.TRAINER, 4193, A.TRAINER, 26964, A.TRAINER, 3523, A.TRAINER, 33684, A.TRAINER, 11557)

	-- Cloak of Fire -- 18422
	AddRecipe(18422, 275, 14134, R_RARE, GAME_ORIG, 275, 290, 305, 320)
	self:addTradeFlags(RecipeDB, 18422, F.ALLIANCE, F.HORDE, F.INSTANCE, F.MOB_DROP, F.IBOE, F.RBOP, F.CLOAK)
	self:addTradeAcquire(RecipeDB, 18422, A.MOB, 9026)

	-- Runecloth Boots -- 18423
	AddRecipe(18423, 280, 13864, R_COMMON, GAME_ORIG, 280, 295, 310, 325)
	self:addTradeFlags(RecipeDB, 18423, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOE, F.HEALER, F.CASTER, F.CLOTH)
	self:addTradeAcquire(RecipeDB, 18423, A.TRAINER, 2399, A.TRAINER, 11052, A.TRAINER, 18749, A.TRAINER, 18772, A.TRAINER, 28699, A.TRAINER, 1346, A.TRAINER, 4159, A.TRAINER, 16729, A.TRAINER, 3004, A.TRAINER, 3484, A.TRAINER, 3704, A.TRAINER, 2627, A.TRAINER, 33580, A.TRAINER, 3363, A.TRAINER, 1103, A.TRAINER, 27001, A.TRAINER, 33613, A.TRAINER, 33636, A.TRAINER, 26914, A.TRAINER, 4576, A.TRAINER, 17487, A.TRAINER, 16640, A.TRAINER, 16366, A.TRAINER, 26969, A.TRAINER, 5153, A.TRAINER, 4193, A.TRAINER, 26964, A.TRAINER, 3523, A.TRAINER, 33684, A.TRAINER, 11557)

	-- Frostweave Pants -- 18424
	AddRecipe(18424, 280, 13871, R_UNCOMMON, GAME_ORIG, 280, 295, 310, 325)
	self:addTradeFlags(RecipeDB, 18424, F.ALLIANCE, F.HORDE, F.TRAINER, F.MOB_DROP, F.IBOE, F.RBOE, F.HEALER, F.CASTER, F.CLOTH)
	self:addTradeAcquire(RecipeDB, 18424, A.TRAINER, 2399, A.TRAINER, 11052, A.TRAINER, 18749, A.TRAINER, 18772, A.TRAINER, 28699, A.TRAINER, 1346, A.TRAINER, 4159, A.TRAINER, 16729, A.TRAINER, 3004, A.TRAINER, 3484, A.TRAINER, 3704, A.TRAINER, 2627, A.TRAINER, 33580, A.TRAINER, 3363, A.TRAINER, 1103, A.TRAINER, 27001, A.TRAINER, 33613, A.TRAINER, 33636, A.TRAINER, 26914, A.TRAINER, 4576, A.TRAINER, 17487, A.TRAINER, 16640, A.TRAINER, 16366, A.TRAINER, 26969, A.TRAINER, 5153, A.TRAINER, 4193, A.TRAINER, 26964, A.TRAINER, 3523, A.TRAINER, 33684, A.TRAINER, 11557)

	-- Cindercloth Pants -- 18434
	AddRecipe(18434, 280, 14045, R_UNCOMMON, GAME_ORIG, 280, 295, 310, 325)
	self:addTradeFlags(RecipeDB, 18434, F.ALLIANCE, F.HORDE, F.MOB_DROP, F.IBOE, F.RBOE, F.HEALER, F.CASTER, F.CLOTH)
	self:addTradeAcquire(RecipeDB, 18434, A.MOB, 7037)

	-- Robe of Winter Night -- 18436
	AddRecipe(18436, 285, 14136, R_RARE, GAME_ORIG, 285, 300, 315, 330)
	self:addTradeFlags(RecipeDB, 18436, F.ALLIANCE, F.HORDE, F.MOB_DROP, F.IBOE, F.RBOP, F.HEALER, F.CASTER, F.CLOTH)
	self:addTradeAcquire(RecipeDB, 18436, A.MOB, 7437)

	-- Felcloth Boots -- 18437
	AddRecipe(18437, 285, 14108, R_UNCOMMON, GAME_ORIG, 285, 300, 315, 330)
	self:addTradeFlags(RecipeDB, 18437, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOE, F.HEALER, F.CASTER, F.CLOTH)
	self:addTradeAcquire(RecipeDB, 18437, A.TRAINER, 2399, A.TRAINER, 11052, A.TRAINER, 18749, A.TRAINER, 18772, A.TRAINER, 28699, A.TRAINER, 1346, A.TRAINER, 4159, A.TRAINER, 16729, A.TRAINER, 3004, A.TRAINER, 3484, A.TRAINER, 3704, A.TRAINER, 2627, A.TRAINER, 33580, A.TRAINER, 3363, A.TRAINER, 1103, A.TRAINER, 27001, A.TRAINER, 33613, A.TRAINER, 33636, A.TRAINER, 26914, A.TRAINER, 4576, A.TRAINER, 17487, A.TRAINER, 16640, A.TRAINER, 16366, A.TRAINER, 26969, A.TRAINER, 5153, A.TRAINER, 4193, A.TRAINER, 26964, A.TRAINER, 3523, A.TRAINER, 33684, A.TRAINER, 11557)

	-- Runecloth Pants -- 18438
	AddRecipe(18438, 285, 13865, R_UNCOMMON, GAME_ORIG, 285, 300, 315, 330)
	self:addTradeFlags(RecipeDB, 18438, F.ALLIANCE, F.HORDE, F.TRAINER, F.MOB_DROP, F.IBOE, F.RBOE, F.HEALER, F.CASTER, F.CLOTH)
	self:addTradeAcquire(RecipeDB, 18438, A.TRAINER, 2399, A.TRAINER, 11052, A.TRAINER, 18749, A.TRAINER, 18772, A.TRAINER, 28699, A.TRAINER, 1346, A.TRAINER, 4159, A.TRAINER, 16729, A.TRAINER, 3004, A.TRAINER, 3484, A.TRAINER, 3704, A.TRAINER, 2627, A.TRAINER, 33580, A.TRAINER, 3363, A.TRAINER, 1103, A.TRAINER, 27001, A.TRAINER, 33613, A.TRAINER, 33636, A.TRAINER, 26914, A.TRAINER, 4576, A.TRAINER, 17487, A.TRAINER, 16640, A.TRAINER, 16366, A.TRAINER, 26969, A.TRAINER, 5153, A.TRAINER, 4193, A.TRAINER, 26964, A.TRAINER, 3523, A.TRAINER, 33684, A.TRAINER, 11557)

	-- Brightcloth Pants -- 18439
	AddRecipe(18439, 290, 14104, R_UNCOMMON, GAME_ORIG, 290, 305, 320, 335)
	self:addTradeFlags(RecipeDB, 18439, F.ALLIANCE, F.HORDE, F.WORLD_DROP, F.IBOE, F.RBOE, F.CLOTH)
	self:addTradeAcquire(RecipeDB, 18439, A.WORLD_DROP, 2)

	-- Mooncloth Leggings -- 18440
	AddRecipe(18440, 290, 14137, R_RARE, GAME_ORIG, 290, 305, 320, 335)
	self:addTradeFlags(RecipeDB, 18440, F.ALLIANCE, F.HORDE, F.WORLD_DROP, F.IBOE, F.RBOE, F.HEALER, F.CASTER, F.CLOTH)
	self:addTradeAcquire(RecipeDB, 18440, A.WORLD_DROP, 2)

	-- Ghostweave Pants -- 18441
	AddRecipe(18441, 290, 14144, R_UNCOMMON, GAME_ORIG, 290, 305, 320, 335)
	self:addTradeFlags(RecipeDB, 18441, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOE, F.CLOTH)
	self:addTradeAcquire(RecipeDB, 18441, A.TRAINER, 2399, A.TRAINER, 11052, A.TRAINER, 18749, A.TRAINER, 18772, A.TRAINER, 28699, A.TRAINER, 1346, A.TRAINER, 4159, A.TRAINER, 16729, A.TRAINER, 3004, A.TRAINER, 3484, A.TRAINER, 3704, A.TRAINER, 2627, A.TRAINER, 33580, A.TRAINER, 3363, A.TRAINER, 1103, A.TRAINER, 27001, A.TRAINER, 33613, A.TRAINER, 33636, A.TRAINER, 26914, A.TRAINER, 4576, A.TRAINER, 17487, A.TRAINER, 16640, A.TRAINER, 16366, A.TRAINER, 26969, A.TRAINER, 5153, A.TRAINER, 4193, A.TRAINER, 26964, A.TRAINER, 3523, A.TRAINER, 33684, A.TRAINER, 11557)

	-- Felcloth Hood -- 18442
	AddRecipe(18442, 290, 14111, R_UNCOMMON, GAME_ORIG, 290, 305, 320, 335)
	self:addTradeFlags(RecipeDB, 18442, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOE, F.HEALER, F.CASTER, F.CLOTH)
	self:addTradeAcquire(RecipeDB, 18442, A.TRAINER, 2399, A.TRAINER, 11052, A.TRAINER, 18749, A.TRAINER, 18772, A.TRAINER, 28699, A.TRAINER, 1346, A.TRAINER, 4159, A.TRAINER, 16729, A.TRAINER, 3004, A.TRAINER, 3484, A.TRAINER, 3704, A.TRAINER, 2627, A.TRAINER, 33580, A.TRAINER, 3363, A.TRAINER, 1103, A.TRAINER, 27001, A.TRAINER, 33613, A.TRAINER, 33636, A.TRAINER, 26914, A.TRAINER, 4576, A.TRAINER, 17487, A.TRAINER, 16640, A.TRAINER, 16366, A.TRAINER, 26969, A.TRAINER, 5153, A.TRAINER, 4193, A.TRAINER, 26964, A.TRAINER, 3523, A.TRAINER, 33684, A.TRAINER, 11557)

	-- Runecloth Headband -- 18444
	AddRecipe(18444, 295, 13866, R_UNCOMMON, GAME_ORIG, 295, 310, 325, 340)
	self:addTradeFlags(RecipeDB, 18444, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOE, F.HEALER, F.CASTER, F.CLOTH)
	self:addTradeAcquire(RecipeDB, 18444, A.TRAINER, 2399, A.TRAINER, 11052, A.TRAINER, 18749, A.TRAINER, 18772, A.TRAINER, 28699, A.TRAINER, 1346, A.TRAINER, 4159, A.TRAINER, 16729, A.TRAINER, 3004, A.TRAINER, 3484, A.TRAINER, 3704, A.TRAINER, 2627, A.TRAINER, 33580, A.TRAINER, 3363, A.TRAINER, 1103, A.TRAINER, 27001, A.TRAINER, 33613, A.TRAINER, 33636, A.TRAINER, 26914, A.TRAINER, 4576, A.TRAINER, 17487, A.TRAINER, 16640, A.TRAINER, 16366, A.TRAINER, 26969, A.TRAINER, 5153, A.TRAINER, 4193, A.TRAINER, 26964, A.TRAINER, 3523, A.TRAINER, 33684, A.TRAINER, 11557)

	-- Mooncloth Bag -- 18445
	AddRecipe(18445, 300, 14155, R_UNCOMMON, GAME_ORIG, 300, 315, 330, 345)
	self:addTradeFlags(RecipeDB, 18445, F.ALLIANCE, F.HORDE, F.WORLD_DROP, F.IBOE, F.RBOE)
	self:addTradeAcquire(RecipeDB, 18445, A.WORLD_DROP, 2)

	-- Wizardweave Robe -- 18446
	AddRecipe(18446, 300, 14128, R_UNCOMMON, GAME_ORIG, 300, 315, 330, 345)
	self:addTradeFlags(RecipeDB, 18446, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOE, F.CLOTH)
	self:addTradeAcquire(RecipeDB, 18446, A.TRAINER, 2399, A.TRAINER, 11052, A.TRAINER, 18749, A.TRAINER, 18772, A.TRAINER, 28699, A.TRAINER, 1346, A.TRAINER, 4159, A.TRAINER, 16729, A.TRAINER, 3004, A.TRAINER, 3484, A.TRAINER, 3704, A.TRAINER, 2627, A.TRAINER, 33580, A.TRAINER, 3363, A.TRAINER, 1103, A.TRAINER, 27001, A.TRAINER, 33613, A.TRAINER, 33636, A.TRAINER, 26914, A.TRAINER, 4576, A.TRAINER, 17487, A.TRAINER, 16640, A.TRAINER, 16366, A.TRAINER, 26969, A.TRAINER, 5153, A.TRAINER, 4193, A.TRAINER, 26964, A.TRAINER, 3523, A.TRAINER, 33684, A.TRAINER, 11557)

	-- Mooncloth Vest -- 18447
	AddRecipe(18447, 300, 14138, R_RARE, GAME_ORIG, 300, 315, 330, 345)
	self:addTradeFlags(RecipeDB, 18447, F.ALLIANCE, F.HORDE, F.WORLD_DROP, F.IBOE, F.RBOE, F.HEALER, F.CASTER, F.CLOTH)
	self:addTradeAcquire(RecipeDB, 18447, A.WORLD_DROP, 2)

	-- Mooncloth Shoulders -- 18448
	AddRecipe(18448, 300, 14139, R_RARE, GAME_ORIG, 300, 315, 330, 345)
	self:addTradeFlags(RecipeDB, 18448, F.ALLIANCE, F.HORDE, F.WORLD_DROP, F.IBOE, F.RBOE, F.HEALER, F.CASTER, F.CLOTH)
	self:addTradeAcquire(RecipeDB, 18448, A.WORLD_DROP, 2)

	-- Runecloth Shoulders -- 18449
	AddRecipe(18449, 300, 13867, R_UNCOMMON, GAME_ORIG, 300, 315, 330, 345)
	self:addTradeFlags(RecipeDB, 18449, F.ALLIANCE, F.HORDE, F.TRAINER, F.MOB_DROP, F.IBOE, F.RBOE, F.HEALER, F.CASTER, F.CLOTH)
	self:addTradeAcquire(RecipeDB, 18449, A.TRAINER, 2399, A.TRAINER, 11052, A.TRAINER, 18749, A.TRAINER, 18772, A.TRAINER, 28699, A.TRAINER, 1346, A.TRAINER, 4159, A.TRAINER, 16729, A.TRAINER, 3004, A.TRAINER, 3484, A.TRAINER, 3704, A.TRAINER, 2627, A.TRAINER, 33580, A.TRAINER, 3363, A.TRAINER, 1103, A.TRAINER, 27001, A.TRAINER, 33613, A.TRAINER, 33636, A.TRAINER, 26914, A.TRAINER, 4576, A.TRAINER, 17487, A.TRAINER, 16640, A.TRAINER, 16366, A.TRAINER, 26969, A.TRAINER, 5153, A.TRAINER, 4193, A.TRAINER, 26964, A.TRAINER, 3523, A.TRAINER, 33684, A.TRAINER, 11557)

	-- Wizardweave Turban -- 18450
	AddRecipe(18450, 300, 14130, R_UNCOMMON, GAME_ORIG, 300, 315, 330, 345)
	self:addTradeFlags(RecipeDB, 18450, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOE, F.CLOTH)
	self:addTradeAcquire(RecipeDB, 18450, A.TRAINER, 2399, A.TRAINER, 11052, A.TRAINER, 18749, A.TRAINER, 18772, A.TRAINER, 28699, A.TRAINER, 1346, A.TRAINER, 4159, A.TRAINER, 16729, A.TRAINER, 3004, A.TRAINER, 3484, A.TRAINER, 3704, A.TRAINER, 2627, A.TRAINER, 33580, A.TRAINER, 3363, A.TRAINER, 1103, A.TRAINER, 27001, A.TRAINER, 33613, A.TRAINER, 33636, A.TRAINER, 26914, A.TRAINER, 4576, A.TRAINER, 17487, A.TRAINER, 16640, A.TRAINER, 16366, A.TRAINER, 26969, A.TRAINER, 5153, A.TRAINER, 4193, A.TRAINER, 26964, A.TRAINER, 3523, A.TRAINER, 33684, A.TRAINER, 11557)

	-- Felcloth Robe -- 18451
	AddRecipe(18451, 300, 14106, R_UNCOMMON, GAME_ORIG, 300, 315, 330, 345)
	self:addTradeFlags(RecipeDB, 18451, F.ALLIANCE, F.HORDE, F.TRAINER, F.MOB_DROP, F.IBOE, F.RBOE, F.HEALER, F.CASTER, F.CLOTH)
	self:addTradeAcquire(RecipeDB, 18451, A.TRAINER, 2399, A.TRAINER, 11052, A.TRAINER, 18749, A.TRAINER, 18772, A.TRAINER, 28699, A.TRAINER, 1346, A.TRAINER, 4159, A.TRAINER, 16729, A.TRAINER, 3004, A.TRAINER, 3484, A.TRAINER, 3704, A.TRAINER, 2627, A.TRAINER, 33580, A.TRAINER, 3363, A.TRAINER, 1103, A.TRAINER, 27001, A.TRAINER, 33613, A.TRAINER, 33636, A.TRAINER, 26914, A.TRAINER, 4576, A.TRAINER, 17487, A.TRAINER, 16640, A.TRAINER, 16366, A.TRAINER, 26969, A.TRAINER, 5153, A.TRAINER, 4193, A.TRAINER, 26964, A.TRAINER, 3523, A.TRAINER, 33684, A.TRAINER, 11557)

	-- Mooncloth Circlet -- 18452
	AddRecipe(18452, 300, 14140, R_RARE, GAME_ORIG, 300, 315, 330, 345)
	self:addTradeFlags(RecipeDB, 18452, F.ALLIANCE, F.HORDE, F.WORLD_DROP, F.IBOE, F.RBOE, F.HEALER, F.CASTER, F.CLOTH)
	self:addTradeAcquire(RecipeDB, 18452, A.WORLD_DROP, 2)

	-- Felcloth Shoulders -- 18453
	AddRecipe(18453, 300, 14112, R_UNCOMMON, GAME_ORIG, 300, 315, 330, 345)
	self:addTradeFlags(RecipeDB, 18453, F.ALLIANCE, F.HORDE, F.TRAINER, F.MOB_DROP, F.IBOE, F.RBOE, F.HEALER, F.CASTER, F.CLOTH)
	self:addTradeAcquire(RecipeDB, 18453, A.TRAINER, 2399, A.TRAINER, 11052, A.TRAINER, 18749, A.TRAINER, 18772, A.TRAINER, 28699, A.TRAINER, 1346, A.TRAINER, 4159, A.TRAINER, 16729, A.TRAINER, 3004, A.TRAINER, 3484, A.TRAINER, 3704, A.TRAINER, 2627, A.TRAINER, 33580, A.TRAINER, 3363, A.TRAINER, 1103, A.TRAINER, 27001, A.TRAINER, 33613, A.TRAINER, 33636, A.TRAINER, 26914, A.TRAINER, 4576, A.TRAINER, 17487, A.TRAINER, 16640, A.TRAINER, 16366, A.TRAINER, 26969, A.TRAINER, 5153, A.TRAINER, 4193, A.TRAINER, 26964, A.TRAINER, 3523, A.TRAINER, 33684, A.TRAINER, 11557)

	-- Gloves of Spell Mastery -- 18454
	AddRecipe(18454, 300, 14146, R_EPIC, GAME_ORIG, 300, 315, 330, 345)
	self:addTradeFlags(RecipeDB, 18454, F.ALLIANCE, F.HORDE, F.WORLD_DROP, F.MAGE, F.PRIEST, F.WARLOCK, F.IBOE, F.RBOE, F.HEALER, F.CASTER, F.CLOTH)
	self:addTradeAcquire(RecipeDB, 18454, A.WORLD_DROP, 2)

	-- Bottomless Bag -- 18455
	AddRecipe(18455, 300, 14156, R_RARE, GAME_ORIG, 300, 315, 330, 345)
	self:addTradeFlags(RecipeDB, 18455, F.ALLIANCE, F.HORDE, F.WORLD_DROP, F.IBOE, F.RBOE)
	self:addTradeAcquire(RecipeDB, 18455, A.WORLD_DROP, 2)

	-- Truefaith Vestments -- 18456
	AddRecipe(18456, 300, 14154, R_EPIC, GAME_ORIG, 300, 315, 330, 345)
	self:addTradeFlags(RecipeDB, 18456, F.ALLIANCE, F.HORDE, F.INSTANCE, F.PRIEST, F.IBOP, F.RBOP, F.HEALER, F.CASTER, F.CLOTH)
	self:addTradeAcquire(RecipeDB, 18456, A.MOB, 10813)

	-- Robe of the Archmage -- 18457
	AddRecipe(18457, 300, 14152, R_EPIC, GAME_ORIG, 300, 315, 330, 345)
	self:addTradeFlags(RecipeDB, 18457, F.ALLIANCE, F.HORDE, F.INSTANCE, F.IBOP, F.RBOP, F.HEALER, F.CASTER, F.CLOTH)
	self:addTradeAcquire(RecipeDB, 18457, A.MOB, 9264)

	-- Robe of the Void -- 18458
	AddRecipe(18458, 300, 14153, R_EPIC, GAME_ORIG, 300, 315, 330, 345)
	self:addTradeFlags(RecipeDB, 18458, F.ALLIANCE, F.HORDE, F.INSTANCE, F.IBOP, F.RBOE, F.HEALER, F.CASTER, F.CLOTH)
	self:addTradeAcquire(RecipeDB, 18458, A.MOB, 1853)

	-- Mooncloth -- 18560
	AddRecipe(18560, 250, 14342, R_COMMON, GAME_ORIG, 250, 290, 305, 320)
	self:addTradeFlags(RecipeDB, 18560, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOE, F.CLOTH)
	self:addTradeAcquire(RecipeDB, 18560, A.VENDOR, 11189)

	-- Mooncloth Boots -- 19435
	AddRecipe(19435, 290, 15802, R_RARE, GAME_ORIG, 290, 295, 310, 325)
	self:addTradeFlags(RecipeDB, 19435, F.ALLIANCE, F.HORDE, F.QUEST, F.IBOE, F.RBOP, F.HEALER, F.CASTER, F.CLOTH)
	self:addTradeAcquire(RecipeDB, 19435, A.QUEST, 6032)

	-- Flarecore Mantle -- 20848
	AddRecipe(20848, 300, 16980, R_COMMON, GAME_ORIG, 300, 315, 330, 345)
	self:addTradeFlags(RecipeDB, 20848, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOP, F.HEALER, F.CASTER, F.CLOTH, F.THORIUM_BROTHERHOOD)
	self:addTradeAcquire(RecipeDB, 20848, A.REPUTATION, FAC.THORIUM_BROTHERHOOD, REP.HONORED, 12944)

	-- Flarecore Gloves -- 20849
	AddRecipe(20849, 300, 16979, R_COMMON, GAME_ORIG, 300, 315, 330, 345)
	self:addTradeFlags(RecipeDB, 20849, F.ALLIANCE, F.HORDE, F.VENDOR, F.MAGE, F.PRIEST, F.WARLOCK, F.IBOE, F.RBOP, F.CLOTH, F.THORIUM_BROTHERHOOD)
	self:addTradeAcquire(RecipeDB, 20849, A.REPUTATION, FAC.THORIUM_BROTHERHOOD, REP.FRIENDLY, 12944)

	-- Green Holiday Shirt -- 21945
	AddRecipe(21945, 190, 17723, R_COMMON, GAME_ORIG, 190, 200, 205, 210)
	self:addTradeFlags(RecipeDB, 21945, F.ALLIANCE, F.HORDE, F.MOB_DROP, F.IBOE, F.RBOE)
	self:addTradeAcquire(RecipeDB, 21945, A.SEASONAL, 1)

	-- Flarecore Wraps -- 22759
	AddRecipe(22759, 300, 18263, R_RARE, GAME_ORIG, 300, 320, 335, 350)
	self:addTradeFlags(RecipeDB, 22759, F.ALLIANCE, F.HORDE, F.RAID, F.IBOE, F.RBOE, F.CLOTH)
	self:addTradeAcquire(RecipeDB, 22759, A.CUSTOM, 26)

	-- Gordok Ogre Suit -- 22813
	AddRecipe(22813, 275, 18258, R_UNCOMMON, GAME_ORIG, 275, 285, 290, 295)
	self:addTradeFlags(RecipeDB, 22813, F.ALLIANCE, F.HORDE, F.INSTANCE, F.QUEST, F.IBOE, F.RBOP)
	self:addTradeAcquire(RecipeDB, 22813, A.QUEST, 5518)

	-- Belt of the Archmage -- 22866
	AddRecipe(22866, 300, 18405, R_EPIC, GAME_ORIG, 300, 315, 330, 345)
	self:addTradeFlags(RecipeDB, 22866, F.ALLIANCE, F.HORDE, F.INSTANCE, F.IBOE, F.RBOE, F.CLOTH)
	self:addTradeAcquire(RecipeDB, 22866, A.CUSTOM, 23)

	-- Felcloth Gloves -- 22867
	AddRecipe(22867, 300, 18407, R_RARE, GAME_ORIG, 300, 315, 330, 345)
	self:addTradeFlags(RecipeDB, 22867, F.ALLIANCE, F.HORDE, F.INSTANCE, F.IBOE, F.RBOP, F.HEALER, F.CASTER, F.CLOTH)
	self:addTradeAcquire(RecipeDB, 22867, A.CUSTOM, 23)

	-- Inferno Gloves -- 22868
	AddRecipe(22868, 300, 18408, R_RARE, GAME_ORIG, 300, 315, 330, 345)
	self:addTradeFlags(RecipeDB, 22868, F.ALLIANCE, F.HORDE, F.INSTANCE, F.IBOE, F.RBOP, F.HEALER, F.CASTER, F.CLOTH)
	self:addTradeAcquire(RecipeDB, 22868, A.CUSTOM, 23)

	-- Mooncloth Gloves -- 22869
	AddRecipe(22869, 300, 18409, R_RARE, GAME_ORIG, 300, 315, 330, 345)
	self:addTradeFlags(RecipeDB, 22869, F.ALLIANCE, F.HORDE, F.INSTANCE, F.IBOE, F.RBOP, F.HEALER, F.CASTER, F.CLOTH)
	self:addTradeAcquire(RecipeDB, 22869, A.CUSTOM, 23)

	-- Cloak of Warding -- 22870
	AddRecipe(22870, 300, 18413, R_RARE, GAME_ORIG, 300, 315, 330, 345)
	self:addTradeFlags(RecipeDB, 22870, F.ALLIANCE, F.HORDE, F.INSTANCE, F.IBOE, F.RBOP, F.TANK, F.CLOAK)
	self:addTradeAcquire(RecipeDB, 22870, A.CUSTOM, 23)

	-- Mooncloth Robe -- 22902
	AddRecipe(22902, 300, 18486, R_COMMON, GAME_ORIG, 300, 315, 330, 345)
	self:addTradeFlags(RecipeDB, 22902, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOE, F.HEALER, F.CASTER, F.CLOTH)
	self:addTradeAcquire(RecipeDB, 22902, A.VENDOR, 14371)

	-- Wisdom of the Timbermaw -- 23662
	AddRecipe(23662, 290, 19047, R_COMMON, GAME_ORIG, 290, 305, 320, 335)
	self:addTradeFlags(RecipeDB, 23662, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOP, F.CLOTH, F.TIMBERMAW_HOLD)
	self:addTradeAcquire(RecipeDB, 23662, A.REPUTATION, FAC.TIMBERMAW_HOLD, REP.HONORED, 11557)

	-- Mantle of the Timbermaw -- 23663
	AddRecipe(23663, 300, 19050, R_COMMON, GAME_ORIG, 300, 315, 330, 345)
	self:addTradeFlags(RecipeDB, 23663, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOP, F.CLOTH, F.TIMBERMAW_HOLD)
	self:addTradeAcquire(RecipeDB, 23663, A.REPUTATION, FAC.TIMBERMAW_HOLD, REP.REVERED, 11557)

	-- Argent Boots -- 23664
	AddRecipe(23664, 290, 19056, R_COMMON, GAME_ORIG, 290, 305, 320, 335)
	self:addTradeFlags(RecipeDB, 23664, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOP, F.HEALER, F.CASTER, F.CLOTH, F.ARGENTDAWN)
	self:addTradeAcquire(RecipeDB, 23664, A.REPUTATION, FAC.ARGENTDAWN, REP.HONORED, 10856, A.REPUTATION, FAC.ARGENTDAWN, REP.HONORED, 10857, A.REPUTATION, FAC.ARGENTDAWN, REP.HONORED, 11536)

	-- Argent Shoulders -- 23665
	AddRecipe(23665, 300, 19059, R_COMMON, GAME_ORIG, 300, 315, 330, 345)
	self:addTradeFlags(RecipeDB, 23665, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOP, F.HEALER, F.CASTER, F.CLOTH, F.ARGENTDAWN)
	self:addTradeAcquire(RecipeDB, 23665, A.REPUTATION, FAC.ARGENTDAWN, REP.REVERED, 10856, A.REPUTATION, FAC.ARGENTDAWN, REP.REVERED, 10857, A.REPUTATION, FAC.ARGENTDAWN, REP.REVERED, 11536)

	-- Flarecore Robe -- 23666
	AddRecipe(23666, 300, 19156, R_COMMON, GAME_ORIG, 300, 315, 330, 345)
	self:addTradeFlags(RecipeDB, 23666, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOP, F.HEALER, F.CASTER, F.CLOTH, F.THORIUM_BROTHERHOOD)
	self:addTradeAcquire(RecipeDB, 23666, A.REPUTATION, FAC.THORIUM_BROTHERHOOD, REP.HONORED, 12944)

	-- Flarecore Leggings -- 23667
	AddRecipe(23667, 300, 19165, R_COMMON, GAME_ORIG, 300, 315, 330, 345)
	self:addTradeFlags(RecipeDB, 23667, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOP, F.HEALER, F.CASTER, F.CLOTH, F.THORIUM_BROTHERHOOD)
	self:addTradeAcquire(RecipeDB, 23667, A.REPUTATION, FAC.THORIUM_BROTHERHOOD, REP.REVERED, 12944)

	-- Bloodvine Vest -- 24091
	AddRecipe(24091, 300, 19682, R_COMMON, GAME_ORIG, 300, 315, 330, 345)
	self:addTradeFlags(RecipeDB, 24091, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOP, F.HEALER, F.CASTER, F.CLOTH, F.ZANDALAR)
	self:addTradeAcquire(RecipeDB, 24091, A.REPUTATION, FAC.ZANDALAR, REP.REVERED, 14921)

	-- Bloodvine Leggings -- 24092
	AddRecipe(24092, 300, 19683, R_COMMON, GAME_ORIG, 300, 315, 330, 345)
	self:addTradeFlags(RecipeDB, 24092, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOP, F.HEALER, F.CASTER, F.CLOTH, F.ZANDALAR)
	self:addTradeAcquire(RecipeDB, 24092, A.REPUTATION, FAC.ZANDALAR, REP.HONORED, 14921)

	-- Bloodvine Boots -- 24093
	AddRecipe(24093, 300, 19684, R_COMMON, GAME_ORIG, 300, 315, 330, 345)
	self:addTradeFlags(RecipeDB, 24093, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOP, F.HEALER, F.CASTER, F.CLOTH, F.ZANDALAR)
	self:addTradeAcquire(RecipeDB, 24093, A.REPUTATION, FAC.ZANDALAR, REP.FRIENDLY, 14921)

	-- Runed Stygian Leggings -- 24901
	AddRecipe(24901, 300, 20538, R_RARE, GAME_ORIG, 300, 315, 330, 345)
	self:addTradeFlags(RecipeDB, 24901, F.ALLIANCE, F.HORDE, F.QUEST, F.IBOE, F.RBOE, F.CLOTH)
	self:addTradeAcquire(RecipeDB, 24901, A.QUEST, 8323)

	-- Runed Stygian Belt -- 24902
	AddRecipe(24902, 300, 20539, R_RARE, GAME_ORIG, 300, 315, 330, 345)
	self:addTradeFlags(RecipeDB, 24902, F.ALLIANCE, F.HORDE, F.QUEST, F.IBOE, F.RBOE, F.CLOTH)
	self:addTradeAcquire(RecipeDB, 24902, A.QUEST, 8323)

	-- Runed Stygian Boots -- 24903
	AddRecipe(24903, 300, 20537, R_RARE, GAME_ORIG, 300, 315, 330, 345)
	self:addTradeFlags(RecipeDB, 24903, F.ALLIANCE, F.HORDE, F.QUEST, F.IBOE, F.RBOE, F.CLOTH)
	self:addTradeAcquire(RecipeDB, 24903, A.QUEST, 8323)

	-- Soul Pouch -- 26085
	AddRecipe(26085, 260, 21340, R_COMMON, GAME_ORIG, 260, 275, 290, 305)
	self:addTradeFlags(RecipeDB, 26085, F.ALLIANCE, F.HORDE, F.VENDOR, F.WARLOCK, F.IBOE, F.RBOE)
	self:addTradeAcquire(RecipeDB, 26085, A.VENDOR, 6568)

	-- Felcloth Bag -- 26086
	AddRecipe(26086, 280, 21341, R_RARE, GAME_ORIG, 280, 300, 315, 330)
	self:addTradeFlags(RecipeDB, 26086, F.ALLIANCE, F.HORDE, F.INSTANCE, F.WARLOCK, F.IBOE, F.RBOP)
	self:addTradeAcquire(RecipeDB, 26086, A.MOB, 10503, A.CUSTOM, 30)

	-- Core Felcloth Bag -- 26087
	AddRecipe(26087, 300, 21342, R_RARE, GAME_ORIG, 300, 315, 330, 345)
	self:addTradeFlags(RecipeDB, 26087, F.ALLIANCE, F.HORDE, F.RAID, F.MOB_DROP, F.WARLOCK, F.IBOE, F.RBOE)
	self:addTradeAcquire(RecipeDB, 26087, A.CUSTOM, 26)

	-- Festival Dress -- 26403
	AddRecipe(26403, 250, 21154, R_UNCOMMON, GAME_ORIG, 250, 265, 280, 295)
	self:addTradeFlags(RecipeDB, 26403, F.ALLIANCE, F.HORDE, F.VENDOR, F.SEASONAL, F.IBOE, F.RBOP, F.CLOTH)
	self:addTradeAcquire(RecipeDB, 26403, A.SEASONAL, 2, A.VENDOR, 15909)

	-- Festive Red Pant Suit -- 26407
	AddRecipe(26407, 250, 21542, R_UNCOMMON, GAME_ORIG, 250, 265, 280, 295)
	self:addTradeFlags(RecipeDB, 26407, F.ALLIANCE, F.HORDE, F.VENDOR, F.SEASONAL, F.IBOE, F.RBOP)
	self:addTradeAcquire(RecipeDB, 26407, A.SEASONAL, 2, A.VENDOR, 15909)

	-- Bolt of Netherweave -- 26745
	AddRecipe(26745, 300, 21840, R_COMMON, GAME_TBC, 300, 305, 315, 325)
	self:addTradeFlags(RecipeDB, 26745, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP)
	self:addTradeAcquire(RecipeDB, 26745, A.TRAINER, 18749, A.TRAINER, 18772, A.TRAINER, 28699, A.TRAINER, 33580, A.TRAINER, 27001, A.TRAINER, 33613, A.TRAINER, 33636, A.TRAINER, 26914, A.TRAINER, 26969, A.TRAINER, 26964, A.TRAINER, 33684)

	-- Netherweave Bag -- 26746
	AddRecipe(26746, 315, 21841, R_COMMON, GAME_TBC, 315, 320, 330, 340)
	self:addTradeFlags(RecipeDB, 26746, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP)
	self:addTradeAcquire(RecipeDB, 26746, A.TRAINER, 18749, A.TRAINER, 18772, A.TRAINER, 28699, A.TRAINER, 33580, A.TRAINER, 27001, A.TRAINER, 33613, A.TRAINER, 33636, A.TRAINER, 26914, A.TRAINER, 26969, A.TRAINER, 26964, A.TRAINER, 33684)

	-- Bolt of Imbued Netherweave -- 26747
	AddRecipe(26747, 325, 21842, R_COMMON, GAME_TBC, 325, 330, 335, 340)
	self:addTradeFlags(RecipeDB, 26747, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOE)
	self:addTradeAcquire(RecipeDB, 26747, A.VENDOR, 16638, A.VENDOR, 16767, A.VENDOR, 19213)

	-- Imbued Netherweave Bag -- 26749
	AddRecipe(26749, 340, 21843, R_COMMON, GAME_TBC, 340, 340, 345, 350)
	self:addTradeFlags(RecipeDB, 26749, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOE)
	self:addTradeAcquire(RecipeDB, 26749, A.VENDOR, 19015, A.VENDOR, 19213)

	-- Bolt of Soulcloth -- 26750
	AddRecipe(26750, 345, 21844, R_COMMON, GAME_TBC, 345, 345, 350, 355)
	self:addTradeFlags(RecipeDB, 26750, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOE, F.CLOTH)
	self:addTradeAcquire(RecipeDB, 26750, A.VENDOR, 16638, A.VENDOR, 16767, A.VENDOR, 19015, A.VENDOR, 19017)

	-- Primal Mooncloth -- 26751
	AddRecipe(26751, 350, 21845, R_COMMON, GAME_TBC, 350, 350, 355, 360)
	self:addTradeFlags(RecipeDB, 26751, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOE, F.CLOTH)
	self:addTradeAcquire(RecipeDB, 26751, A.VENDOR, 22208, A.VENDOR, 29512)

	-- Spellfire Belt -- 26752
	AddRecipe(26752, 355, 21846, R_COMMON, GAME_TBC, 355, 365, 370, 375, 26797)
	self:addTradeFlags(RecipeDB, 26752, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOP, F.HEALER, F.CASTER, F.CLOTH)
	self:addTradeAcquire(RecipeDB, 26752, A.VENDOR, 22213, A.VENDOR, 29511)

	-- Spellfire Gloves -- 26753
	AddRecipe(26753, 365, 21847, R_COMMON, GAME_TBC, 365, 375, 380, 385, 26797)
	self:addTradeFlags(RecipeDB, 26753, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOP, F.HEALER, F.CASTER, F.CLOTH)
	self:addTradeAcquire(RecipeDB, 26753, A.VENDOR, 22213, A.VENDOR, 29511)

	-- Spellfire Robe -- 26754
	AddRecipe(26754, 375, 21848, R_COMMON, GAME_TBC, 375, 385, 390, 395, 26797)
	self:addTradeFlags(RecipeDB, 26754, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOP, F.HEALER, F.CASTER, F.CLOTH)
	self:addTradeAcquire(RecipeDB, 26754, A.VENDOR, 22213, A.VENDOR, 29511)

	-- Spellfire Bag -- 26755
	AddRecipe(26755, 375, 21858, R_RARE, GAME_TBC, 375, 385, 390, 395)
	self:addTradeFlags(RecipeDB, 26755, F.ALLIANCE, F.HORDE, F.VENDOR, F.MOB_DROP, F.IBOE, F.RBOP)
	self:addTradeAcquire(RecipeDB, 26755, A.MOB, 20134, A.MOB, 20135, A.VENDOR, 22213, A.VENDOR, 29511)

	-- Frozen Shadoweave Shoulders -- 26756
	AddRecipe(26756, 355, 21869, R_COMMON, GAME_TBC, 355, 365, 370, 375, 26801)
	self:addTradeFlags(RecipeDB, 26756, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOP, F.HEALER, F.CASTER, F.CLOTH)
	self:addTradeAcquire(RecipeDB, 26756, A.VENDOR, 22212, A.VENDOR, 29510)

	-- Frozen Shadoweave Boots -- 26757
	AddRecipe(26757, 365, 21870, R_COMMON, GAME_TBC, 365, 375, 380, 385, 26801)
	self:addTradeFlags(RecipeDB, 26757, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOP, F.HEALER, F.CASTER, F.CLOTH)
	self:addTradeAcquire(RecipeDB, 26757, A.VENDOR, 22212, A.VENDOR, 29510)

	-- Frozen Shadoweave Robe -- 26758
	AddRecipe(26758, 375, 21871, R_COMMON, GAME_TBC, 375, 385, 390, 395, 26801)
	self:addTradeFlags(RecipeDB, 26758, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOP, F.HEALER, F.CASTER, F.CLOTH)
	self:addTradeAcquire(RecipeDB, 26758, A.VENDOR, 22212, A.VENDOR, 29510)

	-- Ebon Shadowbag -- 26759
	AddRecipe(26759, 375, 21872, R_RARE, GAME_TBC, 375, 385, 390, 395)
	self:addTradeFlags(RecipeDB, 26759, F.ALLIANCE, F.HORDE, F.VENDOR, F.WARLOCK, F.IBOE, F.RBOP)
	self:addTradeAcquire(RecipeDB, 26759, A.VENDOR, 22212, A.VENDOR, 29510)

	-- Primal Mooncloth Belt -- 26760
	AddRecipe(26760, 355, 21873, R_COMMON, GAME_TBC, 355, 365, 370, 375, 26798)
	self:addTradeFlags(RecipeDB, 26760, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOP, F.HEALER, F.CASTER, F.CLOTH)
	self:addTradeAcquire(RecipeDB, 26760, A.VENDOR, 22208, A.VENDOR, 29512)

	-- Primal Mooncloth Shoulders -- 26761
	AddRecipe(26761, 365, 21874, R_COMMON, GAME_TBC, 365, 375, 380, 385, 26798)
	self:addTradeFlags(RecipeDB, 26761, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOP, F.HEALER, F.CASTER, F.CLOTH)
	self:addTradeAcquire(RecipeDB, 26761, A.VENDOR, 22208, A.VENDOR, 29512)

	-- Primal Mooncloth Robe -- 26762
	AddRecipe(26762, 375, 21875, R_COMMON, GAME_TBC, 375, 385, 390, 395, 26798)
	self:addTradeFlags(RecipeDB, 26762, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOP, F.HEALER, F.CASTER, F.CLOTH)
	self:addTradeAcquire(RecipeDB, 26762, A.VENDOR, 22208, A.VENDOR, 29512)

	-- Primal Mooncloth Bag -- 26763
	AddRecipe(26763, 375, 21876, R_RARE, GAME_TBC, 375, 385, 390, 395)
	self:addTradeFlags(RecipeDB, 26763, F.ALLIANCE, F.HORDE, F.VENDOR, F.MOB_DROP, F.IBOE, F.RBOP)
	self:addTradeAcquire(RecipeDB, 26763, A.MOB, 18872, A.VENDOR, 22208, A.VENDOR, 29512)

	-- Netherweave Bracers -- 26764
	AddRecipe(26764, 310, 21849, R_COMMON, GAME_TBC, 310, 320, 325, 330)
	self:addTradeFlags(RecipeDB, 26764, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.HEALER, F.CASTER, F.CLOTH)
	self:addTradeAcquire(RecipeDB, 26764, A.TRAINER, 18749, A.TRAINER, 18772, A.TRAINER, 28699, A.TRAINER, 33580, A.TRAINER, 27001, A.TRAINER, 33613, A.TRAINER, 33636, A.TRAINER, 26914, A.TRAINER, 26969, A.TRAINER, 26964, A.TRAINER, 33684)

	-- Netherweave Belt -- 26765
	AddRecipe(26765, 310, 21850, R_COMMON, GAME_TBC, 310, 320, 325, 330)
	self:addTradeFlags(RecipeDB, 26765, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.HEALER, F.CASTER, F.CLOTH)
	self:addTradeAcquire(RecipeDB, 26765, A.TRAINER, 18749, A.TRAINER, 18772, A.TRAINER, 28699, A.TRAINER, 33580, A.TRAINER, 27001, A.TRAINER, 33613, A.TRAINER, 33636, A.TRAINER, 26914, A.TRAINER, 26969, A.TRAINER, 26964, A.TRAINER, 33684)

	-- Netherweave Gloves -- 26770
	AddRecipe(26770, 320, 21851, R_COMMON, GAME_TBC, 320, 330, 335, 340)
	self:addTradeFlags(RecipeDB, 26770, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.HEALER, F.CASTER, F.CLOTH)
	self:addTradeAcquire(RecipeDB, 26770, A.TRAINER, 18749, A.TRAINER, 18772, A.TRAINER, 28699, A.TRAINER, 33580, A.TRAINER, 27001, A.TRAINER, 33613, A.TRAINER, 33636, A.TRAINER, 26914, A.TRAINER, 26969, A.TRAINER, 26964, A.TRAINER, 33684)

	-- Netherweave Pants -- 26771
	AddRecipe(26771, 325, 21852, R_COMMON, GAME_TBC, 325, 335, 340, 345)
	self:addTradeFlags(RecipeDB, 26771, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.HEALER, F.CASTER, F.CLOTH)
	self:addTradeAcquire(RecipeDB, 26771, A.TRAINER, 18749, A.TRAINER, 18772, A.TRAINER, 28699, A.TRAINER, 33580, A.TRAINER, 27001, A.TRAINER, 33613, A.TRAINER, 33636, A.TRAINER, 26914, A.TRAINER, 26969, A.TRAINER, 26964, A.TRAINER, 33684)

	-- Netherweave Boots -- 26772
	AddRecipe(26772, 335, 21853, R_COMMON, GAME_TBC, 335, 345, 350, 355)
	self:addTradeFlags(RecipeDB, 26772, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.HEALER, F.CASTER, F.CLOTH)
	self:addTradeAcquire(RecipeDB, 26772, A.TRAINER, 18749, A.TRAINER, 18772, A.TRAINER, 28699, A.TRAINER, 33580, A.TRAINER, 27001, A.TRAINER, 33613, A.TRAINER, 33636, A.TRAINER, 26914, A.TRAINER, 26969, A.TRAINER, 26964, A.TRAINER, 33684)

	-- Netherweave Robe -- 26773
	AddRecipe(26773, 340, 21854, R_COMMON, GAME_TBC, 340, 350, 355, 360)
	self:addTradeFlags(RecipeDB, 26773, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOE, F.HEALER, F.CASTER, F.CLOTH)
	self:addTradeAcquire(RecipeDB, 26773, A.VENDOR, 16638, A.VENDOR, 16767, A.VENDOR, 19213)

	-- Netherweave Tunic -- 26774
	AddRecipe(26774, 345, 21855, R_COMMON, GAME_TBC, 345, 355, 360, 365)
	self:addTradeFlags(RecipeDB, 26774, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOE, F.HEALER, F.CASTER, F.CLOTH)
	self:addTradeAcquire(RecipeDB, 26774, A.VENDOR, 16638, A.VENDOR, 16767, A.VENDOR, 19213)

	-- Imbued Netherweave Pants -- 26775
	AddRecipe(26775, 340, 21859, R_COMMON, GAME_TBC, 340, 350, 355, 360)
	self:addTradeFlags(RecipeDB, 26775, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOE, F.HEALER, F.CASTER, F.CLOTH)
	self:addTradeAcquire(RecipeDB, 26775, A.VENDOR, 18011, A.VENDOR, 19722)

	-- Imbued Netherweave Boots -- 26776
	AddRecipe(26776, 350, 21860, R_COMMON, GAME_TBC, 350, 360, 365, 370)
	self:addTradeFlags(RecipeDB, 26776, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOE, F.HEALER, F.CASTER, F.CLOTH)
	self:addTradeAcquire(RecipeDB, 26776, A.VENDOR, 18011, A.VENDOR, 19722)

	-- Imbued Netherweave Robe -- 26777
	AddRecipe(26777, 360, 21861, R_COMMON, GAME_TBC, 360, 370, 375, 380)
	self:addTradeFlags(RecipeDB, 26777, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOE, F.HEALER, F.CASTER, F.CLOTH)
	self:addTradeAcquire(RecipeDB, 26777, A.VENDOR, 19521)

	-- Imbued Netherweave Tunic -- 26778
	AddRecipe(26778, 360, 21862, R_COMMON, GAME_TBC, 360, 370, 375, 380)
	self:addTradeFlags(RecipeDB, 26778, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOE, F.HEALER, F.CASTER, F.CLOTH)
	self:addTradeAcquire(RecipeDB, 26778, A.VENDOR, 19521)

	-- Soulcloth Gloves -- 26779
	AddRecipe(26779, 355, 21863, R_COMMON, GAME_TBC, 355, 365, 370, 375)
	self:addTradeFlags(RecipeDB, 26779, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOE, F.HEALER, F.CASTER, F.CLOTH)
	self:addTradeAcquire(RecipeDB, 26779, A.VENDOR, 19015, A.VENDOR, 19017)

	-- Soulcloth Shoulders -- 26780
	AddRecipe(26780, 365, 21864, R_EPIC, GAME_TBC, 365, 375, 380, 385)
	self:addTradeFlags(RecipeDB, 26780, F.ALLIANCE, F.HORDE, F.RAID, F.IBOE, F.RBOP, F.HEALER, F.CASTER, F.CLOTH)
	self:addTradeAcquire(RecipeDB, 26780, A.MOB, 16406)

	-- Soulcloth Vest -- 26781
	AddRecipe(26781, 375, 21865, R_EPIC, GAME_TBC, 375, 380, 382, 385)
	self:addTradeFlags(RecipeDB, 26781, F.ALLIANCE, F.HORDE, F.RAID, F.IBOE, F.RBOP, F.HEALER, F.CASTER, F.CLOTH)
	self:addTradeAcquire(RecipeDB, 26781, A.MOB, 16408)

	-- Arcanoweave Bracers -- 26782
	AddRecipe(26782, 350, 21866, R_UNCOMMON, GAME_TBC, 350, 360, 365, 370)
	self:addTradeFlags(RecipeDB, 26782, F.ALLIANCE, F.HORDE, F.INSTANCE, F.IBOE, F.RBOP, F.CLOTH)
	self:addTradeAcquire(RecipeDB, 26782, A.MOB, 20869)

	-- Arcanoweave Boots -- 26783
	AddRecipe(26783, 360, 21867, R_UNCOMMON, GAME_TBC, 360, 370, 375, 380)
	self:addTradeFlags(RecipeDB, 26783, F.ALLIANCE, F.HORDE, F.INSTANCE, F.IBOE, F.RBOP, F.CLOTH)
	self:addTradeAcquire(RecipeDB, 26783, A.MOB, 19168)

	-- Arcanoweave Robe -- 26784
	AddRecipe(26784, 370, 21868, R_UNCOMMON, GAME_TBC, 370, 380, 385, 390)
	self:addTradeFlags(RecipeDB, 26784, F.ALLIANCE, F.HORDE, F.INSTANCE, F.IBOE, F.RBOP, F.CLOTH)
	self:addTradeAcquire(RecipeDB, 26784, A.MOB, 19220)

	-- Enchanted Mageweave Pouch -- 27658
	AddRecipe(27658, 225, 22246, R_COMMON, GAME_TBC, 225, 240, 255, 270)
	self:addTradeFlags(RecipeDB, 27658, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOE)
	self:addTradeAcquire(RecipeDB, 27658, A.VENDOR, 1318, A.VENDOR, 3012, A.VENDOR, 3346, A.VENDOR, 4228, A.VENDOR, 4617, A.VENDOR, 5158, A.VENDOR, 5757, A.VENDOR, 5758, A.VENDOR, 15419, A.VENDOR, 16635, A.VENDOR, 16722, A.VENDOR, 18753, A.VENDOR, 18773, A.VENDOR, 18951, A.VENDOR, 19234, A.VENDOR, 19537, A.VENDOR, 19540, A.VENDOR, 19663, A.VENDOR, 26569, A.VENDOR, 27030, A.VENDOR, 27054, A.VENDOR, 27147, A.VENDOR, 28714)

	-- Enchanted Runecloth Bag -- 27659
	AddRecipe(27659, 275, 22248, R_COMMON, GAME_ORIG, 275, 290, 305, 320)
	self:addTradeFlags(RecipeDB, 27659, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOE)
	self:addTradeAcquire(RecipeDB, 27659, A.VENDOR, 15419)

	-- Big Bag of Enchantment -- 27660
	AddRecipe(27660, 300, 22249, R_UNCOMMON, GAME_ORIG, 300, 315, 330, 345)
	self:addTradeFlags(RecipeDB, 27660, F.ALLIANCE, F.HORDE, F.INSTANCE, F.IBOE, F.RBOE)
	self:addTradeAcquire(RecipeDB, 27660, A.MOB, 11487)

	-- Cenarion Herb Bag -- 27724
	AddRecipe(27724, 275, 22251, R_COMMON, GAME_ORIG, 275, 290, 305, 320)
	self:addTradeFlags(RecipeDB, 27724, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOP, F.CENARION_CIRCLE)
	self:addTradeAcquire(RecipeDB, 27724, A.REPUTATION, FAC.CENARION_CIRCLE, REP.FRIENDLY, 15179)

	-- Satchel of Cenarius -- 27725
	AddRecipe(27725, 300, 22252, R_COMMON, GAME_ORIG, 300, 315, 330, 345)
	self:addTradeFlags(RecipeDB, 27725, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOP, F.CENARION_CIRCLE)
	self:addTradeAcquire(RecipeDB, 27725, A.REPUTATION, FAC.CENARION_CIRCLE, REP.REVERED, 15179)

	-- Glacial Gloves -- 28205
	AddRecipe(28205, 300, 22654, R_EPIC, GAME_ORIG, 300, 315, 330, 345)
	self:addTradeFlags(RecipeDB, 28205, F.ALLIANCE, F.HORDE, F.VENDOR, F.RAID, F.IBOE, F.RBOP, F.HEALER, F.CASTER, F.CLOTH)
	self:addTradeAcquire(RecipeDB, 28205, A.REPUTATION, FAC.ARGENTDAWN, REP.REVERED, 16365, A.CUSTOM, 41)

	-- Glacial Vest -- 28207
	AddRecipe(28207, 300, 22652, R_EPIC, GAME_ORIG, 300, 315, 330, 345)
	self:addTradeFlags(RecipeDB, 28207, F.ALLIANCE, F.HORDE, F.VENDOR, F.RAID, F.IBOE, F.RBOP, F.HEALER, F.CASTER, F.CLOTH)
	self:addTradeAcquire(RecipeDB, 28207, A.REPUTATION, FAC.ARGENTDAWN, REP.EXALTED, 16365, A.CUSTOM, 41)

	-- Glacial Cloak -- 28208
	AddRecipe(28208, 300, 22658, R_EPIC, GAME_ORIG, 300, 315, 330, 345)
	self:addTradeFlags(RecipeDB, 28208, F.ALLIANCE, F.HORDE, F.VENDOR, F.RAID, F.IBOE, F.RBOP, F.CLOAK)
	self:addTradeAcquire(RecipeDB, 28208, A.REPUTATION, FAC.ARGENTDAWN, REP.HONORED, 16365, A.CUSTOM, 41)

	-- Glacial Wrists -- 28209
	AddRecipe(28209, 300, 22655, R_EPIC, GAME_ORIG, 300, 315, 330, 345)
	self:addTradeFlags(RecipeDB, 28209, F.ALLIANCE, F.HORDE, F.VENDOR, F.RAID, F.IBOE, F.RBOP, F.HEALER, F.CASTER, F.CLOTH)
	self:addTradeAcquire(RecipeDB, 28209, A.REPUTATION, FAC.ARGENTDAWN, REP.REVERED, 16365, A.CUSTOM, 41)

	-- Gaea's Embrace -- 28210
	AddRecipe(28210, 300, 22660, R_COMMON, GAME_ORIG, 300, 315, 330, 345)
	self:addTradeFlags(RecipeDB, 28210, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOP, F.CLOAK, F.CENARION_CIRCLE)
	self:addTradeAcquire(RecipeDB, 28210, A.REPUTATION, FAC.CENARION_CIRCLE, REP.REVERED, 15179)

	-- Sylvan Vest -- 28480
	AddRecipe(28480, 300, 22756, R_COMMON, GAME_ORIG, 300, 315, 330, 345)
	self:addTradeFlags(RecipeDB, 28480, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOP, F.HEALER, F.CASTER, F.CLOTH, F.CENARION_CIRCLE)
	self:addTradeAcquire(RecipeDB, 28480, A.REPUTATION, FAC.CENARION_CIRCLE, REP.REVERED, 15179)

	-- Sylvan Crown -- 28481
	AddRecipe(28481, 300, 22757, R_COMMON, GAME_ORIG, 300, 315, 330, 345)
	self:addTradeFlags(RecipeDB, 28481, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOP, F.HEALER, F.CASTER, F.CLOTH, F.CENARION_CIRCLE)
	self:addTradeAcquire(RecipeDB, 28481, A.REPUTATION, FAC.CENARION_CIRCLE, REP.HONORED, 15179)

	-- Sylvan Shoulders -- 28482
	AddRecipe(28482, 300, 22758, R_COMMON, GAME_ORIG, 300, 315, 330, 345)
	self:addTradeFlags(RecipeDB, 28482, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOP, F.HEALER, F.CASTER, F.CLOTH, F.CENARION_CIRCLE)
	self:addTradeAcquire(RecipeDB, 28482, A.REPUTATION, FAC.CENARION_CIRCLE, REP.FRIENDLY, 15179)

	-- Spellcloth -- 31373
	AddRecipe(31373, 350, 24271, R_COMMON, GAME_TBC, 350, 350, 355, 360)
	self:addTradeFlags(RecipeDB, 31373, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOE, F.CLOTH)
	self:addTradeAcquire(RecipeDB, 31373, A.VENDOR, 22213, A.VENDOR, 29511)

	-- Mystic Spellthread -- 31430
	AddRecipe(31430, 335, 24273, R_COMMON, GAME_TBC, 335, 345, 350, 355)
	self:addTradeFlags(RecipeDB, 31430, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOP, F.HEALER, F.CASTER, F.SCRYER)
	self:addTradeAcquire(RecipeDB, 31430, A.REPUTATION, FAC.SCRYER, REP.HONORED, 19331)

	-- Silver Spellthread -- 31431
	AddRecipe(31431, 335, 24275, R_COMMON, GAME_TBC, 335, 345, 350, 355)
	self:addTradeFlags(RecipeDB, 31431, F.ALLIANCE, F.VENDOR, F.IBOE, F.RBOP, F.HEALER, F.CASTER, F.ALDOR)
	self:addTradeAcquire(RecipeDB, 31431, A.REPUTATION, FAC.ALDOR, REP.HONORED, 19321)

	-- Runic Spellthread -- 31432
	AddRecipe(31432, 375, 24274, R_COMMON, GAME_TBC, 375, 385, 390, 395)
	self:addTradeFlags(RecipeDB, 31432, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOP, F.HEALER, F.CASTER, F.SCRYER)
	self:addTradeAcquire(RecipeDB, 31432, A.REPUTATION, FAC.SCRYER, REP.EXALTED, 19331)

	-- Golden Spellthread -- 31433
	AddRecipe(31433, 375, 24276, R_COMMON, GAME_TBC, 375, 385, 390, 395)
	self:addTradeFlags(RecipeDB, 31433, F.ALLIANCE, F.VENDOR, F.IBOE, F.RBOP, F.HEALER, F.CASTER, F.ALDOR)
	self:addTradeAcquire(RecipeDB, 31433, A.REPUTATION, FAC.ALDOR, REP.EXALTED, 19321)

	-- Unyielding Bracers -- 31434
	AddRecipe(31434, 350, 24249, R_RARE, GAME_TBC, 350, 360, 365, 370)
	self:addTradeFlags(RecipeDB, 31434, F.ALLIANCE, F.HORDE, F.MOB_DROP, F.IBOE, F.RBOP, F.CLOTH)
	self:addTradeAcquire(RecipeDB, 31434, A.MOB, 24664)

	-- Bracers of Havok -- 31435
	AddRecipe(31435, 350, 24250, R_RARE, GAME_TBC, 350, 360, 365, 370)
	self:addTradeFlags(RecipeDB, 31435, F.ALLIANCE, F.HORDE, F.WORLD_DROP, F.IBOE, F.RBOE, F.HEALER, F.CASTER, F.CLOTH)
	self:addTradeAcquire(RecipeDB, 31435, A.WORLD_DROP, 3)

	-- Blackstrike Bracers -- 31437
	AddRecipe(31437, 350, 24251, R_RARE, GAME_TBC, 350, 360, 365, 370)
	self:addTradeFlags(RecipeDB, 31437, F.ALLIANCE, F.HORDE, F.WORLD_DROP, F.IBOE, F.RBOE, F.HEALER, F.CASTER, F.CLOTH)
	self:addTradeAcquire(RecipeDB, 31437, A.WORLD_DROP, 3)

	-- Cloak of the Black Void -- 31438
	AddRecipe(31438, 350, 24252, R_RARE, GAME_TBC, 350, 360, 365, 370)
	self:addTradeFlags(RecipeDB, 31438, F.ALLIANCE, F.HORDE, F.WORLD_DROP, F.IBOE, F.RBOE, F.HEALER, F.CASTER, F.CLOAK)
	self:addTradeAcquire(RecipeDB, 31438, A.WORLD_DROP, 3)

	-- Cloak of Eternity -- 31440
	AddRecipe(31440, 350, 24253, R_RARE, GAME_TBC, 350, 360, 365, 370)
	self:addTradeFlags(RecipeDB, 31440, F.ALLIANCE, F.HORDE, F.WORLD_DROP, F.IBOE, F.RBOE, F.TANK, F.CLOAK)
	self:addTradeAcquire(RecipeDB, 31440, A.WORLD_DROP, 3)

	-- White Remedy Cape -- 31441
	AddRecipe(31441, 350, 24254, R_RARE, GAME_TBC, 350, 360, 365, 370)
	self:addTradeFlags(RecipeDB, 31441, F.ALLIANCE, F.HORDE, F.WORLD_DROP, F.IBOE, F.RBOE, F.HEALER, F.CASTER, F.CLOAK)
	self:addTradeAcquire(RecipeDB, 31441, A.WORLD_DROP, 3)

	-- Unyielding Girdle -- 31442
	AddRecipe(31442, 365, 24255, R_EPIC, GAME_TBC, 365, 375, 380, 385)
	self:addTradeFlags(RecipeDB, 31442, F.ALLIANCE, F.HORDE, F.MOB_DROP, F.IBOE, F.RBOP, F.HEALER, F.CASTER, F.CLOTH)
	self:addTradeAcquire(RecipeDB, 31442, A.MOB, 24664)

	-- Girdle of Ruination -- 31443
	AddRecipe(31443, 365, 24256, R_EPIC, GAME_TBC, 365, 375, 380, 385)
	self:addTradeFlags(RecipeDB, 31443, F.ALLIANCE, F.HORDE, F.WORLD_DROP, F.IBOE, F.RBOE, F.HEALER, F.CASTER, F.CLOTH)
	self:addTradeAcquire(RecipeDB, 31443, A.WORLD_DROP, 4)

	-- Black Belt of Knowledge -- 31444
	AddRecipe(31444, 365, 24257, R_EPIC, GAME_TBC, 365, 375, 380, 385)
	self:addTradeFlags(RecipeDB, 31444, F.ALLIANCE, F.HORDE, F.WORLD_DROP, F.IBOE, F.RBOE, F.HEALER, F.CASTER, F.CLOTH)
	self:addTradeAcquire(RecipeDB, 31444, A.WORLD_DROP, 4)

	-- Resolute Cape -- 31448
	AddRecipe(31448, 365, 24258, R_EPIC, GAME_TBC, 365, 375, 380, 385)
	self:addTradeFlags(RecipeDB, 31448, F.ALLIANCE, F.HORDE, F.WORLD_DROP, F.IBOE, F.RBOE, F.CLOAK)
	self:addTradeAcquire(RecipeDB, 31448, A.WORLD_DROP, 4)

	-- Vengeance Wrap -- 31449
	AddRecipe(31449, 365, 24259, R_EPIC, GAME_TBC, 365, 375, 380, 385)
	self:addTradeFlags(RecipeDB, 31449, F.ALLIANCE, F.HORDE, F.WORLD_DROP, F.IBOE, F.RBOE, F.DPS, F.CLOAK)
	self:addTradeAcquire(RecipeDB, 31449, A.WORLD_DROP, 4)

	-- Manaweave Cloak -- 31450
	AddRecipe(31450, 365, 24260, R_EPIC, GAME_TBC, 365, 375, 380, 385)
	self:addTradeFlags(RecipeDB, 31450, F.ALLIANCE, F.HORDE, F.WORLD_DROP, F.IBOE, F.RBOE, F.HEALER, F.CASTER, F.CLOAK)
	self:addTradeAcquire(RecipeDB, 31450, A.WORLD_DROP, 4)

	-- Whitemend Pants -- 31451
	AddRecipe(31451, 375, 24261, R_EPIC, GAME_TBC, 375, 385, 390, 395)
	self:addTradeFlags(RecipeDB, 31451, F.ALLIANCE, F.HORDE, F.INSTANCE, F.IBOE, F.RBOP, F.HEALER, F.CASTER, F.CLOTH)
	self:addTradeAcquire(RecipeDB, 31451, A.MOB, 20885)

	-- Spellstrike Pants -- 31452
	AddRecipe(31452, 375, 24262, R_EPIC, GAME_TBC, 375, 385, 390, 395)
	self:addTradeFlags(RecipeDB, 31452, F.ALLIANCE, F.HORDE, F.INSTANCE, F.MOB_DROP, F.IBOE, F.RBOP, F.HEALER, F.CASTER, F.CLOTH)
	self:addTradeAcquire(RecipeDB, 31452, A.MOB, 18708)

	-- Battlecast Pants -- 31453
	AddRecipe(31453, 375, 24263, R_EPIC, GAME_TBC, 375, 385, 390, 395)
	self:addTradeFlags(RecipeDB, 31453, F.ALLIANCE, F.HORDE, F.INSTANCE, F.IBOE, F.RBOP, F.HEALER, F.CASTER, F.CLOTH)
	self:addTradeAcquire(RecipeDB, 31453, A.MOB, 17978)

	-- Whitemend Hood -- 31454
	AddRecipe(31454, 375, 24264, R_EPIC, GAME_TBC, 375, 385, 390, 395)
	self:addTradeFlags(RecipeDB, 31454, F.ALLIANCE, F.HORDE, F.INSTANCE, F.IBOE, F.RBOP, F.HEALER, F.CASTER, F.CLOTH)
	self:addTradeAcquire(RecipeDB, 31454, A.MOB, 17977)

	-- Spellstrike Hood -- 31455
	AddRecipe(31455, 375, 24266, R_EPIC, GAME_TBC, 375, 385, 390, 395)
	self:addTradeFlags(RecipeDB, 31455, F.ALLIANCE, F.HORDE, F.INSTANCE, F.IBOE, F.RBOP, F.HEALER, F.CASTER, F.CLOTH)
	self:addTradeAcquire(RecipeDB, 31455, A.MOB, 16807)

	-- Battlecast Hood -- 31456
	AddRecipe(31456, 375, 24267, R_EPIC, GAME_TBC, 375, 385, 390, 395)
	self:addTradeFlags(RecipeDB, 31456, F.ALLIANCE, F.HORDE, F.INSTANCE, F.MOB_DROP, F.IBOE, F.RBOP, F.HEALER, F.CASTER, F.CLOTH)
	self:addTradeAcquire(RecipeDB, 31456, A.MOB, 17798)

	-- Bag of Jewels -- 31459
	AddRecipe(31459, 340, 24270, R_COMMON, GAME_TBC, 340, 350, 355, 360)
	self:addTradeFlags(RecipeDB, 31459, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOP, F.CONSORTIUM)
	self:addTradeAcquire(RecipeDB, 31459, A.REPUTATION, FAC.CONSORTIUM, REP.HONORED, 20242, A.REPUTATION, FAC.CONSORTIUM, REP.HONORED, 23007)

	-- Netherweave Net -- 31460
	AddRecipe(31460, 300, 24268, R_COMMON, GAME_TBC, 300, 300, 310, 320)
	self:addTradeFlags(RecipeDB, 31460, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP)
	self:addTradeAcquire(RecipeDB, 31460, A.TRAINER, 18749, A.TRAINER, 18772, A.TRAINER, 28699, A.TRAINER, 33580, A.TRAINER, 27001, A.TRAINER, 33613, A.TRAINER, 33636, A.TRAINER, 26914, A.TRAINER, 26969, A.TRAINER, 26964, A.TRAINER, 33684)

	-- Belt of Blasting -- 36315
	AddRecipe(36315, 375, 30038, R_EPIC, GAME_TBC, 375, 385, 390, 395)
	self:addTradeFlags(RecipeDB, 36315, F.ALLIANCE, F.HORDE, F.RAID, F.IBOE, F.RBOP, F.HEALER, F.CASTER, F.CLOTH)
	self:addTradeAcquire(RecipeDB, 36315, A.CUSTOM, 37, A.CUSTOM, 43)

	-- Belt of the Long Road -- 36316
	AddRecipe(36316, 375, 30036, R_EPIC, GAME_TBC, 375, 385, 390, 395)
	self:addTradeFlags(RecipeDB, 36316, F.ALLIANCE, F.HORDE, F.RAID, F.IBOE, F.RBOP, F.HEALER, F.CASTER, F.CLOTH)
	self:addTradeAcquire(RecipeDB, 36316, A.CUSTOM, 37, A.CUSTOM, 43)

	-- Boots of Blasting -- 36317
	AddRecipe(36317, 375, 30037, R_EPIC, GAME_TBC, 375, 385, 390, 395)
	self:addTradeFlags(RecipeDB, 36317, F.ALLIANCE, F.HORDE, F.RAID, F.IBOP, F.RBOP, F.HEALER, F.CASTER, F.CLOTH)
	self:addTradeAcquire(RecipeDB, 36317, A.CUSTOM, 37, A.CUSTOM, 43)

	-- Boots of the Long Road -- 36318
	AddRecipe(36318, 375, 30035, R_EPIC, GAME_TBC, 375, 385, 390, 395)
	self:addTradeFlags(RecipeDB, 36318, F.ALLIANCE, F.HORDE, F.RAID, F.IBOP, F.RBOP, F.HEALER, F.CASTER, F.CLOTH)
	self:addTradeAcquire(RecipeDB, 36318, A.CUSTOM, 37, A.CUSTOM, 43)

	-- Shadowcloth -- 36686
	AddRecipe(36686, 350, 24272, R_COMMON, GAME_TBC, 350, 350, 355, 360)
	self:addTradeFlags(RecipeDB, 36686, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOE, F.CLOTH)
	self:addTradeAcquire(RecipeDB, 36686, A.VENDOR, 22212, A.VENDOR, 29510)

	-- Cloak of Arcane Evasion -- 37873
	AddRecipe(37873, 350, 30831, R_COMMON, GAME_TBC, 350, 360, 365, 370)
	self:addTradeFlags(RecipeDB, 37873, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOP, F.CLOAK, F.LOWERCITY)
	self:addTradeAcquire(RecipeDB, 37873, A.REPUTATION, FAC.LOWERCITY, REP.HONORED, 21655)

	-- Flameheart Bracers -- 37882
	AddRecipe(37882, 350, 30837, R_COMMON, GAME_TBC, 350, 360, 365, 370)
	self:addTradeFlags(RecipeDB, 37882, F.ALLIANCE, F.VENDOR, F.IBOE, F.RBOP, F.CLOTH, F.ALDOR)
	self:addTradeAcquire(RecipeDB, 37882, A.REPUTATION, FAC.ALDOR, REP.FRIENDLY, 19321)

	-- Flameheart Gloves -- 37883
	AddRecipe(37883, 360, 30838, R_COMMON, GAME_TBC, 360, 370, 375, 380)
	self:addTradeFlags(RecipeDB, 37883, F.ALLIANCE, F.VENDOR, F.IBOE, F.RBOP, F.CLOTH, F.ALDOR)
	self:addTradeAcquire(RecipeDB, 37883, A.REPUTATION, FAC.ALDOR, REP.HONORED, 19321)

	-- Flameheart Vest -- 37884
	AddRecipe(37884, 370, 30839, R_COMMON, GAME_TBC, 370, 380, 385, 390)
	self:addTradeFlags(RecipeDB, 37884, F.ALLIANCE, F.VENDOR, F.IBOE, F.RBOP, F.CLOTH, F.ALDOR)
	self:addTradeAcquire(RecipeDB, 37884, A.REPUTATION, FAC.ALDOR, REP.EXALTED, 19321)

	-- Soulguard Slippers -- 40020
	AddRecipe(40020, 375, 32391, R_COMMON, GAME_TBC, 375, 385, 390, 395)
	self:addTradeFlags(RecipeDB, 40020, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOP, F.CLOTH, F.ASHTONGUE)
	self:addTradeAcquire(RecipeDB, 40020, A.REPUTATION, FAC.ASHTONGUE, REP.HONORED, 23159)

	-- Soulguard Bracers -- 40021
	AddRecipe(40021, 375, 32392, R_COMMON, GAME_TBC, 375, 385, 390, 395)
	self:addTradeFlags(RecipeDB, 40021, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOP, F.CLOTH, F.ASHTONGUE)
	self:addTradeAcquire(RecipeDB, 40021, A.REPUTATION, FAC.ASHTONGUE, REP.FRIENDLY, 23159)

	-- Soulguard Leggings -- 40023
	AddRecipe(40023, 375, 32389, R_COMMON, GAME_TBC, 375, 385, 390, 395)
	self:addTradeFlags(RecipeDB, 40023, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOP, F.CLOTH, F.ASHTONGUE)
	self:addTradeAcquire(RecipeDB, 40023, A.REPUTATION, FAC.ASHTONGUE, REP.HONORED, 23159)

	-- Soulguard Girdle -- 40024
	AddRecipe(40024, 375, 32390, R_COMMON, GAME_TBC, 375, 385, 390, 395)
	self:addTradeFlags(RecipeDB, 40024, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOP, F.CLOTH, F.ASHTONGUE)
	self:addTradeAcquire(RecipeDB, 40024, A.REPUTATION, FAC.ASHTONGUE, REP.FRIENDLY, 23159)

	-- Night's End -- 40060
	AddRecipe(40060, 375, 32420, R_COMMON, GAME_TBC, 375, 385, 390, 395)
	self:addTradeFlags(RecipeDB, 40060, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOP, F.CLOAK, F.ASHTONGUE)
	self:addTradeAcquire(RecipeDB, 40060, A.REPUTATION, FAC.ASHTONGUE, REP.HONORED, 23159)

	-- Bracers of Nimble Thought -- 41205
	AddRecipe(41205, 375, 32586, R_EPIC, GAME_TBC, 375, 385, 390, 395)
	self:addTradeFlags(RecipeDB, 41205, F.ALLIANCE, F.HORDE, F.WORLD_DROP, F.IBOE, F.RBOE, F.HEALER, F.CASTER, F.CLOTH)
	self:addTradeAcquire(RecipeDB, 41205, A.CUSTOM, 27, A.CUSTOM, 34)

	-- Mantle of Nimble Thought -- 41206
	AddRecipe(41206, 375, 32587, R_EPIC, GAME_TBC, 375, 385, 390, 395)
	self:addTradeFlags(RecipeDB, 41206, F.ALLIANCE, F.HORDE, F.RAID, F.IBOP, F.RBOP, F.HEALER, F.CASTER, F.CLOTH)
	self:addTradeAcquire(RecipeDB, 41206, A.CUSTOM, 27, A.CUSTOM, 34)

	-- Swiftheal Wraps -- 41207
	AddRecipe(41207, 375, 32584, R_EPIC, GAME_TBC, 375, 385, 390, 395)
	self:addTradeFlags(RecipeDB, 41207, F.ALLIANCE, F.HORDE, F.RAID, F.IBOE, F.RBOE, F.HEALER, F.CASTER, F.CLOTH)
	self:addTradeAcquire(RecipeDB, 41207, A.CUSTOM, 27, A.CUSTOM, 34)

	-- Swiftheal Mantle -- 41208
	AddRecipe(41208, 375, 32585, R_EPIC, GAME_TBC, 375, 385, 390, 395)
	self:addTradeFlags(RecipeDB, 41208, F.ALLIANCE, F.HORDE, F.WORLD_DROP, F.IBOP, F.RBOP, F.HEALER, F.CASTER, F.CLOTH)
	self:addTradeAcquire(RecipeDB, 41208, A.WORLD_DROP, 4)

	-- Green Winter Clothes -- 44950
	AddRecipe(44950, 250, 34087, R_UNCOMMON, GAME_TBC, 250, 250, 250, 250)
	self:addTradeFlags(RecipeDB, 44950, F.ALLIANCE, F.HORDE, F.VENDOR, F.SEASONAL, F.IBOE, F.RBOP, F.CLOTH)
	self:addTradeAcquire(RecipeDB, 44950, A.VENDOR, 13420, A.SEASONAL, 1)

	-- Red Winter Clothes -- 44958
	AddRecipe(44958, 250, 34085, R_UNCOMMON, GAME_TBC, 250, 250, 250, 250)
	self:addTradeFlags(RecipeDB, 44958, F.ALLIANCE, F.HORDE, F.VENDOR, F.SEASONAL, F.IBOE, F.RBOP, F.CLOTH)
	self:addTradeAcquire(RecipeDB, 44958, A.VENDOR, 13433, A.SEASONAL, 1)

	-- Sunfire Handwraps -- 46128
	AddRecipe(46128, 365, 34366, R_EPIC, GAME_TBC, 365, 375, 392, 410)
	self:addTradeFlags(RecipeDB, 46128, F.ALLIANCE, F.HORDE, F.RAID, F.IBOE, F.RBOP, F.HEALER, F.CASTER, F.CLOTH)
	self:addTradeAcquire(RecipeDB, 46128, A.CUSTOM, 24)

	-- Hands of Eternal Light -- 46129
	AddRecipe(46129, 365, 34367, R_EPIC, GAME_TBC, 365, 375, 392, 410)
	self:addTradeFlags(RecipeDB, 46129, F.ALLIANCE, F.HORDE, F.RAID, F.IBOE, F.RBOE, F.HEALER, F.CASTER, F.CLOTH)
	self:addTradeAcquire(RecipeDB, 46129, A.CUSTOM, 24)

	-- Sunfire Robe -- 46130
	AddRecipe(46130, 365, 34364, R_EPIC, GAME_TBC, 365, 375, 392, 410)
	self:addTradeFlags(RecipeDB, 46130, F.ALLIANCE, F.HORDE, F.RAID, F.IBOP, F.RBOP, F.HEALER, F.CASTER, F.CLOTH)
	self:addTradeAcquire(RecipeDB, 46130, A.CUSTOM, 24)

	-- Robe of Eternal Light -- 46131
	AddRecipe(46131, 365, 34365, R_EPIC, GAME_TBC, 365, 375, 392, 410)
	self:addTradeFlags(RecipeDB, 46131, F.ALLIANCE, F.HORDE, F.RAID, F.IBOP, F.RBOP, F.HEALER, F.CASTER, F.CLOTH)
	self:addTradeAcquire(RecipeDB, 46131, A.CUSTOM, 24)

	-- Dress Shoes -- 49677
	AddRecipe(49677, 250, 6836, R_COMMON, GAME_TBC, 250, 255, 270, 285)
	self:addTradeFlags(RecipeDB, 49677, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOE, F.CLOTH)
	self:addTradeAcquire(RecipeDB, 49677, A.VENDOR, 15165)

	-- Mycah's Botanical Bag -- 50194
	AddRecipe(50194, 375, 38225, R_COMMON, GAME_TBC, 375, 385, 390, 395)
	self:addTradeFlags(RecipeDB, 50194, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOP, F.SPOREGGAR)
	self:addTradeAcquire(RecipeDB, 50194, A.REPUTATION, FAC.SPOREGGAR, REP.REVERED, 18382)

	-- Haliscan Jacket -- 50644
	AddRecipe(50644, 250, 38277, R_COMMON, GAME_TBC, 250, 265, 280, 295)
	self:addTradeFlags(RecipeDB, 50644, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOE, F.CLOTH)
	self:addTradeAcquire(RecipeDB, 50644, A.VENDOR, 15165)

	-- Haliscan Pantaloons -- 50647
	AddRecipe(50647, 245, 38278, R_COMMON, GAME_TBC, 245, 250, 255, 260)
	self:addTradeFlags(RecipeDB, 50647, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOE, F.CLOTH)
	self:addTradeAcquire(RecipeDB, 50647, A.VENDOR, 15165)

	-- Lightweave Embroidery -- 55642
	AddRecipe(55642, 420, nil, R_COMMON, GAME_WOTLK, 420, 420, 420, 420)
	self:addTradeFlags(RecipeDB, 55642, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.HEALER, F.CASTER, F.CLOAK)
	self:addTradeAcquire(RecipeDB, 55642, A.TRAINER, 26914, A.TRAINER, 26964, A.TRAINER, 26969, A.TRAINER, 27001, A.TRAINER, 28699, A.TRAINER, 33580)

	-- Darkglow Embroidery -- 55769
	AddRecipe(55769, 420, nil, R_COMMON, GAME_WOTLK, 420, 420, 420, 420)
	self:addTradeFlags(RecipeDB, 55769, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.CLOAK)
	self:addTradeAcquire(RecipeDB, 55769, A.TRAINER, 26914, A.TRAINER, 26964, A.TRAINER, 26969, A.TRAINER, 27001, A.TRAINER, 28699, A.TRAINER, 33580)

	-- Swordguard Embroidery -- 55777
	AddRecipe(55777, 420, nil, R_COMMON, GAME_WOTLK, 420, 420, 420, 420)
	self:addTradeFlags(RecipeDB, 55777, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.DPS, F.CLOAK)
	self:addTradeAcquire(RecipeDB, 55777, A.TRAINER, 26914, A.TRAINER, 26964, A.TRAINER, 26969, A.TRAINER, 27001, A.TRAINER, 28699, A.TRAINER, 33580)

	-- Frostweave Net -- 55898
	AddRecipe(55898, 360, 41509, R_COMMON, GAME_WOTLK, 360, 370, 375, 380)
	self:addTradeFlags(RecipeDB, 55898, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP)
	self:addTradeAcquire(RecipeDB, 55898, A.TRAINER, 26914, A.TRAINER, 26964, A.TRAINER, 26969, A.TRAINER, 27001, A.TRAINER, 28699, A.TRAINER, 33580)

	-- Bolt of Frostweave -- 55899
	AddRecipe(55899, 350, 41510, R_COMMON, GAME_WOTLK, 350, 370, 372, 375)
	self:addTradeFlags(RecipeDB, 55899, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP)
	self:addTradeAcquire(RecipeDB, 55899, A.TRAINER, 26914, A.TRAINER, 26964, A.TRAINER, 26969, A.TRAINER, 27001, A.TRAINER, 28699, A.TRAINER, 33580)

	-- Bolt of Imbued Frostweave -- 55900
	AddRecipe(55900, 400, 41511, R_COMMON, GAME_WOTLK, 400, 400, 402, 405)
	self:addTradeFlags(RecipeDB, 55900, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP)
	self:addTradeAcquire(RecipeDB, 55900, A.TRAINER, 26914, A.TRAINER, 26964, A.TRAINER, 26969, A.TRAINER, 27001, A.TRAINER, 28699, A.TRAINER, 33580)

	-- Duskweave Leggings -- 55901
	AddRecipe(55901, 395, 41548, R_UNCOMMON, GAME_WOTLK, 395, 405, 410, 415)
	self:addTradeFlags(RecipeDB, 55901, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.HEALER, F.CASTER, F.CLOTH)
	self:addTradeAcquire(RecipeDB, 55901, A.TRAINER, 26914, A.TRAINER, 26964, A.TRAINER, 26969, A.TRAINER, 27001, A.TRAINER, 28699, A.TRAINER, 33580)

	-- Frostwoven Shoulders -- 55902
	AddRecipe(55902, 350, 41513, R_UNCOMMON, GAME_WOTLK, 350, 360, 370, 380)
	self:addTradeFlags(RecipeDB, 55902, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.HEALER, F.CASTER, F.CLOTH)
	self:addTradeAcquire(RecipeDB, 55902, A.TRAINER, 26914, A.TRAINER, 26964, A.TRAINER, 26969, A.TRAINER, 27001, A.TRAINER, 28699, A.TRAINER, 33580)

	-- Frostwoven Robe -- 55903
	AddRecipe(55903, 360, 41515, R_UNCOMMON, GAME_WOTLK, 360, 370, 380, 390)
	self:addTradeFlags(RecipeDB, 55903, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.HEALER, F.CASTER, F.CLOTH)
	self:addTradeAcquire(RecipeDB, 55903, A.TRAINER, 26914, A.TRAINER, 26964, A.TRAINER, 26969, A.TRAINER, 27001, A.TRAINER, 28699, A.TRAINER, 33580)

	-- Frostwoven Gloves -- 55904
	AddRecipe(55904, 360, 44211, R_COMMON, GAME_WOTLK, 360, 370, 380, 390)
	self:addTradeFlags(RecipeDB, 55904, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.HEALER, F.CASTER, F.CLOTH)
	self:addTradeAcquire(RecipeDB, 55904, A.TRAINER, 26914, A.TRAINER, 26964, A.TRAINER, 26969, A.TRAINER, 27001, A.TRAINER, 28699, A.TRAINER, 33580)

	-- Frostwoven Boots -- 55906
	AddRecipe(55906, 375, 41520, R_UNCOMMON, GAME_WOTLK, 375, 385, 395, 405)
	self:addTradeFlags(RecipeDB, 55906, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.HEALER, F.CASTER, F.CLOTH)
	self:addTradeAcquire(RecipeDB, 55906, A.TRAINER, 26914, A.TRAINER, 26964, A.TRAINER, 26969, A.TRAINER, 27001, A.TRAINER, 28699, A.TRAINER, 33580)

	-- Frostwoven Cowl -- 55907
	AddRecipe(55907, 380, 41521, R_UNCOMMON, GAME_WOTLK, 380, 390, 395, 400)
	self:addTradeFlags(RecipeDB, 55907, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.HEALER, F.CASTER, F.CLOTH)
	self:addTradeAcquire(RecipeDB, 55907, A.TRAINER, 26914, A.TRAINER, 26964, A.TRAINER, 26969, A.TRAINER, 27001, A.TRAINER, 28699, A.TRAINER, 33580)

	-- Frostwoven Belt -- 55908
	AddRecipe(55908, 370, 41522, R_UNCOMMON, GAME_WOTLK, 370, 380, 390, 400)
	self:addTradeFlags(RecipeDB, 55908, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.HEALER, F.CASTER, F.CLOTH)
	self:addTradeAcquire(RecipeDB, 55908, A.TRAINER, 26914, A.TRAINER, 26964, A.TRAINER, 26969, A.TRAINER, 27001, A.TRAINER, 28699, A.TRAINER, 33580)

	-- Mystic Frostwoven Shoulders -- 55910
	AddRecipe(55910, 385, 41523, R_RARE, GAME_WOTLK, 385, 395, 405, 415)
	self:addTradeFlags(RecipeDB, 55910, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.HEALER, F.CASTER, F.CLOTH)
	self:addTradeAcquire(RecipeDB, 55910, A.TRAINER, 26914, A.TRAINER, 26964, A.TRAINER, 26969, A.TRAINER, 27001, A.TRAINER, 28699, A.TRAINER, 33580)

	-- Mystic Frostwoven Robe -- 55911
	AddRecipe(55911, 390, 41525, R_RARE, GAME_WOTLK, 390, 400, 410, 420)
	self:addTradeFlags(RecipeDB, 55911, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.HEALER, F.CASTER, F.CLOTH)
	self:addTradeAcquire(RecipeDB, 55911, A.TRAINER, 26914, A.TRAINER, 26964, A.TRAINER, 26969, A.TRAINER, 27001, A.TRAINER, 28699, A.TRAINER, 33580)

	-- Mystic Frostwoven Wristwraps -- 55913
	AddRecipe(55913, 385, 41528, R_RARE, GAME_WOTLK, 385, 395, 405, 415)
	self:addTradeFlags(RecipeDB, 55913, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.HEALER, F.CASTER, F.CLOTH)
	self:addTradeAcquire(RecipeDB, 55913, A.TRAINER, 26914, A.TRAINER, 26964, A.TRAINER, 26969, A.TRAINER, 27001, A.TRAINER, 28699, A.TRAINER, 33580)

	-- Duskweave Belt -- 55914
	AddRecipe(55914, 395, 41543, R_UNCOMMON, GAME_WOTLK, 395, 400, 405, 410)
	self:addTradeFlags(RecipeDB, 55914, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOE, F.HEALER, F.CASTER, F.CLOTH)
	self:addTradeAcquire(RecipeDB, 55914, A.TRAINER, 26914, A.TRAINER, 26964, A.TRAINER, 26969, A.TRAINER, 27001, A.TRAINER, 28699, A.TRAINER, 33580)

	-- Duskweave Cowl -- 55919
	AddRecipe(55919, 395, 41546, R_UNCOMMON, GAME_WOTLK, 395, 405, 410, 415)
	self:addTradeFlags(RecipeDB, 55919, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.HEALER, F.CASTER, F.CLOTH)
	self:addTradeAcquire(RecipeDB, 55919, A.TRAINER, 26914, A.TRAINER, 26964, A.TRAINER, 26969, A.TRAINER, 27001, A.TRAINER, 28699, A.TRAINER, 33580)

	-- Duskweave Wristwraps -- 55920
	AddRecipe(55920, 400, 41551, R_UNCOMMON, GAME_WOTLK, 400, 410, 415, 420)
	self:addTradeFlags(RecipeDB, 55920, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.HEALER, F.CASTER, F.CLOTH)
	self:addTradeAcquire(RecipeDB, 55920, A.TRAINER, 26914, A.TRAINER, 26964, A.TRAINER, 26969, A.TRAINER, 27001, A.TRAINER, 28699, A.TRAINER, 33580)

	-- Duskweave Robe -- 55921
	AddRecipe(55921, 405, 41549, R_UNCOMMON, GAME_WOTLK, 405, 415, 420, 425)
	self:addTradeFlags(RecipeDB, 55921, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.HEALER, F.CASTER, F.CLOTH)
	self:addTradeAcquire(RecipeDB, 55921, A.TRAINER, 26914, A.TRAINER, 26964, A.TRAINER, 26969, A.TRAINER, 27001, A.TRAINER, 28699, A.TRAINER, 33580)

	-- Duskweave Gloves -- 55922
	AddRecipe(55922, 405, 41545, R_UNCOMMON, GAME_WOTLK, 405, 415, 420, 425)
	self:addTradeFlags(RecipeDB, 55922, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.HEALER, F.CASTER, F.CLOTH)
	self:addTradeAcquire(RecipeDB, 55922, A.TRAINER, 26914, A.TRAINER, 26964, A.TRAINER, 26969, A.TRAINER, 27001, A.TRAINER, 28699, A.TRAINER, 33580)

	-- Duskweave Shoulders -- 55923
	AddRecipe(55923, 410, 41550, R_UNCOMMON, GAME_WOTLK, 410, 420, 425, 430)
	self:addTradeFlags(RecipeDB, 55923, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.HEALER, F.CASTER, F.CLOTH)
	self:addTradeAcquire(RecipeDB, 55923, A.TRAINER, 26914, A.TRAINER, 26964, A.TRAINER, 26969, A.TRAINER, 27001, A.TRAINER, 28699, A.TRAINER, 33580)

	-- Duskweave Boots -- 55924
	AddRecipe(55924, 410, 41544, R_COMMON, GAME_WOTLK, 410, 410, 410, 420)
	self:addTradeFlags(RecipeDB, 55924, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.HEALER, F.CASTER, F.CLOTH)
	self:addTradeAcquire(RecipeDB, 55924, A.TRAINER, 26914, A.TRAINER, 26964, A.TRAINER, 26969, A.TRAINER, 27001, A.TRAINER, 28699, A.TRAINER, 33580)

	-- Black Duskweave Leggings -- 55925
	AddRecipe(55925, 415, 41553, R_RARE, GAME_WOTLK, 415, 425, 430, 435)
	self:addTradeFlags(RecipeDB, 55925, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.HEALER, F.CASTER, F.CLOTH)
	self:addTradeAcquire(RecipeDB, 55925, A.TRAINER, 26914, A.TRAINER, 26964, A.TRAINER, 26969, A.TRAINER, 27001, A.TRAINER, 28699, A.TRAINER, 33580)

	-- Black Duskweave Robe -- 55941
	AddRecipe(55941, 420, 41554, R_RARE, GAME_WOTLK, 420, 430, 435, 440)
	self:addTradeFlags(RecipeDB, 55941, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.HEALER, F.CASTER, F.CLOTH)
	self:addTradeAcquire(RecipeDB, 55941, A.TRAINER, 26914, A.TRAINER, 26964, A.TRAINER, 26969, A.TRAINER, 27001, A.TRAINER, 28699, A.TRAINER, 33580)

	-- Black Duskweave Wristwraps -- 55943
	AddRecipe(55943, 415, 41555, R_RARE, GAME_WOTLK, 415, 425, 430, 435)
	self:addTradeFlags(RecipeDB, 55943, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.HEALER, F.CASTER, F.CLOTH)
	self:addTradeAcquire(RecipeDB, 55943, A.TRAINER, 26914, A.TRAINER, 26964, A.TRAINER, 26969, A.TRAINER, 27001, A.TRAINER, 28699, A.TRAINER, 33580)

	-- Red Lumberjack Shirt -- 55993
	AddRecipe(55993, 400, 41248, R_UNCOMMON, GAME_WOTLK, 400, 400, 405, 410)
	self:addTradeFlags(RecipeDB, 55993, F.ALLIANCE, F.HORDE, F.WORLD_DROP, F.IBOE, F.RBOE)
	self:addTradeAcquire(RecipeDB, 55993, A.WORLD_DROP, 2)

	-- Blue Lumberjack Shirt -- 55994
	AddRecipe(55994, 400, 41249, R_UNCOMMON, GAME_WOTLK, 400, 400, 405, 410)
	self:addTradeFlags(RecipeDB, 55994, F.ALLIANCE, F.HORDE, F.WORLD_DROP, F.IBOE, F.RBOE)
	self:addTradeAcquire(RecipeDB, 55994, A.WORLD_DROP, 2)

	-- Yellow Lumberjack Shirt -- 55995
	AddRecipe(55995, 400, 41251, R_COMMON, GAME_WOTLK, 400, 400, 405, 410)
	self:addTradeFlags(RecipeDB, 55995, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP)
	self:addTradeAcquire(RecipeDB, 55995, A.TRAINER, 26914, A.TRAINER, 26964, A.TRAINER, 26969, A.TRAINER, 27001, A.TRAINER, 28699, A.TRAINER, 33580)

	-- Green Lumberjack Shirt -- 55996
	AddRecipe(55996, 400, 41250, R_UNCOMMON, GAME_WOTLK, 400, 400, 405, 410)
	self:addTradeFlags(RecipeDB, 55996, F.ALLIANCE, F.HORDE, F.WORLD_DROP, F.IBOE, F.RBOE)
	self:addTradeAcquire(RecipeDB, 55996, A.WORLD_DROP, 2)

	-- Red Workman's Shirt -- 55997
	AddRecipe(55997, 400, 41252, R_UNCOMMON, GAME_WOTLK, 400, 400, 405, 410)
	self:addTradeFlags(RecipeDB, 55997, F.ALLIANCE, F.HORDE, F.WORLD_DROP, F.IBOE, F.RBOE)
	self:addTradeAcquire(RecipeDB, 55997, A.WORLD_DROP, 2)

	-- Blue Workman's Shirt -- 55998
	AddRecipe(55998, 400, 41253, R_UNCOMMON, GAME_WOTLK, 400, 400, 405, 410)
	self:addTradeFlags(RecipeDB, 55998, F.ALLIANCE, F.HORDE, F.WORLD_DROP, F.IBOE, F.RBOE)
	self:addTradeAcquire(RecipeDB, 55998, A.WORLD_DROP, 2)

	-- Rustic Workman's Shirt -- 55999
	AddRecipe(55999, 400, 41254, R_UNCOMMON, GAME_WOTLK, 400, 400, 405, 410)
	self:addTradeFlags(RecipeDB, 55999, F.ALLIANCE, F.HORDE, F.WORLD_DROP, F.IBOE, F.RBOE)
	self:addTradeAcquire(RecipeDB, 55999, A.WORLD_DROP, 2)

	-- Green Workman's Shirt -- 56000
	AddRecipe(56000, 400, 41255, R_COMMON, GAME_WOTLK, 400, 400, 405, 410)
	self:addTradeFlags(RecipeDB, 56000, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP)
	self:addTradeAcquire(RecipeDB, 56000, A.TRAINER, 26914, A.TRAINER, 26964, A.TRAINER, 26969, A.TRAINER, 27001, A.TRAINER, 28699, A.TRAINER, 33580)

	-- Moonshroud -- 56001
	AddRecipe(56001, 415, 41594, R_RARE, GAME_WOTLK, 415, 425, 430, 435)
	self:addTradeFlags(RecipeDB, 56001, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP)
	self:addTradeAcquire(RecipeDB, 56001, A.TRAINER, 26914, A.TRAINER, 26964, A.TRAINER, 26969, A.TRAINER, 27001, A.TRAINER, 28699, A.TRAINER, 33580)

	-- Ebonweave -- 56002
	AddRecipe(56002, 415, 41593, R_RARE, GAME_WOTLK, 415, 425, 430, 435)
	self:addTradeFlags(RecipeDB, 56002, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP)
	self:addTradeAcquire(RecipeDB, 56002, A.TRAINER, 26914, A.TRAINER, 26964, A.TRAINER, 26969, A.TRAINER, 27001, A.TRAINER, 28699, A.TRAINER, 33580)

	-- Spellweave -- 56003
	AddRecipe(56003, 415, 41595, R_RARE, GAME_WOTLK, 415, 425, 430, 435)
	self:addTradeFlags(RecipeDB, 56003, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP)
	self:addTradeAcquire(RecipeDB, 56003, A.TRAINER, 26914, A.TRAINER, 26964, A.TRAINER, 26969, A.TRAINER, 27001, A.TRAINER, 28699, A.TRAINER, 33580)

	-- Abyssal Bag -- 56004
	AddRecipe(56004, 435, 41597, R_COMMON, GAME_WOTLK, 435, 440, 445, 450)
	self:addTradeFlags(RecipeDB, 56004, F.ALLIANCE, F.HORDE, F.VENDOR, F.WARLOCK, F.IBOE, F.RBOP, F.EBONBLADE)
	self:addTradeAcquire(RecipeDB, 56004, A.REPUTATION, FAC.EBONBLADE, REP.REVERED, 32538)

	-- Glacial Bag -- 56005
	AddRecipe(56005, 445, 41600, R_COMMON, GAME_WOTLK, 445, 450, 455, 460)
	self:addTradeFlags(RecipeDB, 56005, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOP, F.HODIR)
	self:addTradeAcquire(RecipeDB, 56005, A.REPUTATION, FAC.HODIR, REP.EXALTED, 32540)

	-- Mysterious Bag -- 56006
	AddRecipe(56006, 440, 41598, R_COMMON, GAME_WOTLK, 440, 445, 450, 455)
	self:addTradeFlags(RecipeDB, 56006, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOP, F.WYRMREST)
	self:addTradeAcquire(RecipeDB, 56006, A.REPUTATION, FAC.WYRMREST, REP.REVERED, 32533)

	-- Frostweave Bag -- 56007
	AddRecipe(56007, 410, 41599, R_UNCOMMON, GAME_WOTLK, 410, 430, 440, 450)
	self:addTradeFlags(RecipeDB, 56007, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP)
	self:addTradeAcquire(RecipeDB, 56007, A.TRAINER, 26914, A.TRAINER, 26964, A.TRAINER, 26969, A.TRAINER, 27001, A.TRAINER, 28699, A.TRAINER, 33580)

	-- Shining Spellthread -- 56008
	AddRecipe(56008, 400, 41601, R_RARE, GAME_WOTLK, 400, 400, 405, 410)
	self:addTradeFlags(RecipeDB, 56008, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.HEALER, F.CASTER)
	self:addTradeAcquire(RecipeDB, 56008, A.TRAINER, 26914, A.TRAINER, 26964, A.TRAINER, 26969, A.TRAINER, 27001, A.TRAINER, 28699, A.TRAINER, 33580)

	-- Brilliant Spellthread -- 56009
	AddRecipe(56009, 430, 41602, R_COMMON, GAME_WOTLK, 430, 435, 440, 445)
	self:addTradeFlags(RecipeDB, 56009, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOP, F.HEALER, F.CASTER, F.ARGENTCRUSADE)
	self:addTradeAcquire(RecipeDB, 56009, A.REPUTATION, FAC.ARGENTCRUSADE, REP.EXALTED, 30431)

	-- Azure Spellthread -- 56010
	AddRecipe(56010, 400, 41603, R_RARE, GAME_WOTLK, 400, 400, 405, 410)
	self:addTradeFlags(RecipeDB, 56010, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.HEALER, F.CASTER)
	self:addTradeAcquire(RecipeDB, 56010, A.TRAINER, 26914, A.TRAINER, 26964, A.TRAINER, 26969, A.TRAINER, 27001, A.TRAINER, 28699, A.TRAINER, 33580)

	-- Sapphire Spellthread -- 56011
	AddRecipe(56011, 430, 41604, R_COMMON, GAME_WOTLK, 430, 435, 440, 445)
	self:addTradeFlags(RecipeDB, 56011, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOP, F.HEALER, F.CASTER, F.KIRINTOR)
	self:addTradeAcquire(RecipeDB, 56011, A.REPUTATION, FAC.KIRINTOR, REP.EXALTED, 32287)

	-- Cloak of the Moon -- 56014
	AddRecipe(56014, 390, 41607, R_UNCOMMON, GAME_WOTLK, 390, 395, 400, 405)
	self:addTradeFlags(RecipeDB, 56014, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.HEALER, F.CASTER, F.CLOAK)
	self:addTradeAcquire(RecipeDB, 56014, A.TRAINER, 26914, A.TRAINER, 26964, A.TRAINER, 26969, A.TRAINER, 27001, A.TRAINER, 28699, A.TRAINER, 33580)

	-- Cloak of Frozen Spirits -- 56015
	AddRecipe(56015, 395, 41608, R_COMMON, GAME_WOTLK, 395, 400, 405, 410)
	self:addTradeFlags(RecipeDB, 56015, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.HEALER, F.CASTER, F.CLOAK)
	self:addTradeAcquire(RecipeDB, 56015, A.TRAINER, 26914, A.TRAINER, 26964, A.TRAINER, 26969, A.TRAINER, 27001, A.TRAINER, 28699, A.TRAINER, 33580)

	-- Wispcloak -- 56016
	AddRecipe(56016, 420, 41609, R_COMMON, GAME_WOTLK, 420, 435, 445, 455)
	self:addTradeFlags(RecipeDB, 56016, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.HEALER, F.CASTER, F.CLOAK)
	self:addTradeAcquire(RecipeDB, 56016, A.TRAINER, 26914, A.TRAINER, 26964, A.TRAINER, 26969)

	-- Deathchill Cloak -- 56017
	AddRecipe(56017, 420, 41610, R_COMMON, GAME_WOTLK, 420, 435, 445, 455)
	self:addTradeFlags(RecipeDB, 56017, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.HEALER, F.CASTER, F.CLOAK)
	self:addTradeAcquire(RecipeDB, 56017, A.TRAINER, 26914, A.TRAINER, 26964, A.TRAINER, 26969)

	-- Hat of Wintry Doom -- 56018
	AddRecipe(56018, 425, 41984, R_COMMON, GAME_WOTLK, 425, 435, 440, 445)
	self:addTradeFlags(RecipeDB, 56018, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOE, F.HEALER, F.CASTER, F.CLOTH)
	self:addTradeAcquire(RecipeDB, 56018, A.TRAINER, 26914, A.TRAINER, 26964, A.TRAINER, 26969, A.TRAINER, 27001, A.TRAINER, 28699, A.TRAINER, 33580)

	-- Silky Iceshard Boots -- 56019
	AddRecipe(56019, 420, 41985, R_COMMON, GAME_WOTLK, 420, 430, 440, 450)
	self:addTradeFlags(RecipeDB, 56019, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.HEALER, F.CASTER, F.CLOTH)
	self:addTradeAcquire(RecipeDB, 56019, A.TRAINER, 26914, A.TRAINER, 26964, A.TRAINER, 26969, A.TRAINER, 27001, A.TRAINER, 28699, A.TRAINER, 33580)

	-- Deep Frozen Cord -- 56020
	AddRecipe(56020, 420, 41986, R_COMMON, GAME_WOTLK, 420, 430, 440, 450)
	self:addTradeFlags(RecipeDB, 56020, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.HEALER, F.CASTER, F.CLOTH)
	self:addTradeAcquire(RecipeDB, 56020, A.TRAINER, 26914, A.TRAINER, 26964, A.TRAINER, 26969, A.TRAINER, 27001, A.TRAINER, 28699, A.TRAINER, 33580)

	-- Frostmoon Pants -- 56021
	AddRecipe(56021, 425, 42093, R_COMMON, GAME_WOTLK, 425, 435, 440, 445)
	self:addTradeFlags(RecipeDB, 56021, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.HEALER, F.CASTER, F.CLOTH)
	self:addTradeAcquire(RecipeDB, 56021, A.TRAINER, 26914, A.TRAINER, 26964, A.TRAINER, 26969, A.TRAINER, 27001, A.TRAINER, 28699, A.TRAINER, 33580)

	-- Light Blessed Mittens -- 56022
	AddRecipe(56022, 420, 42095, R_COMMON, GAME_WOTLK, 420, 430, 440, 450)
	self:addTradeFlags(RecipeDB, 56022, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.HEALER, F.CASTER, F.CLOTH)
	self:addTradeAcquire(RecipeDB, 56022, A.TRAINER, 26914, A.TRAINER, 26964, A.TRAINER, 26969, A.TRAINER, 27001, A.TRAINER, 28699, A.TRAINER, 33580)

	-- Aurora Slippers -- 56023
	AddRecipe(56023, 420, 42096, R_COMMON, GAME_WOTLK, 420, 430, 440, 450)
	self:addTradeFlags(RecipeDB, 56023, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.HEALER, F.CASTER, F.CLOTH)
	self:addTradeAcquire(RecipeDB, 56023, A.TRAINER, 26914, A.TRAINER, 26964, A.TRAINER, 26969, A.TRAINER, 27001, A.TRAINER, 28699, A.TRAINER, 33580)

	-- Moonshroud Robe -- 56024
	AddRecipe(56024, 440, 42100, R_EPIC, GAME_WOTLK, 440, 450, 455, 460)
	self:addTradeFlags(RecipeDB, 56024, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.HEALER, F.CASTER, F.CLOTH)
	self:addTradeAcquire(RecipeDB, 56024, A.TRAINER, 26914, A.TRAINER, 26964, A.TRAINER, 26969, A.TRAINER, 27001, A.TRAINER, 28699, A.TRAINER, 33580)

	-- Moonshroud Gloves -- 56025
	AddRecipe(56025, 435, 42103, R_COMMON, GAME_WOTLK, 435, 445, 450, 455)
	self:addTradeFlags(RecipeDB, 56025, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.HEALER, F.CASTER, F.CLOTH)
	self:addTradeAcquire(RecipeDB, 56025, A.TRAINER, 26914, A.TRAINER, 26964, A.TRAINER, 26969, A.TRAINER, 27001, A.TRAINER, 28699, A.TRAINER, 33580)

	-- Ebonweave Robe -- 56026
	AddRecipe(56026, 440, 42101, R_COMMON, GAME_WOTLK, 440, 450, 455, 460)
	self:addTradeFlags(RecipeDB, 56026, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.HEALER, F.CASTER, F.CLOTH)
	self:addTradeAcquire(RecipeDB, 56026, A.TRAINER, 26914, A.TRAINER, 26964, A.TRAINER, 26969, A.TRAINER, 27001, A.TRAINER, 28699, A.TRAINER, 33580)

	-- Ebonweave Gloves -- 56027
	AddRecipe(56027, 435, 42111, R_COMMON, GAME_WOTLK, 435, 445, 450, 455)
	self:addTradeFlags(RecipeDB, 56027, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.HEALER, F.CASTER, F.CLOTH)
	self:addTradeAcquire(RecipeDB, 56027, A.TRAINER, 26914, A.TRAINER, 26964, A.TRAINER, 26969, A.TRAINER, 27001, A.TRAINER, 28699, A.TRAINER, 33580)

	-- Spellweave Robe -- 56028
	AddRecipe(56028, 440, 42102, R_COMMON, GAME_WOTLK, 440, 450, 455, 460)
	self:addTradeFlags(RecipeDB, 56028, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.HEALER, F.CASTER, F.CLOTH)
	self:addTradeAcquire(RecipeDB, 56028, A.TRAINER, 26914, A.TRAINER, 26964, A.TRAINER, 26969, A.TRAINER, 27001, A.TRAINER, 28699, A.TRAINER, 33580)

	-- Spellweave Gloves -- 56029
	AddRecipe(56029, 435, 42113, R_COMMON, GAME_WOTLK, 435, 445, 450, 455)
	self:addTradeFlags(RecipeDB, 56029, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.HEALER, F.CASTER, F.CLOTH)
	self:addTradeAcquire(RecipeDB, 56029, A.TRAINER, 26914, A.TRAINER, 26964, A.TRAINER, 26969, A.TRAINER, 27001, A.TRAINER, 28699, A.TRAINER, 33580)

	-- Frostwoven Leggings -- 56030
	AddRecipe(56030, 380, 41519, R_UNCOMMON, GAME_WOTLK, 380, 390, 400, 410)
	self:addTradeFlags(RecipeDB, 56030, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.HEALER, F.CASTER, F.CLOTH)
	self:addTradeAcquire(RecipeDB, 56030, A.TRAINER, 26914, A.TRAINER, 26964, A.TRAINER, 26969, A.TRAINER, 27001, A.TRAINER, 28699, A.TRAINER, 33580)

	-- Frostwoven Wristwraps -- 56031
	AddRecipe(56031, 350, 41512, R_UNCOMMON, GAME_WOTLK, 350, 360, 370, 380)
	self:addTradeFlags(RecipeDB, 56031, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.HEALER, F.CASTER, F.CLOTH)
	self:addTradeAcquire(RecipeDB, 56031, A.TRAINER, 26914, A.TRAINER, 26964, A.TRAINER, 26969, A.TRAINER, 27001, A.TRAINER, 28699, A.TRAINER, 33580)

	-- Master's Spellthread -- 56034
	AddRecipe(56034, 405, nil, R_COMMON, GAME_WOTLK, 405, 405, 405, 405)
	self:addTradeFlags(RecipeDB, 56034, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.HEALER, F.CASTER)
	self:addTradeAcquire(RecipeDB, 56034, A.TRAINER, 26914, A.TRAINER, 26964, A.TRAINER, 26969, A.TRAINER, 27001, A.TRAINER, 28699, A.TRAINER, 33580)

	-- Sanctified Spellthread -- 56039
	AddRecipe(56039, 405, nil, R_COMMON, GAME_WOTLK, 405, 405, 405, 405)
	self:addTradeFlags(RecipeDB, 56039, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.HEALER, F.CASTER)
	self:addTradeAcquire(RecipeDB, 56039, A.TRAINER, 26914, A.TRAINER, 26964, A.TRAINER, 26969, A.TRAINER, 27001, A.TRAINER, 28699, A.TRAINER, 33580)

	-- Frostsavage Belt -- 59582
	AddRecipe(59582, 415, 43969, R_COMMON, GAME_WOTLK, 415, 425, 435, 445)
	self:addTradeFlags(RecipeDB, 59582, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.HEALER, F.CASTER, F.CLOTH)
	self:addTradeAcquire(RecipeDB, 59582, A.TRAINER, 26914, A.TRAINER, 26964, A.TRAINER, 26969, A.TRAINER, 27001, A.TRAINER, 28699, A.TRAINER, 33580)

	-- Frostsavage Bracers -- 59583
	AddRecipe(59583, 415, 43974, R_COMMON, GAME_WOTLK, 415, 425, 435, 445)
	self:addTradeFlags(RecipeDB, 59583, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.HEALER, F.CASTER, F.CLOTH)
	self:addTradeAcquire(RecipeDB, 59583, A.TRAINER, 26914, A.TRAINER, 26964, A.TRAINER, 26969, A.TRAINER, 27001, A.TRAINER, 28699, A.TRAINER, 33580)

	-- Frostsavage Shoulders -- 59584
	AddRecipe(59584, 420, 43973, R_COMMON, GAME_WOTLK, 420, 430, 440, 450)
	self:addTradeFlags(RecipeDB, 59584, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.HEALER, F.CASTER, F.CLOTH)
	self:addTradeAcquire(RecipeDB, 59584, A.TRAINER, 26914, A.TRAINER, 26964, A.TRAINER, 26969, A.TRAINER, 27001, A.TRAINER, 28699, A.TRAINER, 33580)

	-- Frostsavage Boots -- 59585
	AddRecipe(59585, 420, 43970, R_COMMON, GAME_WOTLK, 420, 430, 440, 450)
	self:addTradeFlags(RecipeDB, 59585, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.HEALER, F.CASTER, F.CLOTH)
	self:addTradeAcquire(RecipeDB, 59585, A.TRAINER, 26914, A.TRAINER, 26964, A.TRAINER, 26969, A.TRAINER, 27001, A.TRAINER, 28699, A.TRAINER, 33580)

	-- Frostsavage Gloves -- 59586
	AddRecipe(59586, 420, 41516, R_UNCOMMON, GAME_WOTLK, 420, 430, 440, 450)
	self:addTradeFlags(RecipeDB, 59586, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.HEALER, F.CASTER, F.CLOTH)
	self:addTradeAcquire(RecipeDB, 59586, A.TRAINER, 26914, A.TRAINER, 26964, A.TRAINER, 26969, A.TRAINER, 27001, A.TRAINER, 28699, A.TRAINER, 33580)

	-- Frostsavage Robe -- 59587
	AddRecipe(59587, 420, 43972, R_COMMON, GAME_WOTLK, 420, 430, 440, 450)
	self:addTradeFlags(RecipeDB, 59587, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.HEALER, F.CASTER, F.CLOTH)
	self:addTradeAcquire(RecipeDB, 59587, A.TRAINER, 26914, A.TRAINER, 26964, A.TRAINER, 26969, A.TRAINER, 27001, A.TRAINER, 28699, A.TRAINER, 33580)

	-- Frostsavage Leggings -- 59588
	AddRecipe(59588, 420, 43975, R_COMMON, GAME_WOTLK, 420, 430, 440, 450)
	self:addTradeFlags(RecipeDB, 59588, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.HEALER, F.CASTER, F.CLOTH)
	self:addTradeAcquire(RecipeDB, 59588, A.TRAINER, 26914, A.TRAINER, 26964, A.TRAINER, 26969, A.TRAINER, 27001, A.TRAINER, 28699, A.TRAINER, 33580)

	-- Frostsavage Cowl -- 59589
	AddRecipe(59589, 420, 43971, R_COMMON, GAME_WOTLK, 420, 430, 440, 450)
	self:addTradeFlags(RecipeDB, 59589, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.HEALER, F.CASTER, F.CLOTH)
	self:addTradeAcquire(RecipeDB, 59589, A.TRAINER, 26914, A.TRAINER, 26964, A.TRAINER, 26969, A.TRAINER, 27001, A.TRAINER, 28699, A.TRAINER, 33580)

	-- Flying Carpet -- 60969
	AddRecipe(60969, 300, 44554, R_RARE, GAME_WOTLK, 300, 340, 345, 350)
	self:addTradeFlags(RecipeDB, 60969, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP)
	self:addTradeAcquire(RecipeDB, 60969, A.TRAINER, 26914, A.TRAINER, 26964, A.TRAINER, 26969, A.TRAINER, 27001, A.TRAINER, 28699, A.TRAINER, 33580)

	-- Magnificent Flying Carpet -- 60971
	AddRecipe(60971, 425, 44558, R_EPIC, GAME_WOTLK, 425, 435, 445, 455)
	self:addTradeFlags(RecipeDB, 60971, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOP, F.RBOP)
	self:addTradeAcquire(RecipeDB, 60971, A.TRAINER, 26914, A.TRAINER, 26964, A.TRAINER, 26969, A.TRAINER, 27001, A.TRAINER, 28699, A.TRAINER, 33580)

	-- Glacial Waistband -- 60990
	AddRecipe(60990, 420, 43584, R_COMMON, GAME_WOTLK, 420, 430, 440, 450)
	self:addTradeFlags(RecipeDB, 60990, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.CLOTH)
	self:addTradeAcquire(RecipeDB, 60990, A.TRAINER, 26914, A.TRAINER, 26964, A.TRAINER, 26969, A.TRAINER, 27001, A.TRAINER, 28699, A.TRAINER, 33580)

	-- Glacial Robe -- 60993
	AddRecipe(60993, 425, 43583, R_EPIC, GAME_WOTLK, 425, 435, 445, 455)
	self:addTradeFlags(RecipeDB, 60993, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.CLOTH)
	self:addTradeAcquire(RecipeDB, 60993, A.TRAINER, 26914, A.TRAINER, 26964, A.TRAINER, 26969, A.TRAINER, 27001, A.TRAINER, 28699, A.TRAINER, 33580)

	-- Glacial Slippers -- 60994
	AddRecipe(60994, 420, 43585, R_COMMON, GAME_WOTLK, 420, 430, 440, 450)
	self:addTradeFlags(RecipeDB, 60994, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.CLOTH)
	self:addTradeAcquire(RecipeDB, 60994, A.TRAINER, 26914, A.TRAINER, 26964, A.TRAINER, 26969, A.TRAINER, 27001, A.TRAINER, 28699, A.TRAINER, 33580)

	-- Sash of Ancient Power -- 63203
	AddRecipe(63203, 450, 45102, R_EPIC, GAME_WOTLK, 450, 455, 460, 465)
	self:addTradeFlags(RecipeDB, 63203, F.ALLIANCE, F.HORDE, F.RAID, F.MOB_DROP, F.IBOE, F.RBOE, F.HEALER, F.CASTER, F.CLOTH)
	self:addTradeAcquire(RecipeDB, 63203, A.CUSTOM, 39)

	-- Spellslinger's Slippers -- 63204
	AddRecipe(63204, 450, 45566, R_EPIC, GAME_WOTLK, 450, 455, 460, 465)
	self:addTradeFlags(RecipeDB, 63204, F.ALLIANCE, F.HORDE, F.RAID, F.MOB_DROP, F.IBOE, F.RBOE, F.HEALER, F.CASTER, F.CLOTH)
	self:addTradeAcquire(RecipeDB, 63204, A.CUSTOM, 39)

	-- Cord of the White Dawn -- 63205
	AddRecipe(63205, 450, 45104, R_EPIC, GAME_WOTLK, 450, 455, 460, 465)
	self:addTradeFlags(RecipeDB, 63205, F.ALLIANCE, F.HORDE, F.RAID, F.MOB_DROP, F.IBOE, F.RBOE, F.HEALER, F.CASTER, F.CLOTH)
	self:addTradeAcquire(RecipeDB, 63205, A.CUSTOM, 39)

	-- Savior's Slippers -- 63206
	AddRecipe(63206, 450, 45567, R_EPIC, GAME_WOTLK, 450, 455, 460, 465)
	self:addTradeFlags(RecipeDB, 63206, F.ALLIANCE, F.HORDE, F.RAID, F.MOB_DROP, F.IBOE, F.RBOE, F.HEALER, F.CASTER, F.CLOTH)
	self:addTradeAcquire(RecipeDB, 63206, A.CUSTOM, 39)

	-- Spidersilk Drape -- 63742
	AddRecipe(63742, 125, 45626, R_COMMON, GAME_WOTLK, 125, 150, 167, 185)
	self:addTradeFlags(RecipeDB, 63742, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.HEALER, F.CASTER, F.CLOAK)
	self:addTradeAcquire(RecipeDB, 63742, A.TRAINER, 26914, A.TRAINER, 26964, A.TRAINER, 26969, A.TRAINER, 27001, A.TRAINER, 28699, A.TRAINER, 1346, A.TRAINER, 4159, A.TRAINER, 16729, A.TRAINER, 3004, A.TRAINER, 3484, A.TRAINER, 3704, A.TRAINER, 2627, A.TRAINER, 33580, A.TRAINER, 3363, A.TRAINER, 1103, A.TRAINER, 33613, A.TRAINER, 33636, A.TRAINER, 11052, A.TRAINER, 18772, A.TRAINER, 2399, A.TRAINER, 4576, A.TRAINER, 17487, A.TRAINER, 16640, A.TRAINER, 16366, A.TRAINER, 5153, A.TRAINER, 4193, A.TRAINER, 3523, A.TRAINER, 33684, A.TRAINER, 11557)

	-- Emerald Bag -- 63924
	AddRecipe(63924, 435, 45773, R_RARE, GAME_WOTLK, 435, 440, 445, 450)
	self:addTradeFlags(RecipeDB, 63924, F.ALLIANCE, F.HORDE, F.VENDOR, F.IBOE, F.RBOP, F.KALUAK)
	self:addTradeAcquire(RecipeDB, 63924, A.REPUTATION, FAC.KALUAK, REP.REVERED, 31916, A.REPUTATION, FAC.KALUAK, REP.REVERED, 32763)

	-- Frostguard Drape -- 64729
	AddRecipe(64729, 400, 45811, R_COMMON, GAME_WOTLK, 400, 405, 410, 415)
	self:addTradeFlags(RecipeDB, 64729, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.DPS, F.CLOAK)
	self:addTradeAcquire(RecipeDB, 64729, A.TRAINER, 26914, A.TRAINER, 26964, A.TRAINER, 26969, A.TRAINER, 27001, A.TRAINER, 28699, A.TRAINER, 33580)

	-- Cloak of Crimson Snow -- 64730
	AddRecipe(64730, 405, 45810, R_COMMON, GAME_WOTLK, 405, 410, 415, 420)
	self:addTradeFlags(RecipeDB, 64730, F.ALLIANCE, F.HORDE, F.TRAINER, F.IBOE, F.RBOP, F.HEALER, F.CASTER, F.CLOAK)
	self:addTradeAcquire(RecipeDB, 64730, A.TRAINER, 26914, A.TRAINER, 26964, A.TRAINER, 26969, A.TRAINER, 27001, A.TRAINER, 28699, A.TRAINER, 33580)

	-- Leggings of Woven Death -- 70550
	AddRecipe(70550, 450, 49891, R_EPIC, GAME_WOTLK, 450, 475, 487, 500)
	self:addTradeFlags(RecipeDB, 70550, F.ALLIANCE, F.HORDE, F.VENDOR, F.ASHEN_VERDICT)
	self:addTradeAcquire(RecipeDB, 70550, A.REPUTATION, FAC.ASHEN_VERDICT, REP.REVERED, 37687)

	-- Deathfrost Boots -- 70551
	AddRecipe(70551, 450, 49890, R_EPIC, GAME_WOTLK, 450, 475, 487, 500)
	self:addTradeFlags(RecipeDB, 70551, F.ALLIANCE, F.HORDE, F.VENDOR, F.ASHEN_VERDICT)
	self:addTradeAcquire(RecipeDB, 70551, A.REPUTATION, FAC.ASHEN_VERDICT, REP.HONORED, 37687)

	-- Lightweave Leggings -- 70552
	AddRecipe(70552, 450, 49892, R_EPIC, GAME_WOTLK, 450, 475, 487, 500)
	self:addTradeFlags(RecipeDB, 70552, F.ALLIANCE, F.HORDE, F.VENDOR, F.ASHEN_VERDICT)
	self:addTradeAcquire(RecipeDB, 70552, A.REPUTATION, FAC.ASHEN_VERDICT, REP.REVERED, 37687)

	-- Sandals of Consecration -- 70553
	AddRecipe(70553, 450, 49893, R_EPIC, GAME_WOTLK, 450, 475, 487, 500)
	self:addTradeFlags(RecipeDB, 70553, F.ALLIANCE, F.HORDE, F.VENDOR, F.ASHEN_VERDICT)
	self:addTradeAcquire(RecipeDB, 70553, A.REPUTATION, FAC.ASHEN_VERDICT, REP.HONORED, 37687)

	-- Some recipes are only availible to specific factions.
	-- We only add the faction specific recipes if the user is part of that faction
	local BFAC = LibStub("LibBabble-Faction-3.0"):GetLookupTable()
	local _,faction = UnitFactionGroup("player")

	if faction == BFAC["Alliance"] then

		-- Royal Moonshroud Robe -- 67064
		AddRecipe(67064, 450, 47605, R_EPIC, GAME_WOTLK, 450, 460, 467, 475)
		self:addTradeFlags(RecipeDB, 67064, F.ALLIANCE, F.RAID, F.MOB_DROP, F.IBOE, F.RBOE, F.HEALER, F.CASTER, F.CLOTH)
		self:addTradeAcquire(RecipeDB, 67064, A.CUSTOM, 42)

		-- Royal Moonshroud Bracers -- 67065
		AddRecipe(67065, 450, 47587, R_EPIC, GAME_WOTLK, 450, 460, 467, 475)
		self:addTradeFlags(RecipeDB, 67065, F.ALLIANCE, F.RAID, F.MOB_DROP, F.IBOE, F.RBOE, F.HEALER, F.CASTER, F.CLOTH)
		self:addTradeAcquire(RecipeDB, 67065,  A.CUSTOM, 42)

		-- Merlin's Robe -- 67066
		AddRecipe(67066, 450, 47603, R_EPIC, GAME_WOTLK, 450, 460, 467, 475)
		self:addTradeFlags(RecipeDB, 67066, F.ALLIANCE, F.RAID, F.MOB_DROP, F.IBOE, F.RBOE, F.HEALER, F.CASTER, F.CLOTH)
		self:addTradeAcquire(RecipeDB, 67066,  A.CUSTOM, 42)

		-- Bejeweled Wizard's Bracers -- 67079
		AddRecipe(67079, 450, 47585, R_EPIC, GAME_WOTLK, 450, 460, 467, 475)
		self:addTradeFlags(RecipeDB, 67079, F.ALLIANCE, F.RAID, F.MOB_DROP, F.IBOE, F.RBOE, F.HEALER, F.CASTER, F.CLOTH)
		self:addTradeAcquire(RecipeDB, 67079,  A.CUSTOM, 42)	

	elseif faction == BFAC["Horde"] then

		-- Royal Moonshroud Robe -- 67144
		AddRecipe(67144, 450, 47606, R_EPIC, GAME_WOTLK, 450, 460, 467, 475)
		self:addTradeFlags(RecipeDB, 67144, F.HORDE, F.RAID, F.MOB_DROP, F.IBOE, F.RBOE, F.HEALER, F.CASTER, F.CLOTH)
		self:addTradeAcquire(RecipeDB, 67144, A.CUSTOM, 42)

		-- Bejeweled Wizard's Bracers -- 67145
		AddRecipe(67145, 450, 47586, R_EPIC, GAME_WOTLK, 450, 460, 467, 475)
		self:addTradeFlags(RecipeDB, 67145, F.HORDE, F.RAID, F.MOB_DROP, F.IBOE, F.RBOE, F.HEALER, F.CASTER, F.CLOTH)
		self:addTradeAcquire(RecipeDB, 67145, A.CUSTOM, 42)

		-- Merlin's Robe -- 67146
		AddRecipe(67146, 450, 47604, R_EPIC, GAME_WOTLK, 450, 460, 467, 475)
		self:addTradeFlags(RecipeDB, 67146, F.HORDE, F.RAID, F.MOB_DROP, F.IBOE, F.RBOE, F.HEALER, F.CASTER, F.CLOTH)
		self:addTradeAcquire(RecipeDB, 67146, A.CUSTOM, 42)

		-- Royal Moonshroud Bracers -- 67147
		AddRecipe(67147, 450, 47588, R_EPIC, GAME_WOTLK, 450, 460, 467, 475)
		self:addTradeFlags(RecipeDB, 67147, F.HORDE, F.RAID, F.MOB_DROP, F.IBOE, F.RBOE, F.HEALER, F.CASTER, F.CLOTH)
		self:addTradeAcquire(RecipeDB, 67147, A.CUSTOM, 42)

	end

	return num_recipes

end
